(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    586639,      11987]*)
(*NotebookOutlinePosition[    587305,      12010]*)
(*  CellTagsIndexPosition[    587261,      12006]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Derivation",
  FontSize->16,
  FontWeight->"Bold"]], "Text"],

Cell["\<\
This notebook contains all the information about the derivation of the \
routines in the SMath.m package.  It is designed so it can be copied from the \
documentation folder and used separately elsewhere.  I recommend that you \
evaluate this notebook on a line by line basis.  Some items from the \
sections: Stable Characteristic Function and Stable Density Function are \
needed in later sections so they must be evaluated first.  Some routines take \
a long time; the table that is created in the Interpolation section may take \
eight to ten minutes on a fast computer.

Load the package.\
\>", "Text"],

Cell["\<\
<<StableDistribution`SMath`
Off[General::spell1];
Off[General::\"spell\"];\
\>", "Input",
  FontFamily->"Courier New"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Stable Characteristic Function",
    FontWeight->"Bold"],
  " (CF).  \nI have included for convenience the characteristic functions \
when \[Alpha] \[NotEqual] 1.  Everything else used can be derived from them.  \
The 0-paramterization (CF0) is continuous in all parameters and is useful for \
resolving problems near \[Alpha] = 1.  The 1-parameterizaton (CF1) is \
mathematically simpler and sometimes can be used for simpler expressions.  It \
has the convenient property that \[Delta] is the mean when \[Alpha] > 1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CF0[
      u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]\), "\[IndentingNewLine]", 
    \(CF1[u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \[Gamma]\^\[Alpha]\ \
Abs[u]\^\[Alpha] - \[ImaginaryI]\ u\ \[Beta]\ \[Gamma]\ Tan[\(\[Pi]\ \[Alpha]\
\)\/2] + \[ImaginaryI]\ \[Beta]\ \[Gamma]\^\[Alpha]\ Abs[u]\^\[Alpha]\ \
Sign[u]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\)\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \[Gamma]\^\[Alpha]\ \
Abs[u]\^\[Alpha]\ \((1 - \[ImaginaryI]\ \[Beta]\ Sign[u]\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2])\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
When \[Alpha] = 2 or \[Beta] = 0 they are the same.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CF0[u, {2, \[Beta], \[Gamma], \[Delta]}]\), "\[IndentingNewLine]", 
    \(CF1[u, {2, \[Beta], \[Gamma], \[Delta]}]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \[Gamma]\^2\ \
Abs[u]\^2\)\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \[Gamma]\^2\ \
Abs[u]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CF0[u, {\[Alpha], 0, \[Gamma], \[Delta]}]\), "\[IndentingNewLine]", 
    \(CF1[u, {\[Alpha], 0, \[Gamma], \[Delta]}]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \[Gamma]\^\[Alpha]\ \
Abs[u]\^\[Alpha]\)\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \[Gamma]\^\[Alpha]\ \
Abs[u]\^\[Alpha]\)\)], "Output"]
}, Open  ]],

Cell["\<\
CF0 can be used to derive the CF when \[Alpha] = 1, but CF1 cannot.  CF1 \
however uses the CF0 formula at \[Alpha] = 1 with a different definition for \
\[Delta].  To find the limit one has to work around the Abs[] function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Limit[
      CF0[u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}], \ \[Alpha] \[Rule] \ 
        1, Assumptions \[Rule] \ \ u > \ 0]\), "\[IndentingNewLine]", 
    \(Limit[
      CF0[u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}], \ \[Alpha] \[Rule] \ 
        1, Assumptions \[Rule] \ \ u < \ 0]\), "\[IndentingNewLine]", 
    \(Limit[
      CF1[u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}], \ \[Alpha] \[Rule] \ 
        1, Assumptions \[Rule] \ \ u > 0]\), "\[IndentingNewLine]", 
    \(Limit[
      CF1[u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}], \ \[Alpha] \[Rule] \ 
        1, Assumptions \[Rule] \ \ u < 0]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-u\)\ \((\[Gamma] - \[ImaginaryI]\ \[Delta])\)\)\ \
\((u\ \[Gamma])\)\^\(-\(\(2\ \[ImaginaryI]\ u\ \[Beta]\ \[Gamma]\)\/\[Pi]\)\)\
\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(u\ \((\[Gamma] + \[ImaginaryI]\ \[Delta])\)\)\ \
\((\(-u\)\ \[Gamma])\)\^\(-\(\(2\ \[ImaginaryI]\ u\ \[Beta]\ \
\[Gamma]\)\/\[Pi]\)\)\)], "Output"],

Cell[BoxData[
    \(Limit[\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \
\[Gamma]\^\[Alpha]\ Abs[u]\^\[Alpha]\ \((1 - \[ImaginaryI]\ \[Beta]\ Sign[u]\ \
Tan[\(\[Pi]\ \[Alpha]\)\/2])\)\), \[Alpha] \[Rule] 1, 
      Assumptions \[Rule] u > 0]\)], "Output"],

Cell[BoxData[
    \(Limit[\[ExponentialE]\^\(\[ImaginaryI]\ u\ \[Delta] - \
\[Gamma]\^\[Alpha]\ Abs[u]\^\[Alpha]\ \((1 - \[ImaginaryI]\ \[Beta]\ Sign[u]\ \
Tan[\(\[Pi]\ \[Alpha]\)\/2])\)\), \[Alpha] \[Rule] 1, 
      Assumptions \[Rule] u < 0]\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Stable Density Function",
    FontWeight->"Bold"],
  " (PDF)\nThe PDF can be obtained by the inverse Fourier transform of the \
CF, ",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                CF\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ u\ x\)\)\/\(\(\ \)\
\((2\ \[Pi])\)\)\) \[DifferentialD]u\)]],
  ".  Since this can't be integrated we will use numerical integration.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can handle the complex expression directly, but it will often produce \
complex results when the actual results should be real."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({\[Alpha], \ \[Beta], \ \[Gamma], \[Delta]}\  = \ {1.2, 0.5, 1, 
          0.5};\)\), "\[IndentingNewLine]", 
    \(\(Plot[
        Re[NIntegrate[
            Exp[\(-I\)\ u\ x]\ CF0[
                  u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]/\((2\ Pi)\), \
{u, \(-Infinity\), \ Infinity}]], {x, \(-5\), 
          5}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[
        Re[NIntegrate[
            Exp[\(-I\)\ u\ x]\ CF1[
                  u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]/\((2\ Pi)\), \
{u, \(-Infinity\), \ Infinity}]], {x, \(-5\), 
          5}];\)\), "\[IndentingNewLine]", 
    \(\(Clear[\[Alpha], \ \[Beta], \ \[Gamma], \[Delta]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 2.00781 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .11511 -24 -4.5 ]
[.4875 .11511 0 4.5 ]
[.4875 .2155 -18 -4.5 ]
[.4875 .2155 0 4.5 ]
[.4875 .31589 -24 -4.5 ]
[.4875 .31589 0 4.5 ]
[.4875 .41628 -18 -4.5 ]
[.4875 .41628 0 4.5 ]
[.4875 .51667 -24 -4.5 ]
[.4875 .51667 0 4.5 ]
[.4875 .61706 -18 -4.5 ]
[.4875 .61706 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .11511 m
.50625 .11511 L
s
[(0.05)] .4875 .11511 1 0 Mshowa
.5 .2155 m
.50625 .2155 L
s
[(0.1)] .4875 .2155 1 0 Mshowa
.5 .31589 m
.50625 .31589 L
s
[(0.15)] .4875 .31589 1 0 Mshowa
.5 .41628 m
.50625 .41628 L
s
[(0.2)] .4875 .41628 1 0 Mshowa
.5 .51667 m
.50625 .51667 L
s
[(0.25)] .4875 .51667 1 0 Mshowa
.5 .61706 m
.50625 .61706 L
s
[(0.3)] .4875 .61706 1 0 Mshowa
.125 Mabswid
.5 .03479 m
.50375 .03479 L
s
.5 .05487 m
.50375 .05487 L
s
.5 .07495 m
.50375 .07495 L
s
.5 .09503 m
.50375 .09503 L
s
.5 .13518 m
.50375 .13518 L
s
.5 .15526 m
.50375 .15526 L
s
.5 .17534 m
.50375 .17534 L
s
.5 .19542 m
.50375 .19542 L
s
.5 .23557 m
.50375 .23557 L
s
.5 .25565 m
.50375 .25565 L
s
.5 .27573 m
.50375 .27573 L
s
.5 .29581 m
.50375 .29581 L
s
.5 .33596 m
.50375 .33596 L
s
.5 .35604 m
.50375 .35604 L
s
.5 .37612 m
.50375 .37612 L
s
.5 .3962 m
.50375 .3962 L
s
.5 .43636 m
.50375 .43636 L
s
.5 .45643 m
.50375 .45643 L
s
.5 .47651 m
.50375 .47651 L
s
.5 .49659 m
.50375 .49659 L
s
.5 .53675 m
.50375 .53675 L
s
.5 .55682 m
.50375 .55682 L
s
.5 .5769 m
.50375 .5769 L
s
.5 .59698 m
.50375 .59698 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02259 m
.06244 .02413 L
.10458 .02639 L
.14415 .02933 L
.18221 .03333 L
.20178 .03605 L
.22272 .03968 L
.24402 .04441 L
.26416 .05021 L
.28414 .05779 L
.30258 .0671 L
.3213 .07982 L
.33207 .08919 L
.34193 .09944 L
.36134 .1257 L
.37204 .14451 L
.38221 .16584 L
.40202 .21834 L
.42041 .28053 L
.45954 .43942 L
.47951 .51484 L
.49002 .5473 L
.49576 .56222 L
.50112 .57418 L
.50632 .58387 L
.51107 .59101 L
.51634 .59702 L
.51924 .59947 L
.52199 .60123 L
.5243 .6023 L
.52547 .60269 L
.52676 .60302 L
.52786 .6032 L
.52904 .60331 L
.53016 .60332 L
.53118 .60326 L
.53239 .60309 L
.53351 .60286 L
.53474 .6025 L
.53606 .60201 L
.53874 .60067 L
.54119 .59907 L
.54603 .59485 L
.55117 .58895 L
.56037 .57513 L
.58117 .532 L
.61906 .43335 L
.6594 .33156 L
.69822 .25238 L
.7395 .18987 L
Mistroke
.77926 .14676 L
.8175 .11689 L
.8582 .09389 L
.89738 .07773 L
.93902 .06503 L
.97619 .05645 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00@P3oool01@3ogi`0B000000000000000M;oo04@0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`2:0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0A@3oool0
1@3ogi`0B000000000000000M;oo03d0oooo00140?ooo`030;md001d_ol0oooo04D0oooo00<0_g@0
0000M02oool00P3oool00`3OW7@0W=oo0?ooo`2<0?ooo`030;md000007@0_ooo0080oooo00<0giad
09cOo`3oool0B03oool00`2oM000M;oo0?ooo`0m0?ooo`00A03oool00`2oM000M;oo0?ooo`160?oo
o`030?noM00004P0W=oo0940oooo00<0okmd0000B02Lgol0C03oool00`2oM000M;oo0?ooo`0m0?oo
o`00@03oool00`3OW4P00000000000030000000307Boo`3oool0oooo04D0oooo00<0omnL04P00018
W=l0T@3oool00`3ogi`0B00004RLg`170?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3o
ool0>`3oool003L0oooo00<0W4P00000000000000`0000002@00B9`0oooo0?ooo`3o_g@0001d0;oo
o`3oool0_g@007Boo`0m0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0103oool0
0`2LB000B9cO0?ooo`2A0?ooo`0309a80018W=l0oooo04D0oooo00H0okmd0000M02oool0oooo0;md
001d_oln0?ooo`00@@3oool01@3OW4P007Bo0?ooo`2oM000M;oo04/0oooo00<0W4Qd0;ooo`3oool0
T@3oool00`2LB7@0_ooo0?ooo`150?ooo`050=nLB000M;l0oooo0;md001d_ol0?P3oool00480oooo
00@0W4P004RLg`2oM000M;ooAP3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo08`0
oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`160?ooo`0409a80018W=l0_g@007Bo
och0oooo00120?ooo`040?oOW01804P0B4P007BoodH0oooo00L0okmd0000M02oool0oooo0?noM000
04P0W=oo08d0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo04L0oooo00@0omnL04P0B018
B000M;oo?P3oool004<0oooo00<0okmd0000001d_ol0A`3oool01@3o_g@000000000000004P0W=oo
08l0oooo00D0okmd000000000000001809cOo`190?ooo`030?noM0000000M;oo03h0oooo003o0?oo
ok40oooo003o0?oook40oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo
000?0?ooool00000TP00000@0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo000I0?ooo`P000007P3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo03h0oooo000Q0?oooa000000YP3oool00`000000oooo
0?ooo`3F0?ooo`00<@3oool@000009H0oooo00<000000?ooo`3oool0eP3oool00440oooo3000002:
0?ooo`030000003oool0oooo0=H0oooo001=0?ooo`P00000PP3oool00`000000oooo0?ooo`3F0?oo
o`00E@3oool7000007/0oooo0`00003F0?ooo`00G03oool8000007<0oooo00<000000?ooo`3oool0
eP3oool006@0oooo1`00001/0?ooo`030000003oool0oooo0=H0oooo001[0?ooo`@00000J03oool0
0`000000oooo0?ooo`3F0?ooo`00K`3oool4000006@0oooo00<000000?ooo`3oool0eP3oool007<0
oooo1000001P0?ooo`030000003oool0oooo0=H0oooo001g0?ooo`@00000G03oool00`000000oooo
0?ooo`3F0?ooo`00N`3oool2000005X0oooo00<000000?ooo`3oool0eP3oool007d0oooo0`00001G
0?ooo`<00000eP3oool00800oooo0P00001E0?ooo`030000003oool0oooo0;T0oooo0`00000J0?oo
o`00PP3oool2000005<0oooo00<000000?ooo`3oool0]03oool5000001d0oooo00240?ooo`800000
D@3oool00`000000oooo0?ooo`2_0?ooo`D000008P3oool008H0oooo0P00001?0?ooo`030000003o
ool0oooo0:/0oooo1000000W0?ooo`00R03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0:P0oooo0`00000[0?ooo`00R@3oool2000004`0oooo00<000000?ooo`3oool0Y@3oool30000
02h0oooo002;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0X@3oool400000340
oooo002<0?ooo`800000B@3oool3000009h0oooo0`00000e0?ooo`00SP3oool2000004L0oooo00<0
00000?ooo`3oool0V`3oool3000003P0oooo002@0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0V@3oool2000003/0oooo002A0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0U`3oool2000003d0oooo002B0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0U@3oool2000003l0oooo002C0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
TP3oool300000440oooo002D0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0T03o
ool2000004@0oooo002E0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0SP3oool2
000004H0oooo002F0?ooo`030000003oool0oooo03h0oooo0`00002<0?ooo`800000B03oool009L0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2:0?ooo`800000BP3oool009P0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`280?ooo`800000C03oool009T0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`260?ooo`800000CP3oool009X0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo04h0oooo002J0?oo
o`030000003oool0oooo01<0oooo00D0okmd000000000000000007Boo`050?ooo`030;md00000000
07Bo00D0oooo00D0okmd000000000000000007Boo`040?ooo`050;md0000000000000000001d_ol0
1`3oool00`000000oooo0?ooo`230?ooo`800000D@3oool009/0oooo00<000000?ooo`3oool04P3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01@3oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;ooo`80oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00H0oooo
00<000000?ooo`3oool0P@3oool2000005<0oooo002L0?ooo`030000003oool0oooo0100oooo00<0
okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00<0
gia804RLg`3oool01P3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0oooo07l0oooo0P00
001E0?ooo`00W@3oool00`000000oooo0?ooo`0?0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00<0okmd
001d_`3oool01@3oool3000007d0oooo0P00001G0?ooo`00WP3oool00`000000oooo0?ooo`0>0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00H0oooo00<0W4P007Boo`3oool01@3oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo05L0oooo002N0?ooo`030000003oool0oooo00h0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3o
ool0oooo0?oo_`1d00030000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`1H0?ooo`00W`3oool00`000000oooo0?ooo`0=0?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`070=nLB018W=l0oooo
0?ooo`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo07T0oooo0P00001K0?ooo`00X03oool0
0`000000oooo0?ooo`0=0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo`80oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo05/0oooo002P0?ooo`030000003oool0oooo00d0oooo00D0oono07@00000
0000001809cOo`0=0?ooo`050?oo_`1d000000000000B02Lgol00`3oool00`3ookl0M00000000002
000000030000M02oool0oooo00D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1L
0?ooo`00X@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0G@3oool00:40oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1d0?ooo`80
0000H03oool00:80oooo00<000000?ooo`3oool0<P3oool3000007<0oooo00<000000?ooo`3oool0
H03oool00:80oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo0640oooo002S0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`1R0?ooo`00X`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
06l0oooo0P00001U0?ooo`00Y03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0I@3oool00:@0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo06H0oooo002U0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`1W0?ooo`00Y@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J03oool00:H0oooo00<000000?oo
o`3oool0;P3oool3000006X0oooo00<000000?ooo`3oool0J@3oool00:H0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06X0oooo002W0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1[0?ooo`00Y`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0K03o
ool00:P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06d0oooo002X0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`1^0?ooo`00Z@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0KP3oool00:T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo06l0oooo002Z0?ooo`030000003oool0oooo02X0oooo0`00
001S0?ooo`030000003oool0oooo0700oooo002Z0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`1a0?ooo`00ZP3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0LP3oool00:/0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo07<0oooo002[0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1d0?ooo`00Z`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0M@3o
ool00:`0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo07H0oooo002/0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`1g0?ooo`00[@3oool00`000000oooo0?ooo`0W0?ooo`<00000G03oool00`000000
oooo0?ooo`1g0?ooo`00[@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0N03oool00:d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo07T0oooo002^0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`1i0?ooo`00[P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0NP3oool00:h0oooo00<000000?ooo`3o
ool0203oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o
_g@000000000000300000003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`1k0?ooo`00[`3oool00`000000oooo0?ooo`070?ooo`0609a8M02oool0oooo0?oo
_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00L0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1k0?ooo`00[`3oool00`000000oooo0?ooo`060?oo
o`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`070?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0O03oool00;00oooo00<000000?ooo`3o
ool01@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3o
ool01`3oool3000005H0oooo00<000000?ooo`3oool0O@3oool00;00oooo00<000000?ooo`3oool0
1@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool0
1`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo07d0oooo002`0?ooo`030000003o
ool0oooo00D0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02L
gol0oooo00L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1n0?ooo`00/@3oool0
0`000000oooo0?ooo`040?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03@3oool0
0`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0O`3oool0
0;40oooo00<000000?ooo`3oool01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0
gia800000000B9`0W4Q809cOo`080?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
P03oool00;40oooo00<000000?ooo`3oool01@3oool01@3ookl0M0000000000004P0W=oo00h0oooo
00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0800oooo
002a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`210?ooo`00/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0PP3oool00;80oooo00<000000?ooo`3oool08P3oool300000540oooo00<000000?oo
o`3oool0PP3oool00;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo08<0oooo002c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`240?ooo`00/`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0Q03oool00;<0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo08D0oooo002c0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`260?ooo`00]03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0QP3oool00;@0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo08L0oooo
002d0?ooo`030000003oool0oooo0200oooo0`00001<0?ooo`030000003oool0oooo08L0oooo002d
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`28
0?ooo`00]@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0R03oool00;D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo08T0oooo002e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`290?ooo`00]P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0RP3oool00;H0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo08X0oooo002f0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2;0?ooo`00]P3oool00`000000
oooo0?ooo`0N0?ooo`<00000B03oool00`000000oooo0?ooo`2;0?ooo`00]`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0S03oool00;L0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo08`0oooo002g
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2=
0?ooo`00]`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0S@3oool00;P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo08h0oooo002h0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`2>0?ooo`00^03oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0S`3oool00;P0oooo00<000000?ooo`3oool0703oool3
000004@0oooo00<000000?ooo`3oool0S`3oool00;T0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo08l0oooo002i0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2@0?ooo`00^@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0T03oool00;T0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0940oooo002`
0?ooo`050?noM000000000000000001d_ol01@3oool200000003001d_`3oool0oooo0080oooo00<0
okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?ooo`3oool0
1@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0940oooo002`0?ooo`0609a8M02o
ool0oooo0?oo_`1d07@0_ooo103oool200000003001d_`3oool0oooo00D0oooo00<0W4Q809cOo`3o
ool00`3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0980oooo002_0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RL
g`3oool00`3oool00`000000oooo0?ooo`070?ooo`0309a8B02Lgol0oooo00P0oooo00<0okmd001d
_`3oool01@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0980oooo002_0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
09a8B02Lgol0oooo00P0oooo00<0okmd001d_`3oool01@3oool300000400oooo00<000000?ooo`3o
ool0T`3oool00:l0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<0W4Q809cOo`3oool0203oool00`2LB000M;oo0?ooo`050?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0T`3oool00:l0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0W4Q809cOo`3oool00`3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2D0?ooo`00[`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0
_ooo00X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2D0?ooo`00/03oool01P2L
B000M;oo0?ooo`3ogi`0B01d0;ooo`D0oooo00<000000?ooo`3oool00`3oool01@3OW4P000000018
W02LB4P0W=oo00@0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo09D0oooo002`0?ooo`050?oo_`1d000000000000B02Lgol01`3oool00`000000oooo
0?ooo`040?ooo`030=nLB00004P0W=oo00@0oooo00<0oono07@0000000000P0000000`0007@0_ooo
0?ooo`050?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0U@3oool00;`0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo09H0oooo002l
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2F
0?ooo`00_03oool00`000000oooo0?ooo`0H0?ooo`<00000?@3oool00`000000oooo0?ooo`2F0?oo
o`00_@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0U`3oool00;d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo09L0oooo002m0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`2H0?ooo`00_@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0V03oool00;h0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo09P0oooo002n0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2I0?ooo`00_P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0V@3oool00;h0oooo00<0
00000?ooo`3oool05P3oool3000003T0oooo00<000000?ooo`3oool0VP3oool00;l0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09X0oooo002o0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2J0?oo
o`00_`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0V`3oool00;l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo09/0oooo00300?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2L0?ooo`00`03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0W03oool00<00oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo09`0oooo00300?ooo`030000003oool0oooo01@0
oooo0`00000f0?ooo`030000003oool0oooo09d0oooo00310?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2M0?ooo`00`@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0WP3oool00<40oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo09h0oooo00310?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2N0?oo
o`00`P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0W`3oool00<80oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo09l0oooo00320?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`2P0?ooo`00`P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0X03oool00<<0oooo00<000000?ooo`3oool04@3oool30000
03<0oooo00<000000?ooo`3oool0X03oool00<<0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo0:40oooo00330?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2Q0?ooo`00``3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0XP3oool00;T0oooo00D0okmd
000000000000000007Boo`050?ooo`030;md0000000007Bo00<0oooo00<0oono07@0000000001000
00000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0XP3o
ool00;T0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo
00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`050?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0XP3oool00;P0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<0okmd0000B02Lgol02@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0:<0oooo002h0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool0103oool00`000000oooo0?ooo`050?ooo`030?oOW0180000B9cO00P0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`2S0?ooo`00^03oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool01P3oool00`2LB000B9cO0?ooo`060?oo
o`<00000;`3oool00`000000oooo0?ooo`2T0?ooo`00^03oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo00D0oooo00<000000?ooo`3oool01`3oool00`2LB7@0_ooo0?ooo`050?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0Y03oool00;P0oooo00<0okmd04RLg`3oool0
0P3oool00`3OW4P0B9cO0?ooo`050?ooo`030000003oool0oooo0080oooo00<0gia807Boo`3oool0
0P3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
Y03oool00;T0oooo00H0W4P007Boo`3oool0omnL04P0M02oool60?ooo`030000003oool0oooo0080
oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2U0?ooo`00^@3oool01@3ookl0M0000000000004P0W=oo00P0oooo00<00000
0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2U0?ooo`00aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0YP3oool00<H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0:H0oooo00360?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2V0?ooo`00a`3oool00`000000oooo
0?ooo`0=0?ooo`<00000;03oool00`000000oooo0?ooo`2W0?ooo`00a`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0Y`3oool00<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0:P0oooo00380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2X0?oo
o`00b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0Z03oool00<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0:T0oooo00380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`2Y0?ooo`00b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0ZP3oool00<T0oooo00<000000?ooo`3oool02`3oool30000
02T0oooo00<000000?ooo`3oool0ZP3oool00<T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0:X0oooo00390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2[0?ooo`00bP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0Z`3oool00<X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0:`0oooo003:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2/0?oo
o`00bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0[03oool00</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0:d0oooo003;0?ooo`030000003oool0oooo00T0oooo0`00000V0?ooo`030000003o
ool0oooo0:d0oooo003;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`2^0?ooo`00c03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0[P3oool00<`0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0:h0oooo003<0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2_0?ooo`00c03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0[`3oool00<d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0;00oooo003=0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2`0?oo
o`00c@3oool00`000000oooo0?ooo`070?ooo`<000008`3oool00`000000oooo0?ooo`2`0?ooo`00
c@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
/@3oool00<h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0;40oooo003>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2b0?ooo`00/03oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@0
00000000M;l00`3oool00`3ookl0M000000000040000000507Boo`3oool0oooo0?ooo`2oM0000`00
00000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0/P3o
ool00;00oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo
00<0_g@00000M02oool00P3oool01P3OW7@0W=oo0?ooo`3oool0_g@0001d_`80oooo00<0000004P0
001d_ol01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;80oooo002_0?ooo`03
0?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0001809cOo`0:0?ooo`03
00000000M;l0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2c0?ooo`00
[`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P00018W=l0
2@3oool00`00000007Bo0?ooo`050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
/`3oool00:l0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018
W=l0oooo00L0oooo00<0000007Boo`3oool01@3oool3000001l0oooo00<000000?ooo`3oool0]03o
ool00:l0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0609a8M02oool0
oooo0?ooo`3ookl0M0000`0000000`18W=l000000?ooo`050?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0]03oool00:l0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?oo
o`0:0?ooo`030=nLB01d_ol0oooo0080oooo00L0_g@007Boo`3oool0oooo0?oo_`1d07@0_ooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;@0
oooo002`0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0
okmd0000B02Lgol00P3oool00`3ookl0M01d0;ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`2e0?ooo`00/03oool01@3ookl0M00000000000
04P0W=oo00d0oooo00D0okmd000000000000001809cOo`030?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`0000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;D0oooo
003A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`2f0?ooo`00d@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0]P3oool00=40oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0;H0oooo003B0?ooo`030000003oool0oooo0080oooo0`00000L0?ooo`03
0000003oool0oooo0;L0oooo003B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2g0?ooo`00dP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0^03oool00=<0oooo00D000000?ooo`3oool0oooo0000
000M0?ooo`030000003oool0oooo0;P0oooo003C0?ooo`050000003oool0oooo0?ooo`000000703o
ool00`000000oooo0?ooo`2i0?ooo`00d`3oool01@000000oooo0?ooo`3oool0000001`0oooo00<0
00000?ooo`3oool0^@3oool00=@0oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?oo
o`2j0?ooo`00e03oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo0;X0oooo003D
0?ooo`030000003oool0oooo00<00000603oool00`000000oooo0?ooo`2k0?ooo`00e@3oool00`00
0000oooo0000000J0?ooo`030000003oool0oooo0;/0oooo003E0?ooo`030000003oool0000001T0
oooo00<000000?ooo`3oool0_03oool00=D0oooo00<000000?ooo`0000006@3oool00`000000oooo
0?ooo`2l0?ooo`00eP3oool2000001P0oooo00<000000?ooo`3oool0_@3oool00=H0oooo0P00000H
0?ooo`030000003oool0oooo0;d0oooo003G0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0_P3oool00=L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2n0?ooo`00
e`3oool3000001@0oooo00<000000?ooo`3oool0_`3oool00=L0oooo00<000000?ooo`000000503o
ool00`000000oooo0?ooo`2o0?ooo`00e`3oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo0<00oooo003G0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0`@3o
ool00=L0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0<40oooo003G
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`320?ooo`00e`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0``3oool0
0=L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0<@0oooo003G0?ooo`<00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0<D0
oooo003G0?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`800000b03oool00=L0oooo00<0
00000?ooo`3oool01`3oool500000<X0oooo003G0?ooo`030000003oool0oooo0=H0oooo002i0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md00000000
000000000018W=l01`3oool00`000000oooo0?ooo`3F0?ooo`00^@3oool01P2LB7@0_ooo0?ooo`3o
okl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0oono07@0
0018W=l01P3oool00`000000oooo0?ooo`3F0?ooo`00^03oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo00l0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00
^03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00h0oooo00<0omnL04P0B02Lgol0
1P3oool00`000000oooo0?ooo`3F0?ooo`00^03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00`0oooo00@0gia80000000004P0W=oo1`3oool300000=H0oooo002h0?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B01809cOo`3O0?ooo`00^03oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0_g@007Boo`3oool0gP3oool0
0;T0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00004P0W=oo0?ooo`3ogi`0
B01809cOo`3O0?ooo`00^@3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0omnL04P00000
0000000007Boo`3P0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.66409, -0.0230556, \
0.0394252, 0.00187009}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 2.0078 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .11511 -24 -4.5 ]
[.4875 .11511 0 4.5 ]
[.4875 .2155 -18 -4.5 ]
[.4875 .2155 0 4.5 ]
[.4875 .31589 -24 -4.5 ]
[.4875 .31589 0 4.5 ]
[.4875 .41628 -18 -4.5 ]
[.4875 .41628 0 4.5 ]
[.4875 .51667 -24 -4.5 ]
[.4875 .51667 0 4.5 ]
[.4875 .61706 -18 -4.5 ]
[.4875 .61706 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .11511 m
.50625 .11511 L
s
[(0.05)] .4875 .11511 1 0 Mshowa
.5 .2155 m
.50625 .2155 L
s
[(0.1)] .4875 .2155 1 0 Mshowa
.5 .31589 m
.50625 .31589 L
s
[(0.15)] .4875 .31589 1 0 Mshowa
.5 .41628 m
.50625 .41628 L
s
[(0.2)] .4875 .41628 1 0 Mshowa
.5 .51667 m
.50625 .51667 L
s
[(0.25)] .4875 .51667 1 0 Mshowa
.5 .61706 m
.50625 .61706 L
s
[(0.3)] .4875 .61706 1 0 Mshowa
.125 Mabswid
.5 .03479 m
.50375 .03479 L
s
.5 .05487 m
.50375 .05487 L
s
.5 .07495 m
.50375 .07495 L
s
.5 .09503 m
.50375 .09503 L
s
.5 .13518 m
.50375 .13518 L
s
.5 .15526 m
.50375 .15526 L
s
.5 .17534 m
.50375 .17534 L
s
.5 .19542 m
.50375 .19542 L
s
.5 .23557 m
.50375 .23557 L
s
.5 .25565 m
.50375 .25565 L
s
.5 .27573 m
.50375 .27573 L
s
.5 .29581 m
.50375 .29581 L
s
.5 .33596 m
.50375 .33596 L
s
.5 .35604 m
.50375 .35604 L
s
.5 .37612 m
.50375 .37612 L
s
.5 .3962 m
.50375 .3962 L
s
.5 .43635 m
.50375 .43635 L
s
.5 .45643 m
.50375 .45643 L
s
.5 .47651 m
.50375 .47651 L
s
.5 .49659 m
.50375 .49659 L
s
.5 .53674 m
.50375 .53674 L
s
.5 .55682 m
.50375 .55682 L
s
.5 .5769 m
.50375 .5769 L
s
.5 .59698 m
.50375 .59698 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03192 m
.04262 .03424 L
.06244 .03721 L
.08255 .04098 L
.10458 .04629 L
.12415 .05246 L
.14509 .06127 L
.16639 .07366 L
.18653 .09016 L
.20651 .1134 L
.22495 .14348 L
.24367 .18527 L
.2643 .24667 L
.30459 .40469 L
.32312 .47948 L
.34336 .547 L
.34866 .56091 L
.35432 .57367 L
.35921 .58292 L
.36449 .59098 L
.36732 .59446 L
.36992 .59715 L
.37235 .59922 L
.37503 .60101 L
.37619 .60162 L
.37743 .60217 L
.37851 .60256 L
.37967 .60289 L
.38099 .60315 L
.38224 .60329 L
.38346 .60332 L
.38458 .60326 L
.38576 .6031 L
.387 .60284 L
.38806 .60254 L
.38922 .60212 L
.3918 .60089 L
.39421 .59937 L
.39858 .59573 L
.40325 .59065 L
.41404 .57474 L
.42385 .55604 L
.46383 .45662 L
.5023 .35655 L
.54322 .26784 L
.58262 .2036 L
.62051 .15848 L
.66085 .12388 L
.69967 .09989 L
.74095 .08136 L
Mistroke
.78071 .06824 L
.81895 .0587 L
.85965 .05092 L
.89883 .04511 L
.94047 .04027 L
.97619 .03693 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00@P3oool01@3ogi`0B000000000000000M;oo04@0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`2:0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0A@3oool0
1@3ogi`0B000000000000000M;oo03d0oooo00140?ooo`030;md001d_ol0oooo04D0oooo00<0_g@0
0000M02oool00P3oool00`3OW7@0W=oo0?ooo`2<0?ooo`030;md000007@0_ooo0080oooo00<0giad
09cOo`3oool0B03oool00`2oM000M;oo0?ooo`0m0?ooo`00A03oool00`2oM000M;oo0?ooo`160?oo
o`030?noM00004P0W=oo0940oooo00<0okmd0000B02Lgol0C03oool00`2oM000M;oo0?ooo`0m0?oo
o`00@03oool00`3OW4P00000000000030000000307Boo`3oool0oooo04D0oooo00<0omnL04P00018
W=l0T@3oool00`3ogi`0B00004RLg`170?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3o
ool0>`3oool003L0oooo00<0W4P00000000000000`0000002@00B9`0oooo0?ooo`3o_g@0001d0;oo
o`3oool0_g@007Boo`0m0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0103oool0
0`2LB000B9cO0?ooo`2A0?ooo`0309a80018W=l0oooo04D0oooo00H0okmd0000M02oool0oooo0;md
001d_oln0?ooo`00@@3oool01@3OW4P007Bo0?ooo`2oM000M;oo04/0oooo00<0W4Qd0;ooo`3oool0
T@3oool00`2LB7@0_ooo0?ooo`150?ooo`050=nLB000M;l0oooo0;md001d_ol0?P3oool00480oooo
00@0W4P004RLg`2oM000M;ooAP3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo08`0
oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`160?ooo`0409a80018W=l0_g@007Bo
och0oooo00120?ooo`040?oOW01804P0B4P007BoodH0oooo00L0okmd0000M02oool0oooo0?noM000
04P0W=oo08d0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo04L0oooo00@0omnL04P0B018
B000M;oo?P3oool004<0oooo00<0okmd0000001d_ol0A`3oool01@3o_g@000000000000004P0W=oo
08l0oooo00D0okmd000000000000001809cOo`190?ooo`030?noM0000000M;oo03h0oooo003o0?oo
ok40oooo003o0?oook40oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo
000?0?ooool00000TP00000@0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo000o0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0?P3oool00=L0oooo00<000000?ooo`3oool0eP3oool00=L0oooo00<0
00000?ooo`3oool0eP3oool00=L0oooo00<000000?ooo`3oool0eP3oool001T0oooo1000002j0?oo
o`030000003oool0oooo0=H0oooo000M0?ooo`L00000/`3oool300000=H0oooo000T0?ooo`H00000
[@3oool00`000000oooo0?ooo`2e0?ooo`L000006P3oool002X0oooo1000002Y0?ooo`030000003o
ool0oooo0:T0oooo3000000Q0?ooo`00;P3oool500000:@0oooo00<000000?ooo`3oool0X@3oool8
000002d0oooo000c0?ooo`@00000X03oool00`000000oooo0?ooo`2J0?ooo`L00000=@3oool003L0
oooo1000002L0?ooo`030000003oool0oooo09D0oooo1@00000l0?ooo`00>`3oool4000009P0oooo
00<000000?ooo`3oool0T03oool500000440oooo000o0?ooo`<00000U@3oool00`000000oooo0?oo
o`2;0?ooo`D00000AP3oool00480oooo0P00002C0?ooo`<00000Q@3oool6000004/0oooo00140?oo
o`800000T@3oool00`000000oooo0?ooo`1o0?ooo`H00000D@3oool004H0oooo0P00002?0?ooo`03
0000003oool0oooo07X0oooo1@00001G0?ooo`00B03oool2000008d0oooo00<000000?ooo`3oool0
M@3oool5000005`0oooo001:0?ooo`800000R`3oool00`000000oooo0?ooo`1`0?ooo`D00000H@3o
ool004`0oooo0P0000290?ooo`030000003oool0oooo06`0oooo1000001V0?ooo`00CP3oool20000
08L0oooo00<000000?ooo`3oool0JP3oool2000006X0oooo001@0?ooo`800000Q@3oool00`000000
oooo0?ooo`1W0?ooo`<00000K03oool00580oooo00<000000?ooo`3oool0PP3oool3000006@0oooo
0`00001_0?ooo`00D`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0680oooo0P00
001b0?ooo`00E03oool200000840oooo00<000000?ooo`3oool0G`3oool3000007@0oooo001F0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0G03oool3000007L0oooo001G0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool0FP3oool2000007X0oooo001H0?ooo`800000
O@3oool00`000000oooo0?ooo`1H0?ooo`800000O03oool005X0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`1F0?ooo`800000OP3oool005/0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`1C0?ooo`<00000P03oool005`0oooo00<000000?ooo`3oool0N03oool30000
0540oooo0P0000230?ooo`00G03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04l0
oooo0P0000250?ooo`00G@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04d0oooo
0P0000270?ooo`00GP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04/0oooo0P00
00290?ooo`00G`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0R@3oool00600oooo00<000000?ooo`3oool0C@3oool01@3o_g@00000000000000000
M;oo00D0oooo00<0_g@000000000M;l01@3oool01@3o_g@00000000000000000M;oo00@0oooo00D0
_g@0000000000000000007Boo`070?ooo`030000003oool0oooo04P0oooo0P00002<0?ooo`00H03o
ool00`000000oooo0?ooo`1=0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM000
0000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0P3oool01`2oM00007Bo0?ooo`3o
ool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`160?ooo`800000SP3oool00640oooo00<0
00000?ooo`3oool0B`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0
okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`060?ooo`030?noM000M;l0oooo00D0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`2>0?ooo`00HP3oool00`000000oooo0?ooo`1:
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00H0oooo00<0okmd001d_`3oool01@3oool3000004<0oooo0P00002A
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00<0W4P007Bo
o`3oool01@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0940oooo001S0?ooo`03
0000003oool0oooo04T0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`03
0=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0?oo_`1d00030000000304RLg`3oool0
oooo00D0oooo00<000000?ooo`3oool0@03oool2000009@0oooo001T0?ooo`030000003oool0oooo
04P0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM018W=l0oooo
0080oooo00L0gia804RLg`3oool0oooo0?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0?P3o
ool2000009H0oooo001T0?ooo`030000003oool0oooo04T0oooo00H0W4P007Boo`3oool0omnL04P0
M02oool<0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0P3oool00`3ookl0M01d0;ooo`0:0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool0UP3oool006D0oooo00<000000?ooo`3o
ool0B03oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0oono07@000000000001809cOo`03
0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo09L0oooo001U0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`2H0?ooo`00IP3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0V@3oool006L0oooo00<000000?ooo`3oool0
K@3oool3000003P0oooo0P00002L0?ooo`00I`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0W03oool006P0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo09d0oooo001X0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2N0?ooo`00J@3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0W`3oool006T0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0:00oooo
001Z0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`2Q0?ooo`00JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0300oooo0P00002T
0?ooo`00J`3oool00`000000oooo0?ooo`1Y0?ooo`<00000;`3oool00`000000oooo0?ooo`2T0?oo
o`00J`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0Y@3oool006`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0:H0oooo001/0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`2W0?ooo`00K@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0Z03oool006d0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:T0oooo001^0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2Y0?ooo`00KP3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0ZP3oool006l0oooo00<0
00000?ooo`3oool0I@3oool3000002P0oooo00<000000?ooo`3oool0Z`3oool006l0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0:`0oooo001`0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2]0?oo
o`00L03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0[P3oool00740oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0:h0oooo001a0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`2_0?ooo`00LP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0/03oool00780oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0;40oooo001b0?ooo`030000003oool0oooo0680
oooo0`00000Q0?ooo`030000003oool0oooo0;80oooo001c0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2c0?ooo`00L`3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0/`3oool007<0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;@0oooo001d0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2e0?oo
o`00M03oool00`000000oooo0?ooo`120?ooo`050?noM000000000000000001d_ol01@3oool00`2o
M0000000001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0103oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0;H0oooo001d0?ooo`030000003oool0oooo0480
oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q8
09cOo`3oool01`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;H0oooo001e0?oo
o`030000003oool0oooo0400oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?oo
o`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2g0?oo
o`00M@3oool00`000000oooo0?ooo`100?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool03@3oool00`2LB4P0W=oo0?ooo`070?ooo`<000006`3oool00`000000oooo0?ooo`2h0?ooo`00
M@3oool00`000000oooo0?ooo`100?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
3@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
^03oool007D0oooo00<000000?ooo`3oool0@03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0;T0oooo001f0?ooo`030000003oool0oooo03l0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`2i0?ooo`00MP3oool00`000000oooo0?ooo`100?ooo`0609a8001d_ol0oooo
0?oOW01807@0_ooo2`3oool01@3OW4P000000018W02LB4P0W=oo00P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`100?ooo`050?oo_`1d
000000000000B02Lgol03P3oool00`3OW4P0001809cOo`080?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0^`3oool007L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0;/0oooo001g0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`2l0?ooo`00M`3oool00`000000oooo0?ooo`1M0?oo
o`<000005P3oool00`000000oooo0?ooo`2m0?ooo`00N03oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0_@3oool007P0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0;h0oooo001h0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2o0?ooo`00N@3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0_`3oool0
07T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0<00oooo001i0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`310?ooo`00NP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0`@3oool007X0oooo00<000000?ooo`3oool0FP3oool300000140oooo00<0
00000?ooo`3oool0`P3oool007X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0<80oooo001j0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`330?ooo`00N`3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0a03oool007/0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<@0oooo001k0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`350?ooo`00N`3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0a@3oool0
07`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0<H0oooo001l0?ooo`030000003oool0oooo05P0oooo0`00000=0?ooo`030000003oool0oooo0<H0
oooo001l0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`370?ooo`00O03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0a`3oool007d0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0<P0oooo001m0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`380?ooo`00O@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0b@3oool007d0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0<T0oooo001n0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`390?ooo`00OP3oool0
0`000000oooo0?ooo`1F0?ooo`<000002@3oool00`000000oooo0?ooo`3:0?ooo`00OP3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0bP3oool007h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0</0
oooo001o0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3;0?ooo`00O`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0c03oool007l0oooo00<000000?ooo`3oool0;P3oool01@3o_g@0000000000000
0000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000005001d_`3o
ool0oooo0?ooo`2oM0000`0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0c03oool007l0oooo00<000000?ooo`3oool0;P3oool01P2LB7@0_ooo0?oo
o`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01`3oool00`2LB4P0W=oo0?ooo`030?ooo`07
0;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0c@3oool00800oooo00<000000?ooo`3oool0;03oool00`3o_g@007Bo0?ooo`020?oo
o`030=nLB018W=l0oooo00d0oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0c@3oool00800oooo00<000000?ooo`3o
ool0;03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3o
ool0203oool00`3o_g@007Bo0?ooo`050?ooo`<000001P3oool00`000000oooo0?ooo`3=0?ooo`00
P03oool00`000000oooo0?ooo`0/0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
3@3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3>0?ooo`00P03oool00`000000oooo0?ooo`0/0?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0<h0oooo00210?ooo`030000003oool0oooo02/0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0<l0oooo00210?ooo`030000003oool0oooo
02`0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`050=nLB000000004RL09a8B02Lgol0
103oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
c`3oool00840oooo00<000000?ooo`3oool0;03oool01@3ookl0M0000000000004P0W=oo00h0oooo
00<0gia80000B02Lgol0103oool00`3ookl0M00000000002000000030000M02oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3@0?ooo`00P@3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0d03oool00880oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=40oooo00220?oo
o`030000003oool0oooo0580oooo0`0000020?ooo`030000003oool0oooo0=40oooo00220?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3A0?ooo`00
PP3oool00`000000oooo0?ooo`1B0?ooo`050000003oool0oooo0?ooo`000000e03oool008<0oooo
00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool000000=@0oooo00230?ooo`030000
003oool0oooo0540oooo00@000000?ooo`3oool00000e@3oool008<0oooo00<000000?ooo`3oool0
D@3oool010000000oooo0?ooo`00003E0?ooo`00P`3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool000000=H0oooo00240?ooo`030000003oool0oooo0500oooo00<000000?ooo`000000eP3o
ool008@0oooo00<000000?ooo`3oool0D03oool300000=H0oooo00240?ooo`030000003oool0oooo
0500oooo0P00003G0?ooo`00Q03oool00`000000oooo0?ooo`1@0?ooo`800000e`3oool008D0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3F0?ooo`00Q@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0=H0oooo00250?ooo`030000003oool0oooo04h0oooo0P00003H
0?ooo`00Q@3oool00`000000oooo0?ooo`1>0?ooo`800000f03oool008H0oooo00<000000?ooo`3o
ool0C@3oool200000=P0oooo00260?ooo`030000003oool0oooo04`0oooo00<000000?ooo`000000
0P00003F0?ooo`00QP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool000000=P0oooo0026
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`000000f03oool008L0oooo00<000000?oo
o`3oool0BP3oool010000000oooo0?ooo`00003H0?ooo`00Q`3oool00`000000oooo0?ooo`1:0?oo
o`040000003oool0oooo00000=P0oooo00270?ooo`030000003oool0oooo04T0oooo00D000000?oo
o`3oool0oooo0000003H0?ooo`00Q`3oool00`000000oooo0?ooo`190?ooo`050000003oool0oooo
0?ooo`000000f03oool008P0oooo00<000000?ooo`3oool0B03oool01@000000oooo0?ooo`3oool0
00000=P0oooo00280?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3F0?ooo`00R03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0080
oooo0`00003F0?ooo`00R03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0eP3oool008T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0=H0oooo00290?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3F0?ooo`00R@3oool00`000000oooo0?ooo`0]0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000
000000D000001P3oool00`000000oooo0?ooo`3F0?ooo`00R@3oool00`000000oooo0?ooo`0]0?oo
o`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`030;md0000
07@0_ooo0080oooo00<0giad0000003oool01@3oool00`000000oooo0?ooo`3F0?ooo`00RP3oool0
0`000000oooo0?ooo`0[0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool0
0`3o_g@0001809cOo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0eP3oool0
08X0oooo00<000000?ooo`3oool0:`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
00`0oooo00@0omnL04P00018W=l000001`3oool00`000000oooo0?ooo`3F0?ooo`00RP3oool00`00
0000oooo0?ooo`0[0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`2L
B00000000?ooo`060?ooo`<00000eP3oool008X0oooo00<000000?ooo`3oool0:`3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<000000;ooo`3oool01@3oool00`000000
oooo0?ooo`3F0?ooo`00R`3oool00`000000oooo0?ooo`0Z0?ooo`030?noM018W=l0oooo0080oooo
00<0gia804RLg`3oool02P3oool01`3OW4P0M;oo0?ooo`3oool000000;md001d_ol01P3oool00`00
0000oooo0?ooo`3F0?ooo`00R`3oool00`000000oooo0?ooo`0[0?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool000000000B02Lgol01P3oool00`000000oooo
0?ooo`3F0?ooo`00R`3oool00`000000oooo0?ooo`0[0?ooo`050?oo_`1d000000000000B02Lgol0
3@3oool01@3o_g@000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0eP3oool008/0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=H0oooo
002<0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3F0?ooo`00S03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0eP3oool008`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`080?oo
o`<00000eP3oool008`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0=H0oooo002<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3F0?ooo`00S@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0eP3oool008d0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0=H0oooo002=0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3F0?ooo`00S@3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0eP3oool008h0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=H0oooo
002>0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02`3oool300000=H0oooo002>
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3F
0?ooo`00SP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0eP3oool008l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0=H0oooo002?0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3F0?ooo`00S`3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0eP3oool008l0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=H0oooo002@0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3F0?ooo`00T03oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00h0oooo0`00003F0?ooo`00T03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0eP3oool00900oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0=H0oooo002A
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3F
0?ooo`00T@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0eP3oool00940oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0=H0oooo002A0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`3F0?ooo`00TP3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0eP3oool00980oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0B0?ooo`<00000eP3oool00980oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0=H0oooo002C0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3F0?ooo`00T`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0eP3oool009<0oooo00<0
00000?ooo`3oool06P3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l0
0`3oool00`3ookl00000000000040000000507Boo`3oool0oooo0?ooo`2oM0000`0000000`1d_ol0
oooo0?ooo`050?ooo`030000003oool0oooo0=H0oooo002D0?ooo`030000003oool0oooo01T0oooo
00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00<0oooo00@000000;md
000007@0_ooo0P3oool01P3OW7@0W=oo0?ooo`3oool0_g@0001d_`80oooo00<0omnL04P0001d_ol0
1P3oool00`000000oooo0?ooo`3F0?ooo`00U03oool00`000000oooo0?ooo`0H0?ooo`030?noM000
M;l0oooo0080oooo00<0gia804RLg`3oool02@3oool01@000000oooo0?noM00004P0W=oo00X0oooo
00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00U03oool00`000000oooo0?oo
o`0H0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02@3oool01P000000oooo0?oo
o`3ogi`0B00004RLg`T0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00
U03oool00`000000oooo0?ooo`0H0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
203oool00`000000oooo0?ooo`030?ooo`0309a80018W=l0oooo00L0oooo00<0W4P007Boo`3oool0
1@3oool300000=H0oooo002E0?ooo`030000003oool0oooo01L0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`080?ooo`030000003oool0oooo00@0oooo00H0W4Qd0;ooo`3oool0oooo
0?oo_`1d00030000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0eP3oool009D0oooo
00<000000?ooo`3oool05`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00L0oooo
00D000000?ooo`3oool0gia807Boo`030?ooo`070;md001d_ol0oooo0?ooo`3ookl0M01d0;ooo`0:
0?ooo`030000003oool0oooo0=H0oooo002E0?ooo`030000003oool0oooo01P0oooo00H0W4P007Bo
o`3oool0omnL04P0M02oool80?ooo`0:0000003oool0oooo0?noM00007@0_ooo0?ooo`3o_g@00018
09cOo`80oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`3F0?ooo`00UP3oool00`00
0000oooo0?ooo`0G0?ooo`050?oo_`1d000000000000B02Lgol02@3oool01@000000oooo0?ooo`3o
ool0okmd0080000000<0001809cOo`3oool00P3oool00`3ookl0M00000000002000000030000M02o
ool0oooo00D0oooo00<000000?ooo`3oool0eP3oool009H0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0=H0oooo002F0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3F0?ooo`00U`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0eP3oool009L0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`<00000eP3oool009L0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0=H0oooo002G
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3F
0?ooo`00V03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0eP3oool009P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0=H0oooo002I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`3F0?ooo`00V@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0eP3oool009X0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0=H0oooo002J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool300000=H0oooo002K0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3F0?ooo`00V`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0eP3oool009`0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0=H0oooo002L
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3F
0?ooo`00W@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0eP3oool009d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0=H0oooo002M0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`3F0?ooo`00WP3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0200oooo0`00003F0?ooo`00WP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0eP3oool009l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0=H0oooo002P0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3F0?ooo`00X03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0eP3oool00:40oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0=H0oooo002Q
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3F
0?ooo`00XP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0eP3oool00:<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`<0
0000eP3oool00:@0oooo0P0000060?ooo`800000:@3oool00`000000oooo0?ooo`3F0?ooo`00YP3o
ool6000002/0oooo00<000000?ooo`3oool0eP3oool00=L0oooo00<000000?ooo`3oool0eP3oool0
0;T0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@0
000000000000000004RLg`070?ooo`030000003oool0oooo0=H0oooo002i0?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3o
okl0M00004RLg`060?ooo`030000003oool0oooo0=H0oooo002h0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0oooo0=H0
oooo002h0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B018
09cOo`060?ooo`030000003oool0oooo0=H0oooo002h0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0303oool0103OW4P000000000B02Lgol70?ooo`<00000eP3oool00;P0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`030?oOW01804P0W=oo0=l0oooo002h
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03`3oool00`2oM000M;oo0?ooo`3N
0?ooo`00^@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000B02Lgol0oooo
0?oOW01804P0W=oo0=l0oooo002i0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3ogi`0
B000000000000000M;oo0>00oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.66409, -0.0230557, \
0.0394252, 0.0018701}}]
}, Open  ]],

Cell[TextData[{
  "We will next find an all real valued expression for the integrand.  The \
constant 1/(2 Pi) is being left inside the integral because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " compiles the integrand before evaluation so the result usually executes \
faster this way and also we don't forget it."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ig0 = 
      ComplexExpand[
        Exp[\(-I\)\ u\ x]\ CF0[
              u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]/\((2\ Pi)\), 
        TargetFunctions \[Rule] \ {Re, \ Im}]\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(2\ \
\[Pi]\)\)\((\[ExponentialE]\^\(\(-\((u\^2)\)\^\(\[Alpha]/2\)\)\ \
\((\[Gamma]\^2)\)\^\(\[Alpha]/2\)\ Cos[\[Alpha]\ ArcTan[\[Gamma], 0]] - \(u\ \
\((u\^2)\)\^\(\(-\(1\/2\)\) + \[Alpha]\/2\)\ \[Beta]\ \((\[Gamma]\^2)\)\^\(\
\[Alpha]/2\)\ Sin[\[Pi]\ \[Alpha]]\ Sin[\[Alpha]\ ArcTan[\[Gamma], 0]]\)\/\(1 \
+ Cos[\[Pi]\ \[Alpha]]\)\)\ Cos[
            u\ x - u\ \[Delta] + \(u\ \[Beta]\ \[Gamma]\ Sin[\[Pi]\ \[Alpha]]\
\)\/\(1 + Cos[\[Pi]\ \[Alpha]]\) - \(u\ \((u\^2)\)\^\(\(-\(1\/2\)\) + \
\[Alpha]\/2\)\ \[Beta]\ \((\[Gamma]\^2)\)\^\(\[Alpha]/2\)\ Cos[\[Alpha]\ \
ArcTan[\[Gamma], 0]]\ Sin[\[Pi]\ \[Alpha]]\)\/\(1 + Cos[\[Pi]\ \[Alpha]]\) + \
\((u\^2)\)\^\(\[Alpha]/2\)\ \((\[Gamma]\^2)\)\^\(\[Alpha]/2\)\ Sin[\[Alpha]\ \
ArcTan[\[Gamma], 
                      0]]])\)\) - \(\(1\/\(2\ \[Pi]\)\)\((\[ImaginaryI]\ \
\[ExponentialE]\^\(\(-\((u\^2)\)\^\(\[Alpha]/2\)\)\ \((\[Gamma]\^2)\)\^\(\
\[Alpha]/2\)\ Cos[\[Alpha]\ ArcTan[\[Gamma], 0]] - \(u\ \
\((u\^2)\)\^\(\(-\(1\/2\)\) + \[Alpha]\/2\)\ \[Beta]\ \((\[Gamma]\^2)\)\^\(\
\[Alpha]/2\)\ Sin[\[Pi]\ \[Alpha]]\ Sin[\[Alpha]\ ArcTan[\[Gamma], 0]]\)\/\(1 \
+ Cos[\[Pi]\ \[Alpha]]\)\)\ Sin[
            u\ x - u\ \[Delta] + \(u\ \[Beta]\ \[Gamma]\ Sin[\[Pi]\ \[Alpha]]\
\)\/\(1 + Cos[\[Pi]\ \[Alpha]]\) - \(u\ \((u\^2)\)\^\(\(-\(1\/2\)\) + \
\[Alpha]\/2\)\ \[Beta]\ \((\[Gamma]\^2)\)\^\(\[Alpha]/2\)\ Cos[\[Alpha]\ \
ArcTan[\[Gamma], 0]]\ Sin[\[Pi]\ \[Alpha]]\)\/\(1 + Cos[\[Pi]\ \[Alpha]]\) + \
\((u\^2)\)\^\(\[Alpha]/2\)\ \((\[Gamma]\^2)\)\^\(\[Alpha]/2\)\ Sin[\[Alpha]\ \
ArcTan[\[Gamma], 0]]])\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The PDF is always real so complex part will integrate to zero.  With ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 5.0.1.0  this takes a very long time, earlier versions could \
solve it."
}], "Text"],

Cell[BoxData[
    \( (*Integrate[ig0[\([2]\)], {u, \(-Infinity\), \ Infinity}, 
        Assumptions \[Rule] \ {0 < \ \[Alpha] \[LessEqual] \ 
              2, \(-1\) \[LessEqual] \ \[Beta]\  \[LessEqual] \ 
              1, \ \[Gamma] > \ 0, \ \[Delta]\ \[Epsilon]\ Reals, \ 
            x\ \[Epsilon]\ Reals}]*) \)], "Input"],

Cell["\<\
The real part is symmetric about zero so we can use u > 0 and double the \
result.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrand0\  = \ 
      2\ FullSimplify[ig0[\([1]\)], 
          Assumptions \[Rule] \ {0 < \ \[Alpha] \[LessEqual] \ 
                2, \(-1\) \[LessEqual] \ \[Beta]\  \[LessEqual] \ 
                1, \ \[Gamma] > \ 0, \ \[Delta]\ \[Epsilon]\ Reals, \ 
              x\ \[Epsilon]\ Reals, \ u > 0}]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ Cos[u\ \((x - \
\[Delta])\) - \[Beta]\ \((\(-u\)\ \[Gamma] + \((u\ \[Gamma])\)\^\[Alpha])\)\ \
Tan[\(\[Pi]\ \[Alpha]\)\/2]]\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell["Likewise:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ig1 = \ 
        ComplexExpand[
          Exp[\(-I\)\ u\ x]\ CF1[
                u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]/\((2\ Pi)\), 
          TargetFunctions \[Rule] \ {Re, \ Im}];\)\), "\[IndentingNewLine]", 
    \(integrand1\  = \ 
      2\ FullSimplify[ig1[\([1]\)], 
          Assumptions \[Rule] \ {0 < \ \[Alpha] \[LessEqual] \ 
                2, \(-1\) \[LessEqual] \ \[Beta]\  \[LessEqual] \ 
                1, \ \[Gamma] > \ 0, \ \[Delta]\ \[Epsilon]\ Reals, \ 
              x\ \[Epsilon]\ Reals, \ u > 0}]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ Cos[u\ x - u\ \
\[Delta] - \[Beta]\ \((u\ \[Gamma])\)\^\[Alpha]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\
\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell["For \[Alpha] = 1 ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[integrand0, \ \[Alpha]\  \[Rule] 1]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-u\)\ \[Gamma]\)\ Cos[u\ \((x - \[Delta] + \(2\ \
\[Beta]\ \[Gamma]\ Log[u\ \[Gamma]]\)\/\[Pi])\)]\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell["We can now construct functions for the PDF.", "Text"],

Cell[BoxData[{
    \(\(pdf0[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := \ 
        NIntegrate[\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ Cos[u\
\ \((x - \[Delta])\) - \[Beta]\ \((\(-u\)\ \[Gamma] + \((u\ \[Gamma])\)\^\
\[Alpha])\)\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\)\/\[Pi], \ {u, 0, 
            Infinity}];\)\), "\n", 
    \(pdf0[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := \ 
      NIntegrate[\(\[ExponentialE]\^\(\(-u\)\ \[Gamma]\)\ Cos[u\ \((x - \
\[Delta] + \(2\ \[Beta]\ \[Gamma]\ Log[u\ \[Gamma]]\)\/\[Pi])\)]\)\/\[Pi], \ \
{u, 0, Infinity}] /; \[Alpha] \[Equal] 1\), "\n", 
    \(\(pdf1[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := \ 
        NIntegrate[\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ Cos[u\
\ x - u\ \[Delta] - \[Beta]\ \((u\ \[Gamma])\)\^\[Alpha]\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]]\)\/\[Pi], \ {u, 0, Infinity}];\)\), "\n", 
    \(pdf1[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := \ 
      NIntegrate[\(\[ExponentialE]\^\(\(-u\)\ \[Gamma]\)\ Cos[u\ \((x - \
\[Delta] + \(2\ \[Beta]\ \[Gamma]\ Log[u\ \[Gamma]]\)\/\[Pi])\)]\)\/\[Pi], \ \
{u, 0, Infinity}] /; \[Alpha] \[Equal] 1\)}], "Input"],

Cell["\<\
These functions oscillate so they make calculations difficult for the whole \
range of stable densities.\
\>", "Text"],

Cell[BoxData[
    \(\(OffNIntMsg;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetOptions[NIntegrate, 
        GaussPoints \[Rule] 15];\)\), "\[IndentingNewLine]", 
    \(\({\[Alpha], \ \[Beta], \ \[Gamma], \[Delta]}\  = \ {1.3, 1, 1, 
          0.5};\)\), "\[IndentingNewLine]", 
    \(\(Plot[{pdf0[x, \ {\[Alpha], \ \[Beta], \ \[Gamma], \ \[Delta]}], 
          pdf1[x, \ {\[Alpha], \ \[Beta], \ \[Gamma], \ \[Delta]}]}, {x, \(-5\
\), 5}, PlotStyle \[Rule] {Hue[0.7], Hue[1]}, 
        PlotRange \[Rule] All];\)\), "\[IndentingNewLine]", 
    \(\(Clear[\[Alpha], \ \[Beta], \ \[Gamma], \[Delta]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 2.11635 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .12053 -24 -4.5 ]
[.4875 .12053 0 4.5 ]
[.4875 .22635 -18 -4.5 ]
[.4875 .22635 0 4.5 ]
[.4875 .33217 -24 -4.5 ]
[.4875 .33217 0 4.5 ]
[.4875 .43798 -18 -4.5 ]
[.4875 .43798 0 4.5 ]
[.4875 .5438 -24 -4.5 ]
[.4875 .5438 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12053 m
.50625 .12053 L
s
[(0.05)] .4875 .12053 1 0 Mshowa
.5 .22635 m
.50625 .22635 L
s
[(0.1)] .4875 .22635 1 0 Mshowa
.5 .33217 m
.50625 .33217 L
s
[(0.15)] .4875 .33217 1 0 Mshowa
.5 .43798 m
.50625 .43798 L
s
[(0.2)] .4875 .43798 1 0 Mshowa
.5 .5438 m
.50625 .5438 L
s
[(0.25)] .4875 .5438 1 0 Mshowa
.125 Mabswid
.5 .03588 m
.50375 .03588 L
s
.5 .05704 m
.50375 .05704 L
s
.5 .07821 m
.50375 .07821 L
s
.5 .09937 m
.50375 .09937 L
s
.5 .1417 m
.50375 .1417 L
s
.5 .16286 m
.50375 .16286 L
s
.5 .18402 m
.50375 .18402 L
s
.5 .20519 m
.50375 .20519 L
s
.5 .24751 m
.50375 .24751 L
s
.5 .26868 m
.50375 .26868 L
s
.5 .28984 m
.50375 .28984 L
s
.5 .311 m
.50375 .311 L
s
.5 .35333 m
.50375 .35333 L
s
.5 .37449 m
.50375 .37449 L
s
.5 .39566 m
.50375 .39566 L
s
.5 .41682 m
.50375 .41682 L
s
.5 .45915 m
.50375 .45915 L
s
.5 .48031 m
.50375 .48031 L
s
.5 .50148 m
.50375 .50148 L
s
.5 .52264 m
.50375 .52264 L
s
.5 .56497 m
.50375 .56497 L
s
.5 .58613 m
.50375 .58613 L
s
.5 .60729 m
.50375 .60729 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03404 .01472 L
.03523 .01472 L
.03589 .01472 L
.0366 .01472 L
.03786 .01472 L
.03906 .01472 L
.04033 .01472 L
.04153 .01472 L
.04262 .01472 L
.04375 .01472 L
.04495 .01472 L
.04627 .01472 L
.04748 .01472 L
.0486 .01472 L
.04966 .01472 L
.05081 .01472 L
.05205 .01472 L
.05275 .01472 L
.05339 .01472 L
.05484 .01472 L
.05613 .01472 L
.05749 .01472 L
.0587 .01472 L
.05984 .01472 L
.0611 .01472 L
.06244 .01472 L
.06373 .01472 L
.06509 .01472 L
.06639 .01472 L
.06756 .01472 L
.06894 .01472 L
.07044 .01472 L
.07185 .01472 L
.07315 .01472 L
.0745 .01472 L
.07576 .01472 L
.07714 .01472 L
.07863 .01472 L
.08018 .01472 L
.08166 .01472 L
.08298 .01472 L
Mistroke
.08443 .01472 L
.0858 .01472 L
.08708 .01472 L
.08949 .01472 L
.09084 .01472 L
.09208 .01472 L
.09345 .01472 L
.09488 .01472 L
.09604 .01472 L
.09728 .01472 L
.09951 .01472 L
.10087 .01472 L
.10216 .01472 L
.10333 .01472 L
.10458 .01472 L
.10582 .01472 L
.10696 .01472 L
.10918 .01472 L
.11037 .01472 L
.11166 .01472 L
.11302 .01472 L
.11426 .01472 L
.11683 .01472 L
.11825 .01472 L
.11958 .01472 L
.12196 .01472 L
.1233 .01472 L
.12453 .01472 L
.12674 .01472 L
.1288 .01472 L
.13106 .01472 L
.13349 .01472 L
.13603 .01472 L
.13844 .01472 L
.14061 .01472 L
.14296 .01472 L
.14529 .01472 L
.1478 .01472 L
.15017 .01472 L
.15235 .01472 L
.15476 .01472 L
.15739 .01472 L
.16015 .01472 L
.16271 .01472 L
.16544 .01472 L
.16803 .01472 L
.17035 .01472 L
.17286 .01472 L
.1756 .01472 L
.1785 .01472 L
Mistroke
.18098 .01472 L
.18371 .01472 L
.1862 .01472 L
.18891 .01472 L
.19148 .01472 L
.19386 .01472 L
.19835 .01472 L
.20086 .01473 L
.20314 .01473 L
.2083 .01474 L
.21121 .01474 L
.21389 .01475 L
.21882 .01477 L
.2213 .01478 L
.22402 .0148 L
.22653 .01482 L
.22927 .01485 L
.23423 .01491 L
.23907 .015 L
.24354 .01511 L
.24837 .01526 L
.25369 .01551 L
.25925 .01585 L
.26446 .0163 L
.26916 .01683 L
.2743 .01757 L
.27967 .01858 L
.28466 .01978 L
.29361 .02273 L
.29862 .02494 L
.30317 .02735 L
.31316 .03431 L
.32237 .04316 L
.33248 .05612 L
.34317 .07414 L
.36276 .12011 L
.38108 .17856 L
.41992 .33729 L
.43969 .42107 L
.46122 .50087 L
.47122 .53132 L
.48187 .55811 L
.49191 .57772 L
.501 .59062 L
.5059 .59567 L
.50857 .59788 L
.51106 .59959 L
.51337 .60088 L
.51547 .60181 L
.5178 .60258 L
Mistroke
.51909 .60289 L
.5203 .6031 L
.5215 .60324 L
.52282 .60331 L
.52349 .60332 L
.5242 .6033 L
.52549 .6032 L
.52678 .60303 L
.528 .60279 L
.53029 .60216 L
.53298 .60112 L
.53548 .59988 L
.54114 .59609 L
.54621 .59163 L
.5517 .58576 L
.56165 .57263 L
.58026 .54124 L
.62125 .45496 L
.66072 .36925 L
.69868 .29637 L
.73909 .23306 L
.77799 .18557 L
.81934 .14715 L
.85917 .11931 L
.89749 .09894 L
.93826 .0824 L
.97619 .07056 L
Mfstroke
1 0 0 r
.02381 .01474 m
.02605 .01475 L
.02846 .01476 L
.03279 .01478 L
.03543 .01479 L
.03793 .01481 L
.04262 .01485 L
.04756 .01491 L
.05212 .015 L
.05713 .01512 L
.06244 .0153 L
.06743 .01554 L
.0728 .01589 L
.07786 .01633 L
.0825 .01686 L
.08791 .01766 L
.09382 .01881 L
.0994 .02024 L
.10458 .02193 L
.10966 .02398 L
.11515 .02673 L
.1251 .03339 L
.13479 .04244 L
.14371 .05346 L
.15345 .06894 L
.16253 .08699 L
.1832 .14183 L
.20355 .21362 L
.22211 .29011 L
.2428 .3795 L
.26195 .45713 L
.28172 .52391 L
.2914 .54985 L
.30028 .56921 L
.30926 .58435 L
.31398 .5905 L
.31894 .59564 L
.32141 .59769 L
.32404 .59952 L
.32632 .60081 L
.32878 .6019 L
.33029 .60241 L
.33168 .60278 L
.33301 .60304 L
.33369 .60314 L
.33442 .60323 L
.3357 .60331 L
.33642 .60332 L
.33707 .60331 L
.33834 .60323 L
Mistroke
.33955 .60308 L
.3408 .60285 L
.34215 .60253 L
.34459 .60173 L
.34697 .6007 L
.34916 .59954 L
.35414 .59616 L
.35939 .59154 L
.36817 .58163 L
.37779 .56803 L
.41827 .49027 L
.45723 .40448 L
.49864 .32017 L
.53854 .25276 L
.57692 .20144 L
.61776 .15953 L
.65707 .12901 L
.69488 .10663 L
.73513 .08844 L
.77387 .07502 L
.81506 .064 L
.85474 .05575 L
.8929 .04946 L
.93351 .0441 L
.97261 .03994 L
.97619 .0396 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00?P3oool01@3ogi`0B000000000000000M;oo04H0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`2>0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0A`3oool0
1@3ogi`0B000000000000000M;oo03T0oooo00100?ooo`030;md001d_ol0oooo04L0oooo00<0_g@0
0000M02oool00P3oool00`3OW7@0W=oo0?ooo`2@0?ooo`030;md000007@0_ooo0080oooo00<0giad
09cOo`3oool0BP3oool00`2oM000M;oo0?ooo`0i0?ooo`00@03oool00`2oM000M;oo0?ooo`180?oo
o`030?noM00004P0W=oo09D0oooo00<0okmd0000B02Lgol0CP3oool00`2oM000M;oo0?ooo`0i0?oo
o`00?03oool00`3OW4P00000000000030000000307Boo`3oool0oooo04L0oooo00<0omnL04P00018
W=l0U@3oool00`3ogi`0B00004RLg`190?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3o
ool0=`3oool003<0oooo00<0W4P00000000000000`0000002@00B9`0oooo0?ooo`3o_g@0001d0;oo
o`3oool0_g@007Boo`0o0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0103oool0
0`2LB000B9cO0?ooo`2E0?ooo`0309a80018W=l0oooo04L0oooo00H0okmd0000M02oool0oooo0;md
001d_olj0?ooo`00?@3oool01@3OW4P007Bo0?ooo`2oM000M;oo04d0oooo00<0W4Qd0;ooo`3oool0
U@3oool00`2LB7@0_ooo0?ooo`170?ooo`050=nLB000M;l0oooo0;md001d_ol0>P3oool003h0oooo
00@0W4P004RLg`2oM000M;ooB03oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo0900
oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`180?ooo`0409a80018W=l0_g@007Bo
ocX0oooo000n0?ooo`040?oOW01804P0B4P007BoodP0oooo00L0okmd0000M02oool0oooo0?noM000
04P0W=oo0940oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo04T0oooo00@0omnL04P0B018
B000M;oo>P3oool003l0oooo00<0okmd0000001d_ol0B@3oool01@3o_g@000000000000004P0W=oo
09<0oooo00D0okmd000000000000001809cOo`1;0?ooo`030?noM0000000M;oo03X0oooo003o0?oo
ok40oooo003o0?oook40oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo
000:0?ooo`X000004@3o001<03<0ool00000=@00000;0?ooo`00503oool00`000000oooo0?ooo`0>
0?ooo`/0o`002`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0303oool;03<0o`d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01P3oool20?l000T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool403<0o`T0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo000b0?ooo`@0
o`001@3oool00`000000oooo0?ooo`120?ooo`80<`3o1`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0j0?ooo`00
=P3oool20?l004X0oooo0`0c0?mB0?ooo`030000003oool0oooo0=H0oooo000h0?ooo`80o`00B`3o
ool203<0oe00oooo00<000000?ooo`3oool0eP3oool003X0oooo00<0o`000?ooo`3oool0BP3oool0
0`0c0?l0oooo0?ooo`1=0?ooo`030000003oool0oooo0=H0oooo000k0?ooo`80o`00B`3oool203<0
odd0oooo00<000000?ooo`3oool0eP3oool003d0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0
oooo0?ooo`1:0?ooo`030000003oool0oooo0=H0oooo000n0?ooo`030?l0003oool0oooo04X0oooo
00<0<`3o0?ooo`3oool0B@3oool300000=H0oooo000o0?ooo`030?l0003oool0oooo04X0oooo00<0
<`3o0?ooo`3oool0B03oool00`000000oooo0?ooo`300?ooo`030?l0003oool0oooo01<0oooo0010
0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0A`3oool00`000000oooo0?ooo`2h
0?ooo`P0o`005P3oool00440oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`160?oo
o`030000003oool0oooo0:/0oooo3@3o000N0?ooo`00@P3oool00`3o0000oooo0?ooo`1:0?ooo`03
03<0o`3oool0oooo04D0oooo00<000000?ooo`3oool0X`3oool80?l002/0oooo00130?ooo`030?l0
003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0A03oool00`000000oooo0?ooo`2L0?ooo`L0o`00
<`3oool004@0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`140?ooo`030000003o
ool0oooo09L0oooo1@3o000j0?ooo`00A@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo04<0oooo00<000000?ooo`3oool0T@3oool60?l003l0oooo00160?ooo`030?l0003oool0oooo
04T0oooo00<0<`3o0?ooo`3oool0@P3oool00`000000oooo0?ooo`2<0?ooo`D0o`00A@3oool004H0
oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`110?ooo`<00000Q`3oool50?l004X0
oooo00170?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0@@3oool00`000000oooo
0?ooo`210?ooo`H0o`00C`3oool004P0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?oo
o`100?ooo`030000003oool0oooo07d0oooo103o001E0?ooo`00B03oool00`3o0000oooo0?ooo`19
0?ooo`0303<0o`3oool0oooo0400oooo00<000000?ooo`3oool0N@3oool40?l005T0oooo00190?oo
o`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0?`3oool00`000000oooo0?ooo`1f0?oo
o`<0o`00G@3oool004T0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0n0?ooo`03
0000003oool0oooo07<0oooo0`3o00190?ooo`80<`3o5@3oool004X0oooo00<0o`000?ooo`3oool0
B@3oool00`0c0?l0oooo0?ooo`0n0?ooo`030000003oool0oooo06l0oooo103o00190?ooo`<0<`3o
5`3oool004X0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0m0?ooo`030000003o
ool0oooo06`0oooo0`3o001:0?ooo`<0<`3o6P3oool004/0oooo00<0o`000?ooo`3oool0B@3oool0
0`0c0?l0oooo0?ooo`0m0?ooo`<00000J@3oool30?l004X0oooo0`0c0?lM0?ooo`00B`3oool00`3o
0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo03`0oooo00<000000?ooo`3oool0IP3oool30?l0
04X0oooo0`0c0?lP0?ooo`00C03oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo03`0
oooo00<000000?ooo`3oool0HP3oool40?l004X0oooo0`0c0?lS0?ooo`00C03oool00`3o0000oooo
0?ooo`1:0?ooo`0303<0o`3oool0oooo03/0oooo00<000000?ooo`3oool0G`3oool30?l004`0oooo
0P0c0?lV0?ooo`00C@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo03/0oooo00<0
00000?ooo`3oool0G@3oool20?l004`0oooo0`0c0?lX0?ooo`00C@3oool00`3o0000oooo0?ooo`1:
0?ooo`0303<0o`3oool0oooo03X0oooo00<000000?ooo`3oool0F`3oool20?l004`0oooo0P0c0?l[
0?ooo`00CP3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo03X0oooo00<000000?oo
o`3oool0F@3oool20?l004`0oooo0P0c0?l]0?ooo`00CP3oool00`3o0000oooo0?ooo`1:0?ooo`03
03<0o`3oool0oooo03T0oooo00<000000?ooo`3oool0E`3oool20?l004/0oooo0`0c0?l_0?ooo`00
CP3oool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo03T0oooo00<000000?ooo`3oool0
E@3oool20?l004/0oooo0P0c0?lb0?ooo`00C`3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3o
ool0oooo03T0oooo0`00001C0?ooo`80o`00B`3oool203<0oc@0oooo001?0?ooo`030?l0003oool0
oooo04X0oooo00<0<`3o0?ooo`3oool0>03oool00`000000oooo0?ooo`1A0?ooo`80o`00B`3oool2
03<0ocH0oooo001@0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`1?0?ooo`80o`00B`3oool203<0ocP0oooo001@0?ooo`030?l0003oool0oooo04X0
oooo00<0<`3o0?ooo`3oool0=`3oool00`000000oooo0?ooo`1=0?ooo`80o`00B`3oool203<0ocX0
oooo001@0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0=`3oool00`000000oooo
0?ooo`1;0?ooo`80o`00B`3oool203<0oc`0oooo001A0?ooo`030?l0003oool0oooo04X0oooo00<0
<`3o0?ooo`3oool03`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l0
1@3oool01@3o_g@00000000000000000M;oo00@0oooo00D0_g@0000000000000000007Boo`070?oo
o`030000003oool0oooo04T0oooo0P3o001;0?ooo`80<`3o?P3oool00540oooo00<0o`000?ooo`3o
ool0BP3oool00`0c0?l0oooo0?ooo`0?0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool0
0`2oM0000000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0P3oool01`2oM00007Bo
0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`170?ooo`80o`00B`3oool203<0
od00oooo001A0?ooo`030?l0003oool0oooo04/0oooo00<0<`3o0?ooo`3oool03@3oool00`3o_g@0
07Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0
B9cO0?ooo`060?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0AP3oool00`3o0000
oooo0?ooo`190?ooo`80<`3o@P3oool00580oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo
0?ooo`0=0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00<0okmd001d_`3oool01@3oool00`000000oooo
0?ooo`140?ooo`80o`00BP3oool203<0od@0oooo001B0?ooo`030?l0003oool0oooo04X0oooo00<0
<`3o0?ooo`3oool03@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`060?ooo`0309a8001d_ol0oooo00D0oooo1000
00110?ooo`80o`00B`3oool00`0c0?l0oooo0?ooo`140?ooo`00DP3oool00`3o0000oooo0?ooo`1;
0?ooo`0303<0o`3oool0oooo00`0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:
0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0?oo_`1d00030000000304RL
g`3oool0oooo00D0oooo00<000000?ooo`3oool0@03oool20?l004/0oooo0P0c0?m70?ooo`00D`3o
ool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo00`0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM018W=l0oooo0080oooo00L0gia804RLg`3oool0oooo
0?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0?P3oool20?l004`0oooo00<0<`3o0?ooo`3o
ool0A`3oool005<0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0=0?ooo`0609a8
001d_ol0oooo0?oOW01807@0_ooo303oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`80oooo00<0
oono07@0M02oool02P3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo04/0oooo00<0
<`3o0?ooo`3oool0B03oool005@0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0=
0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3ookl0M0000000000004P0W=oo00<0oooo
00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000003oool0oooo03`0oooo
00<0o`000?ooo`3oool0BP3oool203<0od/0oooo001D0?ooo`030?l0003oool0oooo04X0oooo00<0
<`3o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0j0?ooo`80o`00C03oool00`0c0?l0oooo0?oo
o`1;0?ooo`00E03oool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo03<0oooo00<00000
0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`1;0?ooo`0303<0o`3oool0oooo04`0oooo001E0?oo
o`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo04X0oooo0P0c0?m?0?ooo`00E@3oool00`3o0000oooo0?ooo`1:0?ooo`03
03<0o`3oool0oooo0380oooo0`00000g0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o
ool0C`3oool005D0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0b0?ooo`030000
003oool0oooo03H0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`1@0?ooo`00EP3o
ool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo0380oooo00<000000?ooo`3oool0=03o
ool20?l004/0oooo0P0c0?mC0?ooo`00EP3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo0380oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0
oooo05<0oooo001F0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0E03oool005H0
oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0a0?ooo`030000003oool0oooo0340
oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`1E0?ooo`00E`3oool00`3o0000oooo
0?ooo`190?ooo`0303<0o`3oool0oooo0340oooo00<000000?ooo`3oool0;`3oool20?l004`0oooo
00<0<`3o0?ooo`3oool0EP3oool005L0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?oo
o`0`0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0BP3oool203<0oeT0oooo001G
0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0<03oool00`000000oooo0?ooo`0]
0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0F@3oool005P0oooo00<0o`000?oo
o`3oool0B@3oool00`0c0?l0oooo0?ooo`0`0?ooo`<00000;03oool00`3o0000oooo0?ooo`1:0?oo
o`0303<0o`3oool0oooo05X0oooo001H0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o
ool0F`3oool005P0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0_0?ooo`030000
003oool0oooo02X0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`1L0?ooo`00F@3o
ool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02l0oooo00<000000?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo05d0oooo001I0?ooo`030?l0003oool0
oooo04T0oooo00<0<`3o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0
oooo04X0oooo00<0<`3o0?ooo`3oool0GP3oool005T0oooo00<0o`000?ooo`3oool0BP3oool00`0c
0?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0B@3oool203<0
of40oooo001I0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0;P3oool00`000000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0H@3oool005X0oooo
00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo
00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`1R0?ooo`00FP3oool00`3o0000oooo0?oo
o`190?ooo`0303<0o`3oool0oooo02h0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?oo
o`180?ooo`0303<0o`3oool0oooo06<0oooo001J0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o
0?ooo`3oool0;@3oool3000002@0oooo00<0o`000?ooo`3oool0B03oool00`0c0?l0oooo0?ooo`1T
0?ooo`00F`3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02d0oooo00<000000?oo
o`3oool08`3oool00`3o0000oooo0?ooo`180?ooo`0303<0o`3oool0oooo06D0oooo001K0?ooo`03
0?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0R0?ooo`03
0?l0003oool0oooo04P0oooo00<0<`3o0?ooo`3oool0IP3oool005/0oooo00<0o`000?ooo`3oool0
B@3oool00`0c0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0
B@3oool00`0c0?l0oooo0?ooo`1V0?ooo`00G03oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3o
ool0oooo02`0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3o
ool0oooo06L0oooo001L0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0;03oool0
0`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0J03oool0
05`0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0/0?ooo`030000003oool0oooo
01h0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`1Y0?ooo`00G03oool00`3o0000
oooo0?ooo`190?ooo`0303<0o`3oool0oooo02`0oooo00<000000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`190?ooo`0303<0o`3oool0oooo06X0oooo001M0?ooo`030?l0003oool0oooo04T0oooo
00<0<`3o0?ooo`3oool0:`3oool3000001`0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo
0?ooo`1Z0?ooo`00G@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02/0oooo00<0
00000?ooo`3oool06`3oool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo06/0oooo001M
0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0K
0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0K03oool005h0oooo00<0o`000?oo
o`3oool0B03oool00`0c0?l0oooo0?ooo`0[0?ooo`030000003oool0oooo01X0oooo00<0o`000?oo
o`3oool0B@3oool00`0c0?l0oooo0?ooo`1]0?ooo`00GP3oool00`3o0000oooo0?ooo`190?ooo`03
03<0o`3oool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`190?ooo`03
03<0o`3oool0oooo06h0oooo001N0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0
303oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@0
00000000000300000003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0603oool00`3o0000
oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo06h0oooo001N0?ooo`030?l0003oool0oooo04T0oooo
00<0<`3o0?ooo`3oool0303oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@00000
0000M;l01`3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo01P0oooo00<0o`000?oo
o`3oool0B@3oool00`0c0?l0oooo0?ooo`1_0?ooo`00G`3oool00`3o0000oooo0?ooo`180?ooo`03
03<0o`3oool0oooo00/0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`03
09a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`190?ooo`03
03<0o`3oool0oooo0700oooo001O0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0
2P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool0
1`3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0
L@3oool005l0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0:0?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`070?ooo`@00000503o
ool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo0780oooo001O0?ooo`030?l0003oool0
oooo04T0oooo00<0<`3o0?ooo`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0
oooo04T0oooo00<0<`3o0?ooo`3oool0LP3oool00600oooo00<0o`000?ooo`3oool0B03oool00`0c
0?l0oooo0?ooo`0:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03@3oool00`2L
B4P0W=oo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0B@3oool00`0c
0?l0oooo0?ooo`1c0?ooo`00H03oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00X0
oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`050=nLB000000004RL09a8B02Lgol0203o
ool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0M03o
ool00600oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0:0?ooo`050?oo_`1d0000
00000000B02Lgol03P3oool00`3OW4P0001809cOo`080?ooo`030000003oool0oooo0180oooo00<0
o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`1e0?ooo`00H03oool00`3o0000oooo0?ooo`19
0?ooo`0303<0o`3oool0oooo02P0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`19
0?ooo`0303<0o`3oool0oooo07D0oooo001P0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?oo
o`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?oo
o`3oool0MP3oool00640oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo0100oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`1g0?ooo`00
H@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02L0oooo00<000000?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo07L0oooo001Q0?ooo`030?l0003o
ool0oooo04T0oooo00<0<`3o0?ooo`3oool09`3oool3000000l0oooo00<0o`000?ooo`3oool0B@3o
ool00`0c0?l0oooo0?ooo`1h0?ooo`00H@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo02L0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo07T0oooo001R0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool09P3oool00`00
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0N@3oool00680
oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0V0?ooo`030000003oool0oooo00`0
oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`1j0?ooo`00HP3oool00`3o0000oooo
0?ooo`190?ooo`0303<0o`3oool0oooo02H0oooo00<000000?ooo`3oool0303oool00`3o0000oooo
0?ooo`190?ooo`0303<0o`3oool0oooo07/0oooo001R0?ooo`030?l0003oool0oooo04T0oooo00<0
<`3o0?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo04X0oooo00<0
<`3o0?ooo`3oool0N`3oool006<0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0U
0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`1l
0?ooo`00H`3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02D0oooo00<000000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo07d0oooo001S0?ooo`03
0?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool09@3oool3000000T0oooo00<0o`000?ooo`3o
ool0BP3oool00`0c0?l0oooo0?ooo`1m0?ooo`00H`3oool00`3o0000oooo0?ooo`190?ooo`0303<0
o`3oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`190?ooo`0303<0
o`3oool0oooo07h0oooo001S0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0903o
ool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0OP3o
ool006@0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0T0?ooo`030000003oool0
oooo00L0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`1o0?ooo`00I03oool00`3o
0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo0800oooo001T0?ooo`030?l0003oool0oooo04T0
oooo00<0<`3o0?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo04X0
oooo00<0<`3o0?ooo`3oool0P03oool006@0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo
0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo
0?ooo`210?ooo`00I@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo02<0oooo00<0
00000?ooo`3oool01@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo0880oooo001U
0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool08`3oool00`000000oooo0?ooo`04
0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0PP3oool006D0oooo00<0o`000?oo
o`3oool0B@3oool00`0c0?l0oooo0?ooo`0S0?ooo`<00000103oool00`3o0000oooo0?ooo`190?oo
o`0303<0o`3oool0oooo08<0oooo001U0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o
ool08P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3o
ool0Q03oool006D0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0R0?ooo`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`240?ooo`00IP3o
ool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo0280oooo00<000000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo08D0oooo001V0?ooo`030?l0003oool0
oooo04T0oooo00<0<`3o0?ooo`3oool08P3oool01@000000oooo0?ooo`3oool0o`0004/0oooo00<0
<`3o0?ooo`3oool0QP3oool006H0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0Q
0?ooo`040000003oool0oooo0?l004`0oooo00<0<`3o0?ooo`3oool0QP3oool006H0oooo00<0o`00
0?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0Q0?ooo`040000003oool0oooo0?l004/0oooo00<0
<`3o0?ooo`3oool0Q`3oool006L0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0Q
0?ooo`030000003oool0o`0004`0oooo00<0<`3o0?ooo`3oool0Q`3oool006L0oooo00<0o`000?oo
o`3oool0B@3oool00`0c0?l0oooo0?ooo`0Q0?ooo`030000003oool0o`0004/0oooo00<0<`3o0?oo
o`3oool0R03oool006L0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0P0?ooo`03
0000003o0000000004/0oooo00<0<`3o0?ooo`3oool0R03oool006L0oooo00<0o`000?ooo`3oool0
BP3oool00`0c0?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0
R@3oool006P0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo04X0oooo00<0<`3o0?ooo`3oool0R@3oool006P0oooo00<0o`000?ooo`3oool0B@3oool0
0`0c0?l0oooo0?ooo`0O0?ooo`030?l000000000oooo04X0oooo00<0<`3o0?ooo`3oool0RP3oool0
06P0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0N0?ooo`030?l000000000oooo
04X0oooo00<0<`3o0?ooo`3oool0RP3oool006P0oooo00<0o`000?ooo`3oool0A@3oool01P3o_g@0
0000000000000000M;oo03<0o`@0oooo00<0_g@000000000M;l0103oool00`3o_g@0000000000003
00000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d_ol0oooo0?ooo`030?ooo`030?l0003o
ool0000004X0oooo00<0<`3o0?ooo`3oool0R`3oool006T0oooo00<0o`000?ooo`3oool0A03oool0
1P2LB7@0_ooo0?ooo`3ookl0M01d03<0o`@0oooo00<0_g@000000000M;l01`3oool00`2LB4P0W=oo
0?ooo`030?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`040?ooo`030?l0003oool00000
04X0oooo00<0<`3o0?ooo`3oool0R`3oool006T0oooo00<0o`000?ooo`3oool0@`3oool00`3o_g@0
07Bo0?ooo`020?ooo`030=nLB00c0?l0oooo00d0oooo00<0W4Q809cOo`3oool0203oool00`3o_g@0
07Bo0?ooo`020?ooo`040?l0003oool0oooo000004T0oooo00<0<`3o0?ooo`3oool0S03oool006T0
oooo00<0o`000?ooo`3oool0@`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0<`3o00d0
oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`020?ooo`030?l0003oool0oooo00@0
0000AP3oool00`0c0?l0oooo0?ooo`2<0?ooo`00J@3oool00`3o0000oooo0?ooo`130?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`0c0?l03@3oool00`2LB4P0W=oo0?ooo`080?ooo`0509a8
001d_ol0oooo0?ooo`3o00000`3oool00`000000oooo0?ooo`160?ooo`0303<0o`3oool0oooo08d0
oooo001Z0?ooo`030?l0003oool0oooo0480oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
03<0o`0=0?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0000000000P0000001@18W=l0oooo
0?ooo`3oool0o`0000<0oooo00<000000?ooo`3oool0AP3oool00`0c0?l0oooo0?ooo`2=0?ooo`00
JP3oool00`3o0000oooo0?ooo`120?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`0c0?l0
3@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0_ooo00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`150?ooo`0303<0o`3oool0oooo08h0oooo001Z0?ooo`030?l0003o
ool0oooo04<0oooo00L0W4P007Boo`3oool0omnL04P0M02oool0<`3o00X0oooo00D0gia800000000
B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo00D0oooo00<0o`000?ooo`3oool00P3oool00`00
0000oooo0?ooo`150?ooo`0303<0o`3oool0oooo08h0oooo001Z0?ooo`030?l0003oool0oooo04<0
oooo00D0oono07@000000000001809cOo`020?ooo`0303<0o`3oool0oooo00T0oooo00<0gia80000
B02Lgol0103oool00`3ookl0M00000000002000000030000M02oool0o`0000D0oooo00<000000?oo
o`3oool0A03oool00`0c0?l0oooo0?ooo`2?0?ooo`00J`3oool00`3o0000oooo0?ooo`190?ooo`03
03<0o`3oool0oooo01L0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`140?ooo`03
03<0o`3oool0oooo08l0oooo001[0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo04<0oooo00<0<`3o0?ooo`3oool0
T03oool006/0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo00@0oooo00<000000?ooo`3oool0@`3oool00`0c0?l0oooo0?ooo`2@0?ooo`00J`3oool0
0`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo01@0oooo00<0o`000?ooo`3oool01@3oool3
00000480oooo00<0<`3o0?ooo`3oool0T@3oool006`0oooo00<0o`000?ooo`3oool0B@3oool00`0c
0?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`0c
0?l0oooo0?ooo`2A0?ooo`00K03oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo01<0
oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`110?ooo`0303<0o`3oool0oooo0980
oooo001/0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`060?ooo`030000003oool0oooo0440oooo00<0<`3o0?ooo`3oool0TP3oool006`0oooo00<0
o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00<0
00000?ooo`3oool0@03oool00`0c0?l0oooo0?ooo`2C0?ooo`00K@3oool00`3o0000oooo0?ooo`19
0?ooo`0303<0o`3oool0oooo0140oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`10
0?ooo`0303<0o`3oool0oooo09<0oooo001]0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo03l0oooo00<0<`3o0?oo
o`3oool0U03oool006d0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00P0oooo00<000000?ooo`3oool0?`3oool00`0c0?l0oooo0?ooo`2D0?ooo`00
K@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0o0?ooo`0303<0o`3oool0oooo09@0oooo001^0?ooo`030?l0003o
ool0oooo04T0oooo00<0<`3o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?ooo`<00000?P3o
ool00`0c0?l0oooo0?ooo`2E0?ooo`00KP3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0n0?ooo`0303<0o`3oool0
oooo09D0oooo001^0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo00<0<`3o0?ooo`3oool0UP3oool006h0
oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<000000?ooo`3oool0?@3oool00`0c0?l0oooo0?ooo`2F0?ooo`00KP3oool00`3o0000oooo
0?ooo`1:0?ooo`0303<0o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo
0?ooo`0l0?ooo`0303<0o`3oool0oooo09L0oooo001_0?ooo`030?l0003oool0oooo04T0oooo00<0
<`3o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo03`0oooo00<0
<`3o0?ooo`3oool0U`3oool006l0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0>`3oool00`0c0?l0oooo0?ooo`2H
0?ooo`00K`3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool03@3oool00`000000oooo0?ooo`0k0?ooo`0303<0o`3oool0oooo09P0oooo001_0?ooo`03
0?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`<0
0000>P3oool00`0c0?l0oooo0?ooo`2I0?ooo`00L03oool00`3o0000oooo0?ooo`190?ooo`0303<0
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0j0?ooo`0303<0
o`3oool0oooo09T0oooo001`0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo03X0oooo00<0<`3o0?ooo`3oool0V@3o
ool00700oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00l0oooo00<000000?ooo`3oool0>@3oool00`0c0?l0oooo0?ooo`2J0?ooo`00L03oool00`3o
0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00H0oooo00<0o`000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0i0?ooo`0303<0o`3oool0oooo09X0oooo001`0?ooo`030?l0003oool0oooo04X0
oooo00<0<`3o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0oooo03P0
oooo00<0<`3o0?ooo`3oool0V`3oool00740oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0100oooo00<000000?ooo`3oool0>03oool00`0c0?l0oooo
0?ooo`2K0?ooo`00L@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0403oool00`000000oooo0?ooo`0g0?ooo`0303<0o`3oool0oooo09`0oooo001a
0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A
0?ooo`030000003oool0oooo03L0oooo00<0<`3o0?ooo`3oool0W03oool00740oooo00<0o`000?oo
o`3oool0BP3oool00`0c0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo0`00000f0?oo
o`0303<0o`3oool0oooo09d0oooo001a0?ooo`030?l0003oool0oooo04X0oooo00D0<`3o0?ooo`3o
ool0oooo0?l0000D0?ooo`030000003oool0oooo03H0oooo00<0<`3o0?ooo`3oool0W@3oool00780
oooo00<0o`000?ooo`3oool0B@3oool01@0c0?l0oooo0?ooo`3oool0o`0001@0oooo00<000000?oo
o`3oool0=@3oool00`0c0?l0oooo0?ooo`2N0?ooo`00LP3oool00`3o0000oooo0?ooo`190?ooo`05
03<0o`3oool0oooo0?ooo`3o0000503oool00`000000oooo0?ooo`0e0?ooo`0303<0o`3oool0oooo
09h0oooo001b0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o00005@3oool00`000000
oooo0?ooo`0d0?ooo`0303<0o`3oool0oooo09l0oooo001b0?ooo`030?l0003oool0oooo04@0oooo
00d0okmd000000000000000007Boo`3oool0<`3o0?ooo`3o0000oooo0;md0000000007Bo00<0oooo
00<0oono07@000000000100000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo03@0oooo
00<0<`3o0?ooo`3oool0W`3oool007<0oooo00<0o`000?ooo`3oool0@`3oool0202LB7@0_ooo0?oo
o`3ookl0M01d0;ooo`0c0?l0o`000P3oool00`2oM0000000001d_`040?ooo`030;md000007@0_ooo
0080oooo00<0giad09cOo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`0303<0o`3oool0oooo
09l0oooo001c0?ooo`030?l0003oool0oooo0480oooo00<0okmd001d_`3oool00P3oool0103OW4P0
B9cO03<0o`3o000:0?ooo`030?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0<`3oool00`0c
0?l0oooo0?ooo`2P0?ooo`00L`3oool00`3o0000oooo0?ooo`120?ooo`030=nLB018W=l0oooo0080
oooo00@0okmd001d_`3o0000<`3o2`3oool00`3ogi`0B00004RLg`080?ooo`030000003oool0oooo
03<0oooo00<0<`3o0?ooo`3oool0X03oool007<0oooo00<0o`000?ooo`3oool0@P3oool00`3OW4P0
B9cO0?ooo`020?ooo`040?noM000M;l0o`0003<0o`d0oooo00<0W4P004RLg`3oool01P3oool40000
0340oooo00<0<`3o0?ooo`3oool0X@3oool007<0oooo00<0o`000?ooo`3oool0@P3oool00`3OW4P0
B9cO0?ooo`020?ooo`040?noM000M;l0o`0003<0o`h0oooo00<0W4Qd0;ooo`3oool01@3oool00`00
0000oooo0?ooo`0b0?ooo`0303<0o`3oool0oooo0:40oooo001d0?ooo`030?l0003oool0oooo0440
oooo00<0okmd04RLg`3oool00P3oool01@3OW4P0o`000?ooo`3oool0<`3o00P0oooo00<0gia807Bo
o`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo0340oooo00<0<`3o0?oo
o`3oool0XP3oool007@0oooo00<0o`000?ooo`3oool0@P3oool01P2LB000M;oo0?ooo`3ogi`0B01d
0?l00080oooo00<0<`3o0?ooo`3oool01P3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0
1P3oool00`000000oooo0?ooo`0a0?ooo`0303<0o`3oool0oooo0:80oooo001d0?ooo`030?l0003o
ool0oooo0480oooo00D0oono07@00000000000180?l000030?ooo`0303<0o`3oool0oooo00L0oooo
00D0okmd000000000000001809cOo`070?ooo`030000003oool0oooo0300oooo00<0<`3o0?ooo`3o
ool0X`3oool007@0oooo00<0o`000?ooo`3oool0AP3oool01@3o0000oooo0?ooo`3oool0<`3o01D0
oooo00<000000?ooo`3oool0<03oool00`0c0?l0oooo0?ooo`2S0?ooo`00M@3oool00`3o0000oooo
0?ooo`140?ooo`030?l0003oool0oooo00<0oooo00<0<`3o0?ooo`3oool04P3oool00`000000oooo
0?ooo`0_0?ooo`0303<0o`3oool0oooo0:@0oooo001e0?ooo`030?l0003oool0oooo04@0oooo00<0
o`000?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`0B0?ooo`030000003oool0oooo02l0oooo00<0
<`3o0?ooo`3oool0Y03oool007D0oooo00<0o`000?ooo`3oool0A03oool00`3o0000oooo0?ooo`03
0?ooo`0303<0o`3oool0oooo0180oooo0`00000_0?ooo`0303<0o`3oool0oooo0:@0oooo001e0?oo
o`030?l0003oool0oooo04<0oooo00<0o`000?ooo`3oool0103oool00`0c0?l0oooo0?ooo`0B0?oo
o`030000003oool0oooo02h0oooo00<0<`3o0?ooo`3oool0Y@3oool007H0oooo00<0o`000?ooo`3o
ool0@P3oool00`3o0000oooo0?ooo`050?ooo`0303<0o`3oool0oooo0140oooo00<000000?ooo`3o
ool0;P3oool00`0c0?l0oooo0?ooo`2U0?ooo`00MP3oool00`3o0000oooo0?ooo`110?ooo`030?l0
003oool0oooo00H0oooo00<0<`3o0?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`0303<0
o`3oool0oooo0:H0oooo001f0?ooo`030?l0003oool0oooo0440oooo00<0o`000?ooo`3oool01P3o
ool00`0c0?l0oooo0?ooo`0A0?ooo`030000003oool0oooo02d0oooo00<0<`3o0?ooo`3oool0YP3o
ool007L0oooo00<0o`000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`080?ooo`0303<0o`3oool0
oooo0100oooo00<000000?ooo`3oool0;03oool00`0c0?l0oooo0?ooo`2W0?ooo`00M`3oool00`3o
0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00P0oooo00<0<`3o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0/0?ooo`0303<0o`3oool0oooo0:L0oooo001g0?ooo`030?l0003oool0oooo03l0
oooo00<0o`000?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0@0?ooo`030000003oool0oooo02/0
oooo00<0<`3o0?ooo`3oool0Z03oool007P0oooo00<0o`000?ooo`3oool0?@3oool00`3o0000oooo
0?ooo`090?ooo`0303<0o`3oool0oooo0100oooo00<000000?ooo`3oool0:`3oool00`0c0?l0oooo
0?ooo`2X0?ooo`00N03oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00X0oooo00<0
<`3o0?ooo`3oool03`3oool3000002X0oooo00<0<`3o0?ooo`3oool0Z@3oool007P0oooo00<0o`00
0?ooo`3oool0?03oool00`3o0000oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00l0oooo00<00000
0?ooo`3oool0:P3oool00`0c0?l0oooo0?ooo`2Y0?ooo`00N@3oool00`3o0000oooo0?ooo`0k0?oo
o`030?l0003oool0oooo00/0oooo00<0<`3o0?ooo`3oool03`3oool00`000000oooo0?ooo`0Y0?oo
o`0303<0o`3oool0oooo0:X0oooo001i0?ooo`030?l0003oool0oooo03X0oooo00<0o`000?ooo`3o
ool03@3oool00`0c0?l0oooo0?ooo`0>0?ooo`030000003oool0oooo02T0oooo00<0<`3o0?ooo`3o
ool0ZP3oool007T0oooo00<0o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0=0?ooo`0303<0
o`3oool0oooo00h0oooo00<000000?ooo`3oool0:03oool00`0c0?l0oooo0?ooo`2[0?ooo`00NP3o
ool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00h0oooo00<0<`3o0?ooo`3oool03P3o
ool00`000000oooo0?ooo`0X0?ooo`0303<0o`3oool0oooo0:/0oooo001j0?ooo`030?l0003oool0
oooo03P0oooo00<0o`000?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0>0?ooo`030000003oool0
oooo02L0oooo00<0<`3o0?ooo`3oool0[03oool007X0oooo00<0o`000?ooo`3oool0=`3oool00`3o
0000oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo00d0oooo00<000000?ooo`3oool09`3oool00`0c
0?l0oooo0?ooo`2/0?ooo`00N`3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0100
oooo00<0<`3o0?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`0303<0o`3oool0oooo0:d0
oooo001k0?ooo`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool04@3oool00`0c0?l0oooo
0?ooo`0=0?ooo`<000009P3oool00`0c0?l0oooo0?ooo`2]0?ooo`00N`3oool00`3o0000oooo0?oo
o`0e0?ooo`030?l0003oool0oooo0180oooo00<0<`3o0?ooo`3oool0303oool00`000000oooo0?oo
o`0U0?ooo`0303<0o`3oool0oooo0:h0oooo001l0?ooo`030?l0003oool0oooo03<0oooo00<0o`00
0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<0<`3o
0?ooo`3oool0[P3oool007`0oooo00<0o`000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0C0?oo
o`0303<0o`3oool0oooo00`0oooo00<000000?ooo`3oool0903oool00`0c0?l0oooo0?ooo`2_0?oo
o`00O03oool00`3o0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo01D0oooo00<0<`3o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`0T0?ooo`0303<0o`3oool0oooo0:l0oooo001m0?ooo`030?l0
003oool0oooo0340oooo00<0o`000?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0;0?ooo`030000
003oool0oooo02<0oooo00<0<`3o0?ooo`3oool0/03oool007d0oooo00<0o`000?ooo`3oool0<03o
ool00`3o0000oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo00/0oooo00<000000?ooo`3oool08`3o
ool00`0c0?l0oooo0?ooo`2`0?ooo`00O@3oool00`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0
oooo01H0oooo00<0<`3o0?ooo`3oool02`3oool00`000000oooo0?ooo`0R0?ooo`0303<0o`3oool0
oooo0;40oooo001n0?ooo`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3oool0603oool00`0c
0?l0oooo0?ooo`0:0?ooo`<000008P3oool00`0c0?l0oooo0?ooo`2a0?ooo`00OP3oool00`3o0000
oooo0?ooo`0^0?ooo`030?l0003oool0oooo01P0oooo00<0<`3o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0Q0?ooo`0303<0o`3oool0oooo0;80oooo001n0?ooo`030?l0003oool0oooo02d0oooo
00<0o`000?ooo`3oool06@3oool00`0c0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo
00<0<`3o0?ooo`3oool0/P3oool007l0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`0K0?ooo`0303<0o`3oool0oooo00T0oooo00<000000?ooo`3oool0803oool00`0c0?l0oooo0?oo
o`2c0?ooo`00O`3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo01/0oooo00<0<`3o
0?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`0303<0o`3oool0oooo0;<0oooo001o0?oo
o`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0703oool00`0c0?l0oooo0?ooo`090?oo
o`030000003oool0oooo01l0oooo00<0<`3o0?ooo`3oool0]03oool00800oooo00<0o`000?ooo`3o
ool0:@3oool01@3o0000oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool00`3oool00`2o
M0000000001d_`030?ooo`030?oo_`1d0000000000@0000000H0M;oo0?ooo`3oool0oooo0;md000c
0?l20000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`0c0?l0oooo0?oo
o`2d0?ooo`00P03oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0080oooo00H0W4Qd
0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo00<0_g@00000M02oool0
0P3oool02`3OW7@0W=oo0?ooo`3oool0_g@0001d_`0c0?l0oooo0?oOW0180000M;oo00H0oooo00<0
00000?ooo`3oool07P3oool00`0c0?l0oooo0?ooo`2e0?ooo`00P@3oool00`3o0000oooo0?ooo`0W
0?ooo`060?l0003oool0oooo0?ooo`3o_g@007Bo0`3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?no
M00004P0W=oo00P0oooo00@0<`3o0?ooo`3o_g@007Bo1P3oool00`000000oooo0?ooo`0N0?ooo`03
03<0o`3oool0oooo0;D0oooo00210?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0
0P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P00018W=l0
1`3oool0100c0?l0oooo0?noM000M;l60?ooo`@00000703oool00`0c0?l0oooo0?ooo`2f0?ooo`00
P@3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0080oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00H0oooo00<0<`3o09a8001d_ol0
1P3oool00`000000oooo0?ooo`0M0?ooo`0303<0o`3oool0oooo0;H0oooo00220?ooo`030?l0003o
ool0oooo02@0oooo00<0o`000?ooo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00l0oooo00H0W4Qd0;ooo`3oool0oooo0?oo_`1d00020000000303<0o`18W=l0oooo00H0
oooo00<000000?ooo`3oool0703oool00`0c0?l0oooo0?ooo`2g0?ooo`00PP3oool00`3o0000oooo
0?ooo`0T0?ooo`030?l0003oool0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00L0_g@007Boo`3oool0oooo0?oo_`1d07@0_ooo
0080oooo00<0<`3o0?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo
0;L0oooo00220?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool01@3oool01P2LB000
M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo0080oooo
00<0oono07@0M02oool00P3oool00`0c0?l0oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo
00<0<`3o0?ooo`3oool0^03oool008<0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?oo
o`050?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00<0
oooo00<0oono07@0000000000P0000000`0007@0<`3o0?ooo`050?ooo`030000003oool0oooo01X0
oooo00<0<`3o0?ooo`3oool0^@3oool008<0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0V0?ooo`0303<0o`3oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`0c0?l0oooo
0?ooo`2i0?ooo`00Q03oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo02H0oooo00<0
<`3o0?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`0303<0o`3oool0oooo0;X0oooo0024
0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0:03oool00`0c0?l0oooo0?ooo`03
0?ooo`030000003oool0oooo01P0oooo00<0<`3o0?ooo`3oool0^`3oool008D0oooo00<0o`000?oo
o`3oool07P3oool00`3o0000oooo0?ooo`0X0?ooo`0303<0o`3oool0oooo00<0oooo0`00000H0?oo
o`0303<0o`3oool0oooo0;/0oooo00250?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3o
ool0:P3oool00`0c0?l0oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<0<`3o0?ooo`3o
ool0_03oool008H0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0[0?ooo`0303<0
o`3oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`2l0?ooo`00QP3o
ool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo02`0oooo00D0<`3o0?ooo`3oool0oooo
0000000H0?ooo`0303<0o`3oool0oooo0;d0oooo00270?ooo`030?l0003oool0oooo01T0oooo00<0
o`000?ooo`3oool0;@3oool01@0c0?l0oooo0?ooo`3oool0000001L0oooo00<0<`3o0?ooo`3oool0
_P3oool008L0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0_0?ooo`0403<0o`3o
ool0oooo000001H0oooo00<0<`3o0?ooo`3oool0_`3oool008P0oooo00<0o`000?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0`0?ooo`0303<0o`3oool0000001H0oooo00<0<`3o0?ooo`3oool0_`3o
ool008P0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0a0?ooo`0303<0o`3oool0
000001D0oooo00<0<`3o0?ooo`3oool0`03oool008T0oooo00<0o`000?ooo`3oool0503oool00`3o
0000oooo0?ooo`0c0?ooo`0403<0o`000000000000000180oooo00<0<`3o0?ooo`3oool0`@3oool0
08X0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0d0?ooo`0303<0o`000000oooo
0180oooo00<0<`3o0?ooo`3oool0`P3oool008/0oooo00<0o`000?ooo`3oool0403oool00`3o0000
oooo0?ooo`0f0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool0`P3oool008`0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0g0?ooo`030000000c0?l0oooo0100oooo
00<0<`3o0?ooo`3oool0``3oool008d0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?oo
o`0h0?ooo`030000003oool0<`3o00l0oooo00<0<`3o0?ooo`3oool0a03oool008h0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo0080<`3o303oool0
0`0c0?l0oooo0?ooo`350?ooo`00S`3oool20?l000L0oooo0`3o000l0?ooo`030000003oool0oooo
0080oooo00<0<`3o0?ooo`3oool01`3oool203<0olP0oooo002A0?ooo`L0o`00?`3oool00`000000
oooo0?ooo`030?ooo`T0<`3obP3oool00=L0oooo00<000000?ooo`3oool0eP3oool00=L0oooo0`00
003F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?oo
o`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.5213, -0.0214706, \
0.0384313, 0.00172945}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Stable Distribution Function",
    FontWeight->"Bold"],
  " (CDF)  \nThe CDF can be calculated by integrating the PDF integrand with \
respect to x; then integrating with respect to u.  The constant of the x \
integration is 1/2."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Integrate[integrand0, x]\), "\[IndentingNewLine]", 
    \(Integrate[integrand1, x]\), "\[IndentingNewLine]", 
    \(Integrate[Limit[integrand0, \[Alpha] \[Rule] 1], x]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\[Pi]\)\((\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ \((\
\(Cosh[Sec[\(\[Pi]\ \[Alpha]\)\/2]\ \((\(-\[ImaginaryI]\)\ u\ \[Delta]\ \
Cos[\(\[Pi]\ \[Alpha]\)\/2] + \[ImaginaryI]\ u\ \[Beta]\ \[Gamma]\ \
Sin[\(\[Pi]\ \[Alpha]\)\/2] - \[ImaginaryI]\ \[Beta]\ \((u\ \[Gamma])\)\^\
\[Alpha]\ Sin[\(\[Pi]\ \[Alpha]\)\/2])\)]\ Sin[u\ x]\)\/u - \(\[ImaginaryI]\ \
Cos[u\ x]\ Sinh[Sec[\(\[Pi]\ \[Alpha]\)\/2]\ \((\(-\[ImaginaryI]\)\ u\ \
\[Delta]\ Cos[\(\[Pi]\ \[Alpha]\)\/2] + \[ImaginaryI]\ u\ \[Beta]\ \[Gamma]\ \
Sin[\(\[Pi]\ \[Alpha]\)\/2] - \[ImaginaryI]\ \[Beta]\ \((u\ \[Gamma])\)\^\
\[Alpha]\ Sin[\(\[Pi]\ \[Alpha]\)\/2])\)]\)\/u)\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\[Pi]\)\((\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ \((\
\(Cosh[Sec[\(\[Pi]\ \[Alpha]\)\/2]\ \((\(-\[ImaginaryI]\)\ u\ \[Delta]\ \
Cos[\(\[Pi]\ \[Alpha]\)\/2] - \[ImaginaryI]\ \[Beta]\ \((u\ \[Gamma])\)\^\
\[Alpha]\ Sin[\(\[Pi]\ \[Alpha]\)\/2])\)]\ Sin[u\ x]\)\/u - \(\[ImaginaryI]\ \
Cos[u\ x]\ Sinh[Sec[\(\[Pi]\ \[Alpha]\)\/2]\ \((\(-\[ImaginaryI]\)\ u\ \
\[Delta]\ Cos[\(\[Pi]\ \[Alpha]\)\/2] - \[ImaginaryI]\ \[Beta]\ \((u\ \
\[Gamma])\)\^\[Alpha]\ Sin[\(\[Pi]\ \[Alpha]\)\/2])\)]\)\/u)\))\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-u\)\ \[Gamma]\)\ \((\(Cos[\(u\ \((\[Pi]\ \
\[Delta] - 2\ \[Beta]\ \[Gamma]\ Log[u\ \[Gamma]])\)\)\/\[Pi]]\ Sin[u\ \
x]\)\/u - \(Cos[u\ x]\ Sin[\(u\ \((\[Pi]\ \[Delta] - 2\ \[Beta]\ \[Gamma]\ \
Log[u\ \[Gamma]])\)\)\/\[Pi]]\)\/u)\)\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Clear[cdf0, cdf1];\)\)], "Input"],

Cell[BoxData[{
    \(\(cdf0[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := 
        0.5\  + \ 
          NIntegrate[\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ \
Sin[u\ \((x - \[Delta])\) - \[Beta]\ \((\(-u\)\ \[Gamma] + \((u\ \
\[Gamma])\)\^\[Alpha])\)\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\)\/\(\[Pi]\ u\), \ {u, 
              0, Infinity}];\)\), "\n", 
    \(cdf0[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := 
      0.5\  + \ \ NIntegrate[\(\[ExponentialE]\^\(\(-u\)\ \[Gamma]\)\ Sin[u\ \
\((x - \[Delta] + \(2\ \[Beta]\ \[Gamma]\ Log[u\ \[Gamma]]\)\/\[Pi])\)]\)\/\(\
\[Pi]\ u\), \ {u, 0, Infinity}] /; \[Alpha] \[Equal] 1\), "\n", 
    \(\(cdf1[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := 
        0.5\  + \ \ NIntegrate[\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\
\[Alpha]\)\ Sin[u\ \((x - \[Delta])\) - \[Beta]\ \((u\ \[Gamma])\)\^\[Alpha]\ \
Tan[\(\[Pi]\ \[Alpha]\)\/2]]\)\/\(\[Pi]\ u\), \ {u, 0, 
              Infinity}];\)\), "\n", 
    \(cdf1[x_, \ {\[Alpha]_, \ \[Beta]_, \ \[Gamma]_, \ \[Delta]_}]\  := 
      0.5\  + \ 
          NIntegrate[\(\[ExponentialE]\^\(\(-u\)\ \[Gamma]\)\ Sin[u\ \((x - \
\[Delta] + \(2\ \[Beta]\ \[Gamma]\ Log[u\ \[Gamma]]\)\/\[Pi])\)]\)\/\(\[Pi]\ \
u\), \ {u, 0, Infinity}] /; \[Alpha] \[Equal] 1\)}], "Input"],

Cell["These functions are numerically more tractable.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({\[Alpha], \ \[Beta], \ \[Gamma], \[Delta]}\  = \ {1.3, 1, 1, 
          0.5};\)\), "\[IndentingNewLine]", 
    \(\(Plot[{cdf0[x, \ {\[Alpha], \ \[Beta], \ \[Gamma], \ \[Delta]}], 
          cdf1[x, \ {\[Alpha], \ \[Beta], \ \[Gamma], \ \[Delta]}]}, {x, \(-5\
\), 5}, PlotStyle \[Rule] {Hue[0.7], Hue[1]}, 
        PlotRange \[Rule] All];\)\), "\[IndentingNewLine]", 
    \(\(Clear[\[Alpha], \ \[Beta], \ \[Gamma], \[Delta]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.622578 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .13923 -18 -4.5 ]
[.4875 .13923 0 4.5 ]
[.4875 .26375 -18 -4.5 ]
[.4875 .26375 0 4.5 ]
[.4875 .38826 -18 -4.5 ]
[.4875 .38826 0 4.5 ]
[.4875 .51278 -18 -4.5 ]
[.4875 .51278 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13923 m
.50625 .13923 L
s
[(0.2)] .4875 .13923 1 0 Mshowa
.5 .26375 m
.50625 .26375 L
s
[(0.4)] .4875 .26375 1 0 Mshowa
.5 .38826 m
.50625 .38826 L
s
[(0.6)] .4875 .38826 1 0 Mshowa
.5 .51278 m
.50625 .51278 L
s
[(0.8)] .4875 .51278 1 0 Mshowa
.125 Mabswid
.5 .04584 m
.50375 .04584 L
s
.5 .07697 m
.50375 .07697 L
s
.5 .1081 m
.50375 .1081 L
s
.5 .17036 m
.50375 .17036 L
s
.5 .20149 m
.50375 .20149 L
s
.5 .23262 m
.50375 .23262 L
s
.5 .29488 m
.50375 .29488 L
s
.5 .326 m
.50375 .326 L
s
.5 .35713 m
.50375 .35713 L
s
.5 .41939 m
.50375 .41939 L
s
.5 .45052 m
.50375 .45052 L
s
.5 .48165 m
.50375 .48165 L
s
.5 .54391 m
.50375 .54391 L
s
.5 .57504 m
.50375 .57504 L
s
.5 .60616 m
.50375 .60616 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03523 .01472 L
.03754 .01472 L
.03881 .01472 L
.0402 .01472 L
.04145 .01472 L
.04262 .01472 L
.04376 .01472 L
.045 .01472 L
.0457 .01472 L
.04637 .01472 L
.04762 .01472 L
.04894 .01472 L
.05016 .01472 L
.05086 .01472 L
.0515 .01472 L
.05293 .01472 L
.05528 .01472 L
.05783 .01472 L
.06244 .01472 L
.06511 .01472 L
.06796 .01472 L
.07061 .01472 L
.07312 .01472 L
.07446 .01472 L
.07593 .01472 L
.07657 .01472 L
.07726 .01472 L
.07849 .01472 L
.07919 .01472 L
.07994 .01472 L
.08064 .01472 L
.08129 .01472 L
.08201 .01472 L
.0828 .01472 L
.08362 .01472 L
.08439 .01472 L
.08565 .01472 L
.08702 .01472 L
.08831 .01472 L
.0895 .01472 L
.09176 .01472 L
.0929 .01472 L
.09415 .01472 L
.09675 .01472 L
.09821 .01472 L
.09954 .01472 L
.10078 .01472 L
Mistroke
.10212 .01472 L
.10458 .01472 L
.10592 .01472 L
.10714 .01472 L
.10846 .01472 L
.10991 .01472 L
.11235 .01472 L
.11368 .01472 L
.11492 .01472 L
.11614 .01472 L
.11729 .01472 L
.11945 .01472 L
.12065 .01472 L
.12177 .01472 L
.12299 .01472 L
.12429 .01472 L
.12553 .01472 L
.12685 .01472 L
.12922 .01472 L
.13052 .01472 L
.13169 .01472 L
.1344 .01472 L
.1358 .01472 L
.13732 .01472 L
.13866 .01472 L
.14008 .01472 L
.14137 .01472 L
.14278 .01472 L
.14528 .01472 L
.14782 .01472 L
.15014 .01472 L
.15282 .01472 L
.15536 .01472 L
.15771 .01472 L
.15988 .01472 L
.16226 .01472 L
.16479 .01472 L
.16694 .01472 L
.16927 .01472 L
.17146 .01472 L
.17348 .01472 L
.17571 .01472 L
.17815 .01472 L
.18071 .01472 L
.18308 .01472 L
.1857 .01472 L
.18812 .01472 L
.19077 .01472 L
.19359 .01472 L
.19603 .01472 L
Mistroke
.19831 .01472 L
.20082 .01472 L
.20351 .01472 L
.20589 .01472 L
.20849 .01472 L
.21078 .01472 L
.21322 .01472 L
.21563 .01472 L
.21782 .01472 L
.22209 .01472 L
.22442 .01472 L
.22697 .01472 L
.22946 .01472 L
.23213 .01472 L
.2369 .01472 L
.24135 .01473 L
.24404 .01473 L
.24695 .01474 L
.24952 .01474 L
.25225 .01474 L
.25741 .01476 L
.26218 .01478 L
.26707 .0148 L
.27156 .01483 L
.27648 .01487 L
.28167 .01493 L
.28619 .015 L
.2904 .01508 L
.29995 .01534 L
.30501 .01553 L
.31048 .01579 L
.31531 .01608 L
.32042 .01646 L
.3301 .01741 L
.33902 .01864 L
.34846 .02041 L
.3586 .02297 L
.36818 .02615 L
.37692 .02979 L
.39596 .04062 L
.40673 .0487 L
.4167 .05754 L
.45591 .1049 L
.49756 .17276 L
.5377 .24521 L
.57632 .31233 L
.6174 .37483 L
.65696 .42434 L
.695 .46245 L
.7355 .49429 L
Mistroke
.77448 .51812 L
.81591 .53783 L
.85583 .55266 L
.89423 .56402 L
.93508 .57372 L
.97442 .58129 L
.97619 .5816 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02605 .01472 L
.02846 .01472 L
.03279 .01472 L
.03543 .01472 L
.03793 .01472 L
.04262 .01472 L
.04502 .01472 L
.04756 .01472 L
.05212 .01473 L
.05466 .01473 L
.05704 .01473 L
.06244 .01474 L
.06504 .01474 L
.06788 .01475 L
.07305 .01477 L
.07807 .01479 L
.08274 .01482 L
.08829 .01486 L
.09331 .01491 L
.09911 .015 L
.10458 .0151 L
.10923 .01522 L
.11434 .01538 L
.11968 .0156 L
.12466 .01585 L
.13357 .01646 L
.13857 .01691 L
.14313 .01741 L
.15304 .0188 L
.16222 .02056 L
.17228 .02315 L
.18298 .0268 L
.19235 .0309 L
.20245 .03639 L
.22073 .04945 L
.24077 .06881 L
.26187 .09488 L
.29997 .15419 L
.34054 .22665 L
.37958 .29587 L
.42108 .3615 L
.46106 .41403 L
.49953 .45463 L
.54045 .48853 L
.57985 .51386 L
.61774 .53296 L
.65808 .54897 L
.6969 .56118 L
.73818 .57154 L
Mistroke
.77794 .57958 L
.81618 .58595 L
.85688 .59156 L
.89606 .59608 L
.9377 .60013 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00?P3oool01@3ogi`0B000000000000000M;oo04H0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`2>0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0A`3oool0
1@3ogi`0B000000000000000M;oo03T0oooo00100?ooo`030;md001d_ol0oooo04L0oooo00<0_g@0
0000M02oool00P3oool00`3OW7@0W=oo0?ooo`2@0?ooo`030;md000007@0_ooo0080oooo00<0giad
09cOo`3oool0BP3oool00`2oM000M;oo0?ooo`0i0?ooo`00@03oool00`2oM000M;oo0?ooo`180?oo
o`030?noM00004P0W=oo09D0oooo00<0okmd0000B02Lgol0CP3oool00`2oM000M;oo0?ooo`0i0?oo
o`00?03oool00`3OW4P00000000000030000000307Boo`3oool0oooo04L0oooo00<0omnL04P00018
W=l0U@3oool00`3ogi`0B00004RLg`190?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3o
ool0=`3oool003<0oooo00<0W4P00000000000000`0000002@00B9`0oooo0?ooo`3o_g@0001d0;oo
o`3oool0_g@007Boo`0o0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0103oool0
0`2LB000B9cO0?ooo`2E0?ooo`0309a80018W=l0oooo04L0oooo00H0okmd0000M02oool0oooo0;md
001d_olj0?ooo`00?@3oool01@3OW4P007Bo0?ooo`2oM000M;oo04d0oooo00<0W4Qd0;ooo`3oool0
U@3oool00`2LB7@0_ooo0?ooo`170?ooo`050=nLB000M;l0oooo0;md001d_ol0>P3oool003h0oooo
00@0W4P004RLg`2oM000M;ooB03oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo0900
oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`180?ooo`0409a80018W=l0_g@007Bo
ocX0oooo000n0?ooo`040?oOW01804P0B4P007BoodP0oooo00L0okmd0000M02oool0oooo0?noM000
04P0W=oo0940oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo04T0oooo00@0omnL04P0B018
B000M;oo>P3oool003l0oooo00<0okmd0000001d_ol0B@3oool01@3o_g@000000000000004P0W=oo
09<0oooo00D0okmd000000000000001809cOo`1;0?ooo`030?noM0000000M;oo03X0oooo003o0?oo
ok40oooo003o0?oook40oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo
000:0?ooo`X00000903o001;03<0ool000008`00000;0?ooo`00503oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00h0oooo3`3o00070?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0;0?oooa00<`3o2@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`090?ooo`@0o`000`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?oo
o`@0<`3o1@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo000k0?ooo`03
0000003oool0oooo00d0oooo103o000j0?ooo`030000003oool0oooo00/0oooo100c0?ll0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0j0?ooo`00
C`3oool40?l004P0oooo100c0?lh0?ooo`030000003oool0oooo0=H0oooo001C0?ooo`<0o`00B@3o
ool403<0oc@0oooo00<000000?ooo`3oool0eP3oool005H0oooo0P3o001;0?ooo`<0<`3o<@3oool0
0`000000oooo0?ooo`3F0?ooo`00F03oool20?l004`0oooo0P0c0?l_0?ooo`030000003oool0oooo
0=H0oooo001J0?ooo`80o`00C03oool00`0c0?l0oooo0?ooo`0/0?ooo`030000003oool0oooo0=H0
oooo001L0?ooo`80o`00B`3oool00`0c0?l0oooo0?ooo`0[0?ooo`030000003oool0oooo0=H0oooo
001N0?ooo`80o`00BP3oool203<0ob/0oooo00<000000?ooo`3oool0eP3oool00600oooo00<0o`00
0?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0X0?ooo`030000003oool0oooo0=H0oooo001Q0?oo
o`80o`00BP3oool203<0obP0oooo00<000000?ooo`3oool0eP3oool006<0oooo0P3o001:0?ooo`80
<`3o9P3oool300000=H0oooo001U0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0
8`3oool00`000000oooo0?ooo`3F0?ooo`00IP3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3o
ool0oooo0280oooo00<000000?ooo`3oool0eP3oool006L0oooo00<0o`000?ooo`3oool0B@3oool0
0`0c0?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo0=H0oooo001X0?ooo`030?l0003oool0oooo
04T0oooo00<0<`3o0?ooo`3oool0803oool00`000000oooo0?ooo`3F0?ooo`00J@3oool00`3o0000
oooo0?ooo`190?ooo`0303<0o`3oool0oooo01l0oooo00<000000?ooo`3oool0eP3oool006X0oooo
00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0N0?ooo`030000003oool0oooo0=H0oooo
001[0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool07@3oool00`000000oooo0?oo
o`3F0?ooo`00K03oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo01`0oooo00<00000
0?ooo`3oool0eP3oool006d0oooo00<0o`000?ooo`3oool0B03oool00`0c0?l0oooo0?ooo`0L0?oo
o`030000003oool0oooo0=H0oooo001^0?ooo`030?l0003oool0oooo04P0oooo00<0<`3o0?ooo`3o
ool06`3oool00`000000oooo0?ooo`3F0?ooo`00KP3oool00`3o0000oooo0?ooo`190?ooo`0303<0
o`3oool0oooo01X0oooo00<000000?ooo`3oool0eP3oool006l0oooo00<0o`000?ooo`3oool0B@3o
ool00`0c0?l0oooo0?ooo`0I0?ooo`030000003oool0oooo0=H0oooo001`0?ooo`030?l0003oool0
oooo04T0oooo00<0<`3o0?ooo`3oool0603oool300000=H0oooo001a0?ooo`030?l0003oool0oooo
04T0oooo00<0<`3o0?ooo`3oool05`3oool00`000000oooo0?ooo`3F0?ooo`00L@3oool00`3o0000
oooo0?ooo`190?ooo`0303<0o`3oool0oooo01L0oooo00<000000?ooo`3oool0eP3oool00780oooo
00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0=H0oooo
001c0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool05@3oool00`000000oooo0?oo
o`3F0?ooo`00M03oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo01@0oooo00<00000
0?ooo`3oool0eP3oool007@0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0C0?oo
o`030000003oool0oooo0=H0oooo001e0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o
ool04P3oool00`000000oooo0?ooo`3F0?ooo`00MP3oool00`3o0000oooo0?ooo`190?ooo`0303<0
o`3oool0oooo0180oooo00<000000?ooo`3oool0eP3oool007H0oooo00<0o`000?ooo`3oool0BP3o
ool00`0c0?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0=H0oooo001g0?ooo`030?l0003oool0
oooo04X0oooo00<0<`3o0?ooo`3oool0403oool00`000000oooo0?ooo`3F0?ooo`00N03oool00`3o
0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo00l0oooo00<000000?ooo`3oool0eP3oool007P0
oooo00<0o`000?ooo`3oool0B`3oool00`0c0?l0oooo0?ooo`0>0?ooo`030000003oool0oooo0=H0
oooo001i0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool03P3oool300000=H0oooo
001j0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3oool03@3oool00`000000oooo0?oo
o`3F0?ooo`00NP3oool00`3o0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo00d0oooo00<00000
0?ooo`3oool0eP3oool007/0oooo00<0o`000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`0<0?oo
o`030000003oool0oooo0=H0oooo001l0?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`3F0?ooo`00O03oool00`3o0000oooo0?ooo`1:0?ooo`0303<0
o`3oool0oooo00/0oooo00<000000?ooo`3oool0eP3oool007d0oooo00<0o`000?ooo`3oool0BP3o
ool00`0c0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0=H0oooo001n0?ooo`030?l0003oool0
oooo04T0oooo00<0<`3o0?ooo`3oool02P3oool00`000000oooo0?ooo`3F0?ooo`00OP3oool00`3o
0000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo00T0oooo00<000000?ooo`3oool0eP3oool007l0
oooo00<0o`000?ooo`3oool0=`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@00000
0000M;l00`3oool0103ookl0M0000000000c0?l30000000307Boo`3oool0oooo00@0oooo00<00000
0?ooo`3oool0eP3oool00800oooo00<0o`000?ooo`3oool0=P3oool01P2LB7@0_ooo0?ooo`3ookl0
M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool00`2oM000001d03<0o`020?ooo`030=nLM02L
gol0oooo00D0oooo00<000000?ooo`3oool0eP3oool00800oooo00<0o`000?ooo`3oool0=@3oool0
0`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00/0oooo00<0okmd0000B00c0?l02@3oool0
0`000000oooo0?ooo`3F0?ooo`00P@3oool00`3o0000oooo0?ooo`0d0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool0303oool00`3ogi`0<`3o04RLg`080?ooo`@00000e@3oool00880
oooo00<0o`000?ooo`3oool0<`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00h0
oooo00<0<`3o04RLg`3oool01P3oool00`000000oooo0?ooo`3F0?ooo`00PP3oool00`3o0000oooo
0?ooo`0c0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`0c0?l0_ooo
0?ooo`050?ooo`030000003oool0oooo0=H0oooo00230?ooo`030?l0003oool0oooo0380oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0
<`3o07Boo`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00Q03oool00`3o0000oooo0?ooo`0b
0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000
B00c0?l01P3oool00`000000oooo0?ooo`3F0?ooo`00Q03oool00`3o0000oooo0?ooo`0b0?ooo`05
0?oo_`1d000000000000B02Lgol03@3oool01`3o_g@000000000000004P0W=oo0?ooo`0c0?l01@3o
ool00`000000oooo0?ooo`3F0?ooo`00Q@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo00<0oooo00<000000?ooo`3oool0eP3oool008H0oooo00<0o`000?ooo`3oool0B@3oool00`0c
0?l0oooo0?ooo`020?ooo`030000003oool0oooo0=H0oooo00260?ooo`030?l0003oool0oooo04T0
oooo00<0<`3o0?ooo`3oool00P3oool00`000000oooo0?ooo`3F0?ooo`00Q`3oool00`3o0000oooo
0?ooo`190?ooo`0503<0o`3oool0oooo0?ooo`000000f03oool008L0oooo00<0o`000?ooo`3oool0
BP3oool0100c0?l0oooo0?ooo`00003H0?ooo`00R03oool00`3o0000oooo0?ooo`190?ooo`0403<0
o`3oool0oooo00000=P0oooo00280?ooo`030?l0003oool0oooo04X0oooo00<0<`3o0?ooo`000000
f03oool008T0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0000000200000=H0oooo002:
0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0000003oool0e`3oool008X0oooo00<0o`000?oo
o`3oool0BP3oool00`0c0?l0oooo0?ooo`3F0?ooo`00R`3oool00`3o0000oooo0?ooo`190?ooo`03
03<0o`3oool0oooo0=H0oooo002;0?ooo`030?l0003oool0oooo04T0oooo00<0000003<0o`3oool0
eP3oool008`0oooo00<0o`000?ooo`3oool0B03oool00`000000<`3o0?ooo`3F0?ooo`00S03oool0
0`3o0000oooo0?ooo`180?ooo`030000003oool0<`3o0=H0oooo002=0?ooo`030?l0003oool0oooo
04L0oooo00<000000?ooo`0c0?l0eP3oool008d0oooo00<0o`000?ooo`3oool0A`3oool010000000
oooo0?ooo`0c0?oE0?ooo`00SP3oool00`3o0000oooo0?ooo`160?ooo`040000003oool0oooo03<0
omD0oooo002?0?ooo`030?l0003oool0oooo04D0oooo00D000000?ooo`3oool0oooo03<0o`3D0?oo
o`00S`3oool00`3o0000oooo0?ooo`150?ooo`050000003oool0oooo0?ooo`0c0?l0e03oool00900
oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`0303<0o`3oool0oooo0=40
oooo002@0?ooo`030?l0003oool0oooo04@0oooo0`0000020?ooo`0303<0o`3oool0oooo0=40oooo
002A0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool00`3oool00`0c0?l0oooo0?oo
o`3@0?ooo`00T@3oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo00<0<`3o
0?ooo`3oool0d03oool00980oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?oo
o`0303<0o`3oool0oooo0<l0oooo002C0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3o
ool01@3oool00`0c0?l0oooo0?ooo`3>0?ooo`00T`3oool00`3o0000oooo0?ooo`110?ooo`030000
003oool0oooo00D0oooo00<0<`3o0?ooo`3oool0cP3oool009@0oooo00<0o`000?ooo`3oool0@03o
ool00`000000oooo0?ooo`060?ooo`0303<0o`3oool0oooo0<d0oooo002D0?ooo`030?l0003oool0
oooo0400oooo00<000000?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`3=0?ooo`00U@3oool00`3o
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo00<0<`3o0?ooo`3oool0c03oool009D0
oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`070?ooo`0303<0o`3oool0oooo0<`0
oooo002F0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0203oool00`0c0?l0oooo
0?ooo`3;0?ooo`00U`3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo00P0oooo00<0
<`3o0?ooo`3oool0b`3oool009L0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`09
0?ooo`0303<0o`3oool0oooo0<X0oooo002H0?ooo`030?l0003oool0oooo03`0oooo0`0000090?oo
o`0303<0o`3oool0oooo0<X0oooo002H0?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3o
ool02P3oool00`0c0?l0oooo0?ooo`390?ooo`00V@3oool00`3o0000oooo0?ooo`0k0?ooo`030000
003oool0oooo00X0oooo00<0<`3o0?ooo`3oool0b@3oool009T0oooo00<0o`000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo0<P0oooo002J0?ooo`030?l0003oool0
oooo03X0oooo00<000000?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`380?ooo`00V`3oool00`3o
0000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo00<0<`3o0?ooo`3oool0a`3oool009/0
oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo0<H0
oooo002L0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool03@3oool00`0c0?l0oooo
0?ooo`360?ooo`00W03oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo00h0oooo00<0
<`3o0?ooo`3oool0a@3oool009d0oooo00<0o`000?ooo`3oool06@3oool01@3o_g@0000000000000
0000M;oo00D0oooo00<0_g@000000000M;l01P3oool01@3ogi`0B000000000000000M;oo00H0oooo
00<000000?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`350?ooo`00W@3oool00`3o0000oooo0?oo
o`0I0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`080?ooo`03
0;md001d_ol0oooo00H0oooo00<000000?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`340?ooo`00
WP3oool00`3o0000oooo0?ooo`0G0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0
3P3oool00`2oM000M;oo0?ooo`060?ooo`030000003oool0oooo0100oooo00<0<`3o0?ooo`3oool0
``3oool009l0oooo00<0o`000?ooo`3oool05P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00X0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`040?ooo`@000003`3o
ool00`0c0?l0oooo0?ooo`330?ooo`00W`3oool00`3o0000oooo0?ooo`0F0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;ooo`3oool0_g@007Boo`L0oooo
00<000000?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`320?ooo`00X03oool00`3o0000oooo0?oo
o`0E0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo0?oo
o`2oM000M;oo00L0oooo00<000000?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`320?ooo`00X03o
ool00`3o0000oooo0?ooo`0E0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303o
ool0102LB000B9cO0;md001d_ol70?ooo`030000003oool0oooo0180oooo00<0<`3o0?ooo`3oool0
`@3oool00:40oooo00<0o`000?ooo`3oool05@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`d0
oooo00@0omnL04P0B018B000M;oo1`3oool00`000000oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo
0<00oooo002Q0?ooo`030?l0003oool0oooo01D0oooo00D0oono07@000000000001809cOo`0?0?oo
o`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`300?oo
o`00XP3oool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0oooo01@0oooo00<0<`3o0?ooo`3o
ool0_`3oool00:<0oooo00<0o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`0D0?ooo`0303<0
o`3oool0oooo0;l0oooo002S0?ooo`030?l0003oool0oooo0340oooo00<000000?ooo`3oool05@3o
ool00`0c0?l0oooo0?ooo`2n0?ooo`00Y03oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0
oooo01D0oooo00<0<`3o0?ooo`3oool0_P3oool00:@0oooo00<0o`000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo0;d0oooo002U0?ooo`030?l0003oool0oooo02l0
oooo00<000000?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`2l0?ooo`00Y@3oool00`3o0000oooo
0?ooo`0_0?ooo`030000003oool0oooo01L0oooo00<0<`3o0?ooo`3oool0_03oool00:H0oooo00<0
o`000?ooo`3oool0;P3oool3000001P0oooo00<0<`3o0?ooo`3oool0^`3oool00:L0oooo00<0o`00
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo0;/0oooo002W0?oo
o`030?l0003oool0oooo02d0oooo00<000000?ooo`3oool06@3oool00`0c0?l0oooo0?ooo`2j0?oo
o`00Z03oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo01X0oooo00<0<`3o0?ooo`3o
ool0^@3oool00:T0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0J0?ooo`0303<0
o`3oool0oooo0;T0oooo002Y0?ooo`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool06`3o
ool00`0c0?l0oooo0?ooo`2h0?ooo`00ZP3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01/0oooo00<0<`3o0?ooo`3oool0^03oool00:X0oooo00<0o`000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo0;L0oooo002[0?ooo`030?l0003oool0oooo02T0
oooo00<000000?ooo`3oool07@3oool00`0c0?l0oooo0?ooo`2f0?ooo`00[03oool00`3o0000oooo
0?ooo`0X0?ooo`030000003oool0oooo01d0oooo00<0<`3o0?ooo`3oool0]P3oool00:`0oooo00<0
o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`0303<0o`3oool0oooo0;D0oooo002]
0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool07`3oool00`0c0?l0oooo0?ooo`2d
0?ooo`00[P3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo00<0<`3o0?oo
o`3oool0]03oool00:h0oooo00<0o`000?ooo`3oool09P3oool300000200oooo00<0<`3o0?ooo`3o
ool0/`3oool00:l0oooo00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`0303<0
o`3oool0oooo0;80oooo002_0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool08@3o
ool00`0c0?l0oooo0?ooo`2b0?ooo`00/03oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0
oooo0280oooo00<0<`3o0?ooo`3oool0/@3oool00;40oooo00<0o`000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`0303<0o`3oool0oooo0;00oooo002a0?ooo`030?l0003oool0oooo02<0
oooo00<000000?ooo`3oool08`3oool00`0c0?l0oooo0?ooo`2`0?ooo`00/P3oool00`3o0000oooo
0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<0<`3o0?ooo`3oool0[`3oool00;<0oooo00<0
o`000?ooo`3oool08@3oool00`000000oooo0?ooo`0T0?ooo`0303<0o`3oool0oooo0:l0oooo002c
0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool09@3oool00`0c0?l0oooo0?ooo`2^
0?ooo`00]03oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo02H0oooo00<0<`3o0?oo
o`3oool0[@3oool00;@0oooo00<0o`000?ooo`3oool0803oool00`000000oooo0?ooo`0V0?ooo`03
03<0o`3oool0oooo0:d0oooo002e0?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0
9`3oool00`0c0?l0oooo0?ooo`2/0?ooo`00]P3oool00`3o0000oooo0?ooo`0N0?ooo`030000003o
ool0oooo02P0oooo00<0<`3o0?ooo`3oool0Z`3oool00;H0oooo00<0o`000?ooo`3oool07P3oool3
000002P0oooo00<0<`3o0?ooo`3oool0Z`3oool00;L0oooo00<0o`000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0Y0?ooo`0303<0o`3oool0oooo0:X0oooo002h0?ooo`030?l0003oool0oooo01`0
oooo00<000000?ooo`3oool0:P3oool00`0c0?l0oooo0?ooo`2Y0?ooo`00^03oool00`3o0000oooo
0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00<0<`3o0?ooo`3oool0Z@3oool00;T0oooo00<0
o`000?ooo`3oool06`3oool00`000000oooo0?ooo`0[0?ooo`0303<0o`3oool0oooo0:P0oooo002j
0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0;03oool00`0c0?l0oooo0?ooo`2W
0?ooo`00^`3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo02`0oooo00<0<`3o0?oo
o`3oool0Y`3oool00;/0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0]0?ooo`03
03<0o`3oool0oooo0:H0oooo002l0?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0
;P3oool00`0c0?l0oooo0?ooo`2U0?ooo`00^@3oool01@3o_g@00000000000000000o`0000D0oooo
00<0_g@000000000M;l01P3oool01@2oM00000000000000007@0_ooo00H0oooo00<000000?ooo`3o
ool0;`3oool00`0c0?l0oooo0?ooo`2T0?ooo`00^@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0?l0
00@0oooo00<0_g@000000000M;l01@3oool01P3OW4P007Bo0?ooo`3oool0okmd001d_`H0oooo00<0
00000?ooo`3oool0;`3oool00`0c0?l0oooo0?ooo`2T0?ooo`00^03oool00`3o_g@007Bo0?ooo`02
0?ooo`030=nLB03o0000oooo00X0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M4RL0?ooo`05
0?ooo`030000003oool0oooo0300oooo00<0<`3o0?ooo`3oool0X`3oool00;P0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?l0000:0?ooo`070?noM000B4P0M01d0;ooo`3oool0gia8001d
_`060?ooo`@00000<03oool00`0c0?l0oooo0?ooo`2R0?ooo`00^03oool00`3OW4P0B9cO0?ooo`02
0?ooo`040?noM000M;l0oooo0?l000T0oooo00<0omnL04Q8W03o_g@00P0000000`00B9`0oooo0?oo
o`050?ooo`030000003oool0oooo0380oooo00<0<`3o0?ooo`3oool0X@3oool00;P0oooo00<0gia8
04RLg`3oool00P3oool0103o_g@007Bo0?ooo`3o00090?ooo`030?oo_`1d07@0_ooo00X0oooo00<0
00000?ooo`3oool0<`3oool00`0c0?l0oooo0?ooo`2P0?ooo`00^03oool00`3o_g@0B9cO0?ooo`02
0?ooo`050=nLB018W=l0oooo0?ooo`3o00002@3oool00`2oM000B9cO0?ooo`090?ooo`030000003o
ool0oooo03<0oooo00<0<`3o0?ooo`3oool0X03oool00;T0oooo00H0W4P007Boo`3oool0omnL04P0
M02oool30?ooo`030?l0003oool0oooo00H0oooo00<0oono07@00000M;l02@3oool00`000000oooo
0?ooo`0d0?ooo`0303<0o`3oool0oooo09l0oooo002i0?ooo`050?oo_`1d000000000000B02Lgol0
1@3oool00`3o0000oooo0?ooo`070?ooo`040;md0000000000000018W0H0oooo00<000000?ooo`3o
ool0=@3oool00`0c0?l0oooo0?ooo`2N0?ooo`00``3oool00`3o0000oooo0?ooo`0A0?ooo`030000
003oool0oooo03H0oooo00<0<`3o0?ooo`3oool0W@3oool00<@0oooo00<0o`000?ooo`3oool0403o
ool00`000000oooo0?ooo`0g0?ooo`0303<0o`3oool0oooo09`0oooo00350?ooo`030?l0003oool0
oooo00l0oooo00<000000?ooo`3oool0=`3oool00`0c0?l0oooo0?ooo`2L0?ooo`00aP3oool00`3o
0000oooo0?ooo`0>0?ooo`030000003oool0oooo03P0oooo00<0<`3o0?ooo`3oool0V`3oool00<H0
oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0i0?ooo`0303<0o`3oool0oooo09X0
oooo00370?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0>P3oool00`0c0?l0oooo
0?ooo`2I0?ooo`00b03oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo03/0oooo00<0
<`3o0?ooo`3oool0V03oool00<T0oooo00<0o`000?ooo`3oool02`3oool3000003/0oooo00<0<`3o
0?ooo`3oool0V03oool00<X0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0l0?oo
o`0303<0o`3oool0oooo09L0oooo003;0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3o
ool0?@3oool00`0c0?l0oooo0?ooo`2F0?ooo`00c03oool00`3o0000oooo0?ooo`080?ooo`030000
003oool0oooo03h0oooo00<0<`3o0?ooo`3oool0U@3oool00<d0oooo00<0o`000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0o0?ooo`0303<0o`3oool0oooo09@0oooo003>0?ooo`030?l0003oool0
oooo00H0oooo00<000000?ooo`3oool0@03oool00`0c0?l0oooo0?ooo`2C0?ooo`00c`3oool00`3o
0000oooo0?ooo`050?ooo`030000003oool0oooo0440oooo00<0<`3o0?ooo`3oool0TP3oool00<l0
oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`0303<0o`3oool0oooo0940
oooo003@0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool00`0c0?l0oooo
0?ooo`2@0?ooo`00d@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo04@0oooo00<0
<`3o0?ooo`3oool0S`3oool00=80oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`15
0?ooo`0303<0o`3oool0oooo08h0oooo003C0?ooo`050?l0003oool0oooo0?ooo`000000B03oool0
0`0c0?l0oooo0?ooo`2=0?ooo`00e03oool0103o0000oooo0?ooo`0000190?ooo`0303<0o`3oool0
oooo08`0oooo003E0?ooo`030?l0003oool0000000800000B03oool00`0c0?l0oooo0?ooo`2;0?oo
o`00eP3oool00`3o000000000?ooo`1:0?ooo`0303<0o`3oool0oooo08X0oooo003G0?ooo`030?l0
003oool0oooo04X0oooo00<0<`3o0?ooo`3oool0R@3oool00=L0oooo00<000000?l0003oool0B`3o
ool00`0c0?l0oooo0?ooo`280?ooo`00e`3oool010000000oooo0?l0003o001;0?ooo`0303<0o`3o
ool0oooo08L0oooo003G0?ooo`050000003oool0oooo0?ooo`3o0000B`3oool00`0c0?l0oooo0?oo
o`260?ooo`00e`3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo04T0oooo00<0<`3o
0?ooo`3oool0Q@3oool00=L0oooo00<000000?ooo`3oool00`3oool20?l004X0oooo0P0c0?n50?oo
o`00e`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3o
ool0PP3oool00=L0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`190?ooo`0303<0
o`3oool0oooo0840oooo003G0?ooo`030000003oool0oooo00L0oooo0P3o001:0?ooo`80<`3oP@3o
ool00=L0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo07h0oooo003G0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0B@3oool00`0c
0?l0oooo0?ooo`1m0?ooo`00e`3oool3000000/0oooo0P3o001:0?ooo`80<`3oO@3oool00=L0oooo
00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo07X0oooo
003G0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?oo
o`1i0?ooo`00e`3oool00`000000oooo0?ooo`0?0?ooo`80o`00BP3oool203<0ogT0oooo003G0?oo
o`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`1f0?oo
o`00e`3oool00`000000oooo0?ooo`0B0?ooo`80o`00BP3oool00`0c0?l0oooo0?ooo`1e0?ooo`00
e`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo04P0oooo0P0c0?me0?ooo`00e`3o
ool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0LP3o
ool00=L0oooo00<000000?ooo`3oool05P3oool20?l004X0oooo0P0c0?mb0?ooo`00^@3oool01@3o
_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool01@2oM000000000000000
000007Bo00L0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3o
ool0oooo06l0oooo002i0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000
001d_`040?ooo`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool01@3oool00`000000oooo
0?ooo`0I0?ooo`80o`00BP3oool203<0ofl0oooo002h0?ooo`030?noM000M;l0oooo0080oooo00<0
gia804RLg`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo00D0oooo00<0
00000?ooo`3oool06`3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0oooo06`0oooo002h
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3o_g@004RL0?ooo`02
0?ooo`0309a8B02Lgol0oooo00D0oooo1000000K0?ooo`80o`00BP3oool203<0of`0oooo002h0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P00000000000000000
B9cO00L0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`190?ooo`0303<0o`3oool0
oooo06T0oooo002h0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3o
okl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo00D0oooo00<000000?ooo`3oool07`3oool20?l0
04X0oooo0P0c0?mY0?ooo`00^03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0
oooo00<0okmd04RLg`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo0240
oooo0P3o001:0?ooo`80<`3oI`3oool00;T0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?oo
o`070?oOW01807@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`030000003oool0oooo02<0oooo0P3o
001:0?ooo`80<`3oI@3oool00;T0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?noM000
000000000000B02Lgol01`3oool00`000000oooo0?ooo`0U0?ooo`80o`00BP3oool203<0of<0oooo
003G0?ooo`030000003oool0oooo02L0oooo0P3o001:0?ooo`80<`3oH@3oool00=L0oooo00<00000
0?ooo`3oool0:@3oool20?l004X0oooo0P0c0?mO0?ooo`00e`3oool00`000000oooo0?ooo`0[0?oo
o`80o`00BP3oool203<0oed0oooo003G0?ooo`030000003oool0oooo02d0oooo0P3o001:0?ooo`80
<`3oF`3oool00=L0oooo00<000000?ooo`3oool0;`3oool30?l004T0oooo0P0c0?mI0?ooo`00e`3o
ool00`000000oooo0?ooo`0b0?ooo`<0o`00B03oool303<0oeH0oooo003G0?ooo`030000003oool0
oooo03D0oooo0P3o00190?ooo`<0<`3oD`3oool00=L0oooo0`00000g0?ooo`<0o`00B@3oool303<0
oe00oooo003G0?ooo`030000003oool0oooo03X0oooo0`3o00190?ooo`80<`3oCP3oool00=L0oooo
00<000000?ooo`3oool0?@3oool30?l004P0oooo0`0c0?m;0?ooo`00e`3oool00`000000oooo0?oo
o`100?ooo`<0o`00B03oool303<0odP0oooo003G0?ooo`030000003oool0oooo04<0oooo0`3o0018
0?ooo`<0<`3oA@3oool00=L0oooo00<000000?ooo`3oool0AP3oool40?l004L0oooo100c0?m10?oo
o`00e`3oool00`000000oooo0?ooo`1:0?ooo`<0o`00B03oool403<0ocd0oooo003G0?ooo`030000
003oool0oooo04d0oooo103o00180?ooo`@0<`3o>@3oool00=L0oooo00<000000?ooo`3oool0D@3o
ool40?l004P0oooo100c0?le0?ooo`00e`3oool00`000000oooo0?ooo`1E0?ooo`@0o`00B03oool4
03<0oc40oooo003G0?ooo`030000003oool0oooo05T0oooo103o00180?ooo`@0<`3o;@3oool00=L0
oooo00<000000?ooo`3oool0G@3oool40?l004P0oooo100c0?lY0?ooo`00e`3oool00`000000oooo
0?ooo`1Q0?ooo`@0o`00B03oool503<0ob@0oooo003G0?ooo`<00000I@3oool40?l004T0oooo1@0c
0?lO0?ooo`00e`3oool00`000000oooo0?ooo`1Y0?ooo`@0o`00BP3oool603<0oaT0oooo003G0?oo
o`030000003oool0oooo06d0oooo1P3o001:0?ooo`<0<`3o5P3oool00=L0oooo00<000000?ooo`3o
ool0L`3oool80?l004D0oooo00<0<`3o0?ooo`3oool04`3oool00=L0oooo00<000000?ooo`3oool0
N`3oool70?l005@0oooo003G0?ooo`030000003oool0oooo0880oooo1@3o001?0?ooo`00e`3oool0
0`000000oooo0?ooo`270?ooo`H0o`00B@3oool00=L0oooo00<000000?ooo`3oool0S@3oool60?l0
04<0oooo003G0?ooo`030000003oool0oooo09<0oooo203o000k0?ooo`00e`3oool00`000000oooo
0?ooo`2K0?ooo`d0o`00;P3oool00=L0oooo00<000000?ooo`3oool0Z03oool@0?l001h0oooo003G
0?ooo`030000003oool0oooo0;P0oooo2@3o000E0?ooo`00e`3oool00`000000oooo0?ooo`3F0?oo
o`00e`3oool300000=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.5213, -0.0729857, \
0.0384313, 0.00587898}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Zolotarev Integral Transformation",
    FontWeight->"Bold"],
  "\nThis integral was described initially by Zolotarev in 1986, but made \
useful for computation by John Nolan in 1997.  \"Numerical Calculation of \
Stable Densities and Distribution Functions,\"  Commun. Statist.-Stochastic \
Models,13(4),759-774 (1997).  We will start with the standardized complex \
integrand in the 1-parameterization and step through the derivation.  \[Zeta] \
is substituted for ",
  Cell[BoxData[
      \(\(-\[Beta]\)\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\)]],
  ".   This is not easy to follow: it would be a good idea to first read the \
above paper or Nolan's textbook."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ig1 = 
      2  FullSimplify[
            Exp[\(-I\)\ u\ x\ ] 
                CF1[u, {\[Alpha], \[Beta], \[Gamma], \[Delta]}]/\((2  
                      Pi)\) /. {\[Gamma] \[Rule] 1, \[Delta] \[Rule] \ 0}, 
            u > 0] /. \[Beta]\ Tan[
              Pi\ \[Alpha]/2] \[Rule] \(-\[Zeta]\)\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ u\ x + u\^\[Alpha]\ \((\(-1\) - \
\[ImaginaryI]\ \[Zeta])\)\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[z_] = \ 
      z^\[Alpha]\  + \ I \((x\ z\  + \ \[Zeta]\ z^\[Alpha])\)\)], "Input"],

Cell[BoxData[
    \(z\^\[Alpha] + \[ImaginaryI]\ \((x\ z + 
            z\^\[Alpha]\ \[Zeta])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Exp[\(-h[u]\)]/Pi\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-u\^\[Alpha]\) - \[ImaginaryI]\ \((u\ x + u\^\
\[Alpha]\ \[Zeta])\)\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[% \[Equal] ig1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\( \
\[ExponentialE]\^\(-\(h(z)\)\)\/\[Pi]\) \[DifferentialD]z\)]],
  " is a new form for the PDF.  Take the function h and substitute ",
  Cell[BoxData[
      \(r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  " for u."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[r\ Exp[I\ \[Theta]]]\)], "Input"],

Cell[BoxData[
    \(\((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ r)\)\^\[Alpha] + \
\[ImaginaryI]\ \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ r\ x + \((\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ r)\)\^\[Alpha]\ \[Zeta])\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PowerExpand[%]\), "\n", 
    \(Simplify[%]\), "\n", 
    \(ExpToTrig[%]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ \[Theta]\)\ r\^\[Alpha] + \
\[ImaginaryI]\ \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ r\ x + \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ \[Theta]\)\ r\^\[Alpha]\ \[Zeta])\
\)\)], "Output"],

Cell[BoxData[
    \(\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ r\ x + \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ \[Theta]\)\ r\^\[Alpha]\ \((1 + \
\[ImaginaryI]\ \[Zeta])\)\)], "Output"],

Cell[BoxData[
    \(\[ImaginaryI]\ r\ x\ Cos[\[Theta]] + 
      r\^\[Alpha]\ Cos[\[Alpha]\ \[Theta]] + \[ImaginaryI]\ r\^\[Alpha]\ \
\[Zeta]\ Cos[\[Alpha]\ \[Theta]] - 
      r\ x\ Sin[\[Theta]] + \[ImaginaryI]\ r\^\[Alpha]\ Sin[\[Alpha]\ \
\[Theta]] - r\^\[Alpha]\ \[Zeta]\ Sin[\[Alpha]\ \[Theta]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " Define ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]0 = \(\(tan\^\(-1\)\)(\[Beta]\ \(tan(\(\[Pi]\
\ \[Alpha]\)\/2)\))\)\/\[Alpha]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`then\ \[Zeta]\  = \ \(-\(Sin[\[Alpha]\ \
\[Theta]0]\/Cos[\[Alpha]\ \[Theta]0]\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h1 = % /. \[Zeta] \[Rule] \(-Sin[\[Alpha]\ \[Theta]0]\)/
            Cos[\[Alpha]\ \[Theta]0]\)], "Input"],

Cell[BoxData[
    \(\[ImaginaryI]\ r\ x\ Cos[\[Theta]] + 
      r\^\[Alpha]\ Cos[\[Alpha]\ \[Theta]] - 
      r\ x\ Sin[\[Theta]] + \[ImaginaryI]\ r\^\[Alpha]\ Sin[\[Alpha]\ \
\[Theta]] - \[ImaginaryI]\ r\^\[Alpha]\ Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\
\ \[Theta]0] + 
      r\^\[Alpha]\ Sin[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0]\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "The imaginary part: ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \((r\ x\ Cos[\[Theta]] + \ 
            r\^\[Alpha]\ Sin[\[Alpha]\ \[Theta]] - \ 
            r\^\[Alpha]\ Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\
\)]],
  " equals zero when,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\ 
      r\ x\ Cos[\[Theta]] + \ r\^\[Alpha]\ Sin[\[Alpha]\ \[Theta]] - \ 
          r\^\[Alpha]\ Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0] \
\[Equal] 0, r]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({{r \[Rule] \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - Cos[\
\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
 Substituting back to the remaining non-zero real part of the function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h2 = 
      r\^\[Alpha]\ Cos[\[Alpha]\ \[Theta]] - r\ x\ Sin[\[Theta]] + 
          r\^\[Alpha]\ Sin[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0] /. 
        r \[Rule] \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - Cos[\
\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\)\)], "Input"],

Cell[BoxData[
    \(\(-x\)\ Sin[\[Theta]]\ \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \
\[Theta]] - Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \
\[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\) + 
      Cos[\[Alpha]\ \[Theta]]\ \((\((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \
\[Theta]] - Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \
\[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\))\)\^\[Alpha] + 
      Sin[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0]\ \((\((\(-\(\(Sec[\
\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\
\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\))\)\^\[Alpha]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h3 = \ FullSimplify[h2]\)], "Input"],

Cell[BoxData[
    \(\(-x\)\ Sin[\[Theta]]\ \((\(-\(\(Sec[\[Theta]]\ Sec[\[Alpha]\ \
\[Theta]0]\ Sin[\[Alpha]\ \((\[Theta] - \[Theta]0)\)]\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\) + 
      Cos[\[Alpha]\ \((\[Theta] - \[Theta]0)\)]\ Sec[\[Alpha]\ \[Theta]0]\ \
\((\((\(-\(\(Sec[\[Theta]]\ Sec[\[Alpha]\ \[Theta]0]\ Sin[\[Alpha]\ \((\
\[Theta] - \[Theta]0)\)]\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\))\)\^\[Alpha]\)], "Output"]
}, Open  ]],

Cell["\<\
Now find the derivative of the real part of r Exp[I \[Theta]] to get \
\[DifferentialD]z.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexExpand[r\ Exp[I\ \[Theta]], 
      TargetFunctions \[Rule] {\ Re, \ Im}]\)], "Input"],

Cell[BoxData[
    \(r\ Cos[\[Theta]] + \[ImaginaryI]\ r\ Sin[\[Theta]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(r\ Cos[\[Theta]] /. 
      r \[Rule] \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - Cos[\
\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\)\)], "Input"],

Cell[BoxData[
    \(Cos[\[Theta]]\ \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - \
Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dz = \ 
      D[Cos[\[Theta]]\ \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - \
Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\), \[Theta]]\)], "Input"],

Cell[BoxData[
    \(\(-Sin[\[Theta]]\)\ \((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] \
- Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 \
- \[Alpha]\)\) + \(\(1\/\(1 - \[Alpha]\)\)\((Cos[\[Theta]]\ \((\(-\(\(Sec[\
\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\
\ \[Theta]0])\)\)\/x\)\))\)\^\(\(-1\) + 1\/\(1 - \[Alpha]\)\)\ \((\(-\(\(Sec[\
\[Theta]]\ Tan[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - 
                          Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \
\[Theta]0])\)\)\/x\)\) - \(Sec[\[Theta]]\ \((\[Alpha]\ Cos[\[Alpha]\ \
\[Theta]] + \[Alpha]\ Sin[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \
\[Theta]0])\)\)\/x)\))\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dz1\  = Together[dz]\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((\(-\(\(Sec[\[Theta]]\ \((Sin[\[Alpha]\ \[Theta]] - Cos[\
\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\)\ \((\[Alpha]\ Cos[\[Theta]]\ Cos[\[Alpha]\ \[Theta]] + \[Alpha]\ \
Sin[\[Theta]]\ Sin[\[Alpha]\ \[Theta]] - \[Alpha]\ Cos[\[Alpha]\ \[Theta]]\ \
Sin[\[Theta]]\ Tan[\[Alpha]\ \[Theta]0] + \[Alpha]\ Cos[\[Theta]]\ Sin[\
\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \[Theta]0])\))\)/\((\((\(-1\) + \
\[Alpha])\)\ \((Sin[\[Alpha]\ \[Theta]] - 
                Cos[\[Alpha]\ \[Theta]]\ Tan[\[Alpha]\ \
\[Theta]0])\))\)\)\)\)], "Output"]
}, Open  ]],

Cell["The new integrand for the PDF becomes.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newintegrand = FullSimplify[1/Pi\ Exp[\(-h3\)]\ dz1]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(1\/\(\[Pi]\ \((\(-1\) + \[Alpha])\)\)\)\((\[ExponentialE]\^\(x\ \
Sin[\[Theta]]\ \((\(-\(\(Sec[\[Theta]]\ Sec[\[Alpha]\ \[Theta]0]\ \
Sin[\[Alpha]\ \((\[Theta] - \[Theta]0)\)]\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\) - Cos[\[Alpha]\ \((\[Theta] - \[Theta]0)\)]\ Sec[\[Alpha]\ \
\[Theta]0]\ \((\((\(-\(\(Sec[\[Theta]]\ Sec[\[Alpha]\ \[Theta]0]\ \
Sin[\[Alpha]\ \((\[Theta] - \[Theta]0)\)]\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\))\)\^\[Alpha]\)\ \[Alpha]\ Cos[\[Theta] - \[Alpha]\ \[Theta] + \
\[Alpha]\ \[Theta]0]\ Csc[\[Alpha]\ \((\[Theta] - \[Theta]0)\)]\ \
\((\(-\(\(Sec[\[Theta]]\ Sec[\[Alpha]\ \[Theta]0]\ Sin[\[Alpha]\ \((\[Theta] \
- \[Theta]0)\)]\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\))\)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
The following substitutions  rearrange the order and the subsequent integrand \
is integrated from {\[Theta] ,  -\[Theta]0,  \[Pi]/2}.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newintegrand1 = 
      newintegrand /. {\[Theta]0 -> 
            ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha], \[Theta] \
\[Rule] \(-\[Theta]\)}\)], "Input"],

Cell[BoxData[
    \(\(-\(\(1\/\(\[Pi]\ \((\(-1\) + \
\[Alpha])\)\)\)\((\[ExponentialE]\^\(\(-x\)\ Sin[\[Theta]]\ \((\(-\(\(Sec[\
\[Theta]]\ Sin[\[Alpha]\ \((\(-\[Theta]\) - ArcTan[\[Beta]\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]]\/\[Alpha])\)]\ \@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]\^2\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\) - Cos[\[Alpha]\ \
\((\(-\[Theta]\) - ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\
\ \((\((\(-\(\(Sec[\[Theta]]\ Sin[\[Alpha]\ \((\(-\[Theta]\) - ArcTan[\[Beta]\
\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\ \@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\
\ \[Alpha]\)\/2]\^2\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\))\)\^\[Alpha]\ \
\@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\^2\)\)\ \[Alpha]\ \
Cos[\[Theta] - \[Alpha]\ \[Theta] - 
              ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]]\ Csc[\[Alpha]\ \
\((\(-\[Theta]\) - 
                  ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\ \
\((\(-\(\(Sec[\[Theta]]\ Sin[\[Alpha]\ \((\(-\[Theta]\) - ArcTan[\[Beta]\ \
Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\ \@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]\^2\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\))\)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
The formula for the PDF when \[Alpha] \[NotEqual] 1, in the \
1-parameterization becomes:\
\>", "Text"],

Cell[BoxData[
    \(\(pdfz1[x_, \[Alpha]_, \[Beta]_] := \ 
        NIntegrate[\(-\(1\/\(\[Pi]\ \((\(-1\) + \[Alpha])\)\)\)\) \((\
\[ExponentialE]\^\(\(-x\)\ Sin[\[Theta]]\ \((\(-\(\(Sec[\[Theta]]\ Sin[\
\[Alpha]\ \((\(-\[Theta]\) - ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\
\[Alpha])\)]\ \@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]\^2\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\) - Cos[\[Alpha]\ \
\((\(-\[Theta]\) - ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\
\ \((\((\(-\(\(Sec[\[Theta]]\ Sin[\[Alpha]\ \((\(-\[Theta]\) - ArcTan[\[Beta]\
\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\ \@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\
\ \[Alpha]\)\/2]\^2\)\)\/x\)\))\)\^\(1\/\(1 - \[Alpha]\)\))\)\^\[Alpha]\ \
\@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\^2\)\)\ \[Alpha]\ \
Cos[\[Theta] - \[Alpha]\ \[Theta] - 
                    ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]]\ Csc[\
\[Alpha]\ \((\(-\[Theta]\) - 
                        ArcTan[\[Beta]\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]]\/\[Alpha])\)]\ \((\(-\(\(Sec[\[Theta]]\ Sin[\[Alpha]\ \((\(-\
\[Theta]\) - ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha])\)]\ \
\@\(1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\^2\)\)\/x\)\))\)\^\(1\/\(1 - \
\[Alpha]\)\))\), \ {\[Theta], \(-\(ArcTan[\[Beta]\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]]\/\[Alpha]\)\), Pi/2}];\)\)], "Input"],

Cell["\<\
The formula used in the package SMath.m is the 0-parameterization similarly \
derived for the PDF and CDF with separate functions for the condition \
\[Alpha] = 1.  The above formula is valid only for x>0.  x < 0 is obtained by \
reflection.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{pdfz1[Abs[x], \ 1.3, If[x < 0, \(-1\), 1] 1], 
          SPDF[x, {1.3, 1}, 1]}, {x, \(-5\), 5}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 2.11636 [
[.11905 .00222 -6 -9 ]
[.11905 .00222 6 0 ]
[.30952 .00222 -6 -9 ]
[.30952 .00222 6 0 ]
[.69048 .00222 -3 -9 ]
[.69048 .00222 3 0 ]
[.88095 .00222 -3 -9 ]
[.88095 .00222 3 0 ]
[.4875 .12053 -24 -4.5 ]
[.4875 .12053 0 4.5 ]
[.4875 .22635 -18 -4.5 ]
[.4875 .22635 0 4.5 ]
[.4875 .33217 -24 -4.5 ]
[.4875 .33217 0 4.5 ]
[.4875 .43799 -18 -4.5 ]
[.4875 .43799 0 4.5 ]
[.4875 .54381 -24 -4.5 ]
[.4875 .54381 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12053 m
.50625 .12053 L
s
[(0.05)] .4875 .12053 1 0 Mshowa
.5 .22635 m
.50625 .22635 L
s
[(0.1)] .4875 .22635 1 0 Mshowa
.5 .33217 m
.50625 .33217 L
s
[(0.15)] .4875 .33217 1 0 Mshowa
.5 .43799 m
.50625 .43799 L
s
[(0.2)] .4875 .43799 1 0 Mshowa
.5 .54381 m
.50625 .54381 L
s
[(0.25)] .4875 .54381 1 0 Mshowa
.125 Mabswid
.5 .03588 m
.50375 .03588 L
s
.5 .05704 m
.50375 .05704 L
s
.5 .07821 m
.50375 .07821 L
s
.5 .09937 m
.50375 .09937 L
s
.5 .1417 m
.50375 .1417 L
s
.5 .16286 m
.50375 .16286 L
s
.5 .18402 m
.50375 .18402 L
s
.5 .20519 m
.50375 .20519 L
s
.5 .24751 m
.50375 .24751 L
s
.5 .26868 m
.50375 .26868 L
s
.5 .28984 m
.50375 .28984 L
s
.5 .31101 m
.50375 .31101 L
s
.5 .35333 m
.50375 .35333 L
s
.5 .3745 m
.50375 .3745 L
s
.5 .39566 m
.50375 .39566 L
s
.5 .41682 m
.50375 .41682 L
s
.5 .45915 m
.50375 .45915 L
s
.5 .48031 m
.50375 .48031 L
s
.5 .50148 m
.50375 .50148 L
s
.5 .52264 m
.50375 .52264 L
s
.5 .56497 m
.50375 .56497 L
s
.5 .58613 m
.50375 .58613 L
s
.5 .6073 m
.50375 .6073 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01579 m
.02846 .01616 L
.03279 .0166 L
.03754 .01722 L
.04262 .01807 L
.04795 .01922 L
.053 .02061 L
.06244 .02417 L
.06754 .02674 L
.07295 .03006 L
.08265 .03786 L
.09308 .04943 L
.10458 .06675 L
.11472 .08655 L
.12399 .10868 L
.14487 .17262 L
.18458 .33376 L
.22277 .48768 L
.24244 .54655 L
.25344 .57071 L
.26341 .58681 L
.26829 .59266 L
.27344 .59742 L
.27784 .60036 L
.28033 .60157 L
.28266 .60241 L
.28395 .60276 L
.28464 .60291 L
.28536 .60304 L
.28599 .60314 L
.28669 .60322 L
.28792 .60331 L
.28911 .60332 L
.29039 .60326 L
.2916 .60313 L
.29271 .60295 L
.29401 .60267 L
.29522 .60233 L
.29796 .60134 L
.30063 .60005 L
.30348 .59834 L
.30881 .59427 L
.31372 .58957 L
.32483 .57591 L
.34498 .54263 L
.38438 .46013 L
.42227 .37743 L
.46261 .29908 L
.50143 .23743 L
.54271 .18637 L
Mistroke
.58247 .14903 L
.62072 .12172 L
.66141 .09966 L
.70059 .08352 L
.74223 .0704 L
.78235 .06067 L
.82095 .05331 L
.86201 .0471 L
.90155 .04233 L
.93957 .03859 L
.97619 .03562 L
Mfstroke
.02381 .01579 m
.02846 .01616 L
.03279 .0166 L
.03754 .01722 L
.04262 .01807 L
.04795 .01922 L
.053 .02061 L
.06244 .02417 L
.06754 .02674 L
.07295 .03006 L
.08265 .03786 L
.09308 .04943 L
.10458 .06675 L
.11472 .08655 L
.12399 .10868 L
.14487 .17262 L
.18458 .33376 L
.22277 .48768 L
.24244 .54655 L
.25344 .57071 L
.26341 .58681 L
.26829 .59266 L
.27344 .59742 L
.27784 .60036 L
.28033 .60157 L
.28266 .60241 L
.28395 .60276 L
.28464 .60291 L
.28536 .60304 L
.28599 .60314 L
.28669 .60322 L
.28792 .60331 L
.28911 .60332 L
.29039 .60326 L
.2916 .60313 L
.29271 .60295 L
.29401 .60267 L
.29522 .60233 L
.29796 .60134 L
.30063 .60005 L
.30348 .59834 L
.30881 .59427 L
.31372 .58957 L
.32483 .57591 L
.34498 .54263 L
.38438 .46013 L
.42227 .37743 L
.46261 .29908 L
.50143 .23743 L
.54271 .18637 L
Mistroke
.58247 .14903 L
.62072 .12172 L
.66141 .09966 L
.70059 .08352 L
.74223 .0704 L
.78235 .06067 L
.82095 .05331 L
.86201 .0471 L
.90155 .04233 L
.93957 .03859 L
.97619 .03562 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00?P3oool01@3ogi`0B000000000000000M;oo04H0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`2>0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0A`3oool0
1@3ogi`0B000000000000000M;oo03T0oooo00100?ooo`030;md001d_ol0oooo04L0oooo00<0_g@0
0000M02oool00P3oool00`3OW7@0W=oo0?ooo`2@0?ooo`030;md000007@0_ooo0080oooo00<0giad
09cOo`3oool0BP3oool00`2oM000M;oo0?ooo`0i0?ooo`00@03oool00`2oM000M;oo0?ooo`180?oo
o`030?noM00004P0W=oo09D0oooo00<0okmd0000B02Lgol0CP3oool00`2oM000M;oo0?ooo`0i0?oo
o`00?03oool00`3OW4P00000000000030000000307Boo`3oool0oooo04L0oooo00<0omnL04P00018
W=l0U@3oool00`3ogi`0B00004RLg`190?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3o
ool0=`3oool003<0oooo00<0W4P00000000000000`0000002@00B9`0oooo0?ooo`3o_g@0001d0;oo
o`3oool0_g@007Boo`0o0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0103oool0
0`2LB000B9cO0?ooo`2E0?ooo`0309a80018W=l0oooo04L0oooo00H0okmd0000M02oool0oooo0;md
001d_olj0?ooo`00?@3oool01@3OW4P007Bo0?ooo`2oM000M;oo04d0oooo00<0W4Qd0;ooo`3oool0
U@3oool00`2LB7@0_ooo0?ooo`170?ooo`050=nLB000M;l0oooo0;md001d_ol0>P3oool003h0oooo
00@0W4P004RLg`2oM000M;ooB03oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo0900
oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`180?ooo`0409a80018W=l0_g@007Bo
ocX0oooo000n0?ooo`040?oOW01804P0B4P007BoodP0oooo00L0okmd0000M02oool0oooo0?noM000
04P0W=oo0940oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo04T0oooo00@0omnL04P0B018
B000M;oo>P3oool003l0oooo00<0okmd0000001d_ol0B@3oool01@3o_g@000000000000004P0W=oo
09<0oooo00D0okmd000000000000001809cOo`1;0?ooo`030?noM0000000M;oo03X0oooo003o0?oo
ok40oooo003o0?oook40oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo
000:0?ooool00000W000000;0?ooo`00503oool7000000`0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`040?ooo`@00000203oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo000O0?ooo`<000006@3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo03X0oooo000R0?ooo`<00000/P3oool00`000000oooo
0?ooo`3F0?ooo`009@3oool200000;00oooo00<000000?ooo`3oool0eP3oool002L0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`3F0?ooo`00:03oool00`000000oooo0?ooo`2/0?oo
o`030000003oool0oooo0=H0oooo000Y0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool0eP3oool002X0oooo0P00002[0?ooo`<00000^@3oool8000001D0oooo000/0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0[P3oool;000001d0oooo000]0?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool0YP3oool8000002P0oooo000^0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool0WP3oool800000300oooo000_0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0UP3oool8000003P0oooo000`0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0SP3oool800000400oooo000a0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0QP3oool8000004P0oooo000a0?ooo`030000003oool0oooo0:<0oooo00<00000
0?ooo`3oool0O`3oool700000500oooo000b0?ooo`030000003oool0oooo0:80oooo00<000000?oo
o`3oool0NP3oool5000005L0oooo000b0?ooo`030000003oool0oooo0:80oooo0`00001d0?ooo`H0
0000G03oool003<0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`1_0?ooo`D00000
HP3oool003@0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1[0?ooo`@00000I`3o
ool003@0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1W0?ooo`@00000J`3oool0
03D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1S0?ooo`@00000K`3oool003D0
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1O0?ooo`@00000L`3oool003H0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`1K0?ooo`@00000M`3oool003H0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`1H0?ooo`<00000N`3oool003L0oooo00<00000
0?ooo`3oool0W@3oool3000005D0oooo0`00001n0?ooo`00=`3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo0540oooo100000210?ooo`00>03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo04h0oooo0`0000250?ooo`00>03oool00`000000oooo0?ooo`2L0?ooo`030000
003oool0oooo04`0oooo0P0000280?ooo`00>@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo04X0oooo0P00002:0?ooo`00>@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo04P0oooo0P00002<0?ooo`00>P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
04D0oooo0`00002>0?ooo`00>P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo04<0
oooo0P00002A0?ooo`00>`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0440oooo
0P00002C0?ooo`00>`3oool00`000000oooo0?ooo`2I0?ooo`<00000?`3oool2000009D0oooo000l
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0?@3oool2000009L0oooo000l0?oo
o`030000003oool0oooo09P0oooo00<000000?ooo`3oool0>`3oool2000009T0oooo000m0?ooo`03
0000003oool0oooo09L0oooo00<000000?ooo`3oool0>@3oool2000009/0oooo000m0?ooo`030000
003oool0oooo09L0oooo00<000000?ooo`3oool0=`3oool2000009d0oooo000m0?ooo`030000003o
ool0oooo0700oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo
00D0okmd000000000000000007Boo`040?ooo`050;md0000000000000000001d_ol01`3oool00`00
0000oooo0?ooo`0e0?ooo`800000W`3oool003h0oooo00<000000?ooo`3oool0K`3oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01@3oool01P2LB7@0_ooo0?ooo`3o
okl0M01d0;ooo`80oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00H0oooo00<000000?oo
o`3oool0<`3oool200000:40oooo000n0?ooo`030000003oool0oooo06h0oooo00<0okmd001d_`3o
ool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3o
ool01P3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0oooo0340oooo0P00002S0?ooo`00
?P3oool00`000000oooo0?ooo`1^0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
2P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00<0okmd001d_`3oool0
1@3oool00`000000oooo0?ooo`0_0?ooo`800000Y@3oool003l0oooo00<000000?ooo`3oool0K@3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`060?ooo`0309a8001d_ol0oooo00D0oooo1000000]0?ooo`030000003o
ool0oooo0:D0oooo000o0?ooo`030000003oool0oooo06d0oooo00<0gia804RLg`3oool00P3oool0
0`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0?oo
_`1d00030000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0;03oool200000:P0oooo
000o0?ooo`030000003oool0oooo06d0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?oo
o`0:0?ooo`030?noM018W=l0oooo0080oooo00L0gia804RLg`3oool0oooo0?oo_`1d07@0_ooo00X0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2X0?ooo`00?`3oool00`000000oooo
0?ooo`1^0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool01P2LB000M;oo0?ooo`3ogi`0
B01d0;ooo`80oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0:T0oooo00100?ooo`030000003oool0oooo06d0oooo00D0oono07@000000000001809cO
o`0=0?ooo`050?oo_`1d000000000000B02Lgol00`3oool00`3ookl0M00000000002000000030000
M02oool0oooo00D0oooo00<000000?ooo`3oool0:03oool200000:`0oooo00100?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2/0?ooo`00@03oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0[@3oool0
0440oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0T0?ooo`800000/03oool00440
oooo00<000000?ooo`3oool0T`3oool3000002<0oooo00<000000?ooo`3oool0/03oool00440oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;40oooo
00120?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0803oool200000;@0oooo0012
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2d
0?ooo`00@P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0]@3oool004<0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0;H0oooo00130?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2g0?ooo`00@`3oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0^03oool004<0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0;T0oooo00140?ooo`030000003oool0oooo
0900oooo0`00000I0?ooo`030000003oool0oooo0;X0oooo00140?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2k0?ooo`00A03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0_03oool004D0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0;d0oooo0015
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2n
0?ooo`00A@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0_`3oool004H0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0<00oooo00160?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`310?ooo`00AP3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0`P3oool004H0oooo00<000000?ooo`3oool0SP3oool3
00000100oooo00<000000?ooo`3oool0``3oool004L0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0<@0oooo00170?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`350?ooo`00A`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0aP3oool004L0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0<H0oooo0018
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`37
0?ooo`00B03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0b03oool004P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0<T0oooo00180?ooo`030000003oool0oooo08`0oooo0`0000090?ooo`030000
003oool0oooo0<X0oooo00190?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3:0?ooo`00B@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0b`3oool004T0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0<`0oooo00190?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3=0?ooo`00BP3oool00`000000oooo
0?ooo`1/0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`03
0?noM0000000000000<0000000<007Bo0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0<h0oooo001:0?ooo`030000003oool0oooo06`0oooo00H0W4Qd0;ooo`3oool0
oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0<l0oooo001:0?ooo`030000003oool0oooo06/0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3?0?ooo`00BP3oool00`000000oooo
0?ooo`1[0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0d03oool004/0oooo00<0
00000?ooo`3oool0JP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0
W4Q809cOo`3oool01`3oool4000000030?ooo`000000oooo0=80oooo001;0?ooo`030000003oool0
oooo06X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00L0oooo00D000000?ooo`3oool0oooo0000003D0?ooo`00B`3oool00`000000oooo0?ooo`1Z
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`07
0?ooo`040000003oool0oooo00000=D0oooo001;0?ooo`030000003oool0oooo06/0oooo00H0W4P0
07Boo`3oool0omnL04P0M02oool;0?ooo`050=nLB000000004RL09a8B02Lgol0203oool010000000
oooo0?ooo`00003E0?ooo`00C03oool00`000000oooo0?ooo`1Z0?ooo`050?oo_`1d000000000000
B02Lgol03P3oool00`3OW4P0001809cOo`080?ooo`030000003oool000000=H0oooo001<0?ooo`03
0000003oool0oooo08P0oooo0P00003G0?ooo`00C03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo0=H0oooo001<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0eP3o
ool004d0oooo00<000000?ooo`3oool0QP3oool200000=P0oooo001=0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`0000000P00003F0?ooo`00C@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool000000=P0oooo001=0?ooo`030000003oool0oooo08@0oooo00@000000?ooo`3oool0
0000f03oool004h0oooo00<000000?ooo`3oool0P`3oool010000000oooo0?ooo`00003H0?ooo`00
CP3oool00`000000oooo0?ooo`220?ooo`050000003oool0oooo0?ooo`000000f03oool004h0oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=H0oooo
001?0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3F0?ooo`00C`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0eP3oool004l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`040?oo
o`<00000eP3oool004l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0=H0oooo001@0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3F0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0eP3oool00500oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0=H0oooo001@0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3F0?ooo`00D@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0eP3oool00540oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=H0oooo
001A0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3F0?ooo`00D@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00T0oooo0`00003F
0?ooo`00DP3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0eP3oool00580oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0=H0oooo001B0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`3F0?ooo`00DP3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0eP3oool005<0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=H0oooo001C0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3F0?ooo`00D`3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0eP3oool005<0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=H0oooo
001D0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool03`3oool300000=H0oooo001D
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3F
0?ooo`00E03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0eP3oool005@0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0=H0oooo001E0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`3F0?ooo`00E@3oool00`000000oooo0?ooo`1H0?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM0000000000000<00000
00D007Bo0?ooo`3oool0oooo0;md00030000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3o
ool0eP3oool005D0oooo00<000000?ooo`3oool0F03oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`@0oooo00<0_g@000000000M;l01@3oool010000000oooo09a8B02Lgol40?ooo`070;md0000M;l0
oooo0?ooo`3ogi`0B00007Boo`060?ooo`030000003oool0oooo0=H0oooo001E0?ooo`030000003o
ool0oooo05L0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`040000003o
ool0W4Q809cOo`T0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00EP3o
ool00`000000oooo0?ooo`1F0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3o
ool01@000000oooo0?ooo`2LB4P0W=oo00T0oooo00<0okmd001d_`3oool01@3oool400000=D0oooo
001F0?ooo`030000003oool0oooo05H0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0:0?ooo`050000003oool0oooo09a8B02Lgol02@3oool00`2LB000M;oo0?ooo`050?ooo`030000
003oool0oooo0=H0oooo001F0?ooo`030000003oool0oooo05H0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`090?ooo`060000003oool0oooo0?ooo`2LB4P0W=oo103oool00`3ookl0
M000000000020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0eP3oool005H0oooo
00<000000?ooo`3oool0EP3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0_ooo00X0oooo
00<000000?ooo`3oool0eP3oool005L0oooo00<000000?ooo`3oool0EP3oool01P2LB000M;oo0?oo
o`3ogi`0B01d0;ooo`T0oooo00L000000?ooo`3OW4P000000018W02LB4P0W=oo00@0oooo00<0oono
07@0M02oool02P3oool00`000000oooo0?ooo`3F0?ooo`00E`3oool00`000000oooo0?ooo`1F0?oo
o`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`020?ooo`030=nLB00004P0
W=oo00@0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000003oool0
oooo0=H0oooo001G0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`3F0?ooo`00E`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0eP3oool005P0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0=H0oooo001H0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0603oool300000=H0oooo001H0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`3F0?ooo`00F03oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0eP3oool005T0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0=H0oooo001I0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3F0?ooo`00F@3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0eP3o
ool005T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0=H0oooo001J0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`3F0?ooo`00FP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0eP3oool005X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0L0?ooo`<00000eP3oool005X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0=H0oooo001K0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`3F0?ooo`00F`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0eP3oool005/0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0=H0oooo001K0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3F0?ooo`00F`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0eP3o
ool005`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0=H0oooo001L0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0803oool30000
0=H0oooo001L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`3F0?ooo`00G03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0eP3oool005d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0=H0oooo001M0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`3F0?ooo`00G@3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0eP3oool005d0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0=H0oooo001N0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3F0?ooo`00GP3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0eP3o
ool005h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0T0?ooo`<00000eP3oool0
05h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0=H0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`3F0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0eP3oool005l0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0=H0oooo001O0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0203oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l00`3o
ool00`3ookl0M000000000040000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0eP3o
ool00600oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`090?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`030;md000007@0_ooo0080oooo
00<0giad09cOo`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00H03oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00P0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0;0?ooo`030?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0eP3oool00600oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`090?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool0303oool00`3ogi`0B00004RLg`080?ooo`030000003oool0oooo0=H0oooo001P0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3oool01P3oool400000=D0oooo001P0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00
H@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00X0oooo00<0okmd04RLg`3oool0
0P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool0
1@3oool00`000000oooo0?ooo`3F0?ooo`00H@3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo00/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?oo
o`3o_g@0001809cOo`060?ooo`030000003oool0oooo0=H0oooo001Q0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0303oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd
000000000000001809cOo`070?ooo`030000003oool0oooo0=H0oooo001Q0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3F0?ooo`00HP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0eP3oool00680
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0=H0
oooo001R0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0;03oool300000=H0oooo
001R0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`3F0?ooo`00H`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0eP3oool006<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0=H0oooo001S0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`3F0?ooo`00H`3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0eP3oool006@0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=H0oooo001T0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3F0?ooo`00I03oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0eP3oool006@0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0`0?ooo`<00000eP3oool006D0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0=H0oooo
001U0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`3F0?ooo`00I@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0eP3oool006D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0=H0oooo001V0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`3F0?ooo`00IP3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0eP3oool006H0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0=H0oooo001W0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3F0?ooo`00I`3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo0`00003F0?ooo`00I`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0eP3oool006P0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0=H0oooo
001X0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`3F0?ooo`00J03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0eP3oool006T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0=H0oooo001Y0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`3F0?ooo`00J@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0eP3oool006X0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0i0?ooo`<00000eP3oool006X0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0=H0oooo001Z0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3F0?ooo`00J`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0eP3oool006/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0=H0oooo
001[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`3F0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo00D0okmd
000000000000000007Boo`050?ooo`030;md0000000007Bo00<0oooo00<0oono07@0000000001000
00001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?ooo`3oool01@3oool00`000000oooo
0?ooo`3F0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo00H0
W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo00<0_g@00000M02o
ool00P3oool01P3OW7@0W=oo0?ooo`3oool0_g@0001d_`80oooo00<0omnL04P0001d_ol01P3oool0
0`000000oooo0?ooo`3F0?ooo`00K03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01D0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?noM00004P0W=oo
00X0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00K@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00T0oooo00<0okmd001d_`3oool01@3oool400000=D0
oooo001]0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3oool01`3oool00`2LB000M;oo
0?ooo`050?ooo`030000003oool0oooo0=H0oooo001]0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool05P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00H0
W4Qd0;ooo`3oool0oooo0?oo_`1d00030000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3o
ool0eP3oool006h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0G0?ooo`030?no
M018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`070;md
001d_ol0oooo0?ooo`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo0=H0oooo001^0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool01P2LB000M;oo0?ooo`3ogi`0B01d
0;ooo`/0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo0080oooo00<0oono07@0M02oool0
2P3oool00`000000oooo0?ooo`3F0?ooo`00K`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01T0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02L
gol00`3oool00`3ookl0M00000000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3o
ool0eP3oool006l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0=H0oooo001`0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3F0?ooo`00L03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0eP3oool00740oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`130?ooo`<00000eP3oool00740oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo0=H0oooo001b0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3F0?ooo`00L`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0eP3oool007<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0=H0oooo001d0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3F0?oo
o`00M03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0eP3oool007D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0=H0oooo001e0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0B03o
ool300000=H0oooo001f0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`3F0?ooo`00M`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0eP3oool007P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0=H0oooo001i0?ooo`030000003oool0oooo00`0oooo
0P00001=0?ooo`030000003oool0oooo0=H0oooo001j0?ooo`030000003oool0oooo00T0oooo0P00
001?0?ooo`030000003oool0oooo0=H0oooo001k0?ooo`800000203oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0=H0oooo001m0?ooo`P00000DP3oool00`000000oooo0?ooo`3F0?oo
o`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool300000=H0oooo003G0?ooo`030000003o
ool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.5213, -0.0214705, \
0.0384313, 0.00172944}}]
}, Open  ]],

Cell["\<\
It also doesn't work at x=0, but fortunately the value of the PDF and CDF and \
all the derivatives of the stable distribution has a closed form at x = 0.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdfz1[0, \ 1.3, \ 1]\)], "Input"],

Cell[BoxData[
    \(0.`\)], "Output"]
}, Open  ]],

Cell["\<\
The closed form for the PDF at x = 0 in the 1-parameterization.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[\(\[ExponentialE]\^\(-\((u\ \[Gamma])\)\^\[Alpha]\)\ Cos[u\ x \
- u\ \[Delta] - \[Beta]\ \((u\ \[Gamma])\)\^\[Alpha]\ Tan[\(\[Pi]\ \[Alpha]\)\
\/2]]\)\/\[Pi] /. {x \[Rule] 0, \[Gamma] \[Rule] 1, \[Delta] \[Rule] 
            0}, \ {u, 0, Infinity}, 
      Assumptions \[Rule] \ {0 < \ \[Alpha] \[LessEqual] \ 
            2, \(-1\) \[LessEqual] \ \[Beta]\  \[LessEqual] \ 1}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Integrate::"gener"\), \(\(:\)\(\ \)\), "\<\"Unable to check \
convergence. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Integrate::gener\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(\(Cos[ArcTan[Abs[\[Beta]]\ Abs[Tan[\(\[Pi]\ \[Alpha]\)\/2]]]\/\[Alpha]]\
\ Gamma[1 + 1\/\[Alpha]]\ \((1 + \[Beta]\^2\ Tan[\(\[Pi]\ \
\[Alpha]\)\/2]\^2)\)\^\(-\(1\/\(2\ \[Alpha]\)\)\)\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {\[Alpha] \[Rule] 1.3, \[Beta] \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(0.106195665808831`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Fast Fourier Transform",
    FontWeight->"Bold"],
  " (FFT)\nThe FFT can be used to calculate an approximation of the PDF by \
sampling the CF at equally spaced intervals then performing the FFT.  An \
explanation of the algorithm can be found in Rachev & Mittnick, Stable \
Paretian Models in Finance, p. 121-122.  The implementation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is straight forward.  Optimized code used in the SMath.m is given below."
}], "Text"],

Cell[BoxData[
    \(\(cf0\  = \ 
        Compile[{u, \[Alpha], \[Beta]}, 
          Block[{btn = \[Beta]*Tan[\((Pi*\[Alpha])\)/2]}, \n\t
            If[\[Alpha]\  != \ 1, 
              E^\((\(-Abs[u]^\[Alpha]\) - 
                    I*\((u - Abs[u]^\[Alpha]*Sign[u])\)*
                      btn)\), \ \n\ \ \ \ \ 1/\((E^Abs[u]*
                    Abs[u]^\((\((2*I*u*\[Beta])\)/Pi)\))\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(cf1\  = \ 
        Compile[{u, \[Alpha], \[Beta]}, 
          Block[{btn = \[Beta]*
                  Tan[\((Pi*\[Alpha])\)/
                      2]}, \[IndentingNewLine]If[\[Alpha]\  \[NotEqual] \ 1, 
              E^\((Abs[u]^\[Alpha]*\((\(-1\) + 
                        I*Sign[u]*btn)\))\), \[IndentingNewLine]1/\((E^Abs[u]*
                    Abs[u]^\((\((2*I*u*\[Beta])\)/Pi)\))\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*xrange\ is\ _Real, \ 
      but\ the\ designation\ _Complex\ sets\ up\ complex\ output\ for\ cf0\
*) \)\(\[IndentingNewLine]\)\( (*the\ left\ half\ of\ the\ list\ is\ \
calculated\ and\ the\ right\ half\ is\ the\ conjugate\ of\ its\ \
reverse*) \)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(CTable0\  = \ 
        Compile[{\[Alpha], \[Beta], {xrange, _Complex}, {twoexp, _Integer}}, 
          Block[{clist}, \[IndentingNewLine]clist = 
              Table[If[OddQ[n], 1, \(-1\)] 
                    cf0[2. \ Pi\ \((n - 1 - 2^\((twoexp - 1)\))\)/
                          xrange, \[Alpha], \[Beta]], {n, 
                    2^\((twoexp - 1)\)}]/
                xrange; \[IndentingNewLine]clist\  = \ 
              Join[clist, {1. /xrange}, 
                Conjugate[Reverse[Rest[clist]]]]\n\t]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(CTable1\  = \ 
        Compile[{\[Alpha], \[Beta], {xrange, _Complex}, {twoexp, _Integer}}, 
          Block[{clist}, \[IndentingNewLine]clist = 
              Table[If[OddQ[n], 1, \(-1\)] 
                    cf1[2. \ Pi\ \((n - 1 - 2^\((twoexp - 1)\))\)/
                          xrange, \[Alpha], \[Beta]], {n, 
                    2^\((twoexp - 1)\)}]/
                xrange; \[IndentingNewLine]clist\  = \ 
              Join[clist, {1. /xrange}, 
                Conjugate[Reverse[Rest[clist]]]]\n\t]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(XTable\ \  = \ 
        Compile[{xrange, \ {len, _Integer}}, \n
          Range[\(-1\)/2, 1/2 - 1/len, 1/len] xrange];\)\)\)], "Input"],

Cell[BoxData[
    \(Clear[pdff0, pdff1]\)], "Input"],

Cell[BoxData[
    \(\(pdff0[\[Alpha]_, \[Beta]_, xr_, \ tw_] := 
        Interpolation[
          Transpose[{XTable[xr, 2^tw], 
              Abs[Re[InverseFourier[CTable0[\[Alpha], \[Beta], xr, tw], 
                    FourierParameters \[Rule] {\(-1\), 1}]]]}]];\)\)], "Input"],

Cell[BoxData[
    \(pdff1[\[Alpha]_, \[Beta]_, xr_, \ tw_] := 
      Interpolation[
        Transpose[{XTable[xr, 2^tw], 
            Abs[Re[InverseFourier[CTable1[\[Alpha], \[Beta], xr, tw], 
                  FourierParameters \[Rule] {\(-1\), 1}]]]}]]\)], "Input"],

Cell["\<\
Here tw = twoexp and xr = xrange as described in the fMLFit algorithm.  This \
method of calculation for the PDF can be used close to \[Alpha] = 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1 = pdff1[1.001, 0.3, 1024, 13];\)\), "\[IndentingNewLine]", 
    \(\(f0 = \ pdff0[1.001, 0.3, 1024, 13];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{f0[x], f1[x]}, {x, \(-200\), 20}, 
        PlotStyle \[Rule] {Hue[0.7], Hue[1]}, 
        PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.88961 0.004329 0.0147026 1.8762 [
[.02381 .0022 -12 -9 ]
[.02381 .0022 12 0 ]
[.24026 .0022 -12 -9 ]
[.24026 .0022 12 0 ]
[.45671 .0022 -12 -9 ]
[.45671 .0022 12 0 ]
[.67316 .0022 -9 -9 ]
[.67316 .0022 9 0 ]
[.87711 .10851 -24 -4.5 ]
[.87711 .10851 0 4.5 ]
[.87711 .20232 -18 -4.5 ]
[.87711 .20232 0 4.5 ]
[.87711 .29613 -24 -4.5 ]
[.87711 .29613 0 4.5 ]
[.87711 .38994 -18 -4.5 ]
[.87711 .38994 0 4.5 ]
[.87711 .48375 -24 -4.5 ]
[.87711 .48375 0 4.5 ]
[.87711 .57756 -18 -4.5 ]
[.87711 .57756 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .0147 m
.02381 .02095 L
s
[(-200)] .02381 .0022 0 1 Mshowa
.24026 .0147 m
.24026 .02095 L
s
[(-150)] .24026 .0022 0 1 Mshowa
.45671 .0147 m
.45671 .02095 L
s
[(-100)] .45671 .0022 0 1 Mshowa
.67316 .0147 m
.67316 .02095 L
s
[(-50)] .67316 .0022 0 1 Mshowa
.125 Mabswid
.0671 .0147 m
.0671 .01845 L
s
.11039 .0147 m
.11039 .01845 L
s
.15368 .0147 m
.15368 .01845 L
s
.19697 .0147 m
.19697 .01845 L
s
.28355 .0147 m
.28355 .01845 L
s
.32684 .0147 m
.32684 .01845 L
s
.37013 .0147 m
.37013 .01845 L
s
.41342 .0147 m
.41342 .01845 L
s
.5 .0147 m
.5 .01845 L
s
.54329 .0147 m
.54329 .01845 L
s
.58658 .0147 m
.58658 .01845 L
s
.62987 .0147 m
.62987 .01845 L
s
.71645 .0147 m
.71645 .01845 L
s
.75974 .0147 m
.75974 .01845 L
s
.80303 .0147 m
.80303 .01845 L
s
.84632 .0147 m
.84632 .01845 L
s
.9329 .0147 m
.9329 .01845 L
s
.97619 .0147 m
.97619 .01845 L
s
.25 Mabswid
0 .0147 m
1 .0147 L
s
.88961 .10851 m
.89586 .10851 L
s
[(0.05)] .87711 .10851 1 0 Mshowa
.88961 .20232 m
.89586 .20232 L
s
[(0.1)] .87711 .20232 1 0 Mshowa
.88961 .29613 m
.89586 .29613 L
s
[(0.15)] .87711 .29613 1 0 Mshowa
.88961 .38994 m
.89586 .38994 L
s
[(0.2)] .87711 .38994 1 0 Mshowa
.88961 .48375 m
.89586 .48375 L
s
[(0.25)] .87711 .48375 1 0 Mshowa
.88961 .57756 m
.89586 .57756 L
s
[(0.3)] .87711 .57756 1 0 Mshowa
.125 Mabswid
.88961 .03346 m
.89336 .03346 L
s
.88961 .05223 m
.89336 .05223 L
s
.88961 .07099 m
.89336 .07099 L
s
.88961 .08975 m
.89336 .08975 L
s
.88961 .12727 m
.89336 .12727 L
s
.88961 .14604 m
.89336 .14604 L
s
.88961 .1648 m
.89336 .1648 L
s
.88961 .18356 m
.89336 .18356 L
s
.88961 .22108 m
.89336 .22108 L
s
.88961 .23985 m
.89336 .23985 L
s
.88961 .25861 m
.89336 .25861 L
s
.88961 .27737 m
.89336 .27737 L
s
.88961 .31489 m
.89336 .31489 L
s
.88961 .33366 m
.89336 .33366 L
s
.88961 .35242 m
.89336 .35242 L
s
.88961 .37118 m
.89336 .37118 L
s
.88961 .40871 m
.89336 .40871 L
s
.88961 .42747 m
.89336 .42747 L
s
.88961 .44623 m
.89336 .44623 L
s
.88961 .46499 m
.89336 .46499 L
s
.88961 .50252 m
.89336 .50252 L
s
.88961 .52128 m
.89336 .52128 L
s
.88961 .54004 m
.89336 .54004 L
s
.88961 .5588 m
.89336 .5588 L
s
.88961 .59633 m
.89336 .59633 L
s
.88961 .61509 m
.89336 .61509 L
s
.25 Mabswid
.88961 0 m
.88961 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01473 L
.34309 .01473 L
.3815 .01473 L
.42237 .01474 L
.46172 .01475 L
.49955 .01476 L
.53984 .01477 L
.57861 .01478 L
.59975 .0148 L
.61984 .01481 L
.63987 .01483 L
.65803 .01485 L
.6777 .01487 L
.69867 .01491 L
.71792 .01496 L
.72876 .015 L
.73874 .01504 L
.75756 .01514 L
.76825 .01522 L
.77823 .01531 L
.78868 .01544 L
.79858 .01561 L
.80747 .01582 L
.81245 .01596 L
.81714 .01613 L
.82654 .01658 L
.83153 .01691 L
.83691 .01738 L
.84225 .018 L
.84516 .01844 L
.84787 .01894 L
.85267 .0201 L
.85521 .02091 L
.85792 .02201 L
.86051 .02335 L
.86325 .02522 L
.86559 .02735 L
.86816 .03053 L
.86961 .03289 L
.87093 .03553 L
.87245 .03937 L
.8739 .04409 L
.87523 .04976 L
Mistroke
.87647 .05661 L
.87782 .06673 L
.87858 .07405 L
.87926 .08208 L
.88053 .10176 L
.88117 .11498 L
.88187 .13304 L
.8831 .17821 L
.88426 .24314 L
.88571 .36808 L
.88642 .44335 L
.88708 .51076 L
.88831 .59393 L
.88896 .60332 L
.88965 .58811 L
.89081 .52359 L
.89189 .44587 L
.89318 .35772 L
.89437 .29043 L
.89555 .23684 L
.8968 .19328 L
.89805 .15985 L
.89942 .13211 L
.90074 .11164 L
.90196 .09688 L
.90328 .08428 L
.90472 .07336 L
.90715 .05982 L
.90848 .05426 L
.90972 .04991 L
.91208 .04336 L
.91423 .03882 L
.91671 .03478 L
.91907 .0318 L
.92159 .02928 L
.92428 .02716 L
.9291 .02434 L
.93178 .02317 L
.93429 .02225 L
.94003 .02064 L
.94441 .01973 L
.94921 .01895 L
.95389 .01836 L
.95889 .01785 L
.96785 .01716 L
.97619 .01671 L
Mfstroke
1 0 0 r
.02381 .01954 m
.02605 .02014 L
.02846 .02092 L
.03279 .02282 L
.03543 .02445 L
.03793 .02648 L
.04018 .02891 L
.04144 .03062 L
.04262 .03251 L
.045 .03755 L
.04626 .04114 L
.04762 .04605 L
.04904 .0528 L
.05039 .06147 L
.0516 .07201 L
.05229 .07957 L
.05293 .08811 L
.05418 .11034 L
.05532 .13996 L
.05654 .18835 L
.05723 .22677 L
.05786 .2714 L
.05909 .3852 L
.06026 .50694 L
.06131 .5848 L
.06244 .60024 L
.06371 .54437 L
.06488 .46257 L
.06613 .37567 L
.0675 .29508 L
.06868 .24074 L
.06978 .20066 L
.07095 .16753 L
.07221 .13992 L
.07351 .118 L
.07494 .0996 L
.07642 .08492 L
.07781 .07427 L
.08028 .06022 L
.08167 .05435 L
.08293 .04992 L
.08571 .04239 L
.08828 .03735 L
.09109 .03323 L
.09407 .02996 L
.09665 .02777 L
.09907 .02612 L
.10193 .02453 L
.10458 .02334 L
.10956 .02161 L
Mistroke
.11499 .02025 L
.11977 .01936 L
.12487 .01862 L
.12988 .01806 L
.1346 .01763 L
.1434 .01702 L
.15319 .01655 L
.16352 .01618 L
.17234 .01595 L
.18201 .01576 L
.19224 .0156 L
.20156 .01548 L
.21243 .01537 L
.22248 .01529 L
.24161 .01517 L
.26238 .01508 L
.28108 .01502 L
.3017 .01496 L
.32108 .01493 L
.34195 .01489 L
.36164 .01487 L
.38315 .01485 L
.42282 .01482 L
.46344 .0148 L
.50253 .01478 L
.54408 .01477 L
.58412 .01476 L
.62264 .01475 L
.66361 .01474 L
.70306 .01474 L
.741 .01474 L
.78139 .01473 L
.82027 .01473 L
.8616 .01473 L
.90141 .01473 L
.93971 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`003`3oool00`3ookl0M000000000040000000507Boo`3oool0oooo0?ooo`3o_g@00`000000
0`1d_ol0oooo0?ooo`020?ooo`050?noM000000000000000001d_ol0@@3oool00`3o_g@000000000
000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d_ol0oooo0?ooo`020?ooo`050?no
M000000000000000001d_ol0@03oool00`3o_g@000000000000300000005001d_`3oool0oooo0?oo
o`3o_g@00`0000000`1d_ol0oooo0?ooo`020?ooo`050?noM000000000000000001d_ol0A`3oool0
1@2oM0000000000000000000M;oo00@0oooo00D0okmd000000000000000007Boo`220?ooo`00403o
ool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0080oooo00H0W4Qd0;ooo`3oool0oono
07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo@`3oool00`2LB4P0W=oo0?ooo`03
0?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`030?ooo`0609a8M02oool0oooo0?oo_`1d
07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooodD0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000
M;oo00<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooon10?ooo`004@3oool00`3o_g@0001809cO
o`050?ooo`030?noM000M;l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`03
0=nLB018W=l0oooo0480oooo00<0W4Q809cOo`3oool0203oool01P3o_g@007Bo0?ooo`3oool0okmd
001d_`<0oooo00<0gia804RLg`3oool0@@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0
oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo04T0oooo
00H0okmd001d_`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo0800oooo000B0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia8
04RLg`<0oooo00<0okmd001d_`3oool0@P3oool00`2LB4P0W=oo0?ooo`080?ooo`060?noM000M;l0
oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo
00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d
_`3oool0B@3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0P03o
ool000L0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0
oooo0080oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo
00<0okmd001d_`3oool0=P3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo
00<0W4Q809cOo`3oool0203oool01P2LB000M;oo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d
_`3oool0=@3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cO
o`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`0k0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool01@3o
ool01P2LB000M;oo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0P03oool001D0oooo
00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`120?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0000000000P00
00001P18W=l0oooo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0@@3oool00`2LB4P0
W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l3
0?ooo`030?noM000M;l0oooo04@0oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3o
ool0gia804RLg`<0oooo00<0okmd001d_`3oool0P03oool00100oooo00<0gia807Boo`3oool00P3o
ool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00H0gia804RLg`3oool0oooo0?noM018W=l3
0?ooo`030=nLB018W=l0oooo0480oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M01d0;ooo`06
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0@@3oool00`2LB4P0W=oo0?ooo`03
0?ooo`030?noM018W=l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM018W=l30?ooo`030=nL
B018W=l0oooo04@0oooo00<0oono07@0M02oool01P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nL
B018W=l0oooo0800oooo000@0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`06
09a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;oood00oooo
00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo00L0oooo00H0W4P007Boo`3o
ool0omnL04P0M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?oo
o`3ogi`0B01d0;ooo`<0oooo00H0W4P007Boo`3oool0omnL04P0M02ooom50?ooo`030?oo_`1d07@0
_ooo00L0oooo00H0W4P007Boo`3oool0omnL04P0M02ooon10?ooo`004@3oool01@3o_g@000000000
000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d000000000000
B02Lgol0@`3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;oo
o`3oool00P3oool01@3ookl0M0000000000004P0W=oo0480oooo00<0gia80000B02Lgol01@3oool0
1@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`160?ooo`030?oo
_`1d000000000080000000<0001d0;ooo`3oool00P3oool01@3ookl0M0000000000004P0W=oo0880
oooo003o0?oook40oooo003o0?oook40oooo003o0?ooog`0oooo00<000000?ooo`3oool0<P3oool0
0?l0ooooO03oool00`000000oooo0?ooo`0b0?ooo`00o`3oooml0?ooo`030000003oool0oooo0380
oooo003o0?ooog`0oooo00<000000?ooo`3oool0<P3oool00?l0ooooO03oool00`000000oooo0?oo
o`0b0?ooo`00o`3oooml0?ooo`030000003oool0oooo0380oooo000>0?ooo`X00000D00c0?oo0?l0
03P0o`002P0000070?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3ooolS0?l000T0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3ooolG03<0o`<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0
oooo1@0c0?lA0?ooo`00603oool20?l00100oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`3oool60?l000P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool703<0o`h0oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`3oool903<0o`@0oooo00<000000?ooo`3oool03`3oool001P0
oooo00<000000?ooo`3o0000803oool40?l00380oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo04P0oooo0P0c0?l<0?ooo`030000003oool0oooo00l0
oooo100c0?lO0?ooo`006`3oool30?l001X0oooo0`3o003o0?ooocD0oooo00<0<`3o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`80<`3o8`3oool001h0oooo00<0o`000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`3o0?ooocL0oooo0P0c0?l90?ooo`030000003oool0oooo00/0oooo0P0c
0?lU0?ooo`007`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo>@3oool0
0`0c0?l0oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0<`3o0?ooo`3oool09@3oool0
01l0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?oooc/0oooo00<0<`3o0?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`0303<0o`3oool0oooo02H0oooo000P0?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0o`3ooolm0?ooo`0303<0o`3oool0oooo00D0
oooo0P0000090?ooo`0303<0o`3oool0oooo02L0oooo000P0?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool0o`3oooln0?ooo`0303<0o`3oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`0c0?l0oooo0?ooo`0X0?ooo`008@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0?l0oooo@03oool00`0c0?l0oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
<`3o0?ooo`3oool0:03oool00240oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3o
0?oood40oooo00<0<`3o0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`0303<0o`3oool0
oooo02T0oooo000Q0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0o`3ooom10?oo
o`0303<0o`3oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`0Y0?oo
o`008P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?l0oooo@@3oool00`0c0?l0
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0<`3o0?ooo`3oool0:@3oool00280oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o0?oood<0oooo00<0<`3o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`0303<0o`3oool0oooo02X0oooo000R0?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000?ooo`3oool0o`3ooom30?ooo`0303<0o`3oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`0Z0?ooo`008P3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo0?l0oooo@`3oool00`0c0?l0oooo0?ooo`030?ooo`8000001P3oool0
0`0c0?l0oooo0?ooo`0Z0?ooo`008P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
0?l0oooo@`3oool00`0c0?l0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0<`3o0?oo
o`3oool0:P3oool002<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?oood@0
oooo00<0<`3o0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`0303<0o`3oool0oooo02/0
oooo000S0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooom40?ooo`0303<0
o`3oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`0c0?l0oooo0?ooo`0[0?ooo`008`3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0?l0ooooA@3oool00`0c0?l0oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<0<`3o0?ooo`3oool0:`3oool002<0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?ooodD0oooo00<0<`3o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`0303<0o`3oool0oooo02/0oooo000S0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool0o`3ooom60?ooo`0303<0o`3oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`0c0?l0oooo0?ooo`0/0?ooo`008`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0?l0ooooAP3oool00`0c0?l0oooo0?ooo`020?ooo`800000103oool00`0c0?l0
oooo0?ooo`0/0?ooo`008`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0oooo
AP3oool00`0c0?l0oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0<`3o0?ooo`3oool0
;03oool002<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`3o0?ooodH0oooo00<0
<`3o0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`0303<0o`3oool0oooo02`0oooo000T
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooom60?ooo`0303<0o`3oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`0/0?ooo`00903oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0ooooA`3oool01@0c0?l0oooo0?ooo`3oool0
000000@0oooo00<0<`3o0?ooo`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`3o0?ooodL0oooo00D0<`3o0?ooo`3oool0oooo000000040?ooo`0303<0o`3oool0
oooo02d0oooo000T0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooom70?oo
o`0503<0o`3oool0oooo0?ooo`000000103oool00`0c0?l0oooo0?ooo`0]0?ooo`00903oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0ooooA`3oool01@0c0?l0oooo0?ooo`3oool0
000000@0oooo00<0<`3o0?ooo`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`3o0?ooodL0oooo00@0<`3o0?ooo`3oool0oooo0P0000030?ooo`0303<0o`3oool0
oooo02d0oooo000T0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0o`3ooom80?oo
o`0503<0o`3oool0oooo0?ooo`000000103oool00`0c0?l0oooo0?ooo`0]0?ooo`00903oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0ooooB03oool01@0c0?l0oooo0?ooo`3oool0
000000@0oooo00<0<`3o0?ooo`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`3o0?ooodP0oooo00D0<`3o0?ooo`3oool0oooo000000040?ooo`0303<0o`3oool0
oooo02d0oooo000T0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0o`3ooolU0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050?noM0000000
00000000001d_ol0103oool01@2oM0000000000000000000M;oo00<0oooo00D0<`3o0?ooo`3oool0
oooo000000040?ooo`0303<0o`3oool0oooo02d0oooo000T0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool0o`3ooolU0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2o
M0000000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0P3oool01`2oM00007Bo0?oo
o`3oool0omnL04P0001d_ol00P3oool01@0c0?l0oooo0?ooo`3oool0000000@0oooo00<0<`3o0?oo
o`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o0?ooob@0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool01P3oool01@3o_g@007Bo0?ooo`3oool0<`3o00<0oooo00D000000?oo
o`3oool0oooo03<0o`0`0?ooo`00903oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
0?l0oooo903oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`060?ooo`050?noM000M;l0oooo0?ooo`0c0?l00`3oool0
1@000000oooo0?ooo`3oool0<`3o0300oooo000T0?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0o`3ooolU0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00D0W4P007Boo`3oool0oooo03<0
o`030?ooo`<0000000<0oooo03<0o`3oool0;`3oool002@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`3o0?ooobD0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:
0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0?oo_`1d00030000000504RL
g`3oool0oooo0?ooo`0c0?l00`3oool01@000000oooo0?ooo`3oool0<`3o0300oooo000T0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`030?noM018W=l0oooo0080
oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`070=nLB018W=l0oooo0?oo
o`3ookl0M01d0;ooo`060?ooo`0503<0o`3oool0oooo0?ooo`0000000`3oool00`0c0?l0oooo0?oo
o`0^0?ooo`00903oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0oooo9P3oool0
1P2LB000M;oo0?ooo`3ogi`0B01d0;ooo``0oooo00H0W4P007Boo`3oool0omnL04P0M02oool20?oo
o`030?oo_`1d07@0_ooo00H0oooo00D0<`3o0?ooo`3oool0oooo000000030?ooo`0303<0o`3oool0
oooo02h0oooo000T0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooolV0?oo
o`050?oo_`1d000000000000B02Lgol03@3oool01@3ookl0M0000000000004P0W=oo00<0oooo00<0
oono07@0000000000P0000001@0007@0_ooo0?ooo`3oool0<`3o00<0oooo00D000000?ooo`3oool0
oooo03<0o`0`0?ooo`00903oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0oooo
B@3oool01@0c0?l0oooo0?ooo`3oool0000000<0oooo00<0<`3o0?ooo`3oool0;P3oool002@0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?ooodT0oooo00D0<`3o0?ooo`3oool0
oooo000000030?ooo`0303<0o`3oool0oooo02h0oooo000U0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0o`3ooom:0?ooo`0303<0o`3oool0oooo008000000P3oool00`0c0?l0oooo
0?ooo`0^0?ooo`009@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0ooooBP3o
ool0100c0?l0oooo0?ooo`0000030?ooo`0303<0o`3oool0oooo02h0oooo000U0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooom:0?ooo`0403<0o`3oool0oooo000000<0oooo
00<0<`3o0?ooo`3oool0;P3oool002D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`3o0?ooodX0oooo00@0<`3o0?ooo`3oool000000`3oool00`0c0?l0oooo0?ooo`0^0?ooo`009@3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0ooooBP3oool0100c0?l0oooo0?oo
o`0000030?ooo`0303<0o`3oool0oooo02h0oooo000U0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0o`3ooom:0?ooo`0403<0o`3oool0oooo000000<0oooo00<0<`3o0?ooo`3oool0
;P3oool002D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooodX0oooo00@0
<`3o0?ooo`3oool000000`3oool00`0c0?l0oooo0?ooo`0^0?ooo`009@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo0?l0ooooBP3oool0100c0?l0oooo0?ooo`0000030?ooo`0303<0
o`3oool0oooo02h0oooo000U0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0o`3o
oom:0?ooo`0303<0o`3oool0oooo0080000000<0oooo03<0o`3oool0<03oool002D0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooodX0oooo00@0<`3o0?ooo`3oool000000P3o
ool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0?l0ooooBP3oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooom:0?ooo`0403<0o`3oool0
oooo00000080oooo00<0<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`3o0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?oo
o`0_0?ooo`009@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooB`3oool0
100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom;0?ooo`0403<0o`3oool0oooo00000080oooo00<0
<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o
0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooB`3oool00`0c0?l0oooo0?ooo`02
000000030?ooo`0c0?l0oooo0300oooo000U0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0o`3ooom;0?ooo`0403<0o`3oool0oooo00000080oooo00<0<`3o0?ooo`3oool0;`3oool0
02D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oood/0oooo00@0<`3o0?oo
o`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0?l0ooooB`3oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0
oooo02l0oooo000U0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom;0?oo
o`0403<0o`3oool0oooo00000080oooo00<0<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`3o0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool0
0`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0?l0ooooB`3oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom;0?ooo`0303<0o`3oool0oooo
0080000000<0oooo03<0o`3oool0<03oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`3o0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?oo
o`009@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooB`3oool0100c0?l0
oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0o`3ooom;0?ooo`0403<0o`3oool0oooo00000080oooo00<0<`3o0?oo
o`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oood/0
oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo<03oool01@3o_g@00000000000000000M;oo
00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000005001d_`3oool0oooo
0?ooo`0c0?l00P3oool010000000oooo0?ooo`0c0?la0?ooo`009@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo0?l0oooo<03oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo
00<0_g@000000000M;l01`3oool00`2LB4P0W=oo0?ooo`040?ooo`0403<0o`3oool0oooo00000080
oooo00<0<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`3o0?ooobl0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00@0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`00
9@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo;`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool0103oool00`0c0?l0oooo
0?ooo`030000000303<0o`3oool0oooo02l0oooo000U0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0o`3oool_0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3o
ool00`2LB4P0W=oo0?ooo`040?ooo`0403<0o`3oool0oooo00000080oooo00<0<`3o0?ooo`3oool0
;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooobl0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00@0oooo00@0
<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0?l0oooo;`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018
W=l0oooo00d0oooo00<0W4Q809cOo`3oool0103oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0
o`3oool0oooo02l0oooo000V0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3o
ool`0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01@3OW4P000000018W02LB4P0W=oo
00H0oooo00<0<`3o0?ooo`0000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo<03oool01@3ookl0M0000000000004P0W=oo
00h0oooo00<0gia80000B02Lgol01P3oool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooom<0?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?oo
od`0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0
o`000?l0ooooC`3oool01@0c0?l0oooo000000000000<`3o0380oooo000V0?ooo`050?l0003oool0
oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0
o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`00
9P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o
0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o
0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3o
ool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000
o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0
oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000000003<0o`0b0?ooo`009P3oool01@3o0000
oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?oo
o`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3o
ool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo
03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo
0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`05
03<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?oo
odl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0
o`000?l0ooooC`3oool01@0c0?l0oooo000000000000<`3o0380oooo000V0?ooo`050?l0003oool0
oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0
o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`00
9P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o
0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o
0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3o
ool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000
o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0
oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000000003<0o`0b0?ooo`009P3oool01@3o0000
oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?oo
o`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3o
ool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo
03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0oooo:P3oool01@3o_g@00000
000000000000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000005
001d_`3oool0oooo0?ooo`2oM0000`0000000`1d_ol0oooo0?ooo`030?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooobX0oooo00H0W4Qd
0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool0
0`3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0103oool01@0c0?l0oooo0000003oool0
<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooolY0?ooo`030?noM000M;l0
oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`080?ooo`030?noM000M;l0
oooo00<0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3o
ool0o`000?l0oooo:@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0
W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`030?ooo`0503<0o`3oool000000?ooo`0c0?l0
<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooobT0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00P0oooo00<0W4P007Boo`3oool0
0`3oool01@0c0?l0oooo000000000000<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o
0000o`3ooolY0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0
W=oo0?ooo`030?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool00`3oool01@0c0?l0
oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooolY0?oo
o`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`030?oo
o`030?oo_`1d07@0_ooo00P0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o
0000oooo0?ooo`3oool0o`000?l0oooo:P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo
00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo00P0oooo00D0<`3o0?ooo`00
0000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0oooo:P3oool01@3o
okl0M0000000000004P0W=oo00h0oooo00<0gia80000B02Lgol0103oool00`3ookl0M00000000002
000000030000M02oool0oooo00<0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool0
1@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o0380oooo
000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c
0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`00
0000000003<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c
0?l0oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?
0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0
003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?oo
o`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool01@3o0000oooo
0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool01@3o0000
oooo0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool01@3o
0000oooo0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0
1@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3o
ool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo
00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`04
0?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o
0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`00
0?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003o
ool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo
0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3o
ool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo
0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o
003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00
o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0
ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oo
oe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@
0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03o
ool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo
00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`04
03<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c
0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o
0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooold0?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000000000@00000
00<0M;oo0?ooo`3oool00P3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo
0?ooo`3o003o0?oooc@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`030?ooo`0403<0o`3oool0
000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0oooo<`3oool00`3o_g@007Bo0?oo
o`020?ooo`030=nLB018W=l0oooo00/0oooo00<0okmd0000B02Lgol01`3oool0100c0?l0oooo0000
000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooc<0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00H0oooo00D0<`3o0?ooo`000000
<`3o0000000b0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooc<0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00@0oooo00@0<`3o0?ooo`00
0000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooolc0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`030?ooo`0403<0o`3oool00000
03<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0oooo<`3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`03
0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0oooo=03o
ool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000M02oool0oooo0?noM00004P0
W=oo00@0oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3o
oold0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00D0
oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?oo
o`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0
100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0
<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0
o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0
oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?oo
o`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0
000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000
000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000
<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0
oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc
0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3o
ool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo
000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`00
9P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0
oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?oo
o`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0
103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002L0oooo00<0
o`000?ooo`3o0000o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000W0?ooo`030?l0003o
ool0o`000?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000oooo0?l0
003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002L0oooo00<0o`000?ooo`3o0000o`3o
oom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000W0?ooo`030?l0003oool0o`000?l0ooooD03o
ool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000oooo0?l0003o0?oooe00oooo00@0
<`3o0?ooo`000000<`3o<`3oool002L0oooo00<0o`000?ooo`3o0000o`3ooom@0?ooo`0403<0o`3o
ool0000003<0oc<0oooo000W0?ooo`030?l0003oool0o`000?l0ooooD03oool0100c0?l0oooo0000
000c0?lc0?ooo`009`3oool00`3o0000oooo0?l0003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o
<`3oool002L0oooo00<0o`000?ooo`3o0000o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo
000W0?ooo`030?l0003oool0o`000?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009`3o
ool00`3o0000oooo0?l0003o0?ooob/0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00<0oooo00<0oono07@000000000100000001@1d_ol0oooo0?ooo`3oool0_g@000<0
000000<0M;oo0?ooo`3oool00`3oool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000
oooo0?l0003o0?ooob/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00<0_g@00000M02oool00P3oool01P3OW7@0W=oo0?ooo`3oool0_g@0001d_`80oooo
00<0omnL04P0001d_ol0103oool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000oooo
0?l0003o0?ooobX0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?no
M00004P0W=oo00X0oooo00<0okmd001d_`3oool0103oool00`0c0?l0000003<0o`0c0?ooo`009`3o
ool00`3o0000oooo0?l0003o0?ooobX0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0<0?ooo`030?oOW0180000B9cO00T0oooo00<0okmd001d_`3oool0103oool0100c0?l0000003<0
o`00000b0?ooo`009`3oool00`3o0000oooo0?l0003o0?ooobX0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00L0oooo00<0W4P007Boo`3oool0103o
ool203<0oc@0oooo000W0?ooo`030?l0003oool0o`000?l0oooo:P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00l0oooo00H0W4Qd0;ooo`3oool0oooo0?oo_`1d00030000000304RL
g`3oool0oooo00@0oooo0P0c0?ld0?ooo`009`3oool00`3o0000oooo0?l0003o0?ooobX0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00L0
_g@007Boo`3oool0oooo0?oo_`1d07@0_ooo00T0oooo0P0c0?ld0?ooo`009`3oool00`3o0000oooo
0?l0003o0?ooob/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo
0?ooo`3o_g@0001809cOo`020?ooo`030?oo_`1d07@0_ooo00T0oooo0P0c0?ld0?ooo`009`3oool0
0`3o0000oooo0?l0003o0?ooob/0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?noM000
000000000000B02Lgol00`3oool00`3ookl0M00000000002000000030000M02oool0oooo00@0oooo
0P0c0?ld0?ooo`009`3oool00`3o0000oooo0?l0003o0?oooe40oooo0P0c0?ld0?ooo`009`3oool0
0`3o0000oooo0?l0003o0?oooe40oooo0P0c0?ld0?ooo`009`3oool00`3o0000oooo0?l0003o0?oo
oe40oooo0P0c0?l00`000000oooo0?ooo`0a0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0
oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo0P0c
0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?oo
o`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0oooo
DP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o00<000000?ooo`3oool0<@3o
ool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0
oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo
0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB
0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0
ooooDP3oool203<0o`030000003oool0oooo0340oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o
=03oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool2
03<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80
oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3o
oomB0?ooo`80<`3o00<000000?ooo`3oool0<@3oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld
0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80
<`3o=03oool002L0oooo0P3o003o0?ooocD0oooo00D0okmd000000000000000007Boo`050?ooo`03
0;md0000000007Bo00D0oooo00D0_g@0000000000000000004RLg`060?ooo`80<`3o=03oool002L0
oooo0P3o003o0?ooocD0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oo_`1d0000B9cO00D0oooo0P0c0?ld0?ooo`009`3o
ool20?l00?l0oooo=03oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0
okmd001d_`3oool0103oool203<0oc@0oooo000W0?ooo`80o`00o`3ooold0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B01809cOo`050?ooo`80<`3o=03oool0
02L0oooo0P3o003o0?oooc@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0<0?oo
o`040=nLB0000000001809cOo`H0oooo0P0c0?l200000380oooo000W0?ooo`80o`00o`3ooold0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B01809cOo`050?oo
o`80<`3o=03oool002L0oooo0P3o003o0?oooc@0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`0?0?ooo`030;md001d_ol0oooo00@0oooo0P0c0?ld0?ooo`009`3oool20?l00?l0oooo
=@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000B02Lgol0oooo0?oOW018
04P0W=oo00D0oooo0P0c0?ld0?ooo`009`3oool20?l00?l0oooo=@3oool01@3ookl0M00000000000
04P0W=oo00d0oooo00D0omnL04P000000000000007Boo`060?ooo`80<`3o=03oool002L0oooo0P3o
003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000X0?oo
o`030?l0003oool0oooo0?l0ooooD03oool203<0oc@0oooo000X0?ooo`030?l0003oool0oooo0?l0
ooooD03oool203<0o`030000003oool0oooo0340oooo000X0?ooo`030?l0003oool0oooo0?l0oooo
D@3oool00`0c0?l0oooo0?ooo`0b0?ooo`00o`3oooml0?ooo`0303<0o`3oool0oooo0380oooo003o
0?ooog`0oooo00<000000?ooo`3oool0<P3oool00?l0ooooO03oool00`000000oooo0?ooo`0b0?oo
o`00o`3oooml0?ooo`030000003oool0oooo0380oooo003o0?ooog`0oooo00<000000?ooo`3oool0
<P3oool00?l0ooooO03oool2000003<0oooo003o0?ooog`0oooo00<000000?ooo`3oool0<P3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-213.796, -0.0242234, \
0.845517, 0.00195088}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Stable Random Numbers",
    FontWeight->"Bold"],
  "\nStable random numbers are generated using the algorithm of Chambers, \
Mallows, and Stuck that has been clarified by Nolan.  The compiled algorithm \
for the 0-parameterization is presented below."
}], "Text"],

Cell[BoxData[{
    \(\(SRa = 
        Compile[{\[Alpha], \[Beta], r1, r2}, 
          Module[{w, \[Theta], \[Zeta]}, 
            w = \(-Log[r1]\); \[IndentingNewLine]\[Theta] = 
              Pi*\((r2 - 0.5)\); \[Zeta] = \((\(-\[Beta]\))\)*
                Tan[Pi*\((\[Alpha]/
                        2)\)]; \[IndentingNewLine]\[Zeta] + \
\((\((Sin[\[Alpha]*\[Theta]] - \[Zeta]*Cos[\[Alpha]*\[Theta]])\)/
                    Cos[\[Theta]]^\((1/\[Alpha])\))\)*\((\((Cos[\((1 - \
\[Alpha])\)*\[Theta]] - \[Zeta]*Sin[\((1 - \[Alpha])\)*\[Theta]])\)/
                      w)\)^\((\((1 - \[Alpha])\)/\[Alpha])\)]];\)\), "\n", 
    \(\(\(SR1 = 
        Compile[{\[Alpha], \[Beta], r1, r2}, 
          Module[{w, \[Theta]}, 
            w = \(-Log[r1]\); \[Theta] = 
              Pi*\((r2 - 
                    0.5)\); \[IndentingNewLine]\((\((Pi/
                          2 + \[Beta]*\[Theta])\)*Tan[\[Theta]] - \[Beta]*
                    Log[\((Pi/2)\)*
                        w*\((Cos[\[Theta]]/\((Pi/
                                  2 + \[Beta]*\[Theta])\))\)])\)*\((2/
                  Pi)\)]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(SRandom0[
          n_:  1, {\[Alpha]_, \[Beta]_:  0, \[Gamma]_:  1, \[Delta]_:  0}] := 
        Module[{mSR, rnd}, 
          mSR[{r1_, r2_}] := 
            If[\[Alpha] \[Equal] 1, SR1[\[Alpha], \[Beta], r1, r2], 
              SRa[\[Alpha], \[Beta], r1, r2]]; \[IndentingNewLine]rnd = 
            Table[{Random[], Random[]}, {n}]; \[IndentingNewLine]Map[mSR, 
                rnd]*\[Gamma] + \[Delta]];\)\), "\n", 
    \(\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SRandom0[20, {1.3, \(-1\), 0.5, 2}]\)], "Input"],

Cell[BoxData[
    \({2.619528893788933`, \(-6.293310628924498`\), \(-2.2216884351593746`\), 
      2.0252939091440836`, \(-1.9988259155868353`\), 1.4396514867430203`, 
      2.396711766737814`, 2.189581094475024`, 2.311050471123283`, 
      1.29240290605266`, 2.599567276244203`, \(-20.101394997301384`\), 
      2.03314236357613`, 2.047730581845933`, 2.5576604601215043`, 
      1.0713825062547595`, 1.8767054883889793`, 1.697347907520871`, 
      2.493884609662615`, 2.240174596324154`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The code does not round to \[Alpha]=1, but it can be used quite close, so \
there seems to be no need for the rounding in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  This algorithm when fed the same sequence of uniform random numbers \
that is given to the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " version of STABLE will produce a few random numbers in 10000 that are \
significantly different from the output of the STABLE program.  I believe the \
difference may be due to a routine to prevent the occurrence of w = 0, should \
Random[] generate a 1, or possibly due to a Tolerance setting of ",
  Cell[BoxData[
      \(10\^\(-14\)\)]],
  " in the STABLE program.  This algorithm is probably more accurate."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(seed = $RandomState;\)\), "\n", 
    \(SRandom0[10, {1.000000001, \(-1\), 0.5, 2}]\), "\n", 
    \(\($RandomState = seed;\)\), "\[IndentingNewLine]", 
    \(SRandom0[10, {1, \(-1\), 0.5, 2}]\)}], "Input"],

Cell[BoxData[
    \({0.7599461078643799`, \(-0.4090402126312256`\), 2.015596628189087`, 
      0.8420093655586243`, 2.343284845352173`, 
      1.69856858253479`, \(-1.2629019618034363`\), 
      1.341356873512268`, \(-1.4976858496665955`\), 
      1.5259844660758972`}\)], "Output"],

Cell[BoxData[
    \({0.7599461804912517`, \(-0.40904016145465505`\), 2.015596640514551`, 
      0.8420093330931975`, 2.3432847668920167`, 
      1.6985685996206161`, \(-1.262901815109442`\), 
      1.341356859207829`, \(-1.4976857752929238`\), 
      1.52598451825303`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - %%%\)], "Input"],

Cell[BoxData[
    \({7.262687184983463`*^-8, 5.117657053688163`*^-8, 
      1.2325464204820946`*^-8, \(-3.246542679136155`*^-8\), \
\(-7.846015614987323`*^-8\), 1.708582608728193`*^-8, 
      1.4669399428512975`*^-7, \(-1.4304438966661337`*^-8\), 
      7.43736716657395`*^-8, 5.217713283656167`*^-8}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Stable Series Expansion",
    FontWeight->"Bold"],
  "\nThe integrand of the PDF or CDF can be expanded by a Taylor series to \
create an infinite series.  It turns out that each of these terms can be \
integrated."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pfs = \(integrand1 /. {\[Gamma] \[Rule] 1, \[Delta] \[Rule] 
              0}\) /. \(-\[Beta]\)\ Tan[\[Pi]\ \[Alpha]/
                  2] \[Rule] \[Zeta]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-u\^\[Alpha]\)\ Cos[u\ x + u\^\[Alpha]\ \[Zeta]]\)\
\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zs = Normal[Series[pfs, {x, 0, 7}]]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-u\^\[Alpha]\)\ Cos[u\^\[Alpha]\ \[Zeta]]\)\/\[Pi] \
- \(\[ExponentialE]\^\(-u\^\[Alpha]\)\ u\^2\ x\^2\ Cos[u\^\[Alpha]\ \
\[Zeta]]\)\/\(2\ \[Pi]\) + \(\[ExponentialE]\^\(-u\^\[Alpha]\)\ u\^4\ x\^4\ \
Cos[u\^\[Alpha]\ \[Zeta]]\)\/\(24\ \[Pi]\) - \
\(\[ExponentialE]\^\(-u\^\[Alpha]\)\ u\^6\ x\^6\ Cos[u\^\[Alpha]\ \
\[Zeta]]\)\/\(720\ \[Pi]\) - \(\[ExponentialE]\^\(-u\^\[Alpha]\)\ u\ x\ Sin[u\
\^\[Alpha]\ \[Zeta]]\)\/\[Pi] + \(\[ExponentialE]\^\(-u\^\[Alpha]\)\ u\^3\ \
x\^3\ Sin[u\^\[Alpha]\ \[Zeta]]\)\/\(6\ \[Pi]\) - \(\[ExponentialE]\^\(-u\^\
\[Alpha]\)\ u\^5\ x\^5\ Sin[u\^\[Alpha]\ \[Zeta]]\)\/\(120\ \[Pi]\) + \(\
\[ExponentialE]\^\(-u\^\[Alpha]\)\ u\^7\ x\^7\ Sin[u\^\[Alpha]\ \
\[Zeta]]\)\/\(5040\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ts = 
        Table[Integrate[zs[\([i]\)], {u, 0, Infinity}, 
            Assumptions \[Rule] {\[Alpha] > 0, \[Zeta] \[Element] \ Reals, 
                x \[Element] \ Reals}], {i, 
            Length[zs]}];\)\), "\[IndentingNewLine]", 
    \(ts // TableForm\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(\((1 + \[Zeta]\^2)\)\^\(-\(1\/\(2\ \[Alpha]\)\)\)\ Cos[
                    ArcTan[Abs[\[Zeta]]]\/\[Alpha]]\ Gamma[
                    1 + 1\/\[Alpha]]\)\/\[Pi]\)},
          {\(-\(\(x\^2\ \((1 + \[Zeta]\^2)\)\^\(-\(3\/\(2\ \[Alpha]\)\)\)\ \
Cos[\(3\ ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\ Gamma[
                      3\/\[Alpha]]\)\/\(2\ \[Pi]\ \[Alpha]\)\)\)},
          {\(\(x\^4\ \((1 + \[Zeta]\^2)\)\^\(-\(5\/\(2\ \[Alpha]\)\)\)\ \
Cos[\(5\ ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\ Gamma[
                    5\/\[Alpha]]\)\/\(24\ \[Pi]\ \[Alpha]\)\)},
          {\(-\(\(x\^6\ \((1 + \[Zeta]\^2)\)\^\(-\(7\/\(2\ \[Alpha]\)\)\)\ \
Cos[\(7\ ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\ Gamma[
                      7\/\[Alpha]]\)\/\(720\ \[Pi]\ \[Alpha]\)\)\)},
          {\(-\(\(x\ \((1 + \[Zeta]\^2)\)\^\(\(-1\)/\[Alpha]\)\ Gamma[
                      2\/\[Alpha]]\ Sign[\[Zeta]]\ Sin[\(2\ \
ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\)\/\(\[Pi]\ \[Alpha]\)\)\)},
          {\(\(x\^3\ \((1 + \[Zeta]\^2)\)\^\(\(-2\)/\[Alpha]\)\ Gamma[
                    4\/\[Alpha]]\ Sign[\[Zeta]]\ Sin[\(4\ \
ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\)\/\(6\ \[Pi]\ \[Alpha]\)\)},
          {\(-\(\(x\^5\ \((1 + \[Zeta]\^2)\)\^\(\(-3\)/\[Alpha]\)\ Gamma[
                      6\/\[Alpha]]\ Sign[\[Zeta]]\ Sin[\(6\ \
ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\)\/\(120\ \[Pi]\ \[Alpha]\)\)\)},
          {\(\(x\^7\ \((1 + \[Zeta]\^2)\)\^\(\(-4\)/\[Alpha]\)\ Gamma[
                    8\/\[Alpha]]\ Sign[\[Zeta]]\ Sin[\(8\ \
ArcTan[Abs[\[Zeta]]]\)\/\[Alpha]]\)\/\(5040\ \[Pi]\ \[Alpha]\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Times[ 
          Power[ Pi, -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ 
              Rational[ -1, 2], 
              Power[ \[Alpha], -1]]], 
          Cos[ 
            Times[ 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]], 
          Gamma[ 
            Plus[ 1, 
              Power[ \[Alpha], -1]]]], 
        Times[ 
          Rational[ -1, 2], 
          Power[ Pi, -1], 
          Power[ x, 2], 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ 
              Rational[ -3, 2], 
              Power[ \[Alpha], -1]]], 
          Cos[ 
            Times[ 3, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]], 
          Gamma[ 
            Times[ 3, 
              Power[ \[Alpha], -1]]]], 
        Times[ 
          Rational[ 1, 24], 
          Power[ Pi, -1], 
          Power[ x, 4], 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ 
              Rational[ -5, 2], 
              Power[ \[Alpha], -1]]], 
          Cos[ 
            Times[ 5, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]], 
          Gamma[ 
            Times[ 5, 
              Power[ \[Alpha], -1]]]], 
        Times[ 
          Rational[ -1, 720], 
          Power[ Pi, -1], 
          Power[ x, 6], 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ 
              Rational[ -7, 2], 
              Power[ \[Alpha], -1]]], 
          Cos[ 
            Times[ 7, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]], 
          Gamma[ 
            Times[ 7, 
              Power[ \[Alpha], -1]]]], 
        Times[ -1, 
          Power[ Pi, -1], x, 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ -1, 
              Power[ \[Alpha], -1]]], 
          Gamma[ 
            Times[ 2, 
              Power[ \[Alpha], -1]]], 
          Sign[ \[Zeta]], 
          Sin[ 
            Times[ 2, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]]], 
        Times[ 
          Rational[ 1, 6], 
          Power[ Pi, -1], 
          Power[ x, 3], 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ -2, 
              Power[ \[Alpha], -1]]], 
          Gamma[ 
            Times[ 4, 
              Power[ \[Alpha], -1]]], 
          Sign[ \[Zeta]], 
          Sin[ 
            Times[ 4, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]]], 
        Times[ 
          Rational[ -1, 120], 
          Power[ Pi, -1], 
          Power[ x, 5], 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ -3, 
              Power[ \[Alpha], -1]]], 
          Gamma[ 
            Times[ 6, 
              Power[ \[Alpha], -1]]], 
          Sign[ \[Zeta]], 
          Sin[ 
            Times[ 6, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]]], 
        Times[ 
          Rational[ 1, 5040], 
          Power[ Pi, -1], 
          Power[ x, 7], 
          Power[ \[Alpha], -1], 
          Power[ 
            Plus[ 1, 
              Power[ \[Zeta], 2]], 
            Times[ -4, 
              Power[ \[Alpha], -1]]], 
          Gamma[ 
            Times[ 8, 
              Power[ \[Alpha], -1]]], 
          Sign[ \[Zeta]], 
          Sin[ 
            Times[ 8, 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Abs[ \[Zeta]]]]]]}]]], "Output"]
}, Open  ]],

Cell["\<\
This can be put back together in a series.  Below this series is shown as \
MidPDF.  The rest of the series for the PDF and CDF are given for \[Alpha] \
\[NotEqual] 1.  The Mid series converge when \[Alpha] > 1 and the Tail series \
converge when \[Alpha] < 1.  They both explode before they converge.  In the \
range that they do not converge they still can be used asymptotically before \
they explode.  The Tail series is most useful in this respect as it can give \
highly accurate estimates with few terms when \[Alpha] > 1, but the Mid \
series can also give the formula for the case x = 0.\
\>", "Text"],

Cell[BoxData[{
    \(\(MidPDF[\[Alpha]_, \[Beta]_, x_, 
          n_]\  := \ \ \ \ Sum[\(-\(\(1\/\(\[Pi]\ \(k!\)\)\) \
\((\((\(-1\))\)\^k\ x\^\(\(-1\) + k\)\ Gamma[\(k + \[Alpha]\)\/\[Alpha]]\ \
Sin[\(k\ \[Pi]\)\/2 + \(k\ ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\)\/\
\[Alpha]]\ \((1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\^2)\)\^\(-\(k\/\(2\ \
\[Alpha]\)\)\))\)\)\), {k, 1, n}];\)\), "\n", 
    \(\(TailPDF[\[Alpha]_, \[Beta]_, x_, 
          n_] := \ \ Sum[\(-\(\(1\/\(\[Pi]\ \(k!\)\)\) \((\((\(-1\))\)\^k\ \
x\^\(\(-1\) - k\ \[Alpha]\)\ Gamma[
                    1 + k\ \[Alpha]]\ Sin[\(k\ \[Pi]\ \[Alpha]\)\/2 + 
                      k\ ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]]\ \((1 \
+ \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\^2)\)\^\(k/2\))\)\)\), {k, 1, 
            n}];\)\), "\n", 
    \(\ \(MidCDF[\[Alpha]_, \[Beta]_, x_, n_] := \ 
        1/2 - ArcTan[\[Beta]\ Tan[Pi\ \[Alpha]/2]]\/\(Pi\ \[Alpha]\)\  + 
          Sum[\(-\(\(\((\(-1\))\)\^k\ x\^k\ Gamma[\(k + \[Alpha]\)\/\[Alpha]]\
\ Sin[\(k\ \[Pi]\)\/2 + \(k\ ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\)\/\
\[Alpha]]\ \((1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\^2)\)\^\(-\(k\/\(2\ \
\[Alpha]\)\)\)\)\/\(k\ \[Pi]\ \(k!\)\)\)\), {k, 1, n}];\)\), "\n", 
    \(\(TailCDF[\[Alpha]_, \[Beta]_, x_, 
          n_] := \ \ 1\  + \ \ Sum[\(\((\(-1\))\)\^k\ x\^\(\(-k\)\ \[Alpha]\)\
\ Gamma[1 + k\ \[Alpha]]\ Sin[\(k\ \[Pi]\ \[Alpha]\)\/2 + k\ ArcTan[\[Beta]\ \
Tan[\(\[Pi]\ \[Alpha]\)\/2]]]\ \((1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\/2]\
\^2)\)\^\(k/2\)\)\/\(k\ \[Pi]\ \[Alpha]\ \(k!\)\), {k, 1, n}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(MidPDF[\[Alpha], \[Beta], x, 3];\)\), "\[IndentingNewLine]", 
    \(% /. x \[Rule] 0\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(Cos[ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\[Alpha]]\ \
Gamma[\(1 + \[Alpha]\)\/\[Alpha]]\ \((1 + \[Beta]\^2\ Tan[\(\[Pi]\ \[Alpha]\)\
\/2]\^2)\)\^\(-\(1\/\(2\ \[Alpha]\)\)\)\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(MidCDF[\[Alpha], \[Beta], x, 1];\)\), "\[IndentingNewLine]", 
    \(% /. x \[Rule] 0\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(1\/2 - 
      ArcTan[\[Beta]\ Tan[\(\[Pi]\ \[Alpha]\)\/2]]\/\(\[Pi]\ \[Alpha]\)\)], \
"Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      Create\ compiled\ functions\ for\ greater\ speed\ in\ Mathematica\ \
*) \)\(\n\)\(\(FnMidPDF[\[Alpha]_, \[Beta]_, n_] := \ 
        Function[x, Evaluate[MidPDF[\[Alpha], \[Beta], x, n]]];\)\n
    \(FnTailPDF[\[Alpha]_, \[Beta]_, n_] := \ 
        Function[x, Evaluate[TailPDF[\[Alpha], \[Beta], x, n]]];\)\n
    \(FnLeftTailPDF[\[Alpha]_, \[Beta]_, n_] := \ 
        Function[x, 
          Evaluate[TailPDF[\[Alpha], \(-\[Beta]\), \(-x\), n]]];\)\n
    \(FnMidCDF[\[Alpha]_, \[Beta]_, n_] := \ 
        Function[x, Evaluate[MidCDF[\[Alpha], \[Beta], x, n]]];\)\n
    \(FnTailCDF[\[Alpha]_, \[Beta]_, n_] := \ 
        Function[x, Evaluate[TailCDF[\[Alpha], \[Beta], x, n]]];\)\n
    \(FnLeftTailCDF[\[Alpha]_, \[Beta]_, n_] := \ 
        Function[x, 
          1 - Evaluate[
              TailCDF[\[Alpha], \(-\[Beta]\), \(-x\), n]]];\)\)\)\)], "Input"],

Cell["The graphs show where the explosion occurs.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      To\ demonstrate\ different\ values\ for\ \[Alpha]\ and\ \[Beta], \ 
      change\ the\ values\ below\ and\ re - 
        evaluate\ this\ cell\ *) \)\(\[IndentingNewLine]\)\( (*\ 
      The\ plot\ range\ of\ x\ may\ have\ to\ be\ extended\ for\ some\ values\
\ of\ \[Alpha]\ and\ \[Beta]\ *) \)\(\n\)\(\(Off[
        Plot::"\<plnr\>"];\)\[IndentingNewLine]
    \(Clear[\[Alpha], \[Beta], x];\)\n
    \[Alpha]\  = 1.3; \ \[Beta]\  = \(-0.91\);\n
    Clear[rt]; \ rt\  = FnTailCDF[\[Alpha], \[Beta], 20];\n
    Clear[lt]; \ lt\  = \ FnLeftTailCDF[\[Alpha], \[Beta], 20];\n
    Clear[mid]; mid = FnMidCDF[\[Alpha], \[Beta], 100];\n
    \(dist\  = \ \ Plot[Evaluate[{lt[x], mid[x], rt[x]}], {x, \(-15\), 15}, 
          PlotRange \[Rule] \ {{\(-15\), 15}, {0, 1.0}}, 
          PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 0, 1], 
              RGBColor[1, 0, 0]}];\)\[IndentingNewLine]
    Clear[rt]; \ rt\  = FnTailPDF[\[Alpha], \[Beta], 20];\n
    Clear[lt]; \ lt\  = \ FnLeftTailPDF[\[Alpha], \[Beta], 20];\n
    Clear[mid]; mid = FnMidPDF[\[Alpha], \[Beta], 100];\n
    \(dens\  = \ \ Plot[Evaluate[{lt[x], mid[x], rt[x]}], {x, \(-15\), 15}, 
          PlotRange \[Rule] \ {{\(-15\), 15}, {0, 1.0}}, 
          PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 0, 1], 
              RGBColor[1, 0, 0]}];\)\[IndentingNewLine]
    \(Show[dist, dens];\)\[IndentingNewLine]
    \(On[Plot::"\<plnr\>"];\)\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0 0.618034 [
[0 -0.0125 -9 -9 ]
[0 -0.0125 9 0 ]
[.16667 -0.0125 -9 -9 ]
[.16667 -0.0125 9 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-15)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-5)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(5)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(15)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .00842 m
.04057 .00934 L
.08481 .01057 L
.12636 .012 L
.16632 .01373 L
.20885 .0161 L
.2498 .01916 L
.27066 .02112 L
.29331 .02368 L
.33524 .0301 L
.35566 .03434 L
.36125 .03563 L
.36727 .03698 L
.36866 .03726 L
.37018 .03754 L
.37152 .03774 L
.37226 .03784 L
.37295 .03791 L
.37363 .03796 L
.37437 .038 L
.37565 .03798 L
.37695 .03784 L
.37815 .03755 L
.3794 .03705 L
.38054 .03634 L
.38186 .03513 L
.3831 .03346 L
.38425 .0313 L
.38532 .02861 L
.38649 .02464 L
.38773 .01887 L
.38897 .01091 L
s
.38897 .01091 m
.39019 0 L
s
0 0 1 r
.3253 .61803 m
.32613 .37265 L
.3274 .19362 L
.32879 .10245 L
.3301 .06323 L
.33131 .04599 L
.33251 .0377 L
.3336 .03401 L
.33486 .032 L
.33604 .03121 L
.33734 .03093 L
.33871 .03094 L
.33988 .03108 L
.34116 .03128 L
.34669 .03238 L
.36592 .03692 L
.38645 .04306 L
.40843 .05174 L
.43078 .06384 L
.44104 .07095 L
.45192 .07991 L
.46189 .08971 L
.47287 .1027 L
.49223 .13298 L
.50286 .15488 L
.51259 .17908 L
.53451 .25133 L
.55442 .33999 L
.57617 .45146 L
.5868 .50249 L
.59681 .54297 L
.60236 .56114 L
.60835 .57711 L
.61381 .58837 L
.61883 .59625 L
.62375 .60199 L
.62646 .60444 L
.62904 .60636 L
.63142 .60785 L
.63402 .60919 L
.63857 .61097 L
.64117 .61173 L
.64403 .6124 L
.64682 .61293 L
.64984 .61339 L
.65264 .61373 L
.65387 .61386 L
.65521 .61398 L
.65649 .61408 L
.65767 .61413 L
Mistroke
.65892 .61413 L
.66026 .61397 L
.66155 .6135 L
.66229 .61297 L
.66298 .61217 L
.66436 .60899 L
.66514 .60556 L
.66585 .60064 L
.66711 .58451 L
.66849 .54558 L
.6698 .46457 L
.671 .30817 L
.67174 .14347 L
Mfstroke
.67174 .14347 m
.67215 0 L
s
1 0 0 r
.60402 0 m
.60519 .14306 L
.60642 .25266 L
.60776 .34207 L
.60922 .41229 L
.61077 .46623 L
.61224 .50288 L
.61358 .52766 L
.61492 .54653 L
.61617 .55994 L
.61754 .57128 L
.61899 .58045 L
.62025 .58659 L
.62143 .59119 L
.62273 .59524 L
.62411 .59867 L
.62545 .60129 L
.62667 .60322 L
.62905 .60608 L
.63038 .60729 L
.63183 .60836 L
.63445 .60985 L
.6372 .61098 L
.64011 .61184 L
.64259 .61241 L
.64532 .6129 L
.65016 .61356 L
.65536 .61407 L
.66027 .61444 L
.66476 .61472 L
.67513 .61521 L
.68475 .61554 L
.6953 .61583 L
.70653 .61607 L
.72907 .61642 L
.75026 .61666 L
.7714 .61684 L
.79082 .61697 L
.81232 .61709 L
.83235 .61718 L
.8723 .61731 L
.91323 .61742 L
.95674 .6175 L
.99865 .61757 L
1 .61757 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{514.688, 318.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<40001gB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo000F0?ooo`030?noM0000000000000<0
000000D007Bo0?ooo`3oool0oooo0;md00030000000307Boo`3oool0oooo06P0oooo00<0okmd0000
000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0K@3oool0
1@2oM0000000000000000000M;oo0>L0oooo00D0_g@0000000000000000007Boo`1^0?ooo`030?no
M0000000000000<0000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo06P0
oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?oo
o`3oool03P3oool001T0oooo00<0W4Q809cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0omnL
04P0001d_ol0K03oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo
K@3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0i@3oool01`2oM00007Bo0?ooo`3oool0
omnL04P0001d_ol0L03oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_oooK03oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0?
0?ooo`006@3oool00`2LB4P0W=oo0?ooo`080?ooo`030?noM000M;l0oooo06/0oooo00<0W4Q809cO
o`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo0740oooo00<0okmd001d
_`3oool0j@3oool00`3o_g@007Bo0?ooo`1_0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`1[0?ooo`0309a8B02Lgol0oooo00P0oooo00<0okmd001d
_`3oool03P3oool001T0oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`1[0?ooo`03
09a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1a0?ooo`03
0?noM000M;l0oooo0>T0oooo00<0okmd001d_`3oool0K`3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0J`3oool00`2LB4P0W=oo0?ooo`080?ooo`03
0?noM000M;l0oooo00h0oooo000=0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
0`3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo05l0oooo00<0W4P0000000000000
0`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`1S0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
1@3oool00`2LB000M;oo0?ooo`3Y0?ooo`0309a8001d_ol0oooo06l0oooo00<0W4Q809cOo`3oool0
0`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo06/0oooo00<0W4Q809cOo`3oool0
203oool00`2LB000M;oo0?ooo`0>0?ooo`006@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0J`3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool0K03oool00`3ookl0M000000000020000000304RLg`3o
ool0oooo0>@0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`1_0?ooo`0309a8B02L
gol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1[0?ooo`0309a8B02L
gol0oooo00<0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0>0?ooo`006@3oool0
0`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0_ooo0700oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo06`0oooo00<0oono07@0M02oool0j@3oool0
0`3ookl0M01d0;ooo`1d0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`1[0?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool04`3oool0
01H0oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo06d0oooo00D0gia8
00000000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_oooK@3oool00`3ookl0
M01d0;ooo`3Y0?ooo`030?oo_`1d07@0_ooo0740oooo00D0gia800000000B9`0W4Q809cOo`050?oo
o`0609a8001d_ol0oooo0?oOW01807@0_oooJ@3oool01@3OW4P000000018W02LB4P0W=oo00@0oooo
00<0oono07@0M02oool04`3oool001P0oooo00<0gia80000B02Lgol0103oool00`3ookl0M0000000
0002000000030000M02oool0oooo06X0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000
000004P0W=oo06h0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`3T0?ooo`030?oo
_`1d000000000080000000<0001d0;ooo`3oool0KP3oool00`3OW4P0001809cOo`050?ooo`050?oo
_`1d000000000000B02Lgol0K03oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080
000000<0001d0;ooo`3oool03P3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?ooool0ooooo`3o
ool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?ooool0
ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o
0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0
oooo003o0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool001X0ooooo`00000K
000000030?l000000000000009L0000000<0o`00000000000000;`0000000`000?l000000000003[
000001H0oooo000J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o00005@3oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000?l04`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D
0?ooo`006P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0o`0001D0oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool0003o01<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool0
01X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00h0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?l0000E0?ooo`030000003oool0oooo
01D0oooo00D000000?ooo`3oool0oooo0000o`0C0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo000J0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0U0?oo
o`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0[0?oo
o`050000003oool0oooo0?ooo`000?l0L`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo01@0oooo003o0?oooc@0oooo00<0o`000?ooo`3oool0C@3oool00`000000oooo0?ooo`180?oo
o`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`006P3oool?0?l00?l0
oooo2`3oool00`3o0000oooo0?ooo`1=0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3o
ool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo000Y0?ooocH0o`00e03oool00`3o0000oooo
0?ooo`1=0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo001O0?ooo`l0o`00a@3oool00`3o0000oooo0?ooo`1=0?ooo`030000003o
ool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo001^
0?oooaH0o`00[`3oool00`3o0000oooo0?ooo`1=0?ooo`030000003oool0oooo04P0oooo00<0o`00
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo00240?oooah0o`00T@3oool00`3o
0000oooo0?ooo`1=0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`3o0?ooo`80oooo002R0?oooa@0o`00O03oool00`3o0000oooo0?ooo`1>0?ooo`03
0000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80
oooo002f0?ooo`X0o`00LP3oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo04P0oooo
00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo00300?ooo`X0o`00J03o
ool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3o
ool00`000?l0oooo0?ooo`3o0?ooo`80oooo003:0?ooo``0o`00G03oool00`3o0000oooo0?ooo`1>
0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o
0?ooo`80oooo003F0?ooo``0o`00D03oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo
04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003R0?ooo`P0
o`00A`3oool00`3o0000oooo0?ooo`1?0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3o
ool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003Z0?ooo`L0o`00@03oool00`3o0000oooo
0?ooo`1?0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo003a0?ooo`H0o`00>P3oool00`3o0000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003g
0?ooo`H0o`00=03oool00`3o0000oooo0?ooo`1?0?ooo`030000003oool0oooo04P0oooo00<0o`00
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003m0?ooo`H0o`00;@3oool00`3o
0000oooo0?ooo`1@0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`@0oooo1P3o000W0?ooo`030?l0003oool0oooo0500
oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0
oooo0P3oool00?l0oooo2P3oool40?l000D0003o7P3oool00`3o0000oooo0?ooo`1@0?ooo`@00000
A`3oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo3@3o
ool00`000?l0oooo0?ooo`030?l000@0003o6@3oool00`3o0000oooo0?ooo`1A0?ooo`030000003o
ool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o
0?ooo``0oooo00<0003o0?ooo`3oool01P3oool20?l000@0003o5@3oool00`3o0000oooo0?ooo`1A
0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o
0?ooo`80oooo003o0?ooo``0oooo00<0003o0?ooo`3oool02`3oool0103o0000003o0000o`000?lA
0?ooo`030?l0003oool0oooo0580oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_
0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2`3oool00`000?l0oooo0?ooo`0@0?oo
o`@0003o303oool00`3o0000oooo0?ooo`1C0?ooo`030000003oool0oooo04P0oooo00<0o`000?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`/0oooo00<0003o0?ooo`3o
ool0503oool30000o`T0o`00EP3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo02l0
oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool;0?ooo`030000o`3oool0oooo01L0oooo
10000?mK0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool06`3oool40000oeL0oooo00<0
00000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0oooo0P3o
ool00?l0oooo2P3oool00`000?l0oooo0?ooo`0P0?ooo`@0003oD`3oool00`000000oooo0?ooo`18
0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool:0?oo
o`030000o`3oool0oooo02@0oooo0`000?m@0?ooo`030000003oool0oooo04P0oooo00<0o`000?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`X0oooo00<0003o0?ooo`3o
ool09`3oool20000odh0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2P3oool00`000?l0oooo0?ooo`0Y0?ooo`<0003o
B`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0
o`3oool20?ooo`00o`3oool:0?ooo`030000o`3oool0oooo02`0oooo0`000?m80?ooo`030000003o
ool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o
0?ooo`X0oooo00<0003o0?ooo`3oool0;`3oool20000odH0oooo00<000000?ooo`3oool0B03oool0
0`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2P3oool00`00
0?l0oooo0?ooo`0a0?ooo`<0003o@`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo
02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool:0?ooo`030000o`3oool0oooo03@0
oooo0P000?m10?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`3o0?ooo`80oooo003o0?ooo`X0oooo00<0003o0?ooo`3oool0=P3oool20000ocl0oooo
00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0oooo
0P3oool00?l0oooo2P3oool00`000?l0oooo0?ooo`0h0?ooo`80003o?@3oool00`000000oooo0?oo
o`180?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool9
0?ooo`030000o`3oool0oooo03/0oooo0P000?lk0?ooo`030000003oool0oooo04P0oooo00<0o`00
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?oo
o`3oool0?@3oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo04P0oooo00<0o`000?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3o
ool0?P3oool20000ocP0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2@3oool00`000?l0oooo0?ooo`100?ooo`80003o
=P3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0
o`3oool20?ooo`00o`3oool90?ooo`030000o`3oool0oooo0480oooo0P000?ld0?ooo`030000003o
ool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o
0?ooo`T0oooo00<0003o0?ooo`3oool0A03oool20000oc80oooo100000170?ooo`030?l0003oool0
oooo02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool90?ooo`030000o`3oool0oooo
04H0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo
02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool90?ooo`030000o`3oool0oooo04L0
oooo0P000?l_0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0B@3oool00`000?l0oooo
0?ooo`0/0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0BP3oool20000ob`0oooo00<0
00000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0oooo0P3o
ool00?l0oooo2@3oool00`000?l0oooo0?ooo`1<0?ooo`80003o:P3oool00`000000oooo0?ooo`18
0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool90?oo
o`030000o`3oool0oooo04h0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`180?oo
o`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool90?ooo`03
0000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`190?ooo`03
0?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000
o`3oool0oooo0500oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`190?ooo`030?l0
003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3o
ool0oooo0540oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`190?ooo`030?l0003o
ool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3oool0
oooo0580oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0
oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3oool0oooo
05<0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo
02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3oool0oooo05@0
oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3oool0oooo05D0oooo
00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3oool0oooo05H0oooo00<0
003o0?ooo`3oool07`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0
003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo05P0oooo00<0003o
0?ooo`3oool07P3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo05T0oooo00<0003o0?oo
o`3oool07@3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo05X0oooo0P000?lM0?ooo`03
0000003oool0oooo04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0G03oool00`000?l0oooo0?ooo`0J0?ooo`030000
003oool0oooo04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`P0oooo00<0003o0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0I0?ooo`030000003o
ool0oooo04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`P0oooo00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0
oooo04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`P0oooo00<0003o0?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo
04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0
oooo00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`0F0?ooo`@00000B03oool00`3o0000
oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo
0?ooo`1Q0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo
0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?oo
o`1R0?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?oo
o`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1R
0?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1S0?oo
o`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1T0?ooo`03
0000o`3oool0oooo0180oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1U0?ooo`030000
o`3oool0oooo0140oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1V0?ooo`030000o`3o
ool0oooo0100oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1W0?ooo`030000o`3oool0
oooo00l0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0
oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1W0?ooo`030000o`3oool0oooo
00l0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1X0?ooo`030000o`3oool0oooo00h0
oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00d0oooo
00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00d0oooo00<0
00000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3o
ool00?l0oooo203oool00`000?l0oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00`0oooo00<00000
0?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool0
0?l0oooo203oool00`000?l0oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00`0oooo00<000000?oo
o`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo203oool00`000?l0oooo0?ooo`1[0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3o
ool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo
203oool00`000?l0oooo0?ooo`1/0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0
B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203o
ool00`000?l0oooo0?ooo`1/0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0B@3o
ool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool0
0`000?l0oooo0?ooo`1]0?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3oool0B@3oool0
0`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`00
0?l0oooo0?ooo`1G0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`03
0?ooo`030?oo_`1d0000000000@0000000<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`19
0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?oo
o`030000o`3oool0oooo05L0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000
000007Bo00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0003o0?ooo`090?ooo`030000003o
ool0oooo04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`P0oooo00<0003o0?ooo`3oool0EP3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0
oooo00/0oooo00<0okmd0000B02Lgol00`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0
oooo04T0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`P0oooo00<0003o0?ooo`3oool0EP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
00`0oooo00<0omnL04P00018W=l00`3oool00`000?l0oooo0?ooo`060?ooo`H00000AP3oool00`3o
0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0
oooo0?ooo`1F0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool01@2LB000
B9cO0?ooo`3oool0003o00P0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1F0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool01@2LB7@0_ooo0?ooo`3oool0003o
00L0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1F0?ooo`030?noM018W=l0oooo0080
oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`050;md001d_ol0oooo0?oo
o`000?l01`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo05L0oooo00H0W4P007Boo`3o
ool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`030000
o`3oool0oooo00@0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1G0?ooo`050?oo_`1d
000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07<0oooo00<0003o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07@0oooo00<0003o0?ooo`3oool00P3o
ool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3o
ool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07@0oooo00<0003o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool80?ooo`030000o`3oool0oooo07D0oooo00D0003o0?ooo`3oool0oooo0000001;
0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?oo
o`030000o`3oool0oooo07D0oooo00D0003o0?ooo`3oool0oooo0000001;0?ooo`030?l0003oool0
oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo
07H0oooo00@0003o0?ooo`3oool00000B`3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0
oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1f0?ooo`040000o`3oool0oooo
000004/0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`P0oooo00<0003o0?ooo`3oool0M`3oool00`000?l0oooo0000001;0?ooo`030?l0003oool0oooo
02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07L0
oooo00<0003o0?ooo`000000B`3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1g0?ooo`030000o`3oool0000004/0oooo
00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0
003o0?ooo`3oool0N03oool00`000?l000000?ooo`1:0?ooo`030?l0003oool0oooo02d0oooo00<0
003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07P0oooo00<0003o
0000003oool0BP3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool0
0?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000o`3oool0oooo04T0oooo00<0o`000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000?l0oooo0?ooo`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000000o`3oool0
B@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`03000000000?l0oooo04T0oooo00<0o`000?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool0
0`000000oooo0000o`190?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo0P0000000`000?l000000?ooo`170?oo
o`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`000?l0B@3oool00`3o0000oooo0?ooo`0]0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`040000
003oool0oooo0000odP0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool010000000oooo0?ooo`000?m80?ooo`03
0?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00D000000?ooo`3oool0oooo0000o`170?ooo`030?l0003oool0oooo02d0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00D000000?ooo`3oool0oooo0000o`170?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00D000000?ooo`3oool0
oooo0000o`170?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`140?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`140?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`13
0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`130?oo
o`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`120?ooo`03
0?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`120?ooo`030?l0
003oool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`120?ooo`030?l0003o
ool0oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo07X0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`110?ooo`030?l0003oool0
oooo02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`110?ooo`030?l0003oool0oooo
02d0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0
oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`100?ooo`030?l0003oool0oooo02d0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`100?ooo`030?l0003oool0oooo02d0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool01P3oool00`000?l0oooo0?ooo`100?ooo`030?l0003oool0oooo02d0oooo00<0
003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<00000
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0o0?ooo`030?l0003oool0oooo02d0oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0o0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0o0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo100000070?ooo`030000
o`3oool0oooo03h0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`080?ooo`030000o`3o
ool0oooo03h0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0
oooo03h0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo
03h0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo03d0
oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo
00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo03d0oooo
00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo03d0oooo00<0
o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo03`0oooo00<0o`00
0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0
NP3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?ooo`3oool0;03oool0
0`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo03/0oooo00<0o`000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo03/0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo03/0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo03X0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo03X0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo03X0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo03T0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo03T0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool4000000d0oooo00<0003o0?ooo`3oool0>@3oool0
0`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`00
0?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0>@3oool00`3o
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0
oooo0?ooo`1j0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0>03oool00`3o0000
oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0>03oool00`3o0000oooo
0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0>03oool00`3o0000oooo0?oo
o`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0/
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?oo
o`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0/0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo0100oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0/0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000
003oool0oooo0140oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0/0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo0140oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo0140oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo
0140oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0180
oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0180oooo
00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0180oooo00<0
003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3o
ool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01<0oooo00<0003o
0?ooo`3oool0=03oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool0
0?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01<0oooo00<0003o0?oo
o`3oool0=03oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3o
ool0=03oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo
1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0
<`3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1H0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000
001d_`060?ooo`050?oOW018000000000000001d_ol02P3oool00`000000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo03<0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0F03oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`@0oooo00<0_g@000000000M;l0203oool00`2oM000M;oo0?ooo`0:0?ooo`030000003oool0oooo
01@0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1G0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool03P3oool00`2oM000M;oo0?ooo`0:0?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1G0?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool02P3oool00`3OW4P00000000000030000000307Boo`3oool0oooo00P0oooo
00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003oool0oooo02`0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo05L0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`060?noM00007@0_ooo0?ooo`2oM000
M;oo2`3oool600000180oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0/0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1G0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo0?ooo`2oM000M;oo00/0
oooo00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003oool0oooo02`0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo05L0oooo
00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0<0?ooo`0409a80018W=l0_g@007Boo`/0
oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo02`0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo05P0oooo
00H0W4P007Boo`3oool0omnL04P0M02oool=0?ooo`040?oOW01804P0B4P007Boo`/0oooo00<00000
0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo02`0oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo05P0oooo00D0oono07@0
00000000001809cOo`0?0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?oo
o`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`0`0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0`0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?oo
o`0`0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0`
0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0_0?oo
o`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0_0?ooo`03
0?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0_0?ooo`030?l0
003oool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0_0?ooo`030?l0003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo07X0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0
oooo02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo
02`0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0
oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo02`0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo02`0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo02`0oooo00<0
003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<00000
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo02`0oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?oo
o`3oool06P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo1000000I0?ooo`030000
o`3oool0oooo02d0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo02`0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo02`0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
02`0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02`0
oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo
00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo02/0oooo
00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo02/0oooo00<0
o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo02/0oooo00<0o`00
0?ooo`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo02/0oooo00<0o`000?oo
o`3oool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0
NP3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0;03oool0
0`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0N0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0N
0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0O0?oo
o`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo02T0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool4000001l0oooo00<0003o0?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`00
0?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0
oooo0?ooo`1j0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0:03oool00`3o0000
oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo
0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`0[
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?oo
o`030000003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`0[0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`0[0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000
003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`0[0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo0280oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo0280oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0
oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0280
oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02<0oooo
00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02<0oooo00<0
003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3o
ool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02<0oooo00<0003o
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool0
0?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02<0oooo00<0003o0?oo
o`3oool09@3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3o
ool0903oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo
1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0
903oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0903o
ool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0903oool0
0`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`00
0?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`3o
0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0
oooo0?ooo`1j0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`3o0000
oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`@00000903oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02/0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02/0oooo00<0
003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<00000
0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02/0oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?oo
o`3oool09P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool09P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0
9P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09P3o
ool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3o
ool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?oo
o`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`0Q0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0Q0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0Q
0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?ooo`030?l0
003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo07X0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0
oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
05P0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00H0oooo00D0_g@0
000000000000001d0;ooo`0:0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0803o
ool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1H0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000
001d_`050?ooo`060=nLB000M;l0oooo0?ooo`3o_g@007Bo2P3oool00`000000oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0E`3oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo00X0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M4RL0?ooo`090?ooo`03
0000003oool0oooo02T0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0[0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1G0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool01`3o_g@004Q807@0M02oool0oooo0=nL
B000M;l02P3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?oo
o`3oool0:`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0E`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0omnL04Q8W03o
_g@00P0000000`00B9`0oooo0?ooo`090?ooo`H000009P3oool00`000?l0oooo0?ooo`0O0?ooo`03
0?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo05L0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo
_`1d07@0_ooo00h0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0
003oool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo05L0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030;md0018
W=l0oooo00d0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo02/0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo05P0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<0?ooo`030?oo_`1d000007Bo00d0oooo
00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo02/0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo05P0oooo00D0
oono07@000000000001809cOo`0?0?ooo`040;md0000000000000018W0X0oooo00<000000?ooo`3o
ool0:P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0
:P3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:P3o
ool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0o`3o
ool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:P3oool0
0`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:`3oool00`00
0?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0o`3oool30?oo
o`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:`3oool00`000?l0
oooo0?ooo`0N0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`0N0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`0N0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0N
0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?oo
o`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`03
0?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0
003oool0oooo02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0
oooo07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0
oooo02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo
02T0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0
oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo02T0
oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo02T0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo02T0oooo00<0
003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo1000000/
0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o
0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0]0?oo
o`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?oo
o`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0^0?ooo`03
0000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0^0?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0
oooo01/0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?oo
o`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo
01/0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0
oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo
00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0oooo
00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0oooo00<0o`00
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3o
ool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0
NP3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0:@3oool00`00
0?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000
oooo0?ooo`0`0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo
0?ooo`0a0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo
0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0a0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?oo
o`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0a
0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o
0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0a0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?oo
o`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0a0?ooo`03
0000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`3o0?ooo`@0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool400000340oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`00
0?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool05`3oool00`3o
0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0
oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool05`3oool00`3o0000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo
0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?oo
o`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0X
0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?oo
o`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0X0?oo
o`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo03<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000
003oool0oooo03<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0X0?ooo`030000
o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo03@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo03@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0
oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo
03@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo
0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03@0
oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0
oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03@0oooo
00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo
103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103o
ool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo00<0003o
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool0
0?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo00<0003o0?oo
o`3oool05@3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0
oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo
1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0
503oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1j0?ooo`@00000=@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0
oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo02P0
oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02P0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02P0oooo00<0
003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<00000
0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02P0oooo00<0003o
0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?oo
o`3oool0=`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?oo
o`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool0=`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3o
ool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0
>03oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>03o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3o
ool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>03oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3oool4
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>03oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3oool40?oo
o`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo02L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo05P0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo
00D0_g@00000000000000000001d_`0;0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo
1`3oool00`000?l0oooo0?ooo`1H0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2o
M0000000001d_`040?ooo`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool02@3oool00`00
0000oooo0?ooo`0j0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0E`3oool00`3o_g@0
07Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia804RLg`3oool00P3oool00`2oM000
M;oo0?ooo`090?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1G0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3o_g@004RL
0?ooo`020?ooo`0309a8B02Lgol0oooo00T0oooo1P00000h0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0
003o0?ooo`3oool0F03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0
gia8000000000000000004RLg`0;0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1P3o
ool00`000?l0oooo0?ooo`1H0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3o
ool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo00T0oooo00<000000?ooo`3oool0>`3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0o`3o
ool40?ooo`00o`3oool60?ooo`030000o`3oool0oooo05P0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0:0?ooo`030?noM018W=l0oooo0080oooo00<0_g@007Boo`3oool02@3oool0
0`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0F@3oool01P2L
B000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0omnL04P0M02oool0oooo0?oOW01807@0_ooo00X0
oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0
oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool60?ooo`030000o`3oool0oooo05T0oooo
00D0oono07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol02`3oool00`00
0000oooo0?ooo`0l0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000
oooo0?ooo`0l0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo
0?ooo`0l0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?oo
o`0l0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0m
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o
0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0m0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?oo
o`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0m0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`D0
oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0m0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo
003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o
0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?oo
o`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0
oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo
00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0
003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o
0?ooo`3oool0N`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?oo
o`3oool0N`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3o
ool0N`3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0
N`3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3o
ool4000003l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0
oooo0400oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0
oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo
0440oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0440
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0
oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0440oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo
1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0440oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo1@3o
ool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0480oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool0
0?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0480oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0
oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo
1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3o
ool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`00
0?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0
oooo0?ooo`1k0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo
0?ooo`1k0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?oo
o`1k0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0T0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k
0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0T
0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?oo
o`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0T0?oo
o`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`03
0000003oool0oooo04D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000
003oool0oooo04D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003o
ool0oooo04D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3o
ool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0
oooo04H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`@00000A@3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?oo
o`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00
o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3o
ool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool6
0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?oo
o`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`03
0000o`3oool0oooo07/0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000
o`3oool0oooo07/0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo0280oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3o
ool0oooo07/0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo0240oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0
oooo07/0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo0240oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo
07/0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
0240oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0
oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0240
oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo
00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0240oooo
00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<0
00000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0240oooo00<0
003o0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<00000
0?ooo`3oool0C03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0240oooo00<0003o
0?ooo`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?oo
o`3oool0C03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0200oooo00<0003o0?oo
o`3oool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3o
ool0C03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3o
ool0o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0
C@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0
o`3oool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3o
ool60?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0CP3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oool6
0?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0CP3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oool60?oo
o`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00
o`3oool60?ooo`030000o`3oool0oooo07/0oooo1000001>0?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0oooo00<0
003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1@0?ooo`050000o`3oool0oooo0?ooo`3o0000
8@3oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3o
ool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool0
0`000000oooo0?ooo`1A0?ooo`050000o`3oool0oooo0?ooo`3o0000803oool00`000?l0oooo0?oo
o`3o0?ooo`H0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1A
0?ooo`050000o`3oool0oooo0?ooo`3o0000803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o
0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1B0?ooo`050000o`3oool0
oooo0?ooo`3o00007P3oool00`000?l0oooo0?ooo`3o0?ooo`L0oooo003o0?ooo`H0oooo00<0003o
0?ooo`3oool0N`3oool00`000000oooo0?ooo`1B0?ooo`050000o`3oool0oooo0?ooo`3o00007P3o
ool00`000?l0oooo0?ooo`3o0?ooo`L0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool0
0`000000oooo0?ooo`1C0?ooo`040000o`3oool0oooo0?l001h0oooo00<0003o0?ooo`3oool0o`3o
ool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0E03oool0
10000?l0oooo0?ooo`3o000M0?ooo`030000o`3oool0oooo0?l0oooo1`3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3o00007@3oool0
0`000?l0oooo0?ooo`3o0?ooo`L0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`00
0000oooo0?ooo`1F0?ooo`030000o`3o0000oooo01`0oooo00<0003o0?ooo`3oool0o`3oool70?oo
o`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0E`3oool00`000?l0
o`000?ooo`0K0?ooo`030000o`3oool0oooo0?l0oooo1`3oool00?l0oooo1P3oool00`000?l0oooo
0?ooo`1k0?ooo`030000003oool0oooo05P0oooo00<0003o0?l0003oool06P3oool00`000?l0oooo
0?ooo`3o0?ooo`L0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?oo
o`1I0?ooo`030000o`3o0000oooo01T0oooo00<0003o0?ooo`3oool0o`3oool70?ooo`00o`3oool6
0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0FP3oool00`000?l0o`000?ooo`0H
0?ooo`030000o`3oool0oooo0?l0oooo1`3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?oo
o`030000003oool0oooo05`0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`3o0?oo
o`P0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1M0?ooo`03
0?l000000?l0oooo01@0oooo00<0003o0?ooo`3oool0o`3oool80?ooo`00o`3oool60?ooo`030000
o`3oool0oooo07/0oooo00<000000?ooo`3oool0GP3oool00`3o0000003o0000o`0C0?ooo`030000
o`3oool0oooo0?l0oooo203oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003o
ool0oooo05l0oooo1@3o000?0?ooo`030000o`3oool0oooo0?l0oooo2@3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1Z0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0203oool0
0`000000oooo0?ooo`1T0?ooo`@0o`000`000?l70?ooo`80003oo`3oool;0?ooo`00o`3oool60?oo
o`030000o`3oool0oooo06d0oooo00<0W4Q809cOo`3oool02`3oool00`000000oooo0?ooo`1X0?oo
oa00o`00o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo06d0oooo00<0W4Q809cOo`3o
ool02`3oool00`000000oooo0?ooo`1h0?ooob<0o`00h`3oool00?l0oooo1P3oool00`000?l0oooo
0?ooo`1]0?ooo`0309a8B02Lgol0oooo00/0oooo00<000000?ooo`3oool0V`3oooo=0?l001H0oooo
003o0?ooo`H0oooo00<0003o0?ooo`3oool0K@3oool00`2LB4P0W=oo0?ooo`0;0?ooo`H00000o`3o
ooml0?ooo`00o`3ooomf0?ooo`0309a8B02Lgol0oooo0?l0ooooS@3oool00?l0ooooMP3oool00`2L
B4P0W=oo0?ooo`3o0?ooohd0oooo003o0?ooog<0oooo00D0gia800000000B9`0W4Q809cOo`3o0?oo
ohh0oooo003o0?ooogD0oooo00<0gia80000B02Lgol0o`3ooon>0?ooo`00o`3ooooo0?ooool0oooo
1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo0000\
\>"],
  ImageRangeCache->{{{0, 771}, {476.188, 0}} -> {-16.0871, -0.0504388, \
0.0622326, 0.00335648}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0 0.618034 [
[0 -0.0125 -9 -9 ]
[0 -0.0125 9 0 ]
[.16667 -0.0125 -9 -9 ]
[.16667 -0.0125 9 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-15)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-5)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(5)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(15)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .00069 m
.04057 .00083 L
.08481 .00103 L
.12636 .00128 L
.16632 .00162 L
.18687 .00185 L
.20885 .00214 L
.22972 .00248 L
.25237 .00295 L
.27417 .00352 L
.2943 .00419 L
.31396 .00503 L
.33562 .00626 L
.34606 .00697 L
.35121 .00733 L
.35372 .00749 L
.35599 .00762 L
.35736 .00768 L
.35864 .00772 L
.36 .00774 L
.36076 .00774 L
.36147 .00773 L
.36285 .00767 L
.36364 .00761 L
.36437 .00754 L
.36515 .00743 L
.36585 .00731 L
.36667 .00712 L
.36744 .00691 L
.36871 .00643 L
.37005 .00571 L
.37119 .00488 L
.37246 .00363 L
.37381 .00179 L
s
.37381 .00179 m
.37476 0 L
s
0 0 1 r
.3379 0 m
.33849 .00205 L
.3392 .00367 L
.34052 .00534 L
.34172 .00609 L
.34311 .00653 L
.34443 .00677 L
.3456 .00692 L
.34685 .00704 L
.3491 .00724 L
.35421 .00767 L
.37619 .00994 L
.38697 .0114 L
.39865 .01331 L
.40874 .01531 L
.41982 .018 L
.44074 .02494 L
.45217 .03016 L
.46285 .03629 L
.47381 .04417 L
.4842 .05346 L
.50368 .07685 L
.52456 .11148 L
.5439 .14793 L
.54876 .15614 L
.55399 .16373 L
.5564 .16664 L
.55894 .16921 L
.56111 .17096 L
.56224 .1717 L
.56348 .17235 L
.56424 .17268 L
.56494 .17292 L
.56631 .17323 L
.56757 .17333 L
.56889 .17322 L
.56958 .17308 L
.57031 .17287 L
.57165 .1723 L
.57246 .17184 L
.57323 .17132 L
.57468 .17013 L
.57726 .16731 L
.57966 .16386 L
.5851 .1532 L
.59044 .13919 L
.59621 .12094 L
.60667 .084 L
.61679 .05087 L
.62172 .03768 L
Mistroke
.62622 .02781 L
.63104 .01952 L
.63621 .01305 L
.63891 .01052 L
.64184 .00832 L
.64718 .0055 L
.65275 .00363 L
.65411 .00321 L
.65482 .00295 L
.65557 .00262 L
.6564 .00213 L
.65717 .00148 L
.65789 .0006 L
Mfstroke
.65789 .0006 m
.65821 0 L
s
1 0 0 r
.61295 .61803 m
.61358 .53494 L
.61485 .41183 L
.6162 .31383 L
.61735 .25008 L
.61862 .19573 L
.61999 .15151 L
.62146 .11587 L
.62284 .09064 L
.62411 .07286 L
.62546 .05825 L
.62672 .04749 L
.6291 .03302 L
.63043 .02723 L
.63165 .02296 L
.63308 .01898 L
.63442 .01602 L
.63663 .01232 L
.63781 .01081 L
.63907 .00946 L
.64165 .00736 L
.644 .00599 L
.64677 .00482 L
.64934 .00403 L
.65216 .00338 L
.65515 .00286 L
.65802 .00249 L
.66071 .0022 L
.66574 .0018 L
.67065 .00152 L
.67603 .00129 L
.68165 .0011 L
.68688 .00097 L
.69626 .00078 L
.70629 .00064 L
.71701 .00053 L
.72865 .00044 L
.73965 .00037 L
.7498 .00032 L
.76945 .00025 L
.78063 .00022 L
.7911 .0002 L
.81235 .00016 L
.8318 .00014 L
.85173 .00012 L
.87348 .0001 L
.89586 8e-005 L
.91615 7e-005 L
.95722 6e-005 L
.99928 4e-005 L
Mistroke
1 4e-005 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{514.688, 318.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<40001gB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo000F0?ooo`030?noM0000000000000<0
000000D007Bo0?ooo`3oool0oooo0;md00030000000307Boo`3oool0oooo06P0oooo00<0okmd0000
000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0K@3oool0
1@2oM0000000000000000000M;oo0>L0oooo00D0_g@0000000000000000007Boo`1^0?ooo`030?no
M0000000000000<0000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo06P0
oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?oo
o`3oool03P3oool001T0oooo00<0W4Q809cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0omnL
04P0001d_ol0K03oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo
K@3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0i@3oool01`2oM00007Bo0?ooo`3oool0
omnL04P0001d_ol0L03oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_oooK03oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0?
0?ooo`006@3oool00`2LB4P0W=oo0?ooo`080?ooo`030?noM000M;l0oooo06/0oooo00<0W4Q809cO
o`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo0740oooo00<0okmd001d
_`3oool0j@3oool00`3o_g@007Bo0?ooo`1_0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`1[0?ooo`0309a8B02Lgol0oooo00P0oooo00<0okmd001d
_`3oool03P3oool001T0oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`1[0?ooo`03
09a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1a0?ooo`03
0?noM000M;l0oooo0>T0oooo00<0okmd001d_`3oool0K`3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0J`3oool00`2LB4P0W=oo0?ooo`080?ooo`03
0?noM000M;l0oooo00h0oooo000=0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
0`3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo05l0oooo00<0W4P0000000000000
0`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`1S0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
1@3oool00`2LB000M;oo0?ooo`3Y0?ooo`0309a8001d_ol0oooo06l0oooo00<0W4Q809cOo`3oool0
0`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo06/0oooo00<0W4Q809cOo`3oool0
203oool00`2LB000M;oo0?ooo`0>0?ooo`006@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0J`3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool0K03oool00`3ookl0M000000000020000000304RLg`3o
ool0oooo0>@0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`1_0?ooo`0309a8B02L
gol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1[0?ooo`0309a8B02L
gol0oooo00<0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0>0?ooo`006@3oool0
0`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0_ooo0700oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo06`0oooo00<0oono07@0M02oool0j@3oool0
0`3ookl0M01d0;ooo`1d0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`1[0?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool04`3oool0
01H0oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo06d0oooo00D0gia8
00000000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_oooK@3oool00`3ookl0
M01d0;ooo`3Y0?ooo`030?oo_`1d07@0_ooo0740oooo00D0gia800000000B9`0W4Q809cOo`050?oo
o`0609a8001d_ol0oooo0?oOW01807@0_oooJ@3oool01@3OW4P000000018W02LB4P0W=oo00@0oooo
00<0oono07@0M02oool04`3oool001P0oooo00<0gia80000B02Lgol0103oool00`3ookl0M0000000
0002000000030000M02oool0oooo06X0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000
000004P0W=oo06h0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`3T0?ooo`030?oo
_`1d000000000080000000<0001d0;ooo`3oool0KP3oool00`3OW4P0001809cOo`050?ooo`050?oo
_`1d000000000000B02Lgol0K03oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080
000000<0001d0;ooo`3oool03P3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?ooool0ooooo`3o
ool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?ooool0
ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o
0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0
oooo003o0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool001X0oooo;@3o0037
000000030000o`000000000001P0000000<0o`00000000000000b@0000020000oaL00000h03o000F
0?ooo`006P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180ooooLP3o00090?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`040000003oool0oooo0000oa@0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool20000o`030?ooo`3o0000
o`0001D0o`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`006P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?oo
obl0o`002`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo0000oa@0oooo00D00000
0?ooo`3oool0oooo0?l0000C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3o
ool60?l000D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`006P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3ooolM
0?l000H0oooo00D000000?ooo`3oool0oooo0000o`0C0?ooo`040000003oool0oooo0?l001@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`@0o`0000<0003o0?ooo`3oool0
203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo000J0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0L03oool;0?l00080003o4`3oool00`3o0000oooo0?oo
o`1K0?ooo`030000003oool0oooo06D0oooo0P3o00000`3oool0003o0000o`0<0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0D0?ooo`00o`3ooolA
0?ooo`80o`0030000?l70?l005h0oooo00<000000?ooo`3oool0I03oool0103o0000oooo0000o`00
0?oo0?oooaL0oooo003o0?oooal0oooo20000?mM0?ooo`030000003oool0oooo06<0oooo00<0o`00
0000o`000?l0o`3ooolI0?ooo`00o`3ooolW0?ooo`P0003oE@3oool00`000000oooo0?ooo`1R0?oo
o`030?l000000?l0oooo0?l0oooo6P3oool00?l0oooo;`3oool80000odd0oooo00<000000?ooo`3o
ool0H@3oool00`3o0000oooo0?ooo`3o0?oooa/0oooo003o0?ooocL0oooo1P000?m70?ooo`030000
003oool0oooo0600oooo00<0o`000?ooo`3oool0o`3ooolL0?ooo`00o`3ooolm0?ooo`@0003o@`3o
ool00`000000oooo0?ooo`1O0?ooo`030?l0003oool0oooo0?l0oooo7@3oool00?l0oooo@@3oool3
0000od00oooo00<000000?ooo`3oool0GP3oool00`3o0000oooo0?ooo`3o0?oooah0oooo003o0?oo
od@0oooo10000?ll0?ooo`030000003oool0oooo05h0oooo00<0o`000?ooo`3oool0o`3ooolN0?oo
o`00o`3ooom80?ooo`@0003o>03oool00`000000oooo0?ooo`1M0?ooo`030?l0003oool0oooo0?l0
oooo7`3oool00?l0ooooC03oool30000ocD0oooo00<000000?ooo`3oool0G03oool00`000?l0o`00
0?ooo`3o0?ooob00oooo003o0?ooodl0oooo0`000?lb0?ooo`030000003oool0oooo05/0oooo00<0
003o0?l0003oool0o`3ooolQ0?ooo`00o`3ooomB0?ooo`<0003o;`3oool00`000000oooo0?ooo`1K
0?ooo`030000o`3o0000oooo0?l0oooo8@3oool00?l0ooooE@3oool30000ob`0oooo00<000000?oo
o`3oool0FP3oool00`000?l0oooo0?l0003o0?ooob80oooo003o0?oooeP0oooo0`000?lY0?ooo`03
0000003oool0oooo05X0oooo00<0003o0?ooo`3o0000o`3ooolR0?ooo`00o`3ooomK0?ooo`80003o
9`3oool00`000000oooo0?ooo`1I0?ooo`040000o`3oool0oooo0?l00?l0oooo8P3oool00?l0oooo
G@3oool20000obD0oooo00<000000?ooo`3oool0F@3oool010000?l0oooo0?ooo`3o003o0?ooob80
oooo003o0?oooel0oooo0P000?lS0?ooo`030000003oool0oooo05P0oooo00D0003o0?ooo`3oool0
oooo0?l0003o0?ooob80oooo003o0?ooof40oooo0P000?lQ0?ooo`@00000E`3oool010000?l0oooo
0?ooo`3o003o0?ooob<0oooo003o0?ooof<0oooo0P000?lO0?ooo`030000003oool0oooo05L0oooo
00D0003o0?ooo`3oool0oooo0?l0003o0?ooob<0oooo003o0?ooofD0oooo0P000?lM0?ooo`030000
003oool0oooo05L0oooo00D0003o0?ooo`3oool0oooo0?l0003o0?ooob<0oooo003o0?ooofL0oooo
0P000?lK0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`3o0?ooob40oooo003o0?ooofT0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?oo
o`1F0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooolQ0?ooo`00o`3ooomZ
0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0?l0oooo8P3oool00?l0ooooJ`3oool20000oaL0oooo00<000000?oo
o`3oool0E@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo8P3oool00?l0
ooooK@3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`3o0?ooob80oooo003o0?ooofh0oooo00<0003o0?ooo`3oool0
4`3oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
o`3ooolR0?ooo`00o`3ooom_0?ooo`80003o4`3oool00`000000oooo0?ooo`1D0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooolR0?ooo`00o`3oooma0?ooo`030000o`3oool0
oooo0100oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0?l0oooo8`3oool00?l0ooooLP3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo
05<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooob<0oooo003o0?ooog<0
oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0o`3ooolS0?ooo`00o`3ooomd0?ooo`030000o`3oool0oooo00d0oooo
00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo
8`3oool00?l0ooooM@3oool20000o`d0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo0?l0oooo8`3oool00?l0ooooM`3oool00`000?l0oooo0?ooo`0:
0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`3o
0?ooob<0oooo003o0?ooogP0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`1B0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`00o`3ooomi0?ooo`03
0000o`3oool0oooo00P0oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo0?l0oooo903oool00?l0ooooNP3oool00`000?l0oooo0?ooo`070?ooo`030000
003oool0oooo0540oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooob@0oooo
003o0?ooog/0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`00o`3oooml0?ooo`030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo0?l0oooo903oool00?l0ooooO03oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo
0500oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?ooob@0oooo003o0?ooogd0
oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`00o`3ooomn0?ooo`030000o`3oool0oooo00<0oooo
1000001>0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`00o`3o
oomo0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo0?l0oooo903oool00?l0ooooP03oool01@000?l0oooo0?ooo`3o
ool000000540oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o0?ooob@0oooo003o
0?oooh40oooo00@0003o0?ooo`3oool00000D03oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo0?l0oooo9@3oool00?l0ooooPP3oool00`000?l0oooo0000001@0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`00o`3ooon30?ooo`030000o`000000oooo
04l0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o0?ooobD0oooo003o0?oooh<0
oooo00<0003o0000003oool0CP3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0
oooo9@3oool00?l0ooooQ03oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0o`3ooolU0?ooo`00o`3ooon40?ooo`03000000000?l0oooo04d0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`3o0?ooobD0oooo003o0?oooh@0oooo00<00000
0?ooo`000?l0C03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0oooo9@3oool0
0?l0ooooQ03oool010000000oooo0?ooo`000?m;0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0o`3ooolU0?ooo`00o`3ooon40?ooo`050000003oool0oooo0?ooo`000?l0BP3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0oooo9@3oool00?l0ooooQ03oool01@00
0000oooo0?ooo`3oool0003o04T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o
0?ooobD0oooo003o0?oooh@0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`160?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo0080oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo0?l0oooo9P3oool00?l0ooooQ03oool00`000000oooo0?ooo`030?ooo`030000
o`3oool0oooo04@0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo
003o0?oooh@0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`130?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`00o`3ooon40?ooo`030000003oool0
oooo00@0oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo0?l0oooo9P3oool00?l0ooooQ03oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo
0440oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo003o0?oooh@0
oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`00o`3ooon40?ooo`030000003oool0oooo00H0oooo
00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0?l0oooo
9P3oool00?l0ooooQ03oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo03l0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo003o0?oooh@0oooo10000006
0?ooo`030000o`3oool0oooo03h0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o
0?ooobH0oooo003o0?oooh@0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`0m0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo00P0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo0?l0oooo9P3oool00?l0ooooQ03oool00`000000oooo0?ooo`090?ooo`030000
o`3oool0oooo03`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo
003o0?oooh@0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0j0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`00o`3ooon40?ooo`030000003oool0
oooo00X0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo0?l0oooo9P3oool00?l0ooooQ03oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
03T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`3o0?ooobH0oooo003o0?oooh@0
oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`00o`3ooon40?ooo`030000003oool0oooo00`0oooo
00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?l0oooo
9`3oool00?l0ooooQ03oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo03H0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`3o0?ooobL0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0o`3ooolW0?ooo`00o`3ooon40?ooo`030000003oool0oooo00h0oooo00<0003o0?oo
o`3oool0=03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00?l0
ooooQ03oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`3o0?ooobL0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
o`3ooolW0?ooo`00o`3ooon40?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0<P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00?l0ooooQ03oool0
0`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`3o0?ooobL0oooo003o0?oooh@0oooo00<000000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0o`3ooolW0?oo
o`00o`3ooon40?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0<03oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00?l0ooooQ03oool00`000000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`3o0?ooobL0oooo003o0?ooof80oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`080?ooo`030000
003oool0oooo0180oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0?l0oooo9`3oool00?l0ooooHP3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0
oooo00<0_g@000000000M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00T0
oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`00o`3ooomQ0?ooo`030?noM000M;l0oooo0080oooo
00<0gia804RLg`3oool02`3oool00`3o_g@0001809cOo`0=0?ooo`030000003oool0oooo01<0oooo
00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0?l0oooo
9`3oool00?l0ooooH@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0
omnL04P00018W=l0303oool600000140oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00?l0ooooH@3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3oool02P3oool00`000000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`3o
0?ooobL0oooo003o0?ooof40oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?oo
o`0309a8M02oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`00o`3ooomQ0?ooo`03
0?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`03
0;md001d_ol0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Y0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`00o`3ooomR0?ooo`0609a8
001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol02P3o
ool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`3o0?ooobL0oooo003o0?ooof80oooo00D0oono07@000000000001809cO
o`0=0?ooo`050?noM000000000000000B02Lgol02`3oool00`000000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo02P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`3o0?ooobL0oooo
003o0?oooh@0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`00o`3ooon40?ooo`030000003oool0
oooo01L0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0
oooo0?l0oooo9`3oool00?l0ooooQ03oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
02D0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`3o0?ooobP0oooo003o0?oooh@0
oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0o`3ooolX0?ooo`00o`3ooon40?ooo`030000003oool0oooo01T0oooo
00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0oooo
:03oool00?l0ooooQ03oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo02<0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool0o`3ooolX0?ooo`00o`3ooon40?ooo`030000003oool0oooo01X0oooo00<0003o0?oo
o`3oool08@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0
ooooQ03oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
o`3ooolX0?ooo`00o`3ooon40?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0ooooQ03oool0
0`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<000000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooolX0?oo
o`00o`3ooon40?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool06`3oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0ooooQ03oool00`000000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?oo
o`0I0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0o`3ooolX0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0ooooQ03oool4000001l0oooo00<0003o0?oo
o`3oool05`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0
ooooQ03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0
o`3ooolX0?ooo`00o`3ooon40?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0ooooQ03oool0
0`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<000000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0o`3ooolX0?oo
o`00o`3ooon40?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0J0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0ooooQ03oool00`000000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`3o0?ooobP0oooo003o0?oooh@0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0o`3ooolX0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0L
0?ooo`030?l0003oool0oooo0?l0oooo:03oool00?l0ooooQ03oool00`000000oooo0?ooo`0X0?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`3o0?oo
obP0oooo003o0?oooh@0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0o`3ooolX0?ooo`00o`3ooon40?ooo`030000
003oool0oooo02X0oooo0P000?l50?ooo`80003o8@3oool00`3o0000oooo0?ooo`3o0?ooobP0oooo
003o0?oooh@0oooo00<000000?ooo`3oool0;03oool50000ob80oooo00<0o`000?ooo`3oool0o`3o
oolY0?ooo`00o`3ooon40?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY
0?ooo`00o`3ooon40?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?oo
o`00o`3ooon40?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`00
o`3ooon40?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`00o`3o
oon40?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`00o`3ooon40?oo
o`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`00o`3ooon40?ooo`@00000
DP3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3o
ool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool0
0`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o
0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000
oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo
0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?oo
o`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o
0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?oo
obT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0
oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo
003o0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o
0?oooh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oo
oh@0oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0
oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo
00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<0
00000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?oo
o`3oool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3o
ool0D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
D`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D`3o
ool00`3o0000oooo0?ooo`3o0?ooobT0oooo003o0?oooh@0oooo1000001B0?ooo`030?l0003oool0
oooo0?l0oooo:@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo
0?l0oooo:@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0?l0
oooo:@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0?l0oooo
:@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0?l0oooo:@3o
ool00?l0ooooQ03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool0
0?l0ooooQ03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0
ooooQ03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0oooo
Q03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03o
ool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool0
0`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`00
0000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000
oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000oooo
0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000oooo0?oo
o`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000oooo0?ooo`1B
0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000oooo0?ooo`1B0?oo
o`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000oooo0?ooo`1B0?ooo`03
0?l0003oool0oooo0?l0oooo:P3oool00?l0ooooQ03oool00`000000oooo0?ooo`1B0?ooo`030?l0
003oool0oooo0?l0oooo:P3oool00?l0ooooHP3oool01@3o_g@00000000000000000M;oo00D0oooo
00<0_g@000000000M;l01P3oool01@3ogi`0B000000000000000M;oo00X0oooo00<000000?ooo`3o
ool0DP3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo003o0?ooof80oooo00H0W4Qd0;ooo`3oool0
oono07@0M02oool40?ooo`030;md0000000007Bo00P0oooo00<0_g@007Boo`3oool02P3oool00`00
0000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooH@3oool00`3o_g@0
07Bo0?ooo`020?ooo`030=nLB018W=l0oooo00h0oooo00<0_g@007Boo`3oool02P3oool00`000000
oooo0?ooo`1B0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0ooooH@3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia80000000000000`0000000`1d_ol0oooo
0?ooo`080?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
oomQ0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;oo
o`3oool0_g@007Boo`/0oooo1P00001?0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00?l0oooo
H@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia8001d_`3oool0
_g@007Boo`0;0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00
o`3ooomQ0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102LB000B9cO
0;md001d_ol;0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00
o`3ooomR0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo3@3oool0103ogi`0B01804Q8001d_ol;
0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooomR0?oo
o`050?oo_`1d000000000000B02Lgol03`3oool00`3o_g@0000007Boo`0;0?ooo`030000003oool0
oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo
0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580
oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo
00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0
o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`00
0?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?oo
o`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0
o`3ooolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3o
oolZ0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ
0?ooo`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?oo
o`00o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00
o`3ooon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
oon40?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?oo
o`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo0580oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooon40?ooo`@00000
D@3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo003o0?oooh@0oooo00<000000?ooo`3oool0DP3o
ool00`3o0000oooo0?ooo`3o0?ooobX0oooo003o0?oooh@0oooo00<000000?ooo`3oool0DP3oool0
0`3o0000oooo0?ooo`3o0?ooobX0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o
0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000
oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo
0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?oo
o`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o
0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?oo
ob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0
oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo
003o0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o
0?oooh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oo
oh@0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0
oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo
00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<0
00000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?oo
o`3oool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3o
ool0D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
D@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D@3o
ool00`3o0000oooo0?ooo`3o0?ooob/0oooo003o0?oooh@0oooo1000001@0?ooo`030?l0003oool0
oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo
0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0
oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo
:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3o
ool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool0
0?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0
ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0oooo
Q03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03o
ool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool0
0`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`00
0000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000
oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo
0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?oo
o`1A0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A
0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?oo
o`030?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`03
0?l0003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0
003oool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003o
ool0oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0
oooo0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo
0?l0oooo:`3oool00?l0ooooQ03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0
oooo:`3oool00?l0ooooQ03oool400000500oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3o
oon40?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?oo
o`030000003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000
003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003o
ool0oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0
oooo0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo
0540oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540
oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo
00<0o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo00<0
o`000?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo00<0o`00
0?ooo`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo00<0o`000?oo
o`3oool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3o
ool0o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3oool0
o`3oool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3o
ool[0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/
0?ooo`00o`3ooomR0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`06
0?ooo`050;md0000000000000000M02oool02P3oool00`000000oooo0?ooo`1@0?ooo`030?l0003o
ool0oooo0?l0oooo;03oool00?l0ooooHP3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo
00<0_g@000000000M;l01@3oool01P3OW4P007Bo0?ooo`3oool0okmd001d_`X0oooo00<000000?oo
o`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?ooof40oooo00<0okmd001d_`3o
ool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03o
ool02@3oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0oooo
H@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00L0okmd0018B01d07@0
_ooo0?ooo`3OW4P007Bo00X0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?oo
ob`0oooo003o0?ooof40oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`03
0?oOW018B9`0okmd0080000000<004RL0?ooo`3oool02@3oool6000004d0oooo00<0o`000?ooo`3o
ool0o`3oool/0?ooo`00o`3ooomQ0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
2P3oool00`3ookl0M01d0;ooo`0>0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0
o`3oool/0?ooo`00o`3ooomQ0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02`3o
ool00`2oM000B9cO0?ooo`0=0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3o
ool/0?ooo`00o`3ooomR0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool00`3ookl0M000
001d_`0=0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3o
oomR0?ooo`050?oo_`1d000000000000B02Lgol03`3oool0102oM000000000000000B9`:0?ooo`03
0000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000
003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003o
ool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0
oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo
0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500
oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo
00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0
o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`00
0?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?oo
o`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3o
ool0o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0
o`3oool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3o
ool/0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/
0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?oo
o`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00
o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3o
oon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon4
0?ooo`@00000C`3oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?oo
o`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3o
ool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03o
ool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool0
0`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o
0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000
oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo
0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?oo
o`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o
0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?oo
ob`0oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0
oooo003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo
003o0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o
0?oooh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oo
oh@0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0
oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo
00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<0
00000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?oo
o`3oool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo00<000000?ooo`3o
ool0D03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo003o0?oooh@0oooo1000001?0?ooo`030?l0
003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003o
ool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0
oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo
0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0
oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo
;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03o
ool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool0
0?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0
ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0oooo
Q03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03o
ool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool0
0`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`00
0000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000
oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo
0?ooo`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?oo
o`1@0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@
0?ooo`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?oo
o`030?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`03
0?l0003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0
003oool0oooo0?l0oooo;03oool00?l0ooooQ03oool00`000000oooo0?ooo`1@0?ooo`030?l0003o
ool0oooo0?l0oooo;03oool00?l0ooooQ03oool4000004l0oooo00<0o`000?ooo`3oool0o`3oool/
0?ooo`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?oo
o`00o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00
o`3ooon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3o
oon40?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?oo
o`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo0500oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00o`3ooon40?ooo`030000
003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003o
ool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0
oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo
04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0
oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo
00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0
o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`00
0?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?oo
o`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3o
ool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0
o`3oool]0?ooo`00o`3ooomR0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000
001d_`050?ooo`050;md00000000000000000000M;l02`3oool00`000000oooo0?ooo`1?0?ooo`03
0?l0003oool0oooo0?l0oooo;@3oool00?l0ooooHP3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`@0oooo00<0_g@000000000M;l0103oool00`3o_g@007Bo0?ooo`020?ooo`030;mdB02Lgol0oooo
00T0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?ooof40
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB018W=l0oooo0080
oooo00<0_g@007Boo`3oool02@3oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0
oooo;@3oool00?l0ooooH@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo
00<0okmd0018W03oool00P3oool00`2LB4P0W=oo0?ooo`090?ooo`H00000C03oool00`3o0000oooo
0?ooo`3o0?ooobd0oooo003o0?ooof40oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0;0?ooo`050=nLB0000000000000000018W=l02`3oool00`000000oooo0?ooo`1?0?ooo`030?l0
003oool0oooo0?l0oooo;@3oool00?l0ooooH@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00X0oooo00<0oono07A8W03oool00P3oool00`2LB7@0_ooo0?ooo`090?ooo`030000003o
ool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooomQ0?ooo`030?noM018W=l0
oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`030;md001d_ol0
oooo00T0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oo
of80oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0
B01d0;ooo`0:0?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00
o`3ooomR0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo
00/0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0
oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo
00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<0
00000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?oo
o`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3o
ool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3o
ool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool0
0`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o
0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000
oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo
0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?oo
o`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o
0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?oo
obd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0
oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo
003o0?oooh@0oooo1000001>0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool0
0`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`00
0000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000
oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo
0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?oo
o`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?
0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?oo
o`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`03
0?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0
003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003o
ool0oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0
oooo0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo
0?l0oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0
oooo;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo
;@3oool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3o
ool00?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool0
0?l0ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0
ooooQ03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0oooo
Q03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03o
ool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool0
0`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooQ03oool40000
04h0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0
oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo
00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0
o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`00
0?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?oo
o`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3o
ool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0
o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3o
ool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]
0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?oo
o`00o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00
o`3ooon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3o
oon40?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon4
0?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?oo
o`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`03
0000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000
003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003o
ool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0
oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo
04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`030000003oool0oooo04l0
oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooon40?ooo`@00000CP3oool00`3o0000oooo
0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?oo
o`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o
0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?oo
obd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0
oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo
003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o
0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oo
oh@0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0
oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo
00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<0
00000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<00000
0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?oo
o`3oool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3o
ool0C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0
C`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3o
ool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool0
0`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?oooh@0oooo00<000000?ooo`3oool0C`3oool00`3o
0000oooo0?ooo`3o0?ooobd0oooo003o0?ooog<0oooo00<0okmd0000000000000`0000000`00M;l0
oooo0?ooo`080?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00
o`3ooomf0?ooo`0309a8B02Lgol0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo
0?ooo`3o0?ooobd0oooo003o0?ooogH0oooo00<0W4Q809cOo`3oool02`3oool00`000000oooo0?oo
o`1?0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0ooooMP3oool00`2LB4P0W=oo0?ooo`0;
0?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0o`3oool]0?ooo`00o`3ooomf0?oo
o`0309a8B02Lgol0oooo00/0oooo1P00001<0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00?l0
ooooMP3oool00`2LB4P0W=oo0?ooo`3o0?ooohd0oooo003o0?ooogH0oooo00<0W4Q809cOo`3oool0
o`3ooon=0?ooo`00o`3ooomc0?ooo`050=nLB000000004RL09a8B02Lgol0o`3ooon>0?ooo`00o`3o
oome0?ooo`030=nLB00004P0W=oo0?l0ooooSP3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?oo
ool0ooooo`3oool70?ooo`00\
\>"],
  ImageRangeCache->{{{0, 771}, {476.188, 0}} -> {-16.0871, -0.0504388, \
0.0622326, 0.00335648}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0333333 0 0.618034 [
[0 -0.0125 -9 -9 ]
[0 -0.0125 9 0 ]
[.16667 -0.0125 -9 -9 ]
[.16667 -0.0125 9 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-15)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-5)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(5)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(15)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .00842 m
.04057 .00934 L
.08481 .01057 L
.12636 .012 L
.16632 .01373 L
.20885 .0161 L
.2498 .01916 L
.27066 .02112 L
.29331 .02368 L
.33524 .0301 L
.35566 .03434 L
.36125 .03563 L
.36727 .03698 L
.36866 .03726 L
.37018 .03754 L
.37152 .03774 L
.37226 .03784 L
.37295 .03791 L
.37363 .03796 L
.37437 .038 L
.37565 .03798 L
.37695 .03784 L
.37815 .03755 L
.3794 .03705 L
.38054 .03634 L
.38186 .03513 L
.3831 .03346 L
.38425 .0313 L
.38532 .02861 L
.38649 .02464 L
.38773 .01887 L
.38897 .01091 L
s
.38897 .01091 m
.39019 0 L
s
0 0 1 r
.3253 .61803 m
.32613 .37265 L
.3274 .19362 L
.32879 .10245 L
.3301 .06323 L
.33131 .04599 L
.33251 .0377 L
.3336 .03401 L
.33486 .032 L
.33604 .03121 L
.33734 .03093 L
.33871 .03094 L
.33988 .03108 L
.34116 .03128 L
.34669 .03238 L
.36592 .03692 L
.38645 .04306 L
.40843 .05174 L
.43078 .06384 L
.44104 .07095 L
.45192 .07991 L
.46189 .08971 L
.47287 .1027 L
.49223 .13298 L
.50286 .15488 L
.51259 .17908 L
.53451 .25133 L
.55442 .33999 L
.57617 .45146 L
.5868 .50249 L
.59681 .54297 L
.60236 .56114 L
.60835 .57711 L
.61381 .58837 L
.61883 .59625 L
.62375 .60199 L
.62646 .60444 L
.62904 .60636 L
.63142 .60785 L
.63402 .60919 L
.63857 .61097 L
.64117 .61173 L
.64403 .6124 L
.64682 .61293 L
.64984 .61339 L
.65264 .61373 L
.65387 .61386 L
.65521 .61398 L
.65649 .61408 L
.65767 .61413 L
Mistroke
.65892 .61413 L
.66026 .61397 L
.66155 .6135 L
.66229 .61297 L
.66298 .61217 L
.66436 .60899 L
.66514 .60556 L
.66585 .60064 L
.66711 .58451 L
.66849 .54558 L
.6698 .46457 L
.671 .30817 L
.67174 .14347 L
Mfstroke
.67174 .14347 m
.67215 0 L
s
1 0 0 r
.60402 0 m
.60519 .14306 L
.60642 .25266 L
.60776 .34207 L
.60922 .41229 L
.61077 .46623 L
.61224 .50288 L
.61358 .52766 L
.61492 .54653 L
.61617 .55994 L
.61754 .57128 L
.61899 .58045 L
.62025 .58659 L
.62143 .59119 L
.62273 .59524 L
.62411 .59867 L
.62545 .60129 L
.62667 .60322 L
.62905 .60608 L
.63038 .60729 L
.63183 .60836 L
.63445 .60985 L
.6372 .61098 L
.64011 .61184 L
.64259 .61241 L
.64532 .6129 L
.65016 .61356 L
.65536 .61407 L
.66027 .61444 L
.66476 .61472 L
.67513 .61521 L
.68475 .61554 L
.6953 .61583 L
.70653 .61607 L
.72907 .61642 L
.75026 .61666 L
.7714 .61684 L
.79082 .61697 L
.81232 .61709 L
.83235 .61718 L
.8723 .61731 L
.91323 .61742 L
.95674 .6175 L
.99865 .61757 L
1 .61757 L
s
0 .00069 m
.04057 .00083 L
.08481 .00103 L
.12636 .00128 L
.16632 .00162 L
.18687 .00185 L
.20885 .00214 L
.22972 .00248 L
.25237 .00295 L
.27417 .00352 L
.2943 .00419 L
.31396 .00503 L
.33562 .00626 L
.34606 .00697 L
.35121 .00733 L
.35372 .00749 L
.35599 .00762 L
.35736 .00768 L
.35864 .00772 L
.36 .00774 L
.36076 .00774 L
.36147 .00773 L
.36285 .00767 L
.36364 .00761 L
.36437 .00754 L
.36515 .00743 L
.36585 .00731 L
.36667 .00712 L
.36744 .00691 L
.36871 .00643 L
.37005 .00571 L
.37119 .00488 L
.37246 .00363 L
.37381 .00179 L
s
.37381 .00179 m
.37476 0 L
s
0 0 1 r
.3379 0 m
.33849 .00205 L
.3392 .00367 L
.34052 .00534 L
.34172 .00609 L
.34311 .00653 L
.34443 .00677 L
.3456 .00692 L
.34685 .00704 L
.3491 .00724 L
.35421 .00767 L
.37619 .00994 L
.38697 .0114 L
.39865 .01331 L
.40874 .01531 L
.41982 .018 L
.44074 .02494 L
.45217 .03016 L
.46285 .03629 L
.47381 .04417 L
.4842 .05346 L
.50368 .07685 L
.52456 .11148 L
.5439 .14793 L
.54876 .15614 L
.55399 .16373 L
.5564 .16664 L
.55894 .16921 L
.56111 .17096 L
.56224 .1717 L
.56348 .17235 L
.56424 .17268 L
.56494 .17292 L
.56631 .17323 L
.56757 .17333 L
.56889 .17322 L
.56958 .17308 L
.57031 .17287 L
.57165 .1723 L
.57246 .17184 L
.57323 .17132 L
.57468 .17013 L
.57726 .16731 L
.57966 .16386 L
.5851 .1532 L
.59044 .13919 L
.59621 .12094 L
.60667 .084 L
.61679 .05087 L
.62172 .03768 L
Mistroke
.62622 .02781 L
.63104 .01952 L
.63621 .01305 L
.63891 .01052 L
.64184 .00832 L
.64718 .0055 L
.65275 .00363 L
.65411 .00321 L
.65482 .00295 L
.65557 .00262 L
.6564 .00213 L
.65717 .00148 L
.65789 .0006 L
Mfstroke
.65789 .0006 m
.65821 0 L
s
1 0 0 r
.61295 .61803 m
.61358 .53494 L
.61485 .41183 L
.6162 .31383 L
.61735 .25008 L
.61862 .19573 L
.61999 .15151 L
.62146 .11587 L
.62284 .09064 L
.62411 .07286 L
.62546 .05825 L
.62672 .04749 L
.6291 .03302 L
.63043 .02723 L
.63165 .02296 L
.63308 .01898 L
.63442 .01602 L
.63663 .01232 L
.63781 .01081 L
.63907 .00946 L
.64165 .00736 L
.644 .00599 L
.64677 .00482 L
.64934 .00403 L
.65216 .00338 L
.65515 .00286 L
.65802 .00249 L
.66071 .0022 L
.66574 .0018 L
.67065 .00152 L
.67603 .00129 L
.68165 .0011 L
.68688 .00097 L
.69626 .00078 L
.70629 .00064 L
.71701 .00053 L
.72865 .00044 L
.73965 .00037 L
.7498 .00032 L
.76945 .00025 L
.78063 .00022 L
.7911 .0002 L
.81235 .00016 L
.8318 .00014 L
.85173 .00012 L
.87348 .0001 L
.89586 8e-005 L
.91615 7e-005 L
.95722 6e-005 L
.99928 4e-005 L
Mistroke
1 4e-005 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{514.688, 318.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<40001gB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo000F0?ooo`030?noM0000000000000<0
000000D007Bo0?ooo`3oool0oooo0;md00030000000307Boo`3oool0oooo06P0oooo00<0okmd0000
000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0K@3oool0
1@2oM0000000000000000000M;oo0>L0oooo00D0_g@0000000000000000007Boo`1^0?ooo`030?no
M0000000000000<0000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo06P0
oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?oo
o`3oool03P3oool001T0oooo00<0W4Q809cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0omnL
04P0001d_ol0K03oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo
K@3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0i@3oool01`2oM00007Bo0?ooo`3oool0
omnL04P0001d_ol0L03oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_oooK03oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0?
0?ooo`006@3oool00`2LB4P0W=oo0?ooo`080?ooo`030?noM000M;l0oooo06/0oooo00<0W4Q809cO
o`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo0740oooo00<0okmd001d
_`3oool0j@3oool00`3o_g@007Bo0?ooo`1_0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`1[0?ooo`0309a8B02Lgol0oooo00P0oooo00<0okmd001d
_`3oool03P3oool001T0oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`1[0?ooo`03
09a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1a0?ooo`03
0?noM000M;l0oooo0>T0oooo00<0okmd001d_`3oool0K`3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0J`3oool00`2LB4P0W=oo0?ooo`080?ooo`03
0?noM000M;l0oooo00h0oooo000=0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
0`3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo05l0oooo00<0W4P0000000000000
0`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`1S0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
1@3oool00`2LB000M;oo0?ooo`3Y0?ooo`0309a8001d_ol0oooo06l0oooo00<0W4Q809cOo`3oool0
0`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo06/0oooo00<0W4Q809cOo`3oool0
203oool00`2LB000M;oo0?ooo`0>0?ooo`006@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0J`3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool0K03oool00`3ookl0M000000000020000000304RLg`3o
ool0oooo0>@0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`1_0?ooo`0309a8B02L
gol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1[0?ooo`0309a8B02L
gol0oooo00<0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0>0?ooo`006@3oool0
0`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0_ooo0700oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo06`0oooo00<0oono07@0M02oool0j@3oool0
0`3ookl0M01d0;ooo`1d0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`1[0?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool04`3oool0
01H0oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo06d0oooo00D0gia8
00000000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_oooK@3oool00`3ookl0
M01d0;ooo`3Y0?ooo`030?oo_`1d07@0_ooo0740oooo00D0gia800000000B9`0W4Q809cOo`050?oo
o`0609a8001d_ol0oooo0?oOW01807@0_oooJ@3oool01@3OW4P000000018W02LB4P0W=oo00@0oooo
00<0oono07@0M02oool04`3oool001P0oooo00<0gia80000B02Lgol0103oool00`3ookl0M0000000
0002000000030000M02oool0oooo06X0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000
000004P0W=oo06h0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`3T0?ooo`030?oo
_`1d000000000080000000<0001d0;ooo`3oool0KP3oool00`3OW4P0001809cOo`050?ooo`050?oo
_`1d000000000000B02Lgol0K03oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080
000000<0001d0;ooo`3oool03P3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?ooool0ooooo`3o
ool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o0?ooool0
ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0oooo003o
0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool00?l0ooooo`3ooooo0?ooo`L0
oooo003o0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3oool001X0oooo;@3o0037
000000030000o`000000000001P0000000<0o`00000000000000200000000`3o000000000000002G
000000030?l000000000000002@000000P000?l9000000030000o`000000000000/00000h03o000F
0?ooo`006P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180ooooLP3o00090?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`040000003oool0oooo0000oa@0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o00005@3oool00`000000oooo0?ooo`0=
0?ooo`80003o00<0oooo0?l0003o00005@3o00060?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo000J0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00`0oooo;`3o000;0?ooo`030000003oool0oooo01D0oooo00@000000?oo
o`3oool0003o503oool01@000000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?l0000E0?ooo`030000003oool0oooo00X0oooo1P3o00050?ooo`050000003o
ool0oooo0?ooo`000?l04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`006P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3ooolM0?l000H0oooo00D0
00000?ooo`3oool0oooo0000o`0C0?ooo`040000003oool0oooo0?l000d0oooo00<0o`000?ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?l0000E0?ooo`030000003oool0oooo00H0oooo103o00000`000?l0
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000?l04`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?oo
o`006P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0700oooo2`3o00020000oa<0
oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`1=0?ooo`030000003oool0oooo04P0
oooo00<0o`000?ooo`3oool06P3oool20?l000030?ooo`000?l0003o00`0oooo00D000000?ooo`3o
ool0oooo0000o`1c0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0503oool00?l0
oooo4@3oool20?l000`0003o1`3o000>0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3o
ool0B03oool00`3o0000oooo0?ooo`0I0?ooo`040?l0003oool0003o0000oa80oooo00<0003o0?oo
o`3oool0o`3oool20?ooo`006P3oool?0?l00?D0oooo20000?l=0?ooo`030?l0003oool0oooo04d0
oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0H0?ooo`030?l000000?l0003o01@0
oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00:@3ooolf0?l00<L0oooo20000?l50?ooo`030?l0
003oool0oooo04d0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0G0?ooo`030?l0
00000?l0oooo01D0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00G`3oool?0?l00<00oooo2000
0?m=0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo0?l0oooo0P3oool006h0oooo5P3o002_0?ooo`030?l0003oool0
oooo00H0003oA`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo01D0oooo00<0o`00
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo00240?oooah0o`00T@3oool00`3o
0000oooo0?ooo`060?ooo`@0003o@`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`3o0?ooo`80oooo002R0?oooa@0
o`00O03oool00`3o0000oooo0?ooo`0;0?ooo`<0003o@03oool00`000000oooo0?ooo`180?ooo`03
0?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`3o0?ooo`80
oooo002f0?ooo`X0o`00LP3oool00`3o0000oooo0?ooo`0>0?ooo`@0003o?03oool00`000000oooo
0?ooo`180?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo00300?ooo`X0o`00J03oool00`3o0000oooo0?ooo`0B0?ooo`@0003o>03o
ool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`3o0?ooo`80oooo003:0?ooo``0o`00G03oool00`3o0000oooo0?ooo`0F
0?ooo`<0003o=@3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo0140oooo00<0003o
0?l0003oool06`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003F0?ooo``0o`00D03oool00`3o
0000oooo0?ooo`0I0?ooo`<0003o<P3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo
0100oooo00<0003o0?l0003oool0703oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003R0?ooo`P0
o`00A`3oool00`3o0000oooo0?ooo`0M0?ooo`<0003o;`3oool00`000000oooo0?ooo`180?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?l0003oool0703oool00`000?l0oooo0?ooo`3o0?ooo`80
oooo003Z0?ooo`L0o`00@03oool00`3o0000oooo0?ooo`0P0?ooo`<0003o;03oool00`000000oooo
0?ooo`180?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o00007@3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo003a0?ooo`H0o`00>P3oool00`3o0000oooo0?ooo`0S0?ooo`<0003o:@3o
ool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o00007@3o
ool00`000?l0oooo0?ooo`3o0?ooo`80oooo003g0?ooo`H0o`00=03oool00`3o0000oooo0?ooo`0V
0?ooo`80003o9`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00h0oooo00@0003o
0?ooo`3oool0o`007@3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003m0?ooo`H0o`00;@3oool0
0`3o0000oooo0?ooo`0Y0?ooo`80003o9@3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0
oooo00h0oooo00@0003o0?ooo`3oool0o`007@3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o
0?ooo`@0oooo1P3o000W0?ooo`030?l0003oool0oooo02/0oooo0P000?lS0?ooo`030000003oool0
oooo04P0oooo00<0o`000?ooo`3oool03@3oool01@000?l0oooo0?ooo`3oool0o`0001d0oooo00<0
003o0?ooo`3oool0o`3oool20?ooo`00o`3oool:0?ooo`@0o`001@000?lN0?ooo`030?l0003oool0
oooo02d0oooo0P000?lQ0?ooo`@00000A`3oool00`3o0000oooo0?ooo`0=0?ooo`040000o`3oool0
oooo0?l001h0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool=0?ooo`030000o`3oool0
oooo00<0o`0010000?lI0?ooo`030?l0003oool0oooo0300oooo0P000?lO0?ooo`030000003oool0
oooo04P0oooo00<0o`000?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0o`0001h0oooo00<0
003o0?ooo`3oool0o`3oool20?ooo`00o`3oool<0?ooo`030000o`3oool0oooo00H0oooo0P3o0004
0000oaD0oooo00<0o`000?ooo`3oool0<P3oool20000oad0oooo00<000000?ooo`3oool0B03oool0
0`3o0000oooo0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`3o00007P3oool00`000?l0oooo0?oo
o`3o0?ooo`80oooo003o0?ooo``0oooo00<0003o0?ooo`3oool02`3oool0103o0000003o0000o`00
0?lA0?ooo`030?l0003oool0oooo03D0oooo0P000?lK0?ooo`030000003oool0oooo04P0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo01`0oooo00<0
003o0?ooo`3oool0o`3oool20?ooo`00o`3oool;0?ooo`030000o`3oool0oooo0100oooo10000?l<
0?ooo`030?l0003oool0oooo03P0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`18
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2`3oool00`000?l0oooo0?ooo`0D0?oo
o`<0003o2@3o000l0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool0B03oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool05`3oool40000od80
oooo0P000?lG0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00
o`3oool;0?ooo`030000o`3oool0oooo01/0oooo10000?m00?ooo`030000o`3oool0oooo01@0oooo
00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`X0oooo00<0
003o0?ooo`3oool0803oool40000ocd0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?oo
o`180?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0M0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2P3oool00`000?l0oooo0?ooo`0T
0?ooo`<0003o>`3oool20000oa<0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`3o
0?ooo`80oooo003o0?ooo`X0oooo00<0003o0?ooo`3oool09`3oool20000oc/0oooo00<0003o0?oo
o`3oool0403oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0
oooo2P3oool00`000?l0oooo0?ooo`0Y0?ooo`<0003o>@3oool00`000?l0oooo0?ooo`0?0?ooo`03
0000003oool0oooo04P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool:0?ooo`030000
o`3oool0oooo02`0oooo0`000?lg0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0
B03oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`X0oooo00<0003o0?ooo`3oool0;`3o
ool20000ocH0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`180?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3o
ool0oooo0?l0oooo0P3oool00?l0oooo2P3oool00`000?l0oooo0?ooo`0a0?ooo`<0003o=03oool2
0000o`d0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?oo
o`X0oooo00<0003o0?ooo`3oool0=03oool20000oc@0oooo00<0003o0?ooo`3oool02P3oool00`00
0000oooo0?ooo`180?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2P3oool00`000?l0
oooo0?ooo`0f0?ooo`80003o<`3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo04P0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01l0
oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool:0?ooo`030000o`3oool0oooo03P0oooo
0P000?lb0?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0>`3oool20000oc40oooo00<0
003o0?ooo`3oool01`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0?l0oooo0P3o
ool00?l0oooo2@3oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo02l0oooo00<0003o
0?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0?l0oooo0P3oool0
0?l0oooo2@3oool00`000?l0oooo0?ooo`0n0?ooo`80003o<03oool00`000?l0oooo0?ooo`050?oo
o`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool90?ooo`03
0000o`3oool0oooo0400oooo0P000?l^0?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3o
ool0B03oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0
@P3oool20000obd0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`180?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo0?l0oooo0P3oool00?l0oooo2@3oool00`000?l0oooo0?ooo`140?ooo`80003o;03o
ool00`000?l0oooo0?ooo`030?ooo`@00000A`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o
0?ooo`T0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0
oooo0080oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?oo
o`T0oooo00<0003o0?ooo`3oool0A`3oool20000ob/0oooo00D0003o0?ooo`3oool0oooo0000001:
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0O
0?ooo`030000o`3oool0oooo0?l0oooo0P3oool00?l0oooo2@3oool00`000?l0oooo0?ooo`190?oo
o`030000o`3oool0oooo02T0oooo00@0003o0?ooo`3oool00000BP3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o
0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0BP3oool20000obX0oooo00<0003o0?oo
o`000000BP3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`80oooo003o0?ooo`T0oooo00<0003o0?ooo`3o
ool0C03oool20000obT0oooo00<0003o0000003oool0B@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`80
oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0V0?ooo`030000
o`000000oooo04T0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oool20?ooo`00o`3oool90?ooo`030000o`3o
ool0oooo04l0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`190?ooo`050?l0003o
ool0oooo0?ooo`000?l02@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo2@3oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo02D0oooo00<0
00000000o`3oool0B@3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0o`000?ooo`3oool0
7`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0D@3o
ool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0003o04T0oooo00@0o`000?ooo`3oool0003o
2P3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo2@3o
ool00`000?l0oooo0?ooo`1B0?ooo`030000o`3oool0oooo02<0oooo00@000000?ooo`3oool0003o
B03oool0103o0000oooo0?ooo`000?l:0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool90?ooo`030000o`3oool0oooo05<0oooo00<0003o0?ooo`3oool0
8P3oool01@000000oooo0?ooo`3oool0003o04L0oooo00@0o`000?ooo`3oool0003o2P3oool00`3o
0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo2@3oool00`000?l0
oooo0?ooo`1D0?ooo`030000o`3oool0oooo0240oooo00D000000?ooo`3oool0oooo0000o`170?oo
o`030?l0003oool0003o00/0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0P0?ooo`03
0000003oool0oooo0080oooo00<0003o0?ooo`3oool0A03oool00`3o0000oooo0000o`0;0?ooo`03
0?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool90?ooo`030000
o`3oool0oooo05H0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`030000
o`3oool0oooo04@0oooo00<0o`000?ooo`000?l02P3oool00`3o0000oooo0?ooo`0P0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3o
ool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`130?ooo`030?l00000
0?l0oooo00X0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`P0oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0
oooo00@0oooo00<0003o0?ooo`3oool0@P3oool00`3o0000003o0?ooo`0:0?ooo`030?l0003oool0
oooo0200oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo
05X0oooo0P000?lM0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0@P3oool00`3o
0000003o0?ooo`0:0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oool30?oo
o`00o`3oool80?ooo`030000o`3oool0oooo05`0oooo00<0003o0?ooo`3oool06P3oool00`000000
oooo0?ooo`050?ooo`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo
0?ooo`1M0?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`110?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?oo
o`0H0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool8
0?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`07
0?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1P0?oo
o`030000o`3oool0oooo01H0oooo100000060?ooo`030000o`3oool0oooo03h0oooo00<0003o0?l0
003oool02`3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo203oool00`000?l0oooo0?ooo`1Q0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3o0000oooo00/0oooo00<0o`000?ooo`3o
ool0803oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0
HP3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0
?@3oool00`000?l0o`000?ooo`0;0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo0680oooo00<0003o0?ooo`3oool0503o
ool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo03`0oooo00<0003o0?l0003oool02`3o
ool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool0
0`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0j0?ooo`030000o`3oool0o`0000`0oooo00<0o`000?ooo`3oool0803oool0
0`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0I03oool00`00
0?l0oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool0>P3oool00`00
0?l0oooo0?l0000<0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0o`3oool30?oo
o`00o`3oool80?ooo`030000o`3oool0oooo06D0oooo00<0003o0?ooo`3oool04@3oool00`000000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3o0000303oool00`3o0000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo
0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0h0?ooo`040000o`3oool0oooo0?l000`0oooo00<0o`000?ooo`3oool0803oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0I`3oool00`000?l0oooo
0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0=`3oool010000?l0oooo
0?ooo`3o000;0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool80?ooo`030000o`3oool0oooo06L0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo03H0oooo00@0003o0?ooo`3oool0o`002`3oool00`3o0000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo
0?ooo`1X0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0f0?ooo`040000o`3oool0oooo0?l000/0oooo00<0o`000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0=03oool01@000?l0oooo
0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<0003o0?ooo`3oool0=03oool01@000?l0oooo0?ooo`3oool0o`0000/0
oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo
00<0003o0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo
00<0003o0?ooo`3oool0<`3oool01@000?l0oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0
JP3oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0
<P3oool01@000?l0oooo0?ooo`3oool0o`0000/0oooo00<0o`000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0J`3oool00`000?l0oooo
0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0K03oool00`000?l0oooo0?oo
o`0:0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0K03oool00`000?l0oooo0?ooo`0:
0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0K@3oool00`000?l0oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0E`3oool01@3o_g@00000000000000000M;oo
00D0oooo00<0_g@000000000M;l00`3oool00`3ookl0M00000000004000000030000o`3oool0oooo
00P0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1G0?ooo`0609a8M02oool0oooo0?oo
_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`030;md000007@0_ooo0080oooo00<0giad
0000o`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo02d0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0240oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo05H0oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?noM00004P0W=oo00<0oooo00<0003o0?oo
o`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo02d0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0240oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo05H0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00<0oooo00<0003o0?ooo`3o
ool01P3oool600000140oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0EP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?no
M000M;l0oooo00h0oooo00D0W4P004RLg`3oool0oooo0000o`080?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo
00<0003o0?ooo`3oool0EP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo
00D0W4Qd0;ooo`3oool0oooo0000o`070?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3o
ool0:P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0
EP3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Boo`3oool0
0P3oool01@2oM000M;oo0?ooo`3oool0003o00L0oooo00<000000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo
0?ooo`1G0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0
okmd0000B02Lgol00`3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<0
003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o
0?ooo`3oool0E`3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd0000000000000018
09cOo`050?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0X0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?oo
o`1c0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?oo
o`0W0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1d
0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0V
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0Q
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1d0?oo
o`030000o`3oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0U0?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1e0?ooo`05
0000o`3oool0oooo0?ooo`0000006P3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo203oool00`000?l0oooo0?ooo`1e0?ooo`050000o`3oool0oooo0?oo
o`0000006`3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo203oool00`000?l0oooo0?ooo`1f0?ooo`040000o`3oool0oooo000001/0oooo00<0003o0?oo
o`3oool08`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3o
ool0MP3oool010000?l0oooo0?ooo`00000L0?ooo`030000o`3oool0oooo0280oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0280oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07L0oooo00<0003o0?ooo`00
0000703oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo
203oool00`000?l0oooo0?ooo`1g0?ooo`030000o`3oool0000001d0oooo00<0003o0?ooo`3oool0
803oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0M`3o
ool00`000?l0oooo0000000M0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0o`3o
ool30?ooo`00o`3oool80?ooo`030000o`3oool0oooo07P0oooo00<0003o0000003oool07@3oool0
0`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo203oool00`00
0?l0oooo0?ooo`1h0?ooo`030000o`000000oooo01d0oooo00<0003o0?ooo`3oool07P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000?l0
oooo0?ooo`0M0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo
0?ooo`0K0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`03000000000?l0oooo01h0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000003o0?ooo`0O
0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`000?l0803oool00`000?l0oooo0?ooo`0H0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`80
000000<0003o0000003oool07P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0003o0240oooo
00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool010000000oooo0?ooo`000?lQ0?ooo`030000o`3oool0oooo01@0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0280oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00@0
00000?ooo`3oool0003o8@3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`050000003oool0oooo0?ooo`000?l0
8@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`050000003oool0oooo0?ooo`000?l08@3oool00`000?l0oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`050000003oool0oooo0?ooo`000?l08P3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo0080oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00<0
oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00@0oooo
00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01<0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool08`3oool20000o`D0oooo0P000?lF0?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo02D0oooo1@000?lH
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo0440oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo00D0oooo00<0003o0?ooo`3oool0@@3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`100?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0400oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo00H0oooo00<0003o0?ooo`3oool0@03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo02<0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0o0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo03l0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00L0oooo
00<0003o0?ooo`3oool0?`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02<0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo1000
00070?ooo`030000o`3oool0oooo03h0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0S0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0?P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`0n0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`080?ooo`03
0000o`3oool0oooo03h0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000
003oool0oooo00T0oooo00<0003o0?ooo`3oool0?@3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0m0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0
oooo03d0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo
00X0oooo00<0003o0?ooo`3oool0?03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
02<0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0
oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0l0?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo
00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo03`0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00/0oooo00<0
003o0?ooo`3oool0?03oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02<0oooo00<0
003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<00000
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0l0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool08`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0?03oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0k0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
8`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo03/0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0j0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo03X0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0>P3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0i0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo03T0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?oo
o`@000003@3oool00`000?l0oooo0?ooo`0i0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool08`3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo03T0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo
1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0
>03oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0h0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo03P0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`00
0?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0=`3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?oo
o`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0g0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0f
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo03H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo0140oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0e0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo03D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo0180oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo03@0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01<0oooo
00<0003o0?ooo`3oool0=03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0503oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0F03oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3o
ool01@3ogi`0B000000000000000M;oo00X0oooo00<000000?ooo`3oool0503oool00`000?l0oooo
0?ooo`0c0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0F03oool01P2LB7@0_ooo0?oo
o`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0203oool00`2oM000M;oo0?ooo`0:0?ooo`03
0000003oool0oooo01@0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo05L0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030;md
001d_ol0oooo00X0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0c0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0E`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00X0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`080?ooo`030000003o
ool0oooo01D0oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo05L0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`060?noM00007@0
_ooo0?ooo`2oM000M;oo2`3oool600000180oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo05L0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0;0?ooo`050=nLB000M;l0oooo0;md001d_ol02`3oool00`000000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0380oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1G0?ooo`030?noM018
W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102LB000B9cO0;md001d_ol;0?ooo`030000
003oool0oooo01H0oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo05P0oooo00H0W4P007Boo`3oool0omnL04P0M02oool=0?ooo`040?oOW01804P0B4P007Bo
o`/0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0F03oool01@3ookl0M0000000000004P0W=oo00l0oooo00<0okmd0000
001d_ol02`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0340oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01H0oooo00<0003o0?ooo`3o
ool0<@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0300oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`00
0?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000
oooo0?ooo`0H0?ooo`030000o`3oool0oooo02l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0_0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo02l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?oo
o`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0^0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0I0?ooo`030000
o`3oool0oooo02h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo01T0oooo00<0003o0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo07X0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
02d0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01X0
oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool4000001T0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool7
0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0/
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`3o
0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0K0?oo
o`030000o`3oool0oooo02`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0T0?oo
o`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo01/0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000
o`3oool0oooo07X0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0/0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3o
ool0oooo02/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo01`0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo02/0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01d0oooo
00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool0
0?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01d0oooo00<0003o0?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo02D0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool07@3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0
NP3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3o
ool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool07P3oool0
0`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0
oooo0?ooo`1j0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0Y0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0O0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo1000000O0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0
oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3o
ool0:03oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3o
ool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0
803oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool3
0?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo
0?ooo`1j0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0W0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?oo
o`030000003oool0oooo0280oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`03
0000o`3oool0oooo07X0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0V0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0
oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo02H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo02<0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo07X0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?oo
o`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
02D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo
00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo02@0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3o
ool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02@0oooo00<0003o
0?ooo`3oool0903oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o
0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?oo
o`3oool0903oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo
1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo1000000T0?ooo`030000o`3o
ool0oooo02<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo
07X0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0280
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0
oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02H0oooo
00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0280oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool0
0?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo
o`3oool08P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?oo
o`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3o
ool09P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0
NP3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool08@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3o
ool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0
oooo0?ooo`1j0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool08@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00
o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo
0?ooo`0P0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0X0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?oo
o`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0F03oool01@3o_g@00000000000000000M;oo
00D0oooo00<0_g@000000000M;l01P3oool01@2oM00000000000000007@0_ooo00X0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?oo
o`3oool0F03oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01@3o
ool01P3OW4P007Bo0?ooo`3oool0okmd001d_`X0oooo00<000000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`0O0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0E`3oool00`3o_g@007Bo
0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M4RL
0?ooo`090?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo05L0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0:0?ooo`070?noM000B4P0M01d0;ooo`3oool0gia8001d_`0:0?ooo`030000003oool0oooo02T0
oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02H0
oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo05L0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oOW018B9`0okmd00800000
00<004RL0?ooo`3oool02@3oool6000002H0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo05L0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0:0?ooo`030?oo_`1d07@0_ooo00h0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?oo
o`0O0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0E`3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00/0oooo00<0_g@004RLg`3oool03@3oool00`000000oooo0?ooo`0Y
0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0V
0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1H0?oo
o`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool00`3ookl0M000001d_`0=0?ooo`030000003o
ool0oooo02X0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo02H0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0
oooo05P0oooo00D0oono07@000000000001809cOo`0?0?ooo`040;md0000000000000018W0X0oooo
00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo01l0oooo00D0
o`000?ooo`3oool0oooo0?l0000X0?ooo`030000o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool07`3o
ool01@3o0000oooo0?ooo`3oool0o`0002P0oooo00<0003o0?ooo`3oool0o`3oool30?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?oo
o`0O0?ooo`050?l0003oool0oooo0?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`<0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0[0?ooo`030000o`3o
ool0oooo01h0oooo00D0o`000?ooo`3oool0oooo0?l0000X0?ooo`030000o`3oool0oooo0?l0oooo
0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02/0oooo00<0
003o0?ooo`3oool07P3oool01@3o0000oooo0?ooo`3oool0o`0002P0oooo00<0003o0?ooo`3oool0
o`3oool30?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:`3o
ool00`000?l0oooo0?ooo`0N0?ooo`050?l0003oool0oooo0?ooo`3o0000:03oool00`000?l0oooo
0?ooo`3o0?ooo`<0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo01h0oooo00D0o`000?ooo`3oool0oooo0?l0000X0?ooo`030000
o`3oool0oooo0?l0oooo0`3oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo02/0oooo00<0003o0?ooo`3oool07P3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`050?l0003oool0oooo0?ooo`3o0000
9`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo01d0oooo00D0o`000?ooo`3oool0oooo
0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool07@3oool01@3o0000oooo0?oo
o`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0M0?ooo`050?l0003o
ool0oooo0?ooo`3o00009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo01d0oooo00D0
o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool07@3o
ool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?oo
o`0L0?ooo`050?l0003oool0oooo0?ooo`3o00009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0]0?ooo`030000o`3o
ool0oooo01`0oooo00D0o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo
103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02d0oooo00<0
003o0?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo1000000/0?ooo`030000o`3o
ool0oooo01`0oooo00D0o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo
103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02d0oooo00<0
003o0?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`0K0?ooo`050?l0003oool0oooo0?ooo`3o00009`3oool00`000?l0oooo
0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0^0?ooo`030000o`3oool0oooo01/0oooo00D0o`000?ooo`3oool0oooo0?l0000W0?ooo`030000
o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo02h0oooo00<0003o0?ooo`3oool06`3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0K0?ooo`050?l0003oool0oooo0?ooo`3o0000
9`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo01/0oooo00D0o`000?ooo`3oool0oooo
0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool06P3oool01@3o0000oooo0?oo
o`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0J0?ooo`050?l0003o
ool0oooo0?ooo`3o00009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo01X0oooo00D0
o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool06P3o
ool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`0J0?ooo`050?l0003oool0oooo0?ooo`3o00009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3o
ool0oooo01X0oooo00D0o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo
103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0300oooo00<0
003o0?ooo`3oool06@3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<03o
ool00`000?l0oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`3o00009`3oool00`000?l0oooo
0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?oo
o`0`0?ooo`030000o`3oool0oooo01T0oooo00D0o`000?ooo`3oool0oooo0?l0000W0?ooo`030000
o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo0300oooo00<0003o0?ooo`3oool06@3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`3o0000
9`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo
0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?oo
o`1j0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0603oool01@3o0000oooo0?oo
o`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3o
ool0oooo07X0oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0H0?ooo`050?l0003o
ool0oooo0?ooo`3o00009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo01P0oooo00D0
o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0603o
ool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo1000000a0?ooo`030000o`3oool0oooo01L0oooo00D0
o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3o
ool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool05`3o
ool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3o
ool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?oo
o`0G0?ooo`050?l0003oool0oooo0?ooo`3o00009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo01L0oooo00D0o`000?ooo`3oool0oooo0?l0000W0?ooo`030000o`3oool0oooo0?l0oooo
103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo00<0
003o0?ooo`3oool05`3oool01@3o0000oooo0?ooo`3oool0o`0002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<P3o
ool00`000?l0oooo0?ooo`0H0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0G0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0G0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0G0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0G0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0G0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0F0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0F0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0F0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0F0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0F0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=P3o
ool00`000?l0oooo0?ooo`0D0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=P3o
ool00`000?l0oooo0?ooo`0D0?ooo`040?l0003oool0oooo0?l002L0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo1000000e0?ooo`030000o`3o
ool0oooo01@0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0f0?ooo`030000o`3o
ool0oooo01@0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0f0?ooo`030000o`3o
ool0oooo01@0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo01<0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo01<0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo01<0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo01<0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo01<0oooo00@0o`000?ooo`3oool0o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3o
ool0oooo0180oooo00<0o`000?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?oo
o`L0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0
oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo
00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3o0000:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0180oooo0P3o000X0?ooo`03
0000o`3oool0oooo0?l0oooo103oool00?l0oooo1`3oool00`000?l0oooo0?ooo`1j0?ooo`030000
003oool0oooo03X0oooo00<0003o0?ooo`3oool04@3oool20?l002P0oooo00<0003o0?ooo`3oool0
o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>P3o
ool00`000?l0oooo0?ooo`0A0?ooo`80o`00:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o
0?ooo`L0oooo00<0003o0?ooo`3oool0F03oool01@3o_g@00000000000000000M;oo00D0oooo00<0
_g@000000000M;l01@3oool01@2oM000000000000000000007Bo00/0oooo00<000000?ooo`3oool0
>P3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo
003o0?ooo`L0oooo00<0003o0?ooo`3oool0F03oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0
oooo00<0_g@000000000M;l0103oool00`3o_g@007Bo0?ooo`020?ooo`030;mdB02Lgol0oooo00T0
oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00:03oool00`000?l0
oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`L0oooo00<0003o0?ooo`3oool0E`3oool00`3o_g@007Bo
0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo
0?ooo`090?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool04@3oool20?l002P0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool70?ooo`030000o`3oool0oooo05L0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?noM000B9`0oooo0080oooo00<0
W4Q809cOo`3oool02@3oool6000003P0oooo00<0003o0?ooo`3oool0403oool20?l002P0oooo00<0
003o0?ooo`3oool0o`3oool40?ooo`00o`3oool60?ooo`030000o`3oool0oooo05P0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0;0?ooo`050=nLB0000000000000000018W=l02`3o
ool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0100oooo0P3o000X0?ooo`030000o`3o
ool0oooo0?l0oooo103oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1H0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool02P3oool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0
oooo00T0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0@0?ooo`80o`00:03oool0
0`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0F03oool00`3o
_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3oool00P3oool00`2o
M000M;oo0?ooo`090?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool0403oool20?l0
02P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool60?ooo`030000o`3oool0oooo05T0
oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B01d
0;ooo`0:0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool03`3oool20?l002P0oooo
00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3oool60?ooo`030000o`3oool0oooo05T0oooo00D0
oono07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol02`3oool00`000000
oooo0?ooo`0l0?ooo`030000o`3oool0oooo00l0oooo0P3o000X0?ooo`030000o`3oool0oooo0?l0
oooo103oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo03`0oooo
00<0003o0?ooo`3oool03`3oool20?l002P0oooo00<0003o0?ooo`3oool0o`3oool40?ooo`00o`3o
ool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?oo
o`0?0?ooo`80o`00:03oool00`000?l0oooo0?ooo`3o0?ooo`@0oooo003o0?ooo`H0oooo00<0003o
0?ooo`3oool0N`3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo00l0oooo0P3o000W
0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?oo
o`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool03P3oool20?l002L0oooo00<0003o0?oo
o`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3o
ool0?@3oool00`000?l0oooo0?ooo`0>0?ooo`80o`009`3oool00`000?l0oooo0?ooo`3o0?ooo`D0
oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0m0?ooo`030000
o`3oool0oooo00h0oooo0P3o000W0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3o
ool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool03P3o
ool20?l002L0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3oool0
oooo07/0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`009`3oool0
0`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0n0?ooo`030000o`3oool0oooo00d0oooo0P3o000W0?ooo`030000o`3oool0oooo
0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo03h0
oooo00<0003o0?ooo`3oool03@3oool20?l002L0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00
o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3o
ool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool6
0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?oo
o`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`03
0000o`3oool0oooo07/0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000
o`3oool0oooo07/0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3o
ool0oooo07/0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02D0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3oool0
oooo07/0oooo1000000o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`00
0000oooo0?ooo`100?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000
oooo0?ooo`110?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool09@3oool00`000?l0
oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo
0?ooo`110?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?oo
o`110?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?oo
o`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`11
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o
0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`120?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?oo
o`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`120?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0
oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`120?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo
003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`120?ooo`030000o`3o
ool0oooo00X0oooo0P3o000V0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool02@3oool2
0?l002H0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3oool0oooo
07/0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`090?ooo`80o`009P3oool00`00
0?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000
oooo0?ooo`130?ooo`030000o`3oool0oooo00T0oooo0P3o000V0?ooo`030000o`3oool0oooo0?l0
oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04<0oooo
00<0003o0?ooo`3oool02@3oool20?l002H0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3o
ool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?oo
o`080?ooo`80o`009P3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o
0?ooo`3oool0N`3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo00P0oooo0P3o000V
0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?oo
o`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0203oool20?l002H0oooo00<0003o0?oo
o`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3o
ool0A03oool00`000?l0oooo0?ooo`080?ooo`80o`009P3oool00`000?l0oooo0?ooo`3o0?ooo`D0
oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`150?ooo`030000
o`3oool0oooo00L0oooo0P3o000V0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3o
ool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool01`3o
ool20?l002H0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`00o`3oool60?ooo`030000o`3oool0
oooo07/0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`070?ooo`80o`009P3oool0
0`000?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`00
0000oooo0?ooo`160?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o00009@3oool00`00
0?l0oooo0?ooo`3o0?ooo`D0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool4000004D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0
oooo1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0oooo
1@3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0oooo1@3o
ool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04L0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool0
0?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0
oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo
1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?l0000U0?ooo`030000o`3oool0oooo0?l0oooo1@3oool00?l0oooo1P3o
ool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?l0000T0?ooo`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool00`3oool0
103o0000oooo0?ooo`3o000S0?ooo`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool00`3oool0
103o0000oooo0?ooo`3o000S0?ooo`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00P3oool0
103o0000oooo0?ooo`3o000S0?ooo`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00P3oool0
103o0000oooo0?ooo`3o000S0?ooo`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool0
0`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo04/0oooo00D0003o0?ooo`3oool0oooo0?l0
00020?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0o`3oool60?ooo`00o`3oool6
0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0B`3oool01@000?l0oooo0?ooo`3o
ool0o`000080oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o
0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1<0?ooo`040000o`3oool0
oooo0?l00080oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o
0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1<0?ooo`040000o`3oool0
oooo0?l000<0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o
0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1<0?ooo`040000o`3oool0
oooo0?l000<0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o
0?ooo`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0
o`0000<0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?oo
o`H0oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0o`00
00<0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0
oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1>0?ooo`030000o`3o0000oooo0080
oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0oooo
00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1>0?ooo`030000o`3o0000oooo0080oooo
00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0oooo00<0
003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`H0oooo00<0003o
0?ooo`3oool0N`3oool4000004h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0O
0?ooo`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?oo
o`030000003oool0oooo04l0oooo00<0o`000000o`3oool00P3oool00`3o0000oooo0?ooo`0O0?oo
o`030000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`03
0000003oool0oooo04l0oooo00<0o`000000o`3oool00`3oool00`3o0000oooo0?ooo`0N0?ooo`03
0000o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000
003oool0oooo04l0oooo00<0o`000?ooo`000?l00`3oool00`3o0000oooo0?ooo`0N0?ooo`030000
o`3oool0oooo0?l0oooo1P3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003o
ool0oooo04l0oooo00<0o`000?ooo`000?l00`3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3o
ool0oooo0?l0oooo1P3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0
oooo04l0oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3o
ool0oooo0?l0oooo1`3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0
oooo04l0oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3o
ool0oooo0?l0oooo1`3oool00?l0oooo1P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0
oooo04l0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo01`0oooo00<0
003o0?ooo`3oool0o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<00000
0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l001d0oooo00<0
003o0?ooo`3oool0o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<00000
0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0o`0001d0oooo00<0003o
0?ooo`3oool0o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?oo
o`3oool0C`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo01`0oooo00<0003o0?oo
o`3oool0o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3o
ool0C`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000oooo01/0oooo00<0003o0?ooo`3o
ool0o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0
C`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000oooo01X0oooo00<0003o0?ooo`3oool0
o`3oool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3o0000oooo01T0oooo00<0003o0?ooo`3oool0o`3o
ool70?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3o0000oooo01P0oooo00<0003o0?ooo`3oool0o`3oool7
0?ooo`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0o`3oool80?oo
o`00o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l000000?l0oooo01@0oooo00<0003o0?ooo`3oool0o`3oool80?ooo`00
o`3oool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo
0?ooo`0<0?ooo`030?l000000?l0003o01<0oooo00<0003o0?ooo`3oool0o`3oool80?ooo`00o`3o
ool60?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?oo
o`0=0?ooo`D0o`003`3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo003o0?ooo`H0oooo00<0003o
0?ooo`3oool0JP3oool00`3o_g@000000000000300000003001d_`3oool0oooo00P0oooo00<00000
0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`0B0?ooo`@0o`000`000?l70?ooo`80003oo`3oool;
0?ooo`00o`3oool60?ooo`030000o`3oool0oooo06d0oooo00<0W4Q809cOo`3oool02`3oool00`00
0000oooo0?ooo`1?0?ooo`030?l0003oool0oooo01H0oooo403o003o0?ooo`L0oooo003o0?ooo`H0
oooo00<0003o0?ooo`3oool0K@3oool00`2LB4P0W=oo0?ooo`0;0?ooo`030000003oool0oooo04l0
oooo00<0o`000?ooo`3oool09P3ooolS0?l00><0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0
K@3oool00`2LB4P0W=oo0?ooo`0;0?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0
B@3oooo=0?l001H0oooo003o0?ooo`H0oooo00<0003o0?ooo`3oool0K@3oool00`2LB4P0W=oo0?oo
o`0;0?ooo`H00000C03oool00`3o0000oooo0?ooo`3o0?ooobd0oooo003o0?ooogH0oooo00<0W4Q8
09cOo`3oool0o`3ooon=0?ooo`00o`3ooomf0?ooo`0309a8B02Lgol0oooo0?l0ooooS@3oool00?l0
ooooL`3oool01@3OW4P000000018W02LB4P0W=oo0?l0ooooSP3oool00?l0ooooM@3oool00`3OW4P0
001809cOo`3o0?ooohh0oooo003o0?ooool0ooooo`3oool70?ooo`00o`3ooooo0?ooool0oooo1`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 771}, {476.188, 0}} -> {-16.0871, -0.0504388, \
0.0622326, 0.00335648}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Interpolation of PDF from Table",
    FontWeight->"Bold"],
  "\nSince the 0-parameterization is continuous in all four parameters it can \
be used to estimate interpolated values from a table.  This is a useful \
approach for fast PDF calculations.  It is used in the STABLE program and can \
also be implemented in ",
  StyleBox["Mathematica.  ",
    FontSlant->"Italic"],
  StyleBox["Such a routine has not been given within the SMath.m package, \
because the files would not be compatible across systems.  The code below \
can, however, create a file that will run on your system.  The xq table could \
be enlarged to higher resolution for greater accuracy.  Proceed through the \
following code very carefully and be sure file directory will work before \
Exporting.",
    FontVariations->{"CompatibilityType"->0}]
}], "Text"],

Cell[BoxData[
    \(<< Developer`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xq = 
        Table[\ 4  Tan[x], {x, \(-Pi\)/2 + Pi/1000, Pi/2, 
            Pi/500}];\)\), "\[IndentingNewLine]", 
    \(\(xq = 
        Join[{\(-10000\), \(-3200\)}, 
          xq, {3200, 10000}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[xq];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00188964 0.309017 0.0111134 [
[.21277 .29652 -9 -9 ]
[.21277 .29652 9 0 ]
[.40174 .29652 -9 -9 ]
[.40174 .29652 9 0 ]
[.5907 .29652 -9 -9 ]
[.5907 .29652 9 0 ]
[.77967 .29652 -9 -9 ]
[.77967 .29652 9 0 ]
[.96863 .29652 -9 -9 ]
[.96863 .29652 9 0 ]
[.01131 .08675 -18 -4.5 ]
[.01131 .08675 0 4.5 ]
[.01131 .19788 -18 -4.5 ]
[.01131 .19788 0 4.5 ]
[.01131 .42015 -12 -4.5 ]
[.01131 .42015 0 4.5 ]
[.01131 .53129 -12 -4.5 ]
[.01131 .53129 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21277 .30902 m
.21277 .31527 L
s
[(100)] .21277 .29652 0 1 Mshowa
.40174 .30902 m
.40174 .31527 L
s
[(200)] .40174 .29652 0 1 Mshowa
.5907 .30902 m
.5907 .31527 L
s
[(300)] .5907 .29652 0 1 Mshowa
.77967 .30902 m
.77967 .31527 L
s
[(400)] .77967 .29652 0 1 Mshowa
.96863 .30902 m
.96863 .31527 L
s
[(500)] .96863 .29652 0 1 Mshowa
.125 Mabswid
.0616 .30902 m
.0616 .31277 L
s
.0994 .30902 m
.0994 .31277 L
s
.13719 .30902 m
.13719 .31277 L
s
.17498 .30902 m
.17498 .31277 L
s
.25057 .30902 m
.25057 .31277 L
s
.28836 .30902 m
.28836 .31277 L
s
.32615 .30902 m
.32615 .31277 L
s
.36395 .30902 m
.36395 .31277 L
s
.43953 .30902 m
.43953 .31277 L
s
.47732 .30902 m
.47732 .31277 L
s
.51512 .30902 m
.51512 .31277 L
s
.55291 .30902 m
.55291 .31277 L
s
.6285 .30902 m
.6285 .31277 L
s
.66629 .30902 m
.66629 .31277 L
s
.70408 .30902 m
.70408 .31277 L
s
.74187 .30902 m
.74187 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85525 .30902 m
.85525 .31277 L
s
.89305 .30902 m
.89305 .31277 L
s
.93084 .30902 m
.93084 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .08675 m
.03006 .08675 L
s
[(-20)] .01131 .08675 1 0 Mshowa
.02381 .19788 m
.03006 .19788 L
s
[(-10)] .01131 .19788 1 0 Mshowa
.02381 .42015 m
.03006 .42015 L
s
[(10)] .01131 .42015 1 0 Mshowa
.02381 .53129 m
.03006 .53129 L
s
[(20)] .01131 .53129 1 0 Mshowa
.125 Mabswid
.02381 .10898 m
.02756 .10898 L
s
.02381 .1312 m
.02756 .1312 L
s
.02381 .15343 m
.02756 .15343 L
s
.02381 .17566 m
.02756 .17566 L
s
.02381 .22011 m
.02756 .22011 L
s
.02381 .24234 m
.02756 .24234 L
s
.02381 .26456 m
.02756 .26456 L
s
.02381 .28679 m
.02756 .28679 L
s
.02381 .33124 m
.02756 .33124 L
s
.02381 .35347 m
.02756 .35347 L
s
.02381 .3757 m
.02756 .3757 L
s
.02381 .39792 m
.02756 .39792 L
s
.02381 .44238 m
.02756 .44238 L
s
.02381 .4646 m
.02756 .4646 L
s
.02381 .48683 m
.02756 .48683 L
s
.02381 .50906 m
.02756 .50906 L
s
.02381 .06452 m
.02756 .06452 L
s
.02381 .0423 m
.02756 .0423 L
s
.02381 .02007 m
.02756 .02007 L
s
.02381 .55351 m
.02756 .55351 L
s
.02381 .57574 m
.02756 .57574 L
s
.02381 .59797 m
.02756 .59797 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.07294 .01014 Mdot
.07483 .02253 Mdot
.07672 .03394 Mdot
.07861 .04451 Mdot
.0805 .05431 Mdot
.08239 .06343 Mdot
.08428 .07194 Mdot
.08617 .0799 Mdot
.08806 .08735 Mdot
.08995 .09436 Mdot
.09184 .10095 Mdot
.09373 .10717 Mdot
.09562 .11304 Mdot
.09751 .11859 Mdot
.0994 .12385 Mdot
.10128 .12885 Mdot
.10317 .1336 Mdot
.10506 .13811 Mdot
.10695 .14242 Mdot
.10884 .14652 Mdot
.11073 .15044 Mdot
.11262 .15419 Mdot
.11451 .15778 Mdot
.1164 .16122 Mdot
.11829 .16452 Mdot
.12018 .16768 Mdot
.12207 .17073 Mdot
.12396 .17365 Mdot
.12585 .17647 Mdot
.12774 .17918 Mdot
.12963 .18179 Mdot
.13152 .18431 Mdot
.13341 .18675 Mdot
.1353 .1891 Mdot
.13719 .19137 Mdot
.13908 .19357 Mdot
.14097 .1957 Mdot
.14286 .19776 Mdot
.14475 .19976 Mdot
.14664 .2017 Mdot
.14853 .20358 Mdot
.15042 .2054 Mdot
.15231 .20717 Mdot
.1542 .20889 Mdot
.15608 .21056 Mdot
.15797 .21219 Mdot
.15986 .21377 Mdot
.16175 .21531 Mdot
.16364 .21681 Mdot
.16553 .21828 Mdot
.16742 .2197 Mdot
.16931 .22109 Mdot
.1712 .22245 Mdot
.17309 .22377 Mdot
.17498 .22506 Mdot
.17687 .22632 Mdot
.17876 .22755 Mdot
.18065 .22875 Mdot
.18254 .22993 Mdot
.18443 .23108 Mdot
.18632 .23221 Mdot
.18821 .23331 Mdot
.1901 .23439 Mdot
.19199 .23544 Mdot
.19388 .23648 Mdot
.19577 .23749 Mdot
.19766 .23848 Mdot
.19955 .23945 Mdot
.20144 .24041 Mdot
.20333 .24134 Mdot
.20522 .24226 Mdot
.20711 .24316 Mdot
.20899 .24405 Mdot
.21088 .24491 Mdot
.21277 .24577 Mdot
.21466 .2466 Mdot
.21655 .24743 Mdot
.21844 .24823 Mdot
.22033 .24903 Mdot
.22222 .24981 Mdot
.22411 .25058 Mdot
.226 .25133 Mdot
.22789 .25208 Mdot
.22978 .25281 Mdot
.23167 .25353 Mdot
.23356 .25424 Mdot
.23545 .25494 Mdot
.23734 .25562 Mdot
.23923 .2563 Mdot
.24112 .25697 Mdot
.24301 .25763 Mdot
.2449 .25827 Mdot
.24679 .25891 Mdot
.24868 .25954 Mdot
.25057 .26016 Mdot
.25246 .26078 Mdot
.25435 .26138 Mdot
.25624 .26198 Mdot
.25813 .26256 Mdot
.26002 .26314 Mdot
.2619 .26372 Mdot
.26379 .26428 Mdot
.26568 .26484 Mdot
.26757 .26539 Mdot
.26946 .26594 Mdot
.27135 .26648 Mdot
.27324 .26701 Mdot
.27513 .26753 Mdot
.27702 .26805 Mdot
.27891 .26857 Mdot
.2808 .26907 Mdot
.28269 .26958 Mdot
.28458 .27007 Mdot
.28647 .27056 Mdot
.28836 .27105 Mdot
.29025 .27153 Mdot
.29214 .27201 Mdot
.29403 .27248 Mdot
.29592 .27294 Mdot
.29781 .2734 Mdot
.2997 .27386 Mdot
.30159 .27431 Mdot
.30348 .27476 Mdot
.30537 .2752 Mdot
.30726 .27564 Mdot
.30915 .27607 Mdot
.31104 .27651 Mdot
.31293 .27693 Mdot
.31481 .27736 Mdot
.3167 .27777 Mdot
.31859 .27819 Mdot
.32048 .2786 Mdot
.32237 .27901 Mdot
.32426 .27941 Mdot
.32615 .27982 Mdot
.32804 .28021 Mdot
.32993 .28061 Mdot
.33182 .281 Mdot
.33371 .28139 Mdot
.3356 .28178 Mdot
.33749 .28216 Mdot
.33938 .28254 Mdot
.34127 .28292 Mdot
.34316 .28329 Mdot
.34505 .28366 Mdot
.34694 .28403 Mdot
.34883 .2844 Mdot
.35072 .28476 Mdot
.35261 .28512 Mdot
.3545 .28548 Mdot
.35639 .28584 Mdot
.35828 .28619 Mdot
.36017 .28654 Mdot
.36206 .28689 Mdot
.36395 .28724 Mdot
.36584 .28758 Mdot
.36772 .28793 Mdot
.36961 .28827 Mdot
.3715 .28861 Mdot
.37339 .28895 Mdot
.37528 .28928 Mdot
.37717 .28961 Mdot
.37906 .28995 Mdot
.38095 .29028 Mdot
.38284 .2906 Mdot
.38473 .29093 Mdot
.38662 .29125 Mdot
.38851 .29158 Mdot
.3904 .2919 Mdot
.39229 .29222 Mdot
.39418 .29254 Mdot
.39607 .29285 Mdot
.39796 .29317 Mdot
.39985 .29348 Mdot
.40174 .2938 Mdot
.40363 .29411 Mdot
.40552 .29442 Mdot
.40741 .29473 Mdot
.4093 .29503 Mdot
.41119 .29534 Mdot
.41308 .29565 Mdot
.41497 .29595 Mdot
.41686 .29625 Mdot
.41875 .29656 Mdot
.42063 .29686 Mdot
.42252 .29716 Mdot
.42441 .29745 Mdot
.4263 .29775 Mdot
.42819 .29805 Mdot
.43008 .29834 Mdot
.43197 .29864 Mdot
.43386 .29893 Mdot
.43575 .29923 Mdot
.43764 .29952 Mdot
.43953 .29981 Mdot
.44142 .3001 Mdot
.44331 .30039 Mdot
.4452 .30068 Mdot
.44709 .30097 Mdot
.44898 .30126 Mdot
.45087 .30155 Mdot
.45276 .30183 Mdot
.45465 .30212 Mdot
.45654 .30241 Mdot
.45843 .30269 Mdot
.46032 .30298 Mdot
.46221 .30326 Mdot
.4641 .30354 Mdot
.46599 .30383 Mdot
.46788 .30411 Mdot
.46977 .30439 Mdot
.47166 .30467 Mdot
.47354 .30496 Mdot
.47543 .30524 Mdot
.47732 .30552 Mdot
.47921 .3058 Mdot
.4811 .30608 Mdot
.48299 .30636 Mdot
.48488 .30664 Mdot
.48677 .30692 Mdot
.48866 .3072 Mdot
.49055 .30748 Mdot
.49244 .30776 Mdot
.49433 .30804 Mdot
.49622 .30832 Mdot
.49811 .3086 Mdot
.5 .30888 Mdot
.50189 .30916 Mdot
.50378 .30944 Mdot
.50567 .30972 Mdot
.50756 .30999 Mdot
.50945 .31027 Mdot
.51134 .31055 Mdot
.51323 .31083 Mdot
.51512 .31111 Mdot
.51701 .31139 Mdot
.5189 .31167 Mdot
.52079 .31195 Mdot
.52268 .31223 Mdot
.52457 .31252 Mdot
.52646 .3128 Mdot
.52834 .31308 Mdot
.53023 .31336 Mdot
.53212 .31364 Mdot
.53401 .31392 Mdot
.5359 .31421 Mdot
.53779 .31449 Mdot
.53968 .31477 Mdot
.54157 .31506 Mdot
.54346 .31534 Mdot
.54535 .31563 Mdot
.54724 .31591 Mdot
.54913 .3162 Mdot
.55102 .31649 Mdot
.55291 .31678 Mdot
.5548 .31706 Mdot
.55669 .31735 Mdot
.55858 .31764 Mdot
.56047 .31793 Mdot
.56236 .31822 Mdot
.56425 .31851 Mdot
.56614 .31881 Mdot
.56803 .3191 Mdot
.56992 .31939 Mdot
.57181 .31969 Mdot
.5737 .31999 Mdot
.57559 .32028 Mdot
.57748 .32058 Mdot
.57937 .32088 Mdot
.58125 .32118 Mdot
.58314 .32148 Mdot
.58503 .32178 Mdot
.58692 .32208 Mdot
.58881 .32239 Mdot
.5907 .32269 Mdot
.59259 .323 Mdot
.59448 .32331 Mdot
.59637 .32362 Mdot
.59826 .32393 Mdot
.60015 .32424 Mdot
.60204 .32455 Mdot
.60393 .32486 Mdot
.60582 .32518 Mdot
.60771 .3255 Mdot
.6096 .32581 Mdot
.61149 .32613 Mdot
.61338 .32646 Mdot
.61527 .32678 Mdot
.61716 .3271 Mdot
.61905 .32743 Mdot
.62094 .32776 Mdot
.62283 .32809 Mdot
.62472 .32842 Mdot
.62661 .32875 Mdot
.6285 .32909 Mdot
.63039 .32943 Mdot
.63228 .32976 Mdot
.63416 .33011 Mdot
.63605 .33045 Mdot
.63794 .33079 Mdot
.63983 .33114 Mdot
.64172 .33149 Mdot
.64361 .33184 Mdot
.6455 .3322 Mdot
.64739 .33255 Mdot
.64928 .33291 Mdot
.65117 .33327 Mdot
.65306 .33364 Mdot
.65495 .334 Mdot
.65684 .33437 Mdot
.65873 .33474 Mdot
.66062 .33512 Mdot
.66251 .3355 Mdot
.6644 .33588 Mdot
.66629 .33626 Mdot
.66818 .33664 Mdot
.67007 .33703 Mdot
.67196 .33742 Mdot
.67385 .33782 Mdot
.67574 .33822 Mdot
.67763 .33862 Mdot
.67952 .33902 Mdot
.68141 .33943 Mdot
.6833 .33984 Mdot
.68519 .34026 Mdot
.68707 .34068 Mdot
.68896 .3411 Mdot
.69085 .34153 Mdot
.69274 .34196 Mdot
.69463 .34239 Mdot
.69652 .34283 Mdot
.69841 .34328 Mdot
.7003 .34372 Mdot
.70219 .34417 Mdot
.70408 .34463 Mdot
.70597 .34509 Mdot
.70786 .34556 Mdot
.70975 .34603 Mdot
.71164 .3465 Mdot
.71353 .34698 Mdot
.71542 .34747 Mdot
.71731 .34796 Mdot
.7192 .34846 Mdot
.72109 .34896 Mdot
.72298 .34947 Mdot
.72487 .34998 Mdot
.72676 .3505 Mdot
.72865 .35103 Mdot
.73054 .35156 Mdot
.73243 .3521 Mdot
.73432 .35264 Mdot
.73621 .35319 Mdot
.7381 .35375 Mdot
.73998 .35432 Mdot
.74187 .35489 Mdot
.74376 .35547 Mdot
.74565 .35606 Mdot
.74754 .35665 Mdot
.74943 .35726 Mdot
.75132 .35787 Mdot
.75321 .35849 Mdot
.7551 .35912 Mdot
.75699 .35976 Mdot
.75888 .36041 Mdot
.76077 .36107 Mdot
.76266 .36173 Mdot
.76455 .36241 Mdot
.76644 .3631 Mdot
.76833 .3638 Mdot
.77022 .3645 Mdot
.77211 .36522 Mdot
.774 .36596 Mdot
.77589 .3667 Mdot
.77778 .36746 Mdot
.77967 .36822 Mdot
.78156 .36901 Mdot
.78345 .3698 Mdot
.78534 .37061 Mdot
.78723 .37143 Mdot
.78912 .37227 Mdot
.79101 .37312 Mdot
.79289 .37399 Mdot
.79478 .37487 Mdot
.79667 .37577 Mdot
.79856 .37669 Mdot
.80045 .37763 Mdot
.80234 .37858 Mdot
.80423 .37955 Mdot
.80612 .38055 Mdot
.80801 .38156 Mdot
.8099 .38259 Mdot
.81179 .38365 Mdot
.81368 .38473 Mdot
.81557 .38583 Mdot
.81746 .38695 Mdot
.81935 .3881 Mdot
.82124 .38928 Mdot
.82313 .39048 Mdot
.82502 .39171 Mdot
.82691 .39298 Mdot
.8288 .39427 Mdot
.83069 .39559 Mdot
.83258 .39694 Mdot
.83447 .39833 Mdot
.83636 .39976 Mdot
.83825 .40122 Mdot
.84014 .40272 Mdot
.84203 .40426 Mdot
.84392 .40584 Mdot
.8458 .40747 Mdot
.84769 .40914 Mdot
.84958 .41086 Mdot
.85147 .41264 Mdot
.85336 .41446 Mdot
.85525 .41634 Mdot
.85714 .41827 Mdot
.85903 .42027 Mdot
.86092 .42233 Mdot
.86281 .42446 Mdot
.8647 .42666 Mdot
.86659 .42893 Mdot
.86848 .43129 Mdot
.87037 .43372 Mdot
.87226 .43624 Mdot
.87415 .43886 Mdot
.87604 .44157 Mdot
.87793 .44438 Mdot
.87982 .44731 Mdot
.88171 .45035 Mdot
.8836 .45352 Mdot
.88549 .45681 Mdot
.88738 .46025 Mdot
.88927 .46384 Mdot
.89116 .46759 Mdot
.89305 .47151 Mdot
.89494 .47562 Mdot
.89683 .47992 Mdot
.89872 .48444 Mdot
.9006 .48919 Mdot
.90249 .49418 Mdot
.90438 .49944 Mdot
.90627 .505 Mdot
.90816 .51087 Mdot
.91005 .51708 Mdot
.91194 .52368 Mdot
.91383 .53068 Mdot
.91572 .53814 Mdot
.91761 .5461 Mdot
.9195 .5546 Mdot
.92139 .56372 Mdot
.92328 .57353 Mdot
.92517 .58409 Mdot
.92706 .59551 Mdot
.92895 .60789 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000
003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool00200oooo00<000000?oo
o`3oool0403oool300000?l0ooooN`3oool00200oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`3o0?ooogX0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<0
00000?ooo`3oool0o`3ooon>0?ooo`00803oool200000180oooo00<000000?ooo`3oool0o`3ooomj
0?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`<00000o`3ooomk0?ooo`00803oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool00200oooo00<000000?ooo`3oool0
o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooN@3o
ool00200oooo00<000000?ooo`3oool04@3oool300000?l0ooooNP3oool00200oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3o0?ooogT0oooo000P0?ooo`030000003oool0oooo0?l0
ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool2000001@0oooo00<0
00000?ooo`3oool0o`3ooomh0?ooo`00803oool00`000000oooo0?ooo`0B0?ooo`<00000o`3ooomi
0?ooo`00803oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooN03oool00200
oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0?l0ooooM`3oool00200oooo00<000000?ooo`3oool04`3oool300000?l0ooooN03o
ool00200oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooogL0oooo000P0?oo
o`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`3o0?ooogL0oooo000P0?ooo`800000503oool300000?l0ooooN03oool00200oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooogL0oooo000P0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00803oool00`000000oooo0?ooo`0D0?oo
o`<00000o`3ooomg0?ooo`00803oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooMP3oool000T0oooo00<0oono07@000000000100000001@1d_ol0oooo0?ooo`3oool0okmd00<0
000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0
ooooM@3oool000X0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`020?ooo`0609a8
M02oool0oooo0?oo_`1d07@0_ooo1P3oool00`000000oooo0?ooo`0E0?ooo`<00000o`3ooomf0?oo
o`002`3oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3o
ool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooM@3oool000`0oooo
00<0omnL04P00018W=l0103oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooog@0oooo00000`3oool0W4P00000
0004000000030018W03oool0oooo00@0oooo00<0W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo00D0oooo0`00000F0?ooo`<00000o`3ooome0?ooo`003`3oool0
1P2LB7@0_ooo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool01@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooM03oool000X0oooo00<0gia807Boo`3oool00P3o
ool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00<0gia804RLg`3oool01@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooM03oool000X0oooo00L0okmd0000M02oool0
oooo0?noM00004P0W=oo00<0oooo00H0W4P007Boo`3oool0omnL04P0M02oool60?ooo`030000003o
ool0oooo01H0oooo0`00003o0?ooogD0oooo000;0?ooo`050?noM000000000000000B02Lgol0103o
ool01@3ookl0M0000000000004P0W=oo00L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`3o0?ooog@0oooo000P0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3o
oomc0?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`<00000o`3ooomd0?ooo`00803oool00`00
0000oooo0?ooo`0H0?ooo`800000o`3ooomd0?ooo`00803oool00`000000oooo0?ooo`0H0?ooo`<0
0000o`3ooomc0?ooo`00803oool2000001X0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00803o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooL@3oool00200oooo00<00000
0?ooo`3oool06@3oool300000?l0ooooLP3oool00200oooo00<000000?ooo`3oool06P3oool20000
0?l0ooooLP3oool00200oooo00<000000?ooo`3oool06P3oool300000?l0ooooL@3oool00200oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooog00oooo000P0?ooo`030000003o
ool0oooo01X0oooo0`00003o0?ooog40oooo000P0?ooo`030000003oool0oooo01/0oooo0P00003o
0?ooog40oooo000P0?ooo`030000003oool0oooo01/0oooo0`00003o0?ooog00oooo000P0?ooo`80
00007@3oool200000?l0ooooL03oool00200oooo00<000000?ooo`3oool0703oool300000?l0oooo
K`3oool00200oooo00<000000?ooo`3oool07@3oool200000?l0ooooK`3oool00200oooo00<00000
0?ooo`3oool07@3oool300000?l0ooooKP3oool00200oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3o0?ooofd0oooo000P0?ooo`030000003oool0oooo01d0oooo0`00003o0?ooofh0
oooo000P0?ooo`030000003oool0oooo01h0oooo0`00003o0?ooofd0oooo000P0?ooo`030000003o
ool0oooo01l0oooo0P00003o0?ooofd0oooo000P0?ooo`030000003oool0oooo01l0oooo0`00003o
0?ooof`0oooo000P0?ooo`8000008@3oool200000?l0ooooK03oool00200oooo00<000000?ooo`3o
ool0803oool300000?l0ooooJ`3oool00200oooo00<000000?ooo`3oool0803oool300000?l0oooo
J`3oool00200oooo00<000000?ooo`3oool08@3oool300000?l0ooooJP3oool00200oooo00<00000
0?ooo`3oool08P3oool200000?l0ooooJP3oool00200oooo00<000000?ooo`3oool08P3oool30000
0?l0ooooJ@3oool00200oooo00<000000?ooo`3oool08`3oool300000?l0ooooJ03oool00200oooo
00<000000?ooo`3oool0903oool300000?l0ooooI`3oool00200oooo00<000000?ooo`3oool0903o
ool300000?l0ooooI`3oool00200oooo0P00000V0?ooo`800000o`3ooomW0?ooo`00803oool00`00
0000oooo0?ooo`0U0?ooo`<00000o`3ooomV0?ooo`00803oool00`000000oooo0?ooo`0V0?ooo`<0
0000o`3ooomU0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`<00000o`3ooomT0?ooo`00803o
ool00`000000oooo0?ooo`0W0?ooo`<00000o`3ooomT0?ooo`00803oool00`000000oooo0?ooo`0X
0?ooo`<00000o`3ooomS0?ooo`002P3oool00`3o_g@000000000000300000005001d_`3oool0oooo
0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo0`00003o
0?ooof80oooo000=0?ooo`0309a8B02Lgol0oooo00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02o
ool60?ooo`030000003oool0oooo02X0oooo0`00003o0?ooof40oooo000=0?ooo`0309a8B02Lgol0
oooo00<0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`050?ooo`030000003oool0
oooo02X0oooo1000003o0?ooof00oooo000=0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`050?ooo`<00000:`3oool400000?l0ooooG`3oool00003
0?ooo`2LB000000000@0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`<0
0000o`3ooomN0?ooo`003@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`<00000o`3ooomM0?ooo`003@3o
ool00`2LB4P0W=oo0?ooo`030?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool01@3o
ool00`000000oooo0?ooo`0^0?ooo`@00000o`3ooomL0?ooo`002P3oool01@3OW4P000000018W02L
B4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool60?ooo`030000003oool0oooo02l0
oooo1000003o0?oooe/0oooo000<0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000
001809cOo`070?ooo`030000003oool0oooo0340oooo0`00003o0?oooeX0oooo000P0?ooo`030000
003oool0oooo0340oooo1@00003o0?oooeP0oooo000P0?ooo`030000003oool0oooo0380oooo1@00
003o0?oooeL0oooo000P0?ooo`030000003oool0oooo03@0oooo1000003o0?oooeH0oooo000P0?oo
o`800000=P3oool500000?l0ooooE03oool00200oooo00<000000?ooo`3oool0=P3oool500000?l0
ooooD`3oool00200oooo00<000000?ooo`3oool0>03oool500000?l0ooooD@3oool00200oooo00<0
00000?ooo`3oool0>@3oool500000?l0ooooD03oool00200oooo00<000000?ooo`3oool0>`3oool5
00000?l0ooooCP3oool00200oooo00<000000?ooo`3oool0?03oool500000?l0ooooC@3oool00200
oooo00<000000?ooo`3oool0?P3oool500000?l0ooooB`3oool00200oooo00<000000?ooo`3oool0
@03oool500000?l0ooooB@3oool00200oooo00<000000?ooo`3oool0@@3oool600000?l0ooooA`3o
ool00200oooo0P0000140?ooo`H00000o`3ooom50?ooo`00803oool00`000000oooo0?ooo`150?oo
o`H00000o`3ooom30?ooo`00803oool00`000000oooo0?ooo`170?ooo`L00000o`3ooom00?ooo`00
803oool00`000000oooo0?ooo`190?ooo`P00000o`3ooolm0?ooo`00803oool00`000000oooo0?oo
o`1;0?ooo`P00000o`3ooolk0?ooo`00803oool00`000000oooo0?ooo`1=0?ooo`T00000o`3ooolh
0?ooo`00803oool00`000000oooo0?ooo`1@0?ooo`P00000o`3ooolf0?ooo`00803oool00`000000
oooo0?ooo`1C0?ooo`T00000o`3ooolb0?ooo`00803oool00`000000oooo0?ooo`1F0?ooo`T00000
o`3oool_0?ooo`00803oool2000005T0oooo2P00003o0?ooob`0oooo000P0?ooo`030000003oool0
oooo03d0oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0
M;oo0?ooo`3oool00P3oool01@3o_g@00000000000000000M;oo00L0oooo2P00000S0?ooo`030?oo
_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo0080
oooo00D0okmd000000000000000007Boo`0f0?ooo`050;md00000000000000000018W=l0103oool0
1@3o_g@00000000000000000M;oo00@0oooo00D0okmd000000000000000007Boo`0g0?ooo`050?oO
W018000000000000001d_ol00`3oool01@3o_g@00000000000000000M;oo00@0oooo00D0okmd0000
00000000000007Boo`0g0?ooo`050;md0000000000000000001d_ol0103oool01@3o_g@000000000
00000000M;oo00@0oooo00D0okmd000000000000000007Boo`030?ooo`00803oool00`000000oooo
0?ooo`100?ooo`0309a8B02Lgol0oooo00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool30?oo
o`0609a8M02oool0oooo0?oo_`1d07@0_ooo2@3oool;00000200oooo00<0_g@00000M02oool00P3o
ool00`3OW7@0W=oo0?ooo`020?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;oooc@0oooo00L0_g@0001d_`3oool0oooo0?oo_`1d0000B9cO00<0oooo
00H0W4Qd0;ooo`3oool0oono07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo>03o
ool00`2oM000M;oo0?ooo`030?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;ooocD0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00<0oooo
00H0W4Qd0;ooo`3oool0oono07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0P3o
ool00200oooo00<000000?ooo`3oool0@03oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0
oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo00/0oooo
3000000M0?ooo`030?noM00004P0W=oo00D0oooo00<0okmd001d_`3oool00P3oool01P3OW4P0B9cO
0?ooo`3oool0okmd001d_`<0oooo00<0gia804RLg`3oool0>03oool01P3o_g@007Bo0?ooo`3oool0
okmd001d_`<0oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo03L0
oooo00<0_g@007Boo`3oool00P3oool00`3o_g@007Bo0?ooo`020?ooo`060=nLB018W=l0oooo0?oo
o`3o_g@007Bo0`3oool00`3OW4P0B9cO0?ooo`0i0?ooo`060?noM000M;l0oooo0?ooo`3o_g@007Bo
0`3oool01P3OW4P0B9cO0?ooo`3oool0okmd001d_`<0oooo00<0gia804RLg`3oool00@3oool00200
oooo00<000000?ooo`3oool0@03oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080
oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo00l0oooo3@00000I
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3o
ool0gia804RLg`<0oooo00<0okmd001d_`3oool0=`3oool00`3ogi`0B01809cOo`020?ooo`030=nL
B018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo
03<0oooo00<0gia80000000000000`0000001@1d_ol0oooo0?ooo`3OW4P0B9cO00<0oooo00H0okmd
001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo03T0oooo00H0okmd001d_`3oool0
oooo0=nLB018W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?oo
o`010?ooo`00803oool00`000000oooo0?ooo`100?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia8
04RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0
4`3oool=000001L0oooo00<0W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?no
M000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`0e0?ooo`040=nLB00000000018
09cOo`<0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo
00<0okmd001d_`3oool0<`3oool01P3o_g@0001d0;ooo`3oool0_g@007Boo`<0oooo00<0gia804RL
g`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0>@3o
ool01P2LB000M;oo0?ooo`3oool0gia804RLg`<0oooo00H0okmd001d_`3oool0oooo0=nLB018W=l3
0?ooo`030?noM000M;l0oooo0040oooo000P0?ooo`030000003oool0oooo0400oooo00<0W4Q809cO
o`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`0G0?ooo`h000004`3oool01P2LB7@0_ooo0?ooo`3oool0gia804RLg`<0
oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo03L0oooo00<0omnL
04P0B02Lgol00P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO
0`3oool00`3o_g@007Bo0?ooo`0d0?ooo`050=nLB000M;l0oooo0;md001d_ol00`3oool00`3OW4P0
B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`0d
0?ooo`030?oo_`1d000000000080000000H0B9cO0?ooo`3oool0oooo0=nLB018W=l30?ooo`060?no
M000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`010?ooo`00803oool00`000000
oooo0?ooo`100?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool01P3OW4P0
B9cO0?ooo`3oool0okmd04RLg`<0oooo00<0gia804RLg`3oool06`3oool?000000T0oooo00<0gia8
07Boo`3oool00P3oool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00H0gia804RLg`3oool0
oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo03P0oooo00H0_g@007Boo`3oool0oooo0?noM018
W=l30?ooo`060=nLB018W=l0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0B9cO0?ooo`0e0?ooo`04
09a80018W=l0_g@007Boo`<0oooo00<0okmd04RLg`3oool00P3oool01P3OW4P0B9cO0?ooo`3oool0
okmd04RLg`<0oooo00<0gia804RLg`3oool0=03oool00`3ookl0M01d0;ooo`060?ooo`030?noM018
W=l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo0040
oooo000P0?ooo`030000003oool0oooo03d0oooo00D0gia800000000B9`0W4Q809cOo`050?ooo`06
09a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooob40oooo
3`0000040?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo
0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;oooc@0oooo00L0okmd0000B02L
gol0oooo0?oOW01804P0W=oo00<0oooo00H0W4P007Boo`3oool0omnL04P0M02oool30?ooo`0609a8
001d_ol0oooo0?oOW01807@0_ooo=P3oool0103ogi`0B01804Q8001d_ol40?ooo`0609a8001d_ol0
oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooocD0oooo00<0oono07@0
M02oool01`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`<0oooo00H0W4P007Boo`3oool0omnL
04P0M02oool20?ooo`00803oool200000400oooo00<0gia80000B02Lgol01@3oool01@3ookl0M000
0000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0W0?ooo`l0000000D0okmd0000
00000000001809cOo`040?ooo`050?oo_`1d000000000000B02Lgol0103oool01@3ookl0M0000000
000004P0W=oo03H0oooo00D0omnL04P000000000000007Boo`040?ooo`050?oo_`1d000000000000
B02Lgol0103oool01@3ookl0M0000000000004P0W=oo03P0oooo00<0okmd0000001d_ol0103oool0
1@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0f0?ooo`030?oo
_`1d000000000080000000<0001d0;ooo`3oool00P3oool01@3ookl0M0000000000004P0W=oo00@0
oooo00D0oono07@000000000001809cOo`030?ooo`00803oool00`000000oooo0?ooo`210?oooa00
0000o03oool00200oooo00<000000?ooo`3oool0QP3ooolB00000?D0oooo000P0?ooo`030000003o
ool0oooo08/0oooo4`00003_0?ooo`00803oool00`000000oooo0?ooo`2A0?oooa<00000j@3oool0
0200oooo00<000000?ooo`3oool0U`3ooolC00000><0oooo000P0?ooo`030000003oool0oooo09h0
oooo4`00003L0?ooo`00803oool00`000000oooo0?ooo`2T0?oooa@00000e@3oool00200oooo00<0
00000?ooo`3oool0ZP3ooolD00000<l0oooo000P0?ooo`030000003oool0oooo0;40oooo50000038
0?ooo`005P3ooooo000009X000000@3oool00200oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3ooolE00000003
0?ooo`000000oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`00
803oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
:`3ooolD000000/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo00`0oooo000P0?ooo`030000003oool0oooo0<`0oooo4`00002^0?ooo`00803oool0
0`000000oooo0?ooo`3C0?oooa800000Z03oool00200oooo00<000000?ooo`3oool0f@3ooolC0000
0:40oooo000P0?ooo`030000003oool0oooo0=l0oooo4`00002K0?ooo`00803oool00`000000oooo
0?ooo`3U0?oooa800000UP3oool00200oooo00<000000?ooo`3oool0j`3ooolB00000900oooo000P
0?ooo`800000l`3oool@000008/0oooo000P0?ooo`030000003oool0oooo0?L0oooo400000260?oo
o`00803oool00`000000oooo0?ooo`3l0?ooo`l00000PP3oool00200oooo00<000000?ooo`3oool0
o`3oool30?ooo`h00000O@3oool00200oooo00<000000?ooo`3oool0o`3oool70?ooo`h00000N@3o
ool00200oooo00<000000?ooo`3oool0o`3oool<0?ooo`d00000M@3oool00200oooo00<000000?oo
o`3oool0o`3ooolA0?ooo`/00000LP3oool00200oooo00<000000?ooo`3oool0o`3ooolE0?ooo`/0
0000KP3oool00200oooo00<000000?ooo`3oool0o`3ooolH0?ooo`/00000J`3oool00200oooo0P00
003o0?oooad0oooo2P00001X0?ooo`00803oool00`000000oooo0?ooo`3o0?ooob00oooo2P00001T
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooob<0oooo2P00001Q0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooobH0oooo2@00001O0?ooo`00803oool00`000000oooo0?ooo`3o0?ooobT0oooo
2000001M0?ooo`00803oool00`000000oooo0?ooo`3o0?ooob`0oooo2000001J0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooobl0oooo2000001G0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
oc40oooo1`00001F0?ooo`00803oool00`000000oooo0?ooo`3o0?oooc@0oooo1`00001C0?ooo`00
803oool200000?l0oooo=`3oool700000540oooo000P0?ooo`030000003oool0oooo0?l0oooo>03o
ool600000500oooo000P0?ooo`030000003oool0oooo0?l0oooo>P3oool6000004h0oooo000P0?oo
o`030000003oool0oooo0?l0oooo?@3oool5000004`0oooo000P0?ooo`030000003oool0oooo0?l0
oooo?P3oool6000004X0oooo000P0?ooo`030000003oool0oooo0?l0oooo@03oool5000004T0oooo
000P0?ooo`030000003oool0oooo0?l0oooo@P3oool5000004L0oooo000P0?ooo`030000003oool0
oooo0?l0ooooA03oool4000004H0oooo000P0?ooo`030000003oool0oooo0?l0ooooA@3oool40000
04D0oooo000P0?ooo`800000o`3ooom70?ooo`D00000@`3oool00200oooo00<000000?ooo`3oool0
o`3ooom70?ooo`D00000@P3oool00200oooo00<000000?ooo`3oool0o`3ooom90?ooo`@00000@@3o
ool00200oooo00<000000?ooo`3oool0o`3ooom:0?ooo`@00000@03oool00200oooo00<000000?oo
o`3oool0o`3ooom;0?ooo`@00000?`3oool000X0oooo00<0okmd0000000000000`0000001@00M;l0
oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oo
odd0oooo0`00000n0?ooo`003@3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo
_`1d07@0_ooo1P3oool00`000000oooo0?ooo`3o0?ooodh0oooo1000000l0?ooo`003@3oool00`2L
B4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooodl0oooo1000000k0?ooo`003@3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`3o0?oooe00
oooo0`00000k0?ooo`003@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool01@3oool300000?l0ooooD@3oool3000003X0oooo000=0?ooo`0309a8B02L
gol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`050?ooo`030000003o
ool0oooo0?l0ooooDP3oool3000003T0oooo000=0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd
04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`050?ooo`030000003oool0oooo0?l0ooooD`3oool3
000003P0oooo000:0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3o
gi`0B01d0;ooo`H0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`<00000>03oool000`0oooo00<0
gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo00L0oooo00<000000?ooo`3oool0
o`3ooomD0?ooo`<00000=`3oool00200oooo00<000000?ooo`3oool0o`3ooomE0?ooo`<00000=P3o
ool00200oooo00<000000?ooo`3oool0o`3ooomF0?ooo`<00000=@3oool00200oooo00<000000?oo
o`3oool0o`3ooomG0?ooo`<00000=03oool00200oooo00<000000?ooo`3oool0o`3ooomG0?ooo`<0
0000=03oool00200oooo0P00003o0?oooeT0oooo0`00000c0?ooo`00803oool00`000000oooo0?oo
o`3o0?oooeT0oooo0`00000b0?ooo`00803oool00`000000oooo0?ooo`3o0?oooeX0oooo0`00000a
0?ooo`00803oool00`000000oooo0?ooo`3o0?oooeX0oooo0`00000a0?ooo`00803oool00`000000
oooo0?ooo`3o0?oooe/0oooo0P00000a0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe/0oooo
0`00000`0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe`0oooo0`00000_0?ooo`00803oool0
0`000000oooo0?ooo`3o0?oooed0oooo0`00000^0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
oeh0oooo0P00000^0?ooo`00803oool200000?l0ooooG`3oool3000002d0oooo000P0?ooo`030000
003oool0oooo0?l0ooooGP3oool3000002d0oooo000P0?ooo`030000003oool0oooo0?l0ooooG`3o
ool2000002d0oooo000P0?ooo`030000003oool0oooo0?l0ooooG`3oool3000002`0oooo000P0?oo
o`030000003oool0oooo0?l0ooooH03oool2000002`0oooo000P0?ooo`030000003oool0oooo0?l0
ooooH03oool3000002/0oooo000P0?ooo`030000003oool0oooo0?l0ooooH@3oool3000002X0oooo
000P0?ooo`030000003oool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`0Y0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooof40oooo0`00000Z0?ooo`00803oool200000?l0ooooH`3oool20000
02X0oooo000P0?ooo`030000003oool0oooo0?l0ooooHP3oool3000002T0oooo000P0?ooo`030000
003oool0oooo0?l0ooooH`3oool2000002T0oooo000P0?ooo`030000003oool0oooo0?l0ooooH`3o
ool3000002P0oooo000P0?ooo`030000003oool0oooo0?l0ooooI03oool2000002P0oooo000P0?oo
o`030000003oool0oooo0?l0ooooI03oool3000002L0oooo000P0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0V0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofD0oooo
00<000000?ooo`3oool09P3oool00200oooo00<000000?ooo`3oool0o`3ooomT0?ooo`<000009`3o
ool00200oooo0P00003o0?ooofH0oooo0P00000W0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
ofD0oooo0`00000V0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofH0oooo00<000000?ooo`3o
ool09@3oool00200oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02@0oooo
000P0?ooo`030000003oool0oooo0?l0ooooIP3oool3000002D0oooo000P0?ooo`030000003oool0
oooo0?l0ooooI`3oool2000002D0oooo00090?ooo`030?oo_`1d0000000000@0000000D0M;oo0?oo
o`3oool0oooo0?noM0030000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`<00000903oool000X0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`020?oo
o`0609a8M02oool0oooo0?oo_`1d07@0_ooo1P3oool00`000000oooo0?ooo`3o0?ooofP0oooo00<0
00000?ooo`3oool08`3oool000/0oooo00<0okmd0000B02Lgol01@3oool00`3o_g@007Bo0?ooo`02
0?ooo`030=nLB018W=l0oooo00D0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`030000003oool0
oooo0280oooo000<0?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`050?ooo`<00000o`3ooomX0?ooo`<000008`3oool000h0oooo00<0W4P004RLg`3o
ool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooomY0?ooo`030000003oool0oooo0280oooo000?0?ooo`0609a8M02oool0oooo0?ooo`3O
W4P0B9cO0`3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0oooo0?l0ooooJ@3oool00`00
0000oooo0?ooo`0R0?ooo`002P3oool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?oo
o`3o_g@0B9cO0`3oool00`3OW4P0B9cO0?ooo`050?ooo`030000003oool0oooo0?l0ooooJ03oool3
000002<0oooo000:0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d
_ol0oooo0?oOW01807@0_ooo1P3oool00`000000oooo0?ooo`3o0?ooofT0oooo00<000000?ooo`3o
ool08P3oool000/0oooo00D0okmd000000000000001809cOo`040?ooo`050?oo_`1d000000000000
B02Lgol01`3oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool08@3oool00200
oooo00<000000?ooo`3oool0o`3ooomY0?ooo`<000008P3oool00200oooo00<000000?ooo`3oool0
o`3ooomZ0?ooo`030000003oool0oooo0240oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3o
ool00200oooo0P00003o0?ooof`0oooo00<000000?ooo`3oool0803oool00200oooo00<000000?oo
o`3oool0o`3ooomZ0?ooo`<000008@3oool00200oooo00<000000?ooo`3oool0o`3ooom[0?ooo`03
0000003oool0oooo0200oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<0
00000?ooo`3oool0o`3ooom/0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0
oooo0?l0ooooJ`3oool300000200oooo000P0?ooo`030000003oool0oooo0?l0ooooK03oool00`00
0000oooo0?ooo`0O0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000
003oool0oooo0?l0ooooK03oool00`000000oooo0?ooo`0O0?ooo`00803oool200000?l0ooooK03o
ool300000200oooo000P0?ooo`030000003oool0oooo0?l0ooooK03oool00`000000oooo0?ooo`0O
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0
ooooK@3oool00`000000oooo0?ooo`0N0?ooo`00803oool00`000000oooo0?ooo`3o0?ooof`0oooo
0`00000O0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool07P3o
ool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
ohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0M0?ooo`00
803oool200000?l0ooooKP3oool3000001h0oooo000P0?ooo`030000003oool0oooo0?l0ooooKP3o
ool00`000000oooo0?ooo`0M0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?oo
o`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooom_0?ooo`03
0000003oool0oooo01`0oooo000P0?ooo`030000003oool0oooo0?l0ooooKP3oool3000001d0oooo
000P0?ooo`030000003oool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`0L0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200
oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-41.6461, -29.3254, 1.94604, \
0.330891}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[xq]\)], "Input"],

Cell[BoxData[
    \(504\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(as = Union[Table[i, {i, 0.3, 2. , 0.1}], {1.95}]\)], "Input"],

Cell[BoxData[
    \({0.3`, 0.4`, 0.5`, 0.6`, 0.7`, 0.8`, 0.9`, 1.`, 1.1`, 1.2`, 1.3`, 
      1.4000000000000001`, 1.5`, 1.6`, 1.7000000000000002`, 1.8`, 
      1.9000000000000001`, 1.95`, 2.`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bs = Union[Table[i, {i, 0, 1, 0.1}], {0.99}]\)], "Input"],

Cell[BoxData[
    \({0, 0.1`, 0.2`, 0.30000000000000004`, 0.4`, 0.5`, 0.6000000000000001`, 
      0.7000000000000001`, 0.8`, 0.9`, 0.99`, 1.`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[NIntegrate, GaussPoints \[Rule] 15, 
      SingularityDepth \[Rule] 10]\)], "Input"],

Cell[BoxData[
    \({AccuracyGoal \[Rule] \[Infinity], Compiled \[Rule] True, 
      EvaluationMonitor \[Rule] None, GaussPoints \[Rule] 15, 
      MaxPoints \[Rule] Automatic, MaxRecursion \[Rule] 6, 
      Method \[Rule] Automatic, MinRecursion \[Rule] 0, 
      PrecisionGoal \[Rule] Automatic, SingularityDepth \[Rule] 10, 
      WorkingPrecision \[Rule] MachinePrecision}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(OffNIntMsg;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[
      pf0]; \(pf0\  = \ 
          Table[{N[xq[\([i]\)]], as[\([a]\)], bs[\([b]\)], 
              N[Re[SPDF[xq[\([i]\)], {as[\([a]\)], bs[\([b]\)]}, 0]]]}, {b, 
              Length[bs]}, {a, Length[as]}, {i, Length[xq]}];\) // 
      AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({355.`10.001773346551067\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
The above timing was done on a Dell 5150 with a Pentium 4 3.06GHz HT \
processor.  The laptop computer air intake was over a cooler containing ice \
packs and the fan set to high to prevent thermal shut down.  Desktop \
computers hopefully won't have this problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[pf0]\)], "Input"],

Cell[BoxData[
    \({12, 19, 504, 4}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ft = Flatten[pf0, 2];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PackedArrayQ[ft]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ft1 = \ 
        Map[# < $MinMachineNumber &, \(Transpose[
              ft]\)[\([4]\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(pos = Position[ft1, True];\)\)], "Input"],

Cell[BoxData[
    \(\(ft2 = 
        ReplacePart[\(Transpose[ft]\)[\([4]\)], $MinMachineNumber, 
          pos];\)\)], "Input"],

Cell[BoxData[
    \(\(ft3 = 
        N[Transpose[{\(Transpose[ft]\)[\([1]\)], \(Transpose[
                  ft]\)[\([2]\)], \(Transpose[ft]\)[\([3]\)], 
              ft2}]];\)\)], "Input"],

Cell[BoxData[
    \(\(p0list = ToPackedArray[ft3, Real];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PackedArrayQ[p0list]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[p0list]\)], "Input"],

Cell[BoxData[
    \({114912, 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ByteCount[p0list]\)], "Input"],

Cell[BoxData[
    \(3677244\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Check this directory location for your \
system!!!!!!!!!",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export[
      ToFileName[$TopDirectory, "\<\\AddOns\\Applications\\StableDistribution\
\\p0list\>"], p0list, "\<Dump\>"]\)], "Input"],

Cell[BoxData[
    \("C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.0\\AddOns\\Applications\\StableDistribution\\p0list"\
\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Clear[p0list];\)\)], "Input"],

Cell["\<\
The next part will set up the interface needed for the interpolation \
routines.\
\>", "Text"],

Cell[BoxData[
    \(\(SMLFit::usage = "\<SMLFit[data, iparam] fits data to a S(\[Alpha], \
\[Beta], \[Gamma], \[Delta];0) distribution using the maximum likelihood \
method.  iparam may be ommitted with a default value of 1.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(p0list = 
        Import["\<StableDistribution\\p0list\>", "\<Dump\>"];\)\)], "Input"],

Cell[BoxData[{
    \(\(s0pdf = 
        Interpolation[p0list, InterpolationOrder \[Rule] 1];\)\), "\n", 
    \(\(Clear[p0list];\)\)}], "Input"],

Cell[BoxData[
    \(\(sLogLikelihood[
          sample_, {\[Alpha]_, \[Beta]_:  0, \[Gamma]_:  1, \[Delta]_:  0}] := 
        Plus @@ Log[
            Abs[s0pdf[
                  If[\[Beta] < 0, \(-1\), 
                      1] \((sample - \[Delta])\)/\[Gamma], \[Alpha], 
                  Abs[\[Beta]]]/\[Gamma]]];\)\)], "Input"],

Cell[BoxData[
    \(\(\[Delta]1 = 
        Function[{\[Alpha], \[Beta], \[Gamma], \[Delta]}, 
          If[\[Alpha] \[Equal] 1, \[Delta] - 
              2*\[Beta]*\[Gamma]*\((Log[\[Gamma]]/
                    Pi)\), \[Delta] - \[Beta]*\[Gamma]*
                Tan[Pi*\((\[Alpha]/2)\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(SMLFit[s_, SType_Integer:  1] := 
        Module[{w, za0, zb0, a0, b0, c0, d0, za, zb}, {a0, b0, c0, d0} = 
            SQFit[s]; \[IndentingNewLine]\[IndentingNewLine]za0 = 
            N[Sqrt[Log[
                  2/a0]]]; \
\[IndentingNewLine]\[IndentingNewLine]maxlike[\((a_)\)?NumericQ, \((b_)\)?
                NumericQ, \((c_)\)?NumericQ, \((d_)\)?NumericQ] := 
            sLogLikelihood[s, {a, b, c, d}]; \[IndentingNewLine]w = 
            FindMaximum[a = 2\ Exp[\(-za^2\)]; 
              maxlike[a, b, c, d], {za, za0, \(-20\), 20}, {b, b0, \(-1\), 
                1}, {c, c0, \(-Infinity\), Infinity}, {d, d0, \(-Infinity\), 
                Infinity}]; \[IndentingNewLine]{2*Exp[\(-za^2\)], b, c, 
              If[SType \[Equal] 0, d, \[Delta]1[2*Exp[\(-za^2\)], b, c, d]]} /. 
            w[\([2]\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(sSPDF0::usage = "\<sSPDF0[x, {\[Alpha], \[Beta], \[Gamma], \
\[Delta]}] calculates density of a stable S(\[Alpha], \[Beta], \[Gamma], \
\[Delta]; 0) distribution at the value in x.  \[Beta], \[Gamma] and \[Delta] \
may be omitted with default values of {0, 1, 0}.  The calculation is made by \
interpolating a table of stored values\>";\)\(\n\)
    \)\)], "Input"],

Cell[BoxData[
    \(\(sSPDF0[
          x_, {\[Alpha]_, \[Beta]_:  0, \[Gamma]_:  1, \[Delta]_:  0}] := \ 
        s0pdf[If[\[Beta] < 0, \(-1\), 
                1] \((x - \[Delta])\)/\[Gamma], \[Alpha], 
            Abs[\[Beta]]]/\[Gamma];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Test\ it*) \)\(\[IndentingNewLine]\)\(Plot[
        sSPDF0[x, {0.7, \(-0.3\)}], {x, \(-10\), 10}];\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.0147151 1.50467 [
[.02381 .00222 -9 -9 ]
[.02381 .00222 9 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.4875 .16518 -18 -4.5 ]
[.4875 .16518 0 4.5 ]
[.4875 .31565 -18 -4.5 ]
[.4875 .31565 0 4.5 ]
[.4875 .46612 -18 -4.5 ]
[.4875 .46612 0 4.5 ]
[.4875 .61658 -18 -4.5 ]
[.4875 .61658 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-10)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .16518 m
.50625 .16518 L
s
[(0.1)] .4875 .16518 1 0 Mshowa
.5 .31565 m
.50625 .31565 L
s
[(0.2)] .4875 .31565 1 0 Mshowa
.5 .46612 m
.50625 .46612 L
s
[(0.3)] .4875 .46612 1 0 Mshowa
.5 .61658 m
.50625 .61658 L
s
[(0.4)] .4875 .61658 1 0 Mshowa
.125 Mabswid
.5 .04481 m
.50375 .04481 L
s
.5 .0749 m
.50375 .0749 L
s
.5 .105 m
.50375 .105 L
s
.5 .13509 m
.50375 .13509 L
s
.5 .19528 m
.50375 .19528 L
s
.5 .22537 m
.50375 .22537 L
s
.5 .25546 m
.50375 .25546 L
s
.5 .28556 m
.50375 .28556 L
s
.5 .34574 m
.50375 .34574 L
s
.5 .37584 m
.50375 .37584 L
s
.5 .40593 m
.50375 .40593 L
s
.5 .43602 m
.50375 .43602 L
s
.5 .49621 m
.50375 .49621 L
s
.5 .5263 m
.50375 .5263 L
s
.5 .5564 m
.50375 .5564 L
s
.5 .58649 m
.50375 .58649 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02383 m
.06244 .02514 L
.10458 .02694 L
.14415 .02912 L
.18221 .03187 L
.22272 .03583 L
.26171 .04119 L
.28302 .04509 L
.30316 .04968 L
.32313 .05541 L
.34157 .06213 L
.36029 .07091 L
.38092 .08392 L
.40033 .10101 L
.41123 .11366 L
.42121 .12794 L
.4304 .1441 L
.44019 .16552 L
.45094 .19583 L
.46092 .23282 L
.4712 .28356 L
.48233 .3585 L
.49283 .453 L
.5025 .55181 L
.50491 .57336 L
.5072 .58987 L
.50846 .59664 L
.50917 .59964 L
.50983 .60158 L
.511 .60332 L
.51223 .60242 L
.51331 .599 L
.51446 .59246 L
.51555 .58345 L
.51655 .57281 L
.51888 .53974 L
.52132 .4956 L
.52646 .39719 L
.53131 .32083 L
.53691 .25658 L
.54199 .21459 L
.54691 .18396 L
.55146 .16193 L
.55635 .14298 L
.56173 .12636 L
.57065 .10554 L
.58009 .08966 L
.59026 .07709 L
.59954 .06836 L
.61026 .06052 L
Mistroke
.62043 .05468 L
.64028 .04625 L
.65868 .04074 L
.67924 .03623 L
.69786 .03315 L
.71715 .03064 L
.73798 .0285 L
.75757 .02688 L
.77904 .02543 L
.81858 .0234 L
.85905 .02189 L
.89801 .02081 L
.93943 .01991 L
.97619 .01928 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`005`3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`3o_g@00`000000
0`1d_ol0oooo0?ooo`1D0?ooo`050;md0000000000000000001d_ol0]@3oool01@2oM00000000000
00000000M;oo05@0oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0
000000<0M;oo0?ooo`3oool0403oool001X0oooo00<0W4Q809cOo`3oool0103oool01P2LB7@0_ooo
0?ooo`3ookl0M01d0;oooe@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo0;<0oooo00L0
_g@0001d_`3oool0oooo0?oOW0180000M;oo05H0oooo00<0W4Q809cOo`3oool0103oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;oooa40oooo000J0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`1H0?ooo`030?noM000M;l0oooo0;L0oooo00<0okmd001d
_`3oool0E@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia804RL
g`3oool0403oool001X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo05P0oooo00<0okmd001d_`3oool0]`3oool00`3o_g@007Bo0?ooo`1E0?ooo`03
09a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0@0?ooo`00
3P3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cOo`3oool0
0`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04X0oooo00<0W4P0000000000000
0`0000000`00B9`0oooo0?ooo`050?ooo`0309a8001d_ol0oooo0;L0oooo00<0W4P007Boo`3oool0
E@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
403oool001X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo05<0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`2b0?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0E@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool0403oool001X0oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo05<0oooo00<0oono07@0M02oool0]`3oool0
0`3ookl0M01d0;ooo`1J0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0@0?ooo`005`3oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P0
07Boo`3oool0omnL04P0M02ooomD0?ooo`030?oo_`1d07@0_ooo0;L0oooo00<0oono07@0M02oool0
E`3oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02ooolA
0?ooo`006@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02Lgol0E@3oool0
0`3ookl0M00000000002000000030000M02oool0oooo0;80oooo00<0oono07@0000000000P000000
0`0007@0_ooo0?ooo`1D0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000001809cO
o`0B0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00
f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool0
0`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000
oooo0?ooo`3D0?ooo`004@3ooooo0000098000003P3oool001/0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00d0oooo5`00000H0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0V0?ooob0000005P3oool00`00
0000oooo0?ooo`0F0?ooo`006`3ooolH00000:H0oooo00<000000?ooo`3oool0J@3ooolL000004l0
oooo000c0?oooa000000UP3oool00`000000oooo0?ooo`1Q0?ooo`P00000J`3oool004<0oooo4000
00260?ooo`030000003oool0oooo0540oooo4000001c0?ooo`00D`3oool;000007/0oooo00<00000
0?ooo`3oool0B`3oool6000008<0oooo001N0?ooo`P00000L`3oool00`000000oooo0?ooo`170?oo
o`@00000R@3oool006H0oooo2000001[0?ooo`030000003oool0oooo04<0oooo1000002=0?ooo`00
KP3oool8000006<0oooo00<000000?ooo`3oool0?`3oool400000940oooo001f0?ooo`P00000F`3o
ool00`000000oooo0?ooo`0k0?ooo`@00000U@3oool007h0oooo1P00001E0?ooo`800000>03oool4
000009T0oooo00240?ooo`@00000D@3oool00`000000oooo0?ooo`0d0?ooo`<00000W@3oool008P0
oooo1000001=0?ooo`030000003oool0oooo0380oooo0P00002P0?ooo`00S03oool4000004T0oooo
00<000000?ooo`3oool0;`3oool300000:80oooo002@0?ooo`@00000A@3oool00`000000oooo0?oo
o`0]0?ooo`800000Y@3oool009@0oooo0P0000130?ooo`030000003oool0oooo02/0oooo0P00002W
0?ooo`00UP3oool300000400oooo00<000000?ooo`3oool0:@3oool200000:T0oooo002I0?ooo`80
0000?P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0:T0oooo002K0?ooo`800000
?03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0:X0oooo002M0?ooo`800000>P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:/0oooo002O0?ooo`800000>03oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0:`0oooo002Q0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2]0?ooo`00XP3oool2000003D0
oooo0P00000S0?ooo`800000/03oool00:@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0;00oooo002U0?ooo`800000<P3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0;40oooo002W0?ooo`800000<03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0;80oooo002Y0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`2b0?ooo`00ZP3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0/`3oool00:/0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;@0oooo002/0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2e0?ooo`00[@3oool2
000002X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2e0?ooo`00[`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0]P3oool00;00
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0;L0
oooo002a0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`2g0?ooo`00/P3oool00`000000oooo0?ooo`0T0?ooo`8000006P3oool00`000000oooo0?oo
o`2h0?ooo`00/`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0^03oool00;@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0;T0oooo002e0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`2i0?ooo`00]P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0^@3oool00;L0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0;X0oooo002g0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2j0?ooo`00^03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0^P3oool00;P0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0;/0
oooo002i0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`2k0?ooo`00^P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0^`3oool00;X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0;`0oooo002k0?ooo`030000003oool0oooo01/0oooo0P00000F0?oo
o`030000003oool0oooo0;`0oooo002k0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`2l0?ooo`00_03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0_@3oool00;`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0;d0oooo002m0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2m0?ooo`00_@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0_P3oool00;h0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;h0
oooo002n0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`2n0?ooo`00_`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0_P3oool00;/0oooo00<0okmd0000000000000P0000050?ooo`030;md00000000
07Bo00@0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0_`3oool00;/0oooo00H0W4Qd0;ooo`3oool0oono07@0M000
00040?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0;l0oooo002j0?ooo`030?noM000M;l0oooo0080oooo00<0gia8
0000003oool03@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0_`3oool00;X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0000000=0?oo
o`0309a8B02Lgol0oooo00L0oooo0`00000B0?ooo`030000003oool0oooo0;l0oooo002j0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`0000003@3oool00`2LB4P0W=oo0?ooo`070?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0_`3oool00;X0oooo00<0gia804RLg`3oool0
0P3oool0103o_g@007Bo0?ooo`00000<0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`300?ooo`00^P3oool00`3o_g@0B9cO0?ooo`020?ooo`040=nL
B018W=l0oooo000000`0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0<00oooo002k0?ooo`0809a8001d_ol0oooo0?oOW01807@0_ooo0?ooo`000009
0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0<00oooo002k0?ooo`050?oo_`1d000000000000B02Lgol00`3oool00`000000oooo0?oo
o`080?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`300?ooo`00``3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0`@3oool00<<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0<40oooo00330?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`310?ooo`00a03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0`@3oool00<@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0<40oooo00340?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`320?ooo`00a@3oool00`00
0000oooo0?ooo`0A0?ooo`800000403oool00`000000oooo0?ooo`320?ooo`00a@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0`P3oool00<D0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<80oooo
00360?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`320?ooo`00aP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0`P3oool00<H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0<<0oooo00360?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`330?ooo`00a`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0``3oool00<L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0<<0oooo00370?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`330?ooo`00b03oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0``3oool00<P0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0<<0
oooo00380?ooo`030000003oool0oooo00h0oooo0P00000?0?ooo`030000003oool0oooo0<<0oooo
00380?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0a03oool00<X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0<@0oooo003:0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`340?ooo`00bP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0a03oool00<X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0<D0
oooo003:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`350?ooo`00b`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0a@3oool00</0oooo00<000000?ooo`3oool02`3oool2000000d0oooo00<00000
0?ooo`3oool0a@3oool00</0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0<D0oooo003;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`350?ooo`00b`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0a@3oool00</0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0<D0oooo003<0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`350?ooo`00c03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0a@3oool00<`0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0<D0
oooo003<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`360?ooo`00c03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0aP3oool00<d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0<H0oooo003=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`360?ooo`00c@3oool00`000000oooo0?ooo`090?ooo`80
0000303oool00`000000oooo0?ooo`360?ooo`00c@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0aP3oool00<d0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0<H0oooo003=0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`360?ooo`00cP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0aP3oool00<h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0<H0
oooo003>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`360?ooo`00cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0aP3oool00<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0<H0oooo002k0?ooo`050?noM000000000000000001d_ol01@3oool0
0`2oM0000000001d_`030?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0103oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0<L0oooo002k0?ooo`0609a8M02oool0oooo
0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`070;md000007@0_ooo0000003oool0
giad09cOo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0a`3oool00;X0oooo
00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?noM00004P0000000T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`370?ooo`00^P3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL00000018W=l0203oool3000000X0oooo00<0
00000?ooo`3oool0a`3oool00;X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=
0?ooo`030000002LB000B9cO00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`37
0?ooo`00^P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00@000000?oo
o`2LB7@0_ooo1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0<L0oooo002j0?oo
o`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool01`3OW4P0M;oo0?ooo`000000
oooo0;md001d_ol01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0<L0oooo002k
0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool000000000
B02Lgol01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0<L0oooo002k0?ooo`05
0?oo_`1d000000000000B02Lgol03@3oool01@3o_g@00000000000000000W=oo00L0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`370?ooo`00d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0a`3oool00=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0<L0oooo003@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`370?ooo`00d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0a`3o
ool00=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0<L0oooo003A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`380?ooo`00d@3oool00`000000oooo0?ooo`050?ooo`8000002P3oool00`000000
oooo0?ooo`380?ooo`00d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0b03oool00=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0<P0oooo003A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`380?ooo`00dP3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0b03oool00=80oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<P0oooo003B0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`380?ooo`00dP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0b03o
ool00=80oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0<P0oooo003B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`380?ooo`00dP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0b03oool00=<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0<P0oooo003C0?ooo`030000003oool0oooo00<0oooo0P00
000:0?ooo`030000003oool0oooo0<P0oooo003C0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`380?ooo`00d`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0b@3oool00=<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<T0oooo003C0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`390?ooo`00d`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0b@3o
ool00=<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0<T0oooo003C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`390?ooo`00e03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0b@3oool00=@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0<T0oooo003D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`390?ooo`00e03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0b@3oool00=@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<T0oooo003D0?ooo`03
0000003oool0oooo0080oooo0P0000090?ooo`030000003oool0oooo0<T0oooo003D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`390?ooo`00e03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0b@3o
ool00=@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0<T0oooo003D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`390?ooo`00e@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0b@3oool00=D0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
0<X0oooo003E0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3:0?oo
o`00e@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0bP3oool00=D0
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0<X0oooo003E0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3:0?ooo`00e@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0bP3oool00=D0oooo00@000000?ooo`3o
ool0oooo0P0000080?ooo`030000003oool0oooo0<X0oooo003E0?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`3:0?ooo`00eP3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0<X0oooo003F0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0bP3oool00=H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3:0?oo
o`00eP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0<X0oooo003F0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0bP3oool00=H0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`3:0?ooo`00^`3oool01@3o_g@00000000000000000M;oo
00D0oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000B9cO00@0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`3:0?ooo`00^`3oool01P2LB7@0_ooo0?ooo`3o
okl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0oono07@0
0018W=l00`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0<X0oooo002j0?oo
o`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`020?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0bP3oool00;X0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`030?oOW01804P0W=oo00<0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`3:0?ooo`00^P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00`0oooo00@0gia80000000004P0W=oo1@3oool00`000000oooo00000002
000000L0oooo00<000000?ooo`3oool0bP3oool00;X0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`0>0?ooo`030?oOW01804P0W=oo00@0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`3:0?ooo`00^P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00l0
oooo00<0_g@007Boo`3oool00`3oool00`000000oooo000000080?ooo`030000003oool0oooo0</0
oooo002k0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001809cOo`3oool0
omnL04P0B02Lgol0103oool00`000000oooo000000080?ooo`030000003oool0oooo0</0oooo002k
0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3ogi`0B000000000000000M;oo00D0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`3;0?ooo`00e`3oool00`000000oooo0000
00080?ooo`030000003oool0oooo0</0oooo003G0?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool0b`3oool00=L0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`3;0?oo
o`00e`3oool00`000000oooo000000080?ooo`030000003oool0oooo0</0oooo003G0?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool0b`3oool00=P0oooo0P0000080?ooo`030000003o
ool0oooo0</0oooo003H0?ooo`800000203oool00`000000oooo0?ooo`3;0?ooo`00f03oool30000
00L0oooo00<000000?ooo`3oool0b`3oool00=P0oooo0P0000080?ooo`030000003oool0oooo0</0
oooo003H0?ooo`800000203oool00`000000oooo0?ooo`3;0?ooo`00f03oool2000000P0oooo00<0
00000?ooo`3oool0b`3oool00=P0oooo0P0000080?ooo`030000003oool0oooo0</0oooo003H0?oo
o`800000203oool00`000000oooo0?ooo`3;0?ooo`00f03oool2000000P0oooo00<000000?ooo`3o
ool0b`3oool00=P0oooo0P0000080?ooo`030000003oool0oooo0</0oooo003I0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0c03oool00=T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3<0?ooo`00f@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0<`0oooo003I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0c03oool00=T0oooo
0P0000060?ooo`030000003oool0oooo0<`0oooo003I0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0c03oool00=T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3<
0?ooo`00f@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<`0oooo003I0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0c03oool00=T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3<0?ooo`00f@3oool2000000H0oooo00<000000?ooo`3oool0c03o
ool00=T0oooo0P0000060?ooo`030000003oool0oooo0<`0oooo003I0?ooo`8000001P3oool00`00
0000oooo0?ooo`3<0?ooo`00f@3oool2000000H0oooo00<000000?ooo`3oool0c03oool00=T0oooo
0P0000060?ooo`030000003oool0oooo0<`0oooo003I0?ooo`8000001P3oool00`000000oooo0?oo
o`3<0?ooo`00f@3oool2000000D0oooo00<000000?ooo`3oool0c@3oool00=T0oooo0P0000050?oo
o`030000003oool0oooo0<d0oooo003I0?ooo`8000001@3oool00`000000oooo0?ooo`3=0?ooo`00
f@3oool00`000000oooo000000040?ooo`030000003oool0oooo0<d0oooo003I0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0c@3oool00=T0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`3=0?ooo`00f@3oool00`000000oooo000000040?ooo`030000003oool0oooo
0<d0oooo003I0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0c@3oool00=T0oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`3=0?ooo`00f@3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0<h0oooo003I0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0cP3oool00=T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3>0?ooo`00f@3oool2000000050?ooo`000000oooo0?ooo`000000d03oool00=T0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`3>0?ooo`00f@3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0<h0oooo003I0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0cP3oool00=T0oooo00H000000?ooo`3oool000000?ooo`00003A0?ooo`00f@3o
ool010000000oooo0?ooo`3oool200000=40oooo003I0?ooo`040000003oool0oooo0?ooo`800000
d@3oool00=T0oooo00<000000?ooo`3oool0e03oool00;/0oooo00D0okmd000000000000000007Bo
o`050?ooo`030;md0000000007Bo00H0oooo00D0omnL04P000000000000007Boo`060?ooo`030000
003oool0oooo0=@0oooo002k0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM000
0000001d_`080?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0e03oool00;X0oooo
00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030;md001d_ol0oooo00H0oooo
00<000000?ooo`3oool0e03oool00;X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0:0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool0103oool00`000000oooo0?oo
o`3D0?ooo`00^P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00H0okmd
0000M02oool0oooo0;md001d_ol70?ooo`<00000e03oool00;X0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0;0?ooo`050=nLB000M;l0oooo0;md001d_ol0gP3oool00;X0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0<0?ooo`0409a80018W=l0_g@007Boomh0oooo
002k0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo3@3oool0103ogi`0B01804Q8001d_ooN0?oo
o`00^`3oool01@3ookl0M0000000000004P0W=oo00l0oooo00<0okmd0000001d_ol0gP3oool00?l0
oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-11.4239, -0.0307475, \
0.0787889, 0.00249347}}]
}, Open  ]],

Cell[BoxData[
    \(\(s = \ SRandom[1000, {1.245, 0.7, 0.6, 0.1}, 1];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = \ SMLFit[s, 1];\) // AbsoluteTiming\), "\[IndentingNewLine]", 
    \(p\)}], "Input"],

Cell[BoxData[
    RowBox[{\(FindMaximum::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient increase in the function.  \
You may need more than \\!\\(MachinePrecision\\) digits of working precision \
to meet these tolerances. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindMaximum::lstol\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({7.015625`8.29761136051541\ Second, Null}\)], "Output"],

Cell[BoxData[
    \({1.3095797622815513`, 0.6320479726457146`, 
      0.572994710710666`, \(-0.19804774244861967`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = \ fMLFit[s, 1];\) // AbsoluteTiming\), "\[IndentingNewLine]", 
    \(p1\)}], "Input"],

Cell[BoxData[
    \({12.1875`8.537459622202567\ Second, Null}\)], "Output"],

Cell[BoxData[
    \({1.3039006327174774`, 0.6172186113536244`, 
      0.5701704310159119`, \(-0.20590699264152582`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages may be easily extended.  With this program is included a \
notebook, MySMath.nb; it includes the code above and creates automatically \
the file MySMath.m.  It loads first SMath.m so the entire program with the \
above routines can be loaded with <<StableDistribution`MySMath` once the \
p0list file has been created on your system.  You can write other routines to \
add to this package."
}], "Text"]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
CellGrouping->Manual,
WindowSize->{1233, 836},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 84, 2, 53, "Text"],
Cell[1841, 55, 617, 11, 177, "Text"],
Cell[2461, 68, 128, 5, 87, "Input"],

Cell[CellGroupData[{
Cell[2614, 77, 559, 9, 125, "Text"],

Cell[CellGroupData[{
Cell[3198, 90, 170, 3, 68, "Input"],
Cell[3371, 95, 294, 4, 49, "Output"],
Cell[3668, 101, 196, 3, 49, "Output"]
}, Open  ]],
Cell[3879, 107, 75, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[3979, 113, 149, 2, 68, "Input"],
Cell[4131, 117, 108, 2, 47, "Output"],
Cell[4242, 121, 108, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4387, 128, 151, 2, 68, "Input"],
Cell[4541, 132, 122, 2, 44, "Output"],
Cell[4666, 136, 122, 2, 44, "Output"]
}, Open  ]],
Cell[4803, 141, 249, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[5077, 149, 641, 12, 120, "Input"],
Cell[5721, 163, 186, 3, 51, "Output"],
Cell[5910, 168, 186, 3, 51, "Output"],
Cell[6099, 173, 257, 4, 51, "Output"],
Cell[6359, 179, 257, 4, 51, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6665, 189, 628, 14, 101, "Text"],

Cell[CellGroupData[{
Cell[7318, 207, 688, 15, 120, "Input"],
Cell[8009, 224, 32382, 643, 279, 3974, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[40394, 869, 32229, 641, 279, 3976, 288, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[72638, 1513, 343, 7, 73, "Text"],

Cell[CellGroupData[{
Cell[73006, 1524, 210, 5, 42, "Input"],
Cell[73219, 1531, 1593, 24, 412, "Output"]
}, Open  ]],
Cell[74827, 1558, 240, 6, 73, "Text"],
Cell[75070, 1566, 326, 5, 68, "Input"],
Cell[75399, 1573, 106, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[75530, 1580, 335, 6, 68, "Input"],
Cell[75868, 1588, 219, 3, 70, "Output"]
}, Open  ]],
Cell[76102, 1594, 25, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[76152, 1598, 563, 11, 94, "Input"],
Cell[76718, 1611, 191, 3, 70, "Output"]
}, Open  ]],
Cell[76924, 1617, 33, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[76982, 1621, 74, 1, 42, "Input"],
Cell[77059, 1624, 164, 2, 70, "Output"]
}, Open  ]],
Cell[77238, 1629, 59, 0, 47, "Text"],
Cell[77300, 1631, 1197, 17, 324, "Input"],
Cell[78500, 1650, 128, 3, 47, "Text"],
Cell[78631, 1655, 48, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[78704, 1660, 558, 9, 146, "Input"],
Cell[79265, 1671, 46522, 974, 279, 6998, 482, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[125836, 2651, 270, 6, 92, "Text"],

Cell[CellGroupData[{
Cell[126131, 2661, 202, 3, 94, "Input"],
Cell[126336, 2666, 685, 9, 151, "Output"],
Cell[127024, 2677, 549, 8, 151, "Output"],
Cell[127576, 2687, 297, 4, 94, "Output"]
}, Open  ]],
Cell[127888, 2694, 55, 1, 42, "Input"],
Cell[127946, 2697, 1303, 20, 409, "Input"],
Cell[129252, 2719, 63, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[129340, 2723, 464, 7, 120, "Input"],
Cell[129807, 2732, 31962, 737, 279, 6029, 412, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[161818, 3475, 692, 13, 148, "Text"],

Cell[CellGroupData[{
Cell[162535, 3492, 329, 7, 42, "Input"],
Cell[162867, 3501, 141, 2, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163045, 3508, 105, 2, 42, "Input"],
Cell[163153, 3512, 109, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163299, 3519, 50, 1, 42, "Input"],
Cell[163352, 3522, 131, 2, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163520, 3529, 61, 1, 42, "Input"],
Cell[163584, 3532, 38, 1, 41, "Output"]
}, Open  ]],
Cell[163637, 3536, 333, 9, 63, "Text"],

Cell[CellGroupData[{
Cell[163995, 3549, 55, 1, 42, "Input"],
Cell[164053, 3552, 252, 4, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164342, 3561, 106, 3, 94, "Input"],
Cell[164451, 3566, 260, 4, 43, "Output"],
Cell[164714, 3572, 207, 3, 43, "Output"],
Cell[164924, 3577, 312, 5, 41, "Output"]
}, Open  ]],
Cell[165251, 3585, 308, 9, 66, "Text"],

Cell[CellGroupData[{
Cell[165584, 3598, 126, 2, 42, "Input"],
Cell[165713, 3602, 355, 7, 41, "Output"]
}, Open  ]],
Cell[166083, 3612, 299, 8, 47, "Text"],

Cell[CellGroupData[{
Cell[166407, 3624, 203, 4, 42, "Input"],
Cell[166613, 3630, 368, 6, 53, "Message"],
Cell[166984, 3638, 195, 3, 65, "Output"]
}, Open  ]],
Cell[167194, 3644, 95, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[167314, 3650, 349, 6, 73, "Input"],
Cell[167666, 3658, 626, 9, 196, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168329, 3672, 56, 1, 42, "Input"],
Cell[168388, 3675, 420, 7, 130, "Output"]
}, Open  ]],
Cell[168823, 3685, 113, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[168961, 3692, 112, 2, 42, "Input"],
Cell[169076, 3696, 84, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169197, 3702, 217, 4, 73, "Input"],
Cell[169417, 3708, 196, 3, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169650, 3716, 222, 4, 73, "Input"],
Cell[169875, 3722, 704, 10, 194, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170616, 3737, 53, 1, 42, "Input"],
Cell[170672, 3740, 597, 9, 167, "Output"]
}, Open  ]],
Cell[171284, 3752, 54, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[171363, 3756, 85, 1, 42, "Input"],
Cell[171451, 3759, 735, 10, 201, "Output"]
}, Open  ]],
Cell[172201, 3772, 158, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[172384, 3779, 188, 4, 76, "Input"],
Cell[172575, 3785, 1171, 17, 621, "Output"]
}, Open  ]],
Cell[173761, 3805, 113, 3, 47, "Text"],
Cell[173877, 3810, 1330, 20, 700, "Input"],
Cell[175210, 3832, 265, 5, 73, "Text"],

Cell[CellGroupData[{
Cell[175500, 3841, 139, 2, 42, "Input"],
Cell[175642, 3845, 33556, 705, 279, 4914, 347, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[209213, 4553, 178, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[209416, 4560, 53, 1, 42, "Input"],
Cell[209472, 4563, 37, 1, 41, "Output"]
}, Open  ]],
Cell[209524, 4567, 87, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[209636, 4573, 418, 6, 111, "Input"],
Cell[210057, 4581, 269, 4, 32, "Message"],
Cell[210329, 4587, 225, 3, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210591, 4595, 79, 1, 42, "Input"],
Cell[210673, 4598, 52, 1, 41, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[210774, 4605, 510, 10, 118, "Text"],
Cell[211287, 4617, 408, 8, 94, "Input"],
Cell[211698, 4627, 429, 8, 94, "Input"],
Cell[212130, 4637, 849, 14, 224, "Input"],
Cell[212982, 4653, 547, 10, 146, "Input"],
Cell[213532, 4665, 182, 3, 94, "Input"],
Cell[213717, 4670, 52, 1, 42, "Input"],
Cell[213772, 4673, 280, 5, 120, "Input"],
Cell[214055, 4680, 267, 5, 120, "Input"],
Cell[214325, 4687, 171, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[214521, 4694, 302, 5, 94, "Input"],
Cell[214826, 4701, 40794, 862, 279, 6283, 431, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[255669, 5569, 291, 6, 92, "Text"],
Cell[255963, 5577, 1593, 32, 328, "Input"],

Cell[CellGroupData[{
Cell[257581, 5613, 68, 1, 42, "Input"],
Cell[257652, 5616, 502, 7, 66, "Output"]
}, Open  ]],
Cell[258169, 5626, 772, 16, 151, "Text"],

Cell[CellGroupData[{
Cell[258966, 5646, 227, 4, 120, "Input"],
Cell[259196, 5652, 282, 5, 41, "Output"],
Cell[259481, 5659, 283, 5, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259801, 5669, 40, 1, 42, "Input"],
Cell[259844, 5672, 314, 5, 69, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[260207, 5683, 255, 6, 92, "Text"],

Cell[CellGroupData[{
Cell[260487, 5693, 187, 3, 42, "Input"],
Cell[260677, 5698, 114, 2, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260828, 5705, 68, 1, 42, "Input"],
Cell[260899, 5708, 771, 11, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261707, 5724, 296, 6, 94, "Input"],
Cell[262006, 5732, 5726, 178, 459, "Output"]
}, Open  ]],
Cell[267747, 5913, 620, 9, 125, "Text"],
Cell[268370, 5924, 1595, 24, 523, "Input"],

Cell[CellGroupData[{
Cell[269990, 5952, 155, 3, 94, "Input"],
Cell[270148, 5957, 226, 3, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[270411, 5965, 155, 3, 94, "Input"],
Cell[270569, 5970, 115, 3, 70, "Output"]
}, Open  ]],
Cell[270699, 5976, 889, 17, 198, "Input"],
Cell[271591, 5995, 59, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[271675, 5999, 1457, 25, 484, "Input"],
Cell[273135, 6026, 84169, 1365, 490, 5229, 386, "GraphicsData", "PostScript", \
"Graphics"],
Cell[357307, 7393, 55536, 1019, 490, 5367, 395, "GraphicsData", "PostScript", \
"Graphics"],
Cell[412846, 8414, 99283, 1683, 490, 7658, 547, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[512178, 10103, 858, 16, 170, "Text"],
Cell[513039, 10121, 46, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[513110, 10126, 288, 7, 94, "Input"],
Cell[513401, 10135, 35642, 984, 279, 11695, 684, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[549080, 11124, 43, 1, 42, "Input"],
Cell[549126, 11127, 37, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[549200, 11133, 81, 1, 42, "Input"],
Cell[549284, 11136, 206, 3, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[549527, 11144, 77, 1, 42, "Input"],
Cell[549607, 11147, 156, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[549800, 11154, 115, 2, 42, "Input"],
Cell[549918, 11158, 390, 6, 91, "Output"]
}, Open  ]],
Cell[550323, 11167, 48, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[550396, 11172, 290, 6, 94, "Input"],
Cell[550689, 11180, 73, 1, 41, "Output"]
}, Open  ]],
Cell[550777, 11184, 288, 5, 73, "Text"],

Cell[CellGroupData[{
Cell[551090, 11193, 48, 1, 42, "Input"],
Cell[551141, 11196, 50, 1, 41, "Output"]
}, Open  ]],
Cell[551206, 11200, 58, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[551289, 11205, 49, 1, 42, "Input"],
Cell[551341, 11208, 39, 1, 41, "Output"]
}, Open  ]],
Cell[551395, 11212, 126, 3, 42, "Input"],
Cell[551524, 11217, 63, 1, 42, "Input"],
Cell[551590, 11220, 127, 3, 42, "Input"],
Cell[551720, 11225, 190, 4, 42, "Input"],
Cell[551913, 11231, 71, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[552009, 11236, 53, 1, 42, "Input"],
Cell[552065, 11239, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[552140, 11245, 51, 1, 42, "Input"],
Cell[552194, 11248, 45, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[552276, 11254, 50, 1, 42, "Input"],
Cell[552329, 11257, 41, 1, 41, "Output"]
}, Open  ]],
Cell[552385, 11261, 146, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[552556, 11268, 153, 3, 68, "Input"],
Cell[552712, 11273, 143, 3, 41, "Output"]
}, Open  ]],
Cell[552870, 11279, 51, 1, 42, "Input"],
Cell[552924, 11282, 104, 3, 47, "Text"],
Cell[553031, 11287, 243, 3, 94, "Input"],
Cell[553277, 11292, 108, 2, 42, "Input"],
Cell[553388, 11296, 143, 3, 68, "Input"],
Cell[553534, 11301, 333, 7, 68, "Input"],
Cell[553870, 11310, 305, 6, 42, "Input"],
Cell[554178, 11318, 857, 14, 276, "Input"],
Cell[555038, 11334, 388, 6, 146, "Input"],
Cell[555429, 11342, 255, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[555709, 11351, 142, 2, 68, "Input"],
Cell[555854, 11355, 28941, 577, 279, 3635, 260, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[584810, 11935, 84, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[584919, 11940, 111, 2, 68, "Input"],
Cell[585033, 11944, 520, 7, 95, "Message"],
Cell[585556, 11953, 75, 1, 41, "Output"],
Cell[585634, 11956, 130, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[585801, 11963, 113, 2, 68, "Input"],
Cell[585917, 11967, 75, 1, 41, "Output"],
Cell[585995, 11970, 131, 2, 41, "Output"]
}, Open  ]],
Cell[586141, 11975, 482, 9, 99, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

