(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    135129,       2893]*)
(*NotebookOutlinePosition[    136759,       2942]*)
(*  CellTagsIndexPosition[    136449,       2931]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["More Functions",
  FontSize->16,
  FontWeight->"Bold"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SLogLikelihood\)\)], "Input"],

Cell[BoxData[
    \("SLogLikelihood[x,{\[Alpha], \[Beta], \[Gamma], \[Delta]}, param] \
computes the loglikelihood of the data in x for a S(\[Alpha], \[Beta], \
\[Gamma], \[Delta];  param) stable distribution.  {\[Beta], \[Gamma], \
\[Delta]} may be omitted with default values of {0, 1, 0}.   param may be \
omitted with a default value of 1.  This function is slow; for faster \
execution but lower accuracy use fLogLikelihood."\)], "Print",
  CellTags->"Info3310572771-1617216"]
}, Open  ]],

Cell["\<\
This routine uses the SPDF function for the calculation, so a large list may \
take a long time.  Here the fits from the previous section are tested.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SLogLikelihood[data, p, 0] // AbsoluteTiming\), "\[IndentingNewLine]", 
    \(SLogLikelihood[data, p1, 0] // AbsoluteTiming\)}], "Input"],

Cell[BoxData[
    \({1.5`7.627636252551655\ Second, \(-1048.1852919368785`\)}\)], "Output"],

Cell[BoxData[
    \({1.40625`7.5996075289514105\ Second, \(-1048.1852917924573`\)}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?fLogLikelihood\)\)], "Input"],

Cell[BoxData[
    \("fLogLikelihood[x,{\[Alpha], \[Beta], \[Gamma], \[Delta]},iparam] \
computes the loglikelihood of the data in x for a S(\[Alpha], \[Beta], \
\[Gamma], \[Delta]; iparam) stable distribution.  {\[Beta], \[Gamma], \
\[Delta]} may be omitted with default values of {0, 1, 0}.   param may be \
omitted with a default value of 1.  This function is uses the FFT to \
calculate the PDF."\)], "Print",
  CellTags->"Info3310572774-9592314"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(fLogLikelihood[data, p, 0] // AbsoluteTiming\), "\[IndentingNewLine]", 
    \(fLogLikelihood[data, p1, 0] // AbsoluteTiming\)}], "Input"],

Cell[BoxData[
    \({0.078125`6.344335023848104\ Second, \(-1048.1839916100967`\)}\)], \
"Output"],

Cell[BoxData[
    \({0.078125`6.344335023848104\ Second, \(-1048.1839915926485`\)}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(?fSPDF0\)\), "\[IndentingNewLine]", 
    \(\(?fSPDF1\)\)}], "Input"],

Cell[BoxData[
    \("fSPDF0[\[Alpha], \[Beta]] puts out an interpolating function for \
approximating an S(\[Alpha], \[Beta], 1, 0; 0) density."\)], "Print",
  CellTags->"Info3310572775-6040401"],

Cell[BoxData[
    \("fSPDF1[\[Alpha], \[Beta]] puts out an interpolating function for \
approximating an S(\[Alpha], \[Beta], 1, 0; 1) density."\)], "Print",
  CellTags->"Info3310572775-9610662"]
}, Open  ]],

Cell["\<\
These are the density functions used for fLogLikelihood and fMLFit.  They \
also take two options xrange and twoexp that are explained in the fMLFit \
algorithm.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Options[fSPDF0]\), "\[IndentingNewLine]", 
    \(Options[fSPDF1]\)}], "Input"],

Cell[BoxData[
    \({xrange \[Rule] 1024, twoexp \[Rule] 13}\)], "Output"],

Cell[BoxData[
    \({xrange \[Rule] 1024, twoexp \[Rule] 13}\)], "Output"]
}, Open  ]],

Cell["\<\
The functions can be used arbitrarily close to \[Alpha] = 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f0 = \ fSPDF0[1.001, 0.3];\)\), "\[IndentingNewLine]", 
    \(\(f1 = \ fSPDF1[1.001, 0.3];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{f0[x], f1[x]}, {x, \(-200\), 20}, 
        PlotStyle \[Rule] {Hue[0.7], Hue[1]}, 
        PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.88961 0.004329 0.0147026 1.8762 [
[.02381 .0022 -12 -9 ]
[.02381 .0022 12 0 ]
[.24026 .0022 -12 -9 ]
[.24026 .0022 12 0 ]
[.45671 .0022 -12 -9 ]
[.45671 .0022 12 0 ]
[.67316 .0022 -9 -9 ]
[.67316 .0022 9 0 ]
[.87711 .10851 -24 -4.5 ]
[.87711 .10851 0 4.5 ]
[.87711 .20232 -18 -4.5 ]
[.87711 .20232 0 4.5 ]
[.87711 .29613 -24 -4.5 ]
[.87711 .29613 0 4.5 ]
[.87711 .38994 -18 -4.5 ]
[.87711 .38994 0 4.5 ]
[.87711 .48375 -24 -4.5 ]
[.87711 .48375 0 4.5 ]
[.87711 .57756 -18 -4.5 ]
[.87711 .57756 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .0147 m
.02381 .02095 L
s
[(-200)] .02381 .0022 0 1 Mshowa
.24026 .0147 m
.24026 .02095 L
s
[(-150)] .24026 .0022 0 1 Mshowa
.45671 .0147 m
.45671 .02095 L
s
[(-100)] .45671 .0022 0 1 Mshowa
.67316 .0147 m
.67316 .02095 L
s
[(-50)] .67316 .0022 0 1 Mshowa
.125 Mabswid
.0671 .0147 m
.0671 .01845 L
s
.11039 .0147 m
.11039 .01845 L
s
.15368 .0147 m
.15368 .01845 L
s
.19697 .0147 m
.19697 .01845 L
s
.28355 .0147 m
.28355 .01845 L
s
.32684 .0147 m
.32684 .01845 L
s
.37013 .0147 m
.37013 .01845 L
s
.41342 .0147 m
.41342 .01845 L
s
.5 .0147 m
.5 .01845 L
s
.54329 .0147 m
.54329 .01845 L
s
.58658 .0147 m
.58658 .01845 L
s
.62987 .0147 m
.62987 .01845 L
s
.71645 .0147 m
.71645 .01845 L
s
.75974 .0147 m
.75974 .01845 L
s
.80303 .0147 m
.80303 .01845 L
s
.84632 .0147 m
.84632 .01845 L
s
.9329 .0147 m
.9329 .01845 L
s
.97619 .0147 m
.97619 .01845 L
s
.25 Mabswid
0 .0147 m
1 .0147 L
s
.88961 .10851 m
.89586 .10851 L
s
[(0.05)] .87711 .10851 1 0 Mshowa
.88961 .20232 m
.89586 .20232 L
s
[(0.1)] .87711 .20232 1 0 Mshowa
.88961 .29613 m
.89586 .29613 L
s
[(0.15)] .87711 .29613 1 0 Mshowa
.88961 .38994 m
.89586 .38994 L
s
[(0.2)] .87711 .38994 1 0 Mshowa
.88961 .48375 m
.89586 .48375 L
s
[(0.25)] .87711 .48375 1 0 Mshowa
.88961 .57756 m
.89586 .57756 L
s
[(0.3)] .87711 .57756 1 0 Mshowa
.125 Mabswid
.88961 .03346 m
.89336 .03346 L
s
.88961 .05223 m
.89336 .05223 L
s
.88961 .07099 m
.89336 .07099 L
s
.88961 .08975 m
.89336 .08975 L
s
.88961 .12727 m
.89336 .12727 L
s
.88961 .14604 m
.89336 .14604 L
s
.88961 .1648 m
.89336 .1648 L
s
.88961 .18356 m
.89336 .18356 L
s
.88961 .22108 m
.89336 .22108 L
s
.88961 .23985 m
.89336 .23985 L
s
.88961 .25861 m
.89336 .25861 L
s
.88961 .27737 m
.89336 .27737 L
s
.88961 .31489 m
.89336 .31489 L
s
.88961 .33366 m
.89336 .33366 L
s
.88961 .35242 m
.89336 .35242 L
s
.88961 .37118 m
.89336 .37118 L
s
.88961 .40871 m
.89336 .40871 L
s
.88961 .42747 m
.89336 .42747 L
s
.88961 .44623 m
.89336 .44623 L
s
.88961 .46499 m
.89336 .46499 L
s
.88961 .50252 m
.89336 .50252 L
s
.88961 .52128 m
.89336 .52128 L
s
.88961 .54004 m
.89336 .54004 L
s
.88961 .5588 m
.89336 .5588 L
s
.88961 .59633 m
.89336 .59633 L
s
.88961 .61509 m
.89336 .61509 L
s
.25 Mabswid
.88961 0 m
.88961 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01473 L
.34309 .01473 L
.3815 .01473 L
.42237 .01474 L
.46172 .01475 L
.49955 .01476 L
.53984 .01477 L
.57861 .01478 L
.59975 .0148 L
.61984 .01481 L
.63987 .01483 L
.65803 .01485 L
.6777 .01487 L
.69867 .01491 L
.71792 .01496 L
.72876 .015 L
.73874 .01504 L
.75756 .01514 L
.76825 .01522 L
.77823 .01531 L
.78868 .01544 L
.79858 .01561 L
.80747 .01582 L
.81245 .01596 L
.81714 .01613 L
.82654 .01658 L
.83153 .01691 L
.83691 .01738 L
.84225 .018 L
.84516 .01844 L
.84787 .01894 L
.85267 .0201 L
.85521 .02091 L
.85792 .02201 L
.86051 .02335 L
.86325 .02522 L
.86559 .02735 L
.86816 .03053 L
.86961 .03289 L
.87093 .03553 L
.87245 .03937 L
.8739 .04409 L
.87523 .04976 L
Mistroke
.87647 .05661 L
.87782 .06673 L
.87858 .07405 L
.87926 .08208 L
.88053 .10176 L
.88117 .11498 L
.88187 .13304 L
.8831 .17821 L
.88426 .24314 L
.88571 .36808 L
.88642 .44335 L
.88708 .51076 L
.88831 .59393 L
.88896 .60332 L
.88965 .58811 L
.89081 .52359 L
.89189 .44587 L
.89318 .35772 L
.89437 .29043 L
.89555 .23684 L
.8968 .19328 L
.89805 .15985 L
.89942 .13211 L
.90074 .11164 L
.90196 .09688 L
.90328 .08428 L
.90472 .07336 L
.90715 .05982 L
.90848 .05426 L
.90972 .04991 L
.91208 .04336 L
.91423 .03882 L
.91671 .03478 L
.91907 .0318 L
.92159 .02928 L
.92428 .02716 L
.9291 .02434 L
.93178 .02317 L
.93429 .02225 L
.94003 .02064 L
.94441 .01973 L
.94921 .01895 L
.95389 .01836 L
.95889 .01785 L
.96785 .01716 L
.97619 .01671 L
Mfstroke
1 0 0 r
.02381 .01954 m
.02605 .02014 L
.02846 .02092 L
.03279 .02282 L
.03543 .02445 L
.03793 .02648 L
.04018 .02891 L
.04144 .03062 L
.04262 .03251 L
.045 .03755 L
.04626 .04114 L
.04762 .04605 L
.04904 .0528 L
.05039 .06147 L
.0516 .07201 L
.05229 .07957 L
.05293 .08811 L
.05418 .11034 L
.05532 .13996 L
.05654 .18835 L
.05723 .22677 L
.05786 .2714 L
.05909 .3852 L
.06026 .50694 L
.06131 .5848 L
.06244 .60024 L
.06371 .54437 L
.06488 .46257 L
.06613 .37567 L
.0675 .29508 L
.06868 .24074 L
.06978 .20066 L
.07095 .16753 L
.07221 .13992 L
.07351 .118 L
.07494 .0996 L
.07642 .08492 L
.07781 .07427 L
.08028 .06022 L
.08167 .05435 L
.08293 .04992 L
.08571 .04239 L
.08828 .03735 L
.09109 .03323 L
.09407 .02996 L
.09665 .02777 L
.09907 .02612 L
.10193 .02453 L
.10458 .02334 L
.10956 .02161 L
Mistroke
.11499 .02025 L
.11977 .01936 L
.12487 .01862 L
.12988 .01806 L
.1346 .01763 L
.1434 .01702 L
.15319 .01655 L
.16352 .01618 L
.17234 .01595 L
.18201 .01576 L
.19224 .0156 L
.20156 .01548 L
.21243 .01537 L
.22248 .01529 L
.24161 .01517 L
.26238 .01508 L
.28108 .01502 L
.3017 .01496 L
.32108 .01493 L
.34195 .01489 L
.36164 .01487 L
.38315 .01485 L
.42282 .01482 L
.46344 .0148 L
.50253 .01478 L
.54408 .01477 L
.58412 .01476 L
.62264 .01475 L
.66361 .01474 L
.70306 .01474 L
.741 .01474 L
.78139 .01473 L
.82027 .01473 L
.8616 .01473 L
.90141 .01473 L
.93971 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`003`3oool00`3ookl0M000000000040000000507Boo`3oool0oooo0?ooo`3o_g@00`000000
0`1d_ol0oooo0?ooo`020?ooo`050?noM000000000000000001d_ol0@@3oool00`3o_g@000000000
000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d_ol0oooo0?ooo`020?ooo`050?no
M000000000000000001d_ol0@03oool00`3o_g@000000000000300000005001d_`3oool0oooo0?oo
o`3o_g@00`0000000`1d_ol0oooo0?ooo`020?ooo`050?noM000000000000000001d_ol0A`3oool0
1@2oM0000000000000000000M;oo00@0oooo00D0okmd000000000000000007Boo`220?ooo`00403o
ool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0080oooo00H0W4Qd0;ooo`3oool0oono
07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo@`3oool00`2LB4P0W=oo0?ooo`03
0?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`030?ooo`0609a8M02oool0oooo0?oo_`1d
07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooodD0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000
M;oo00<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooon10?ooo`004@3oool00`3o_g@0001809cO
o`050?ooo`030?noM000M;l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`03
0=nLB018W=l0oooo0480oooo00<0W4Q809cOo`3oool0203oool01P3o_g@007Bo0?ooo`3oool0okmd
001d_`<0oooo00<0gia804RLg`3oool0@@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0
oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo04T0oooo
00H0okmd001d_`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo0800oooo000B0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia8
04RLg`<0oooo00<0okmd001d_`3oool0@P3oool00`2LB4P0W=oo0?ooo`080?ooo`060?noM000M;l0
oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo
00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d
_`3oool0B@3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0P03o
ool000L0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0
oooo0080oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo
00<0okmd001d_`3oool0=P3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo
00<0W4Q809cOo`3oool0203oool01P2LB000M;oo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d
_`3oool0=@3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cO
o`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`0k0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool01@3o
ool01P2LB000M;oo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0P03oool001D0oooo
00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`120?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0000000000P00
00001P18W=l0oooo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0@@3oool00`2LB4P0
W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l3
0?ooo`030?noM000M;l0oooo04@0oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3o
ool0gia804RLg`<0oooo00<0okmd001d_`3oool0P03oool00100oooo00<0gia807Boo`3oool00P3o
ool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00H0gia804RLg`3oool0oooo0?noM018W=l3
0?ooo`030=nLB018W=l0oooo0480oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M01d0;ooo`06
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0@@3oool00`2LB4P0W=oo0?ooo`03
0?ooo`030?noM018W=l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM018W=l30?ooo`030=nL
B018W=l0oooo04@0oooo00<0oono07@0M02oool01P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nL
B018W=l0oooo0800oooo000@0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`06
09a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;oood00oooo
00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo00L0oooo00H0W4P007Boo`3o
ool0omnL04P0M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?oo
o`3ogi`0B01d0;ooo`<0oooo00H0W4P007Boo`3oool0omnL04P0M02ooom50?ooo`030?oo_`1d07@0
_ooo00L0oooo00H0W4P007Boo`3oool0omnL04P0M02ooon10?ooo`004@3oool01@3o_g@000000000
000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d000000000000
B02Lgol0@`3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;oo
o`3oool00P3oool01@3ookl0M0000000000004P0W=oo0480oooo00<0gia80000B02Lgol01@3oool0
1@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`160?ooo`030?oo
_`1d000000000080000000<0001d0;ooo`3oool00P3oool01@3ookl0M0000000000004P0W=oo0880
oooo003o0?oook40oooo003o0?oook40oooo003o0?ooog`0oooo00<000000?ooo`3oool0<P3oool0
0?l0ooooO03oool00`000000oooo0?ooo`0b0?ooo`00o`3oooml0?ooo`030000003oool0oooo0380
oooo003o0?ooog`0oooo00<000000?ooo`3oool0<P3oool00?l0ooooO03oool00`000000oooo0?oo
o`0b0?ooo`00o`3oooml0?ooo`030000003oool0oooo0380oooo000>0?ooo`X00000D00c0?oo0?l0
03P0o`002P0000070?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3ooolS0?l000T0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3ooolG03<0o`<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0
oooo1@0c0?lA0?ooo`00603oool20?l00100oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`3oool60?l000P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool703<0o`h0oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`3oool903<0o`@0oooo00<000000?ooo`3oool03`3oool001P0
oooo00<000000?ooo`3o0000803oool40?l00380oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo04P0oooo0P0c0?l<0?ooo`030000003oool0oooo00l0
oooo100c0?lO0?ooo`006`3oool30?l001X0oooo0`3o003o0?ooocD0oooo00<0<`3o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`80<`3o8`3oool001h0oooo00<0o`000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`3o0?ooocL0oooo0P0c0?l90?ooo`030000003oool0oooo00/0oooo0P0c
0?lU0?ooo`007`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo>@3oool0
0`0c0?l0oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0<`3o0?ooo`3oool09@3oool0
01l0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?oooc/0oooo00<0<`3o0?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`0303<0o`3oool0oooo02H0oooo000P0?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0o`3ooolm0?ooo`0303<0o`3oool0oooo00D0
oooo0P0000090?ooo`0303<0o`3oool0oooo02L0oooo000P0?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool0o`3oooln0?ooo`0303<0o`3oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`0c0?l0oooo0?ooo`0X0?ooo`008@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0?l0oooo@03oool00`0c0?l0oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
<`3o0?ooo`3oool0:03oool00240oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3o
0?oood40oooo00<0<`3o0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`0303<0o`3oool0
oooo02T0oooo000Q0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0o`3ooom10?oo
o`0303<0o`3oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`0Y0?oo
o`008P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?l0oooo@@3oool00`0c0?l0
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0<`3o0?ooo`3oool0:@3oool00280oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o0?oood<0oooo00<0<`3o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`0303<0o`3oool0oooo02X0oooo000R0?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000?ooo`3oool0o`3ooom30?ooo`0303<0o`3oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`0Z0?ooo`008P3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo0?l0oooo@`3oool00`0c0?l0oooo0?ooo`030?ooo`8000001P3oool0
0`0c0?l0oooo0?ooo`0Z0?ooo`008P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
0?l0oooo@`3oool00`0c0?l0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0<`3o0?oo
o`3oool0:P3oool002<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?oood@0
oooo00<0<`3o0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`0303<0o`3oool0oooo02/0
oooo000S0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooom40?ooo`0303<0
o`3oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`0c0?l0oooo0?ooo`0[0?ooo`008`3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0?l0ooooA@3oool00`0c0?l0oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<0<`3o0?ooo`3oool0:`3oool002<0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?ooodD0oooo00<0<`3o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`0303<0o`3oool0oooo02/0oooo000S0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool0o`3ooom60?ooo`0303<0o`3oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`0c0?l0oooo0?ooo`0/0?ooo`008`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0?l0ooooAP3oool00`0c0?l0oooo0?ooo`020?ooo`800000103oool00`0c0?l0
oooo0?ooo`0/0?ooo`008`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0oooo
AP3oool00`0c0?l0oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0<`3o0?ooo`3oool0
;03oool002<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`3o0?ooodH0oooo00<0
<`3o0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`0303<0o`3oool0oooo02`0oooo000T
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooom60?ooo`0303<0o`3oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`0/0?ooo`00903oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0ooooA`3oool01@0c0?l0oooo0?ooo`3oool0
000000@0oooo00<0<`3o0?ooo`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`3o0?ooodL0oooo00D0<`3o0?ooo`3oool0oooo000000040?ooo`0303<0o`3oool0
oooo02d0oooo000T0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooom70?oo
o`0503<0o`3oool0oooo0?ooo`000000103oool00`0c0?l0oooo0?ooo`0]0?ooo`00903oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0ooooA`3oool01@0c0?l0oooo0?ooo`3oool0
000000@0oooo00<0<`3o0?ooo`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`3o0?ooodL0oooo00@0<`3o0?ooo`3oool0oooo0P0000030?ooo`0303<0o`3oool0
oooo02d0oooo000T0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0o`3ooom80?oo
o`0503<0o`3oool0oooo0?ooo`000000103oool00`0c0?l0oooo0?ooo`0]0?ooo`00903oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0ooooB03oool01@0c0?l0oooo0?ooo`3oool0
000000@0oooo00<0<`3o0?ooo`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`3o0?ooodP0oooo00D0<`3o0?ooo`3oool0oooo000000040?ooo`0303<0o`3oool0
oooo02d0oooo000T0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0o`3ooolU0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050?noM0000000
00000000001d_ol0103oool01@2oM0000000000000000000M;oo00<0oooo00D0<`3o0?ooo`3oool0
oooo000000040?ooo`0303<0o`3oool0oooo02d0oooo000T0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool0o`3ooolU0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2o
M0000000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0P3oool01`2oM00007Bo0?oo
o`3oool0omnL04P0001d_ol00P3oool01@0c0?l0oooo0?ooo`3oool0000000@0oooo00<0<`3o0?oo
o`3oool0;@3oool002@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o0?ooob@0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool01P3oool01@3o_g@007Bo0?ooo`3oool0<`3o00<0oooo00D000000?oo
o`3oool0oooo03<0o`0`0?ooo`00903oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
0?l0oooo903oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`060?ooo`050?noM000M;l0oooo0?ooo`0c0?l00`3oool0
1@000000oooo0?ooo`3oool0<`3o0300oooo000T0?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0o`3ooolU0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00D0W4P007Boo`3oool0oooo03<0
o`030?ooo`<0000000<0oooo03<0o`3oool0;`3oool002@0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`3o0?ooobD0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:
0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0?oo_`1d00030000000504RL
g`3oool0oooo0?ooo`0c0?l00`3oool01@000000oooo0?ooo`3oool0<`3o0300oooo000T0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`030?noM018W=l0oooo0080
oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`070=nLB018W=l0oooo0?oo
o`3ookl0M01d0;ooo`060?ooo`0503<0o`3oool0oooo0?ooo`0000000`3oool00`0c0?l0oooo0?oo
o`0^0?ooo`00903oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0oooo9P3oool0
1P2LB000M;oo0?ooo`3ogi`0B01d0;ooo``0oooo00H0W4P007Boo`3oool0omnL04P0M02oool20?oo
o`030?oo_`1d07@0_ooo00H0oooo00D0<`3o0?ooo`3oool0oooo000000030?ooo`0303<0o`3oool0
oooo02h0oooo000T0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooolV0?oo
o`050?oo_`1d000000000000B02Lgol03@3oool01@3ookl0M0000000000004P0W=oo00<0oooo00<0
oono07@0000000000P0000001@0007@0_ooo0?ooo`3oool0<`3o00<0oooo00D000000?ooo`3oool0
oooo03<0o`0`0?ooo`00903oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0oooo
B@3oool01@0c0?l0oooo0?ooo`3oool0000000<0oooo00<0<`3o0?ooo`3oool0;P3oool002@0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?ooodT0oooo00D0<`3o0?ooo`3oool0
oooo000000030?ooo`0303<0o`3oool0oooo02h0oooo000U0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0o`3ooom:0?ooo`0303<0o`3oool0oooo008000000P3oool00`0c0?l0oooo
0?ooo`0^0?ooo`009@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0ooooBP3o
ool0100c0?l0oooo0?ooo`0000030?ooo`0303<0o`3oool0oooo02h0oooo000U0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooom:0?ooo`0403<0o`3oool0oooo000000<0oooo
00<0<`3o0?ooo`3oool0;P3oool002D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`3o0?ooodX0oooo00@0<`3o0?ooo`3oool000000`3oool00`0c0?l0oooo0?ooo`0^0?ooo`009@3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0ooooBP3oool0100c0?l0oooo0?oo
o`0000030?ooo`0303<0o`3oool0oooo02h0oooo000U0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0o`3ooom:0?ooo`0403<0o`3oool0oooo000000<0oooo00<0<`3o0?ooo`3oool0
;P3oool002D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooodX0oooo00@0
<`3o0?ooo`3oool000000`3oool00`0c0?l0oooo0?ooo`0^0?ooo`009@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo0?l0ooooBP3oool0100c0?l0oooo0?ooo`0000030?ooo`0303<0
o`3oool0oooo02h0oooo000U0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0o`3o
oom:0?ooo`0303<0o`3oool0oooo0080000000<0oooo03<0o`3oool0<03oool002D0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooodX0oooo00@0<`3o0?ooo`3oool000000P3o
ool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0?l0ooooBP3oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooom:0?ooo`0403<0o`3oool0
oooo00000080oooo00<0<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`3o0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?oo
o`0_0?ooo`009@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooB`3oool0
100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom;0?ooo`0403<0o`3oool0oooo00000080oooo00<0
<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o
0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooB`3oool00`0c0?l0oooo0?ooo`02
000000030?ooo`0c0?l0oooo0300oooo000U0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0o`3ooom;0?ooo`0403<0o`3oool0oooo00000080oooo00<0<`3o0?ooo`3oool0;`3oool0
02D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oood/0oooo00@0<`3o0?oo
o`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0?l0ooooB`3oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0
oooo02l0oooo000U0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom;0?oo
o`0403<0o`3oool0oooo00000080oooo00<0<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`3o0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool0
0`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0?l0ooooB`3oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom;0?ooo`0303<0o`3oool0oooo
0080000000<0oooo03<0o`3oool0<03oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`3o0?oood/0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?oo
o`009@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooB`3oool0100c0?l0
oooo0?ooo`0000020?ooo`0303<0o`3oool0oooo02l0oooo000U0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0o`3ooom;0?ooo`0403<0o`3oool0oooo00000080oooo00<0<`3o0?oo
o`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oood/0
oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo<03oool01@3o_g@00000000000000000M;oo
00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000005001d_`3oool0oooo
0?ooo`0c0?l00P3oool010000000oooo0?ooo`0c0?la0?ooo`009@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo0?l0oooo<03oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo
00<0_g@000000000M;l01`3oool00`2LB4P0W=oo0?ooo`040?ooo`0403<0o`3oool0oooo00000080
oooo00<0<`3o0?ooo`3oool0;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`3o0?ooobl0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00@0oooo00@0<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`00
9@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo;`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool0103oool00`0c0?l0oooo
0?ooo`030000000303<0o`3oool0oooo02l0oooo000U0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0o`3oool_0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3o
ool00`2LB4P0W=oo0?ooo`040?ooo`0403<0o`3oool0oooo00000080oooo00<0<`3o0?ooo`3oool0
;`3oool002D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooobl0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00@0oooo00@0
<`3o0?ooo`3oool000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0?l0oooo;`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018
W=l0oooo00d0oooo00<0W4Q809cOo`3oool0103oool0100c0?l0oooo0?ooo`0000020?ooo`0303<0
o`3oool0oooo02l0oooo000V0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3o
ool`0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01@3OW4P000000018W02LB4P0W=oo
00H0oooo00<0<`3o0?ooo`0000000P3oool00`0c0?l0oooo0?ooo`0_0?ooo`009P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo<03oool01@3ookl0M0000000000004P0W=oo
00h0oooo00<0gia80000B02Lgol01P3oool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooom<0?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?oo
od`0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0
o`000?l0ooooC`3oool01@0c0?l0oooo000000000000<`3o0380oooo000V0?ooo`050?l0003oool0
oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0
o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`00
9P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o
0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o
0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3o
ool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000
o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0
oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000000003<0o`0b0?ooo`009P3oool01@3o0000
oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?oo
o`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3o
ool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo
03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo
0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`05
03<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?oo
odl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0
o`000?l0ooooC`3oool01@0c0?l0oooo000000000000<`3o0380oooo000V0?ooo`050?l0003oool0
oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0
o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`00
9P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o
0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o
0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3o
ool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000
o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0
oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000000003<0o`0b0?ooo`009P3oool01@3o0000
oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o0380oooo000V0?oo
o`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3o
ool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo
03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0oooo:P3oool01@3o_g@00000
000000000000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000005
001d_`3oool0oooo0?ooo`2oM0000`0000000`1d_ol0oooo0?ooo`030?ooo`0503<0o`3oool00000
0?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooobX0oooo00H0W4Qd
0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool0
0`3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0103oool01@0c0?l0oooo0000003oool0
<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooolY0?ooo`030?noM000M;l0
oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`080?ooo`030?noM000M;l0
oooo00<0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3o
ool0o`000?l0oooo:@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0
W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`030?ooo`0503<0o`3oool000000?ooo`0c0?l0
<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooobT0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00P0oooo00<0W4P007Boo`3oool0
0`3oool01@0c0?l0oooo000000000000<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o
0000o`3ooolY0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0
W=oo0?ooo`030?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool00`3oool01@0c0?l0
oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooolY0?oo
o`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`030?oo
o`030?oo_`1d07@0_ooo00P0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o
0000oooo0?ooo`3oool0o`000?l0oooo:P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo
00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo00P0oooo00D0<`3o0?ooo`00
0000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0oooo:P3oool01@3o
okl0M0000000000004P0W=oo00h0oooo00<0gia80000B02Lgol0103oool00`3ookl0M00000000002
000000030000M02oool0oooo00<0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool0
1@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c0?l0oooo0000003oool0<`3o0380oooo
000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?0?ooo`0503<0o`3oool000000?ooo`0c
0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0003o0?ooodl0oooo00D0<`3o0?ooo`00
0000000003<0o`0b0?ooo`009P3oool01@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool01@0c
0?l0oooo0000003oool0<`3o0380oooo000V0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooom?
0?ooo`0503<0o`3oool000000?ooo`0c0?l0<P3oool002H0oooo00D0o`000?ooo`3oool0oooo0?l0
003o0?ooodl0oooo00D0<`3o0?ooo`000000oooo03<0o`0b0?ooo`009P3oool01@3o0000oooo0?oo
o`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool01@3o0000oooo
0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool01@3o0000
oooo0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool01@3o
0000oooo0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0
1@3o0000oooo0?ooo`3oool0o`000?l0ooooC`3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3o
ool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo
00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`04
0?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o
0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`00
0?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003o
ool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo
0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3o
ool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo
0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o
003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00
o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0
ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oo
oe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@
0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03o
ool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo
00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`04
03<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c
0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o
0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooold0?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000000000@00000
00<0M;oo0?ooo`3oool00P3oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo
0?ooo`3o003o0?oooc@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`030?ooo`0403<0o`3oool0
000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0oooo<`3oool00`3o_g@007Bo0?oo
o`020?ooo`030=nLB018W=l0oooo00/0oooo00<0okmd0000B02Lgol01`3oool0100c0?l0oooo0000
000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooc<0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00H0oooo00D0<`3o0?ooo`000000
<`3o0000000b0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooc<0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00@0oooo00@0<`3o0?ooo`00
0000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooolc0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`030?ooo`0403<0o`3oool00000
03<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0oooo<`3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`03
0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0oooo=03o
ool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000M02oool0oooo0?noM00004P0
W=oo00@0oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3o
oold0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00D0
oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?oo
o`0403<0o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0
100c0?l0oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0
<`3o0?ooo`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0
o`3oool0000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0
oooo0000000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?oo
o`000000<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0
000003<0oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000
000c0?lc0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000
<`3o<`3oool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0
oc<0oooo000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc
0?ooo`009P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3o
ool002H0oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo
000V0?ooo`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`00
9P3oool0103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002H0
oooo00@0o`000?ooo`3oool0o`00o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000V0?oo
o`040?l0003oool0oooo0?l00?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009P3oool0
103o0000oooo0?ooo`3o003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002L0oooo00<0
o`000?ooo`3o0000o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000W0?ooo`030?l0003o
ool0o`000?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000oooo0?l0
003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o<`3oool002L0oooo00<0o`000?ooo`3o0000o`3o
oom@0?ooo`0403<0o`3oool0000003<0oc<0oooo000W0?ooo`030?l0003oool0o`000?l0ooooD03o
ool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000oooo0?l0003o0?oooe00oooo00@0
<`3o0?ooo`000000<`3o<`3oool002L0oooo00<0o`000?ooo`3o0000o`3ooom@0?ooo`0403<0o`3o
ool0000003<0oc<0oooo000W0?ooo`030?l0003oool0o`000?l0ooooD03oool0100c0?l0oooo0000
000c0?lc0?ooo`009`3oool00`3o0000oooo0?l0003o0?oooe00oooo00@0<`3o0?ooo`000000<`3o
<`3oool002L0oooo00<0o`000?ooo`3o0000o`3ooom@0?ooo`0403<0o`3oool0000003<0oc<0oooo
000W0?ooo`030?l0003oool0o`000?l0ooooD03oool0100c0?l0oooo0000000c0?lc0?ooo`009`3o
ool00`3o0000oooo0?l0003o0?ooob/0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00<0oooo00<0oono07@000000000100000001@1d_ol0oooo0?ooo`3oool0_g@000<0
000000<0M;oo0?ooo`3oool00`3oool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000
oooo0?l0003o0?ooob/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00<0_g@00000M02oool00P3oool01P3OW7@0W=oo0?ooo`3oool0_g@0001d_`80oooo
00<0omnL04P0001d_ol0103oool0100c0?l0oooo0000000c0?lc0?ooo`009`3oool00`3o0000oooo
0?l0003o0?ooobX0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?no
M00004P0W=oo00X0oooo00<0okmd001d_`3oool0103oool00`0c0?l0000003<0o`0c0?ooo`009`3o
ool00`3o0000oooo0?l0003o0?ooobX0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0<0?ooo`030?oOW0180000B9cO00T0oooo00<0okmd001d_`3oool0103oool0100c0?l0000003<0
o`00000b0?ooo`009`3oool00`3o0000oooo0?l0003o0?ooobX0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00L0oooo00<0W4P007Boo`3oool0103o
ool203<0oc@0oooo000W0?ooo`030?l0003oool0o`000?l0oooo:P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00l0oooo00H0W4Qd0;ooo`3oool0oooo0?oo_`1d00030000000304RL
g`3oool0oooo00@0oooo0P0c0?ld0?ooo`009`3oool00`3o0000oooo0?l0003o0?ooobX0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00L0
_g@007Boo`3oool0oooo0?oo_`1d07@0_ooo00T0oooo0P0c0?ld0?ooo`009`3oool00`3o0000oooo
0?l0003o0?ooob/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo
0?ooo`3o_g@0001809cOo`020?ooo`030?oo_`1d07@0_ooo00T0oooo0P0c0?ld0?ooo`009`3oool0
0`3o0000oooo0?l0003o0?ooob/0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?noM000
000000000000B02Lgol00`3oool00`3ookl0M00000000002000000030000M02oool0oooo00@0oooo
0P0c0?ld0?ooo`009`3oool00`3o0000oooo0?l0003o0?oooe40oooo0P0c0?ld0?ooo`009`3oool0
0`3o0000oooo0?l0003o0?oooe40oooo0P0c0?ld0?ooo`009`3oool00`3o0000oooo0?l0003o0?oo
oe40oooo0P0c0?l00`000000oooo0?ooo`0a0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0
oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo0P0c
0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?oo
o`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0oooo
DP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o00<000000?ooo`3oool0<@3o
ool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0
oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo
0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB
0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0
ooooDP3oool203<0o`030000003oool0oooo0340oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o
=03oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool2
03<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80<`3o=03oool002L0oooo0P3o003o0?oooe80
oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3o
oomB0?ooo`80<`3o00<000000?ooo`3oool0<@3oool002L0oooo0P3o003o0?oooe80oooo0P0c0?ld
0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000W0?ooo`80o`00o`3ooomB0?ooo`80
<`3o=03oool002L0oooo0P3o003o0?ooocD0oooo00D0okmd000000000000000007Boo`050?ooo`03
0;md0000000007Bo00D0oooo00D0_g@0000000000000000004RLg`060?ooo`80<`3o=03oool002L0
oooo0P3o003o0?ooocD0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oo_`1d0000B9cO00D0oooo0P0c0?ld0?ooo`009`3o
ool20?l00?l0oooo=03oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0
okmd001d_`3oool0103oool203<0oc@0oooo000W0?ooo`80o`00o`3ooold0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B01809cOo`050?ooo`80<`3o=03oool0
02L0oooo0P3o003o0?oooc@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0<0?oo
o`040=nLB0000000001809cOo`H0oooo0P0c0?l200000380oooo000W0?ooo`80o`00o`3ooold0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B01809cOo`050?oo
o`80<`3o=03oool002L0oooo0P3o003o0?oooc@0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`0?0?ooo`030;md001d_ol0oooo00@0oooo0P0c0?ld0?ooo`009`3oool20?l00?l0oooo
=@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000B02Lgol0oooo0?oOW018
04P0W=oo00D0oooo0P0c0?ld0?ooo`009`3oool20?l00?l0oooo=@3oool01@3ookl0M00000000000
04P0W=oo00d0oooo00D0omnL04P000000000000007Boo`060?ooo`80<`3o=03oool002L0oooo0P3o
003o0?oooe80oooo0P0c0?ld0?ooo`009`3oool20?l00?l0ooooDP3oool203<0oc@0oooo000X0?oo
o`030?l0003oool0oooo0?l0ooooD03oool203<0oc@0oooo000X0?ooo`030?l0003oool0oooo0?l0
ooooD03oool203<0o`030000003oool0oooo0340oooo000X0?ooo`030?l0003oool0oooo0?l0oooo
D@3oool00`0c0?l0oooo0?ooo`0b0?ooo`00o`3oooml0?ooo`0303<0o`3oool0oooo0380oooo003o
0?ooog`0oooo00<000000?ooo`3oool0<P3oool00?l0ooooO03oool00`000000oooo0?ooo`0b0?oo
o`00o`3oooml0?ooo`030000003oool0oooo0380oooo003o0?ooog`0oooo00<000000?ooo`3oool0
<P3oool00?l0ooooO03oool2000003<0oooo003o0?ooog`0oooo00<000000?ooo`3oool0<P3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-213.796, -0.0242234, \
0.845517, 0.00195088}}]
}, Open  ]],

Cell["\<\
OffNIntMsg turns off the following warning messages from NIntegrate: \
NIntegrate::\"ncvb\", NIntegrate::\"ploss\", NIntegrate::\"slwcon\", \
NIntegrate::\"nlim\".  OnNIntMsg turns them back on.  The functions produce \
no output.  The default setting is OffNIntMsg;  It might be a good idea to \
turn them on a few times to see what is happening.  It is a particularly good \
idea if you are trying to compute high precision results.\
\>", "Text"],

Cell[BoxData[
    \(OnNIntMsg\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{2^i, 
          SPDF[2^i, {13/10, \(-1\)}, \ GaussPoints \[Rule] 15, 
            WorkingPrecision \[Rule] 64]}, {i, 6}] // TableForm\)], "Input"],

Cell[BoxData[
    RowBox[{\(NIntegrate::"ncvb"\), \(\(:\)\(\ \)\), "\<\"NIntegrate failed \
to converge to prescribed accuracy after \\!\\(7\\) recursive bisections in \
\\!\\(SMath`Private`\[Theta]\\) near \\!\\(SMath`Private`\[Theta]\\) = \
\\!\\(-0.5342973082727833`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(NIntegrate::"ncvb"\), \(\(:\)\(\ \)\), "\<\"NIntegrate failed \
to converge to prescribed accuracy after \\!\\(7\\) recursive bisections in \
\\!\\(SMath`Private`\[Theta]\\) near \\!\\(SMath`Private`\[Theta]\\) = \
\\!\\(1.5707963267948966`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(NIntegrate::"ncvb"\), \(\(:\)\(\ \)\), "\<\"NIntegrate failed \
to converge to prescribed accuracy after \\!\\(7\\) recursive bisections in \
\\!\\(SMath`Private`\[Theta]\\) near \\!\\(SMath`Private`\[Theta]\\) = \
\\!\\(1.5707963267948966`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(NIntegrate :: \\\"ncvb\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    TagBox[GridBox[{
          {"2", 
            "0.273549462258796189509775341539313131858185752986508966233`44.\
8663462905707"},
          {"4", 
            "0.038598879516744249569924583917870716560367065957`32.\
38672495932879"},
          {"8", 
            "3.391979139387401921303888873307117869238901`31.67350775619312*^-\
25"},
          {"16", 
            "1.2921280698768436831216840077516017524322903`30.928885720435968*\
^-496"},
          {"32", 
            "1.49078232764395961425032655790494239205721`30.396297562390583*^-\
10006"},
          {"64", 
            "1.28876881056847406907355147746013211220193`29.77946477600555*^-\
201721"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Here increasing MaxRecursion eliminates the errors and gets the precision \
results desired.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{2^i, 
          SPDF[2^i, {13/10, \(-1\)}, \ GaussPoints \[Rule] 15, 
            MaxRecursion \[Rule] 12, WorkingPrecision \[Rule] 64]}, {i, 6}] // 
      TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"2", 
            "0.273549462258796189509775341539313131858185752986508966232571542\
3434`54.058781967655506"},
          {"4", 
            "0.038598879516744249569924583917870716560367065955283947235868060\
596`54.04113687751255"},
          {"8", 
            "3.391979139387401921303888873307117869238901361946908063386454154\
57247675`54.002167922497634*^-25"},
          {"16", 
            "1.292128069876843683121684007751601752432115597266917711082914461\
801326471`54.084659165372514*^-496"},
          {"32", 
            "1.490782327643959614250326557904942392057212973554181367160448950\
6359152`54.038936243584885*^-10006"},
          {"64", 
            "1.288768810568474069073551477460132112201930213915783030797941069\
4413843`54.04477985398163*^-201721"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Turn it off again.", "Text"],

Cell[BoxData[
    \(OffNIntMsg\)], "Input"],

Cell["\<\
Sometimes it is easier to change the NIntegrate options globally with \
SetOptions.  ResetNInt resets all the options for NIntegrate to the 5.0 \
default values.  The reset function makes it easier to start over after \
globally changing NIntegrate with SetOptions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResetNInt\)], "Input"],

Cell[BoxData[
    \({AccuracyGoal \[Rule] \[Infinity], Compiled \[Rule] True, 
      EvaluationMonitor \[Rule] None, GaussPoints \[Rule] Automatic, 
      MaxPoints \[Rule] Automatic, MaxRecursion \[Rule] 6, 
      Method \[Rule] Automatic, MinRecursion \[Rule] 0, 
      PrecisionGoal \[Rule] Automatic, SingularityDepth \[Rule] 4, 
      WorkingPrecision \[Rule] MachinePrecision}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SMode\)\)], "Input"],

Cell[BoxData[
    \("SMode[{\[Alpha], \[Beta], \[Gamma], \[Delta]}, param] returns the \
location of the mode of a S(\[Alpha], \[Beta], \[Gamma], \[Delta]; param) \
stable distribution.  {\[Beta], \[Gamma], \[Delta]} may be omitted with \
default values of {0, 1, 0}.   param may be omitted with a default value of \
1."\)], "Print",
  CellTags->"Info3310572801-1744629"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SMode[{1.001, 1, 1, 0}, 1, \ GaussPoints \[Rule] 25, 
      MaxRecursion \[Rule] 10, SingularityDepth \[Rule] 15]\)], "Input"],

Cell[BoxData[
    \(\(-637.047924879279`\)\)], "Output"]
}, Open  ]],

Cell["\<\
SMode is provided to help determine where the mode may be in the \
1-parameterization, and it may be useful to implement the 2-parameterization, \
which is so far not supported in this program.  It uses FindRoot get the \
value of x when the first derivative equals 0.  It has some trouble when \
\[Alpha] < 0.5 && Abs[\[Beta]] == 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetOptions[NIntegrate, \ GaussPoints \[Rule] 25, 
        MaxRecursion \[Rule] 10, SingularityDepth \[Rule] 10, 
        WorkingPrecision \[Rule] 
          MachinePrecision];\)\), "\[IndentingNewLine]", 
    \(Off[FindRoot::"\<frmp\>", N::"\<meprec\>"]; 
    Plot[{SMode[{\[Alpha], 0.33, 1, 0}, 0], SMode[{\[Alpha], 0.67, 1, 0}, 0], 
        SMode[{\[Alpha], 0.999, 1, 0}, 0]}, {\[Alpha], 0.01, 
        2}];\), "\[IndentingNewLine]", 
    \(\(On[FindRoot::"\<frmp\>", 
        N::"\<meprec\>"];\)\), "\[IndentingNewLine]", 
    \(\(ResetNInt;\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.603319 0.87979 [
[.2619 .59082 -9 -9 ]
[.2619 .59082 9 0 ]
[.5 .59082 -3 -9 ]
[.5 .59082 3 0 ]
[.7381 .59082 -9 -9 ]
[.7381 .59082 9 0 ]
[.97619 .59082 -3 -9 ]
[.97619 .59082 3 0 ]
[.01131 .07544 -24 -4.5 ]
[.01131 .07544 0 4.5 ]
[.01131 .16342 -24 -4.5 ]
[.01131 .16342 0 4.5 ]
[.01131 .2514 -24 -4.5 ]
[.01131 .2514 0 4.5 ]
[.01131 .33938 -24 -4.5 ]
[.01131 .33938 0 4.5 ]
[.01131 .42736 -24 -4.5 ]
[.01131 .42736 0 4.5 ]
[.01131 .51534 -24 -4.5 ]
[.01131 .51534 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(0.5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(1)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(1.5)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(2)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .07544 m
.03006 .07544 L
s
[(-0.6)] .01131 .07544 1 0 Mshowa
.02381 .16342 m
.03006 .16342 L
s
[(-0.5)] .01131 .16342 1 0 Mshowa
.02381 .2514 m
.03006 .2514 L
s
[(-0.4)] .01131 .2514 1 0 Mshowa
.02381 .33938 m
.03006 .33938 L
s
[(-0.3)] .01131 .33938 1 0 Mshowa
.02381 .42736 m
.03006 .42736 L
s
[(-0.2)] .01131 .42736 1 0 Mshowa
.02381 .51534 m
.03006 .51534 L
s
[(-0.1)] .01131 .51534 1 0 Mshowa
.125 Mabswid
.02381 .09304 m
.02756 .09304 L
s
.02381 .11064 m
.02756 .11064 L
s
.02381 .12823 m
.02756 .12823 L
s
.02381 .14583 m
.02756 .14583 L
s
.02381 .18102 m
.02756 .18102 L
s
.02381 .19862 m
.02756 .19862 L
s
.02381 .21621 m
.02756 .21621 L
s
.02381 .23381 m
.02756 .23381 L
s
.02381 .269 m
.02756 .269 L
s
.02381 .28659 m
.02756 .28659 L
s
.02381 .30419 m
.02756 .30419 L
s
.02381 .32179 m
.02756 .32179 L
s
.02381 .35698 m
.02756 .35698 L
s
.02381 .37457 m
.02756 .37457 L
s
.02381 .39217 m
.02756 .39217 L
s
.02381 .40977 m
.02756 .40977 L
s
.02381 .44496 m
.02756 .44496 L
s
.02381 .46255 m
.02756 .46255 L
s
.02381 .48015 m
.02756 .48015 L
s
.02381 .49774 m
.02756 .49774 L
s
.02381 .53294 m
.02756 .53294 L
s
.02381 .55053 m
.02756 .55053 L
s
.02381 .56813 m
.02756 .56813 L
s
.02381 .58572 m
.02756 .58572 L
s
.02381 .05785 m
.02756 .05785 L
s
.02381 .04025 m
.02756 .04025 L
s
.02381 .02266 m
.02756 .02266 L
s
.02381 .00506 m
.02756 .00506 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02857 .59876 m
.06701 .56166 L
.10894 .51958 L
.14831 .47734 L
.18618 .43658 L
.20728 .41633 L
.22648 .40066 L
.24643 .38775 L
.26528 .37889 L
.27493 .3756 L
.28021 .37415 L
.28516 .373 L
.28972 .37213 L
.29389 .37148 L
.29852 .37092 L
.30108 .37068 L
.3035 .3705 L
.30474 .37042 L
.30608 .37035 L
.30726 .3703 L
.30851 .37026 L
.30963 .37024 L
.31087 .37022 L
.31199 .37021 L
.31304 .37021 L
.31367 .37021 L
.31436 .37022 L
.31561 .37024 L
.31683 .37027 L
.31795 .37031 L
.3205 .37043 L
.32321 .3706 L
.3277 .37098 L
.33191 .37146 L
.34151 .37294 L
.35129 .37496 L
.36159 .37759 L
.38 .38344 L
.41792 .39896 L
.45828 .41871 L
.49713 .43911 L
.53842 .46095 L
.5782 .48131 L
.61647 .49979 L
.65719 .51796 L
.69639 .53386 L
.73409 .54764 L
.77423 .56071 L
.81286 .57176 L
.85393 .58193 L
Mistroke
.89349 .59027 L
.93154 .597 L
.97204 .6028 L
.97619 .60332 L
Mfstroke
.02857 .59406 m
.06701 .51874 L
.10894 .43331 L
.14831 .34841 L
.18618 .27092 L
.20728 .2353 L
.22648 .2096 L
.23605 .19935 L
.24643 .19015 L
.25616 .18329 L
.26528 .17835 L
.27467 .1747 L
.27966 .17333 L
.28502 .17227 L
.2877 .17189 L
.28911 .17173 L
.29062 .17159 L
.29207 .17149 L
.29338 .17142 L
.29402 .1714 L
.2947 .17138 L
.29595 .17135 L
.29715 .17135 L
.29784 .17136 L
.29848 .17137 L
.29977 .17141 L
.30049 .17144 L
.30115 .17148 L
.30361 .17165 L
.30594 .17189 L
.31051 .17254 L
.31555 .17353 L
.32575 .17635 L
.33521 .17987 L
.34408 .18388 L
.38258 .20759 L
.42351 .24031 L
.46294 .27549 L
.50085 .31045 L
.54121 .34731 L
.58006 .38152 L
.62135 .41587 L
.66113 .44666 L
.69941 .47399 L
.74012 .50052 L
.77933 .52359 L
.81703 .5435 L
.85716 .56228 L
.89579 .57802 L
.93687 .59223 L
Mistroke
.97619 .60332 L
Mfstroke
.02857 .58951 m
.06701 .47721 L
.10894 .34986 L
.14831 .22504 L
.18618 .11848 L
.20565 .07689 L
.22648 .04457 L
.23665 .03333 L
.24201 .02856 L
.24768 .02432 L
.25264 .0213 L
.2581 .01866 L
.2605 .01773 L
.26307 .01687 L
.26551 .0162 L
.26772 .0157 L
.27025 .01525 L
.27163 .01507 L
.27294 .01493 L
.27415 .01483 L
.27526 .01477 L
.27648 .01473 L
.27778 .01472 L
.27908 .01474 L
.27981 .01476 L
.28048 .01479 L
.28178 .01488 L
.28301 .01499 L
.28576 .01534 L
.28875 .01587 L
.29379 .01711 L
.29913 .01887 L
.30874 .0231 L
.32811 .03522 L
.3463 .0501 L
.3848 .08909 L
.42573 .13659 L
.46516 .18416 L
.50307 .22943 L
.54343 .27579 L
.58228 .31802 L
.62357 .36006 L
.66336 .39773 L
.70163 .43141 L
.74234 .46459 L
.78155 .49406 L
.81925 .52016 L
.85939 .54552 L
.89802 .56747 L
.93909 .58788 L
Mistroke
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo0`00003o0?oo
ohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0
o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0
oooo05l0oooo2@00003o0?oooah0oooo000X0?ooo`030000003oool0oooo05`0oooo0`0000090?oo
o`800000o`3ooolL0?ooo`00:03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0
oooo0`00003o0?oooaT0oooo000X0?ooo`<00000F@3oool200000180oooo0`00003o0?oooaH0oooo
000X0?ooo`030000003oool0oooo05L0oooo0P00000G0?ooo`800000o`3ooolD0?ooo`00:03oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooolA
0?ooo`00:03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01/0oooo0P00003o0?oo
oa40oooo000X0?ooo`030000003oool0oooo05<0oooo0P00000P0?ooo`800000o`3oool?0?ooo`00
:03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
o`3oool<0?ooo`00:03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`00:03oool300000500oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000X0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0:03oool200000?l0oooo2P3oool002P0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo1`3oool002P0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo1P3oool002P0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo1@3o
ool002P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0?l0oooo103oool002P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0?l0oooo0`3oool002P0oooo0`00001;0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0o`3oool20?ooo`00:03oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0o`3oool10?ooo`00:03oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3oool002P0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?h0oooo000;0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`060?ooo`050;md00000000
00000000M02oool01@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0o@3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md
0000000007Bo00D0oooo00H0gia8001d_`3oool0oooo0?noM000M;l50?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3l0?ooo`002P3oool00`3o_g@0
07Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0001d_ol00P3oool00`3ookl0
M4RL0?ooo`040?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`3k0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo
00L0okmd0018B01d07@0_ooo0?ooo`3OW4P007Bo00D0oooo100000160?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0nP3oool000030?ooo`2LB000000000@0000000D004RL0?ooo`3o
ool0gia804RLg`030?ooo`030?noM000M;l0oooo00X0oooo00<0omnL04Q8W03o_g@00P0000000`00
B9`0oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`3i0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00<0oono07@0M02oool02@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0n03oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0;0?ooo`030;md0018W=l0oooo00P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo0?L0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0
_ooo303oool00`3ookl0M000001d_`080?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`3f0?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00l0
oooo00@0_g@000000000000004RL1@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0m@3oool002P0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0?@0oooo000X0?ooo`<00000@`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0?<0oooo000X0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`3b0?ooo`00:03oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0l@3oool002P0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?40oooo000X0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3`0?ooo`00
:03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
k`3oool002P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo0>h0oooo000X0?ooo`<00000?`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0>d0oooo000X0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3/0?ooo`00:03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0k03oool002P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0>/0oooo000X0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3Z0?ooo`00:03oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0j@3oool002P0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0>P0oooo000X0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0>L0oooo000X0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3W0?ooo`00:03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0iP3o
ool002P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0>D0oooo000X0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`3T0?ooo`00:03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0h`3oool002P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo0>80oooo000X0?ooo`<00000>P3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo0>40oooo000X0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`3Q0?ooo`00:03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0h03oool002P0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0=l0oooo000;0?ooo`050?no
M000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md0000000000000000
001d_ol01P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool0gP3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00D0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0=d0oooo000:0?ooo`030?noM000
M;l0oooo0080oooo00<0gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`040?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3L0?ooo`002P3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0okmd001d_`3oool0103oool4
000003L0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3L0?ooo`0000<0oooo09a8
00000000100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03`3oool0
0`2LB000M;oo0?ooo`040?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`3K0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`040?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`3J0?ooo`002P3oool00`3o_g@0
B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0M02oool02@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0f@3oool000/0oooo
00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0[0?ooo`l00000=`3oool00`000000oooo0?ooo`3H0?oo
o`002`3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0oono07@0000000000P0000000`00
07@0_ooo0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:03oool30000
00l0oooo0P00000f0?ooo`030000003oool0oooo0=L0oooo000X0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool09@3oool3000001@0oooo0`00000c0?ooo`030000003oool0oooo0=L0
oooo000X0?ooo`<00000=@3oool00`000000oooo0?ooo`0T0?ooo`8000006P3oool300000340oooo
00<000000?ooo`3oool0eP3oool002P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0R0?ooo`8000007`3oool200000300oooo00<000000?ooo`3oool0e@3oool002P0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3D0?ooo`00:03oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo0P00000U0?ooo`800000;`3oool00`000000oooo0?ooo`3C0?oo
o`00:03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool09`3oool2000002h0oooo00<000000?ooo`3oool0dP3oool002P0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02X0oooo0P00000/0?ooo`030000
003oool0oooo0=80oooo000X0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0d@3o
ool002P0oooo0`00000c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool2
000002/0oooo00<000000?ooo`3oool0d03oool002P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0380oooo0P00000Z0?ooo`030000003oool0oooo
0<l0oooo000X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0e0?ooo`800000:@3oool00`000000oooo0?ooo`3>0?ooo`00:03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>03oool2000002P0oooo
00<000000?ooo`3oool0c@3oool002P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`3=0?ooo`00:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0<`0oooo000X0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0o0?oo
o`8000009P3oool00`000000oooo0?ooo`3;0?ooo`00:03oool300000300oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0bP3oool002P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`390?ooo`00:03o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0<P0oooo000X0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0b03oool002P0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04P0oooo0P00000T0?ooo`030000003oool0oooo
0<L0oooo000X0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0aP3oool002P0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`350?ooo`00:03oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0<@0oooo000X0?ooo`<00000;P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0500oooo0P00000S0?ooo`030000003oool0oooo0<<0oooo000X0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0`P3oool002P0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`310?ooo`002`3oool01@3o_g@00000000000000000M;oo00D0
oooo00<0_g@000000000M;l01P3oool01@3ogi`0B000000000000000M;oo00D0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`310?ooo`002`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d
0;ooo`@0oooo00<0_g@000000000M;l0203oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0`03oool000X0oooo00<0okmd001d_`3oool00P3oool00`3O
W4P0B9cO0?ooo`0>0?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`2o0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1K0?ooo`8000008@3oool00`000000
oooo0?ooo`2n0?ooo`0000<0oooo09a800000000100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0
oooo00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;ooo`3oool0_g@007Boo`H0oooo1000000[
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0;d0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool02`3oool01@3OW4P007Bo0?ooo`2oM000M;oo00H0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`2l0?ooo`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo
00`0oooo00@0W4P004RLg`2oM000M;oo1P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0;/0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo3@3oool0103ogi`0B01804Q8
001d_ol60?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0^P3oool000/0oooo00D0
oono07@000000000001809cOo`0?0?ooo`030?noM0000000M;oo00H0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`2i0?ooo`00:03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0;T0oooo000X0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1W0?ooo`8000007`3oool00`000000oooo0?ooo`2h0?ooo`00:03oool30000
02X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0]`3oool002P0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`2f0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;D0oooo
000X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0]03oool002P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`2c0?ooo`00:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0;80oooo000X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0/@3oool002P0oooo0`00000W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;00oooo000X0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0[`3oool002P0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07L0oooo0P00000N0?ooo`030000003oool0
oooo0:h0oooo000X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0[@3oool002P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2]0?ooo`00:03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0:`0oooo000X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0Z`3oool002P0oooo0`00000U0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0:X0oooo000X0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0Z@3oool002P0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`2X0?ooo`00:03oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0:L0oooo000X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0YP3o
ool002P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2U0?ooo`00:03oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0:@0oooo000X0?ooo`<000008`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`2S0?ooo`00:03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0:80oooo
000X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0X@3oool000/0oooo00D0okmd
000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@00000000000000000
04RLg`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`2?0?ooo`800000703oool00`000000oooo0?ooo`2P0?ooo`002`3oool01P2LB7@0_ooo0?oo
o`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0oono
07@00018W=l01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo09l0oooo000:0?oo
o`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0WP3oool000X0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`030?oOW01804P0W=oo00D0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`2M0?ooo`0000<0oooo09a800000000100000001@00B9`0oooo
0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool0303oool0103OW4P000000000B02Lgol60?oo
o`@00000803oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo09H0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`2M0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo00h0oooo00<0omnL04P0B02Lgol01@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo09`0oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0
3`3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
V`3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00004P0W=oo0?oo
o`3ogi`0B01809cOo`050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0VP3oool0
00/0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?oOW018000000000000001d_ol01P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo09T0oooo000X0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0V03oool002P0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`2G0?ooo`00:03oool3000001l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`2P0?ooo`8000006P3oool00`000000oooo0?ooo`2F0?ooo`00:03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo09D0oooo000X0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0U03oool002P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2C
0?ooo`00:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0980oooo000X0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0m0?ooo`d0
0000GP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0940oooo000X0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0h0?ooo`D00000
3@3oool6000005T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2@0?ooo`00:03o
ool3000001d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`D00000603o
ool4000005H0oooo0P00000I0?ooo`030000003oool0oooo08l0oooo000X0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0a0?ooo`<000008@3oool4
000005@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2>0?ooo`00:03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<03oool20000
02P0oooo1000001A0?ooo`030000003oool0oooo01L0oooo0P00002>0?ooo`00:03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;P3oool2000002h0
oooo1000001>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0R`3oool002P0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02d0oooo
0P00000d0?ooo`800000C@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo08X0oooo
000X0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0[0?ooo`800000>03oool3000004/0oooo0P00000I0?ooo`030000003oool0oooo08T0oooo000X
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z
0?ooo`800000?@3oool2000004/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`28
0?ooo`00:03oool3000001X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo03l0oooo0`0000190?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0Q`3oool002P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02L0oooo0P0000150?ooo`800000B03oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo08H0oooo000X0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0V0?ooo`800000B@3oool2000004L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`250?ooo`00:03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1;0?ooo`800000AP3o
ool2000001P0oooo00<000000?ooo`3oool0Q03oool002P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0CP3oool2
000004H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`230?ooo`00:03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`1A0?ooo`800000A@3oool00`000000oooo0?ooo`0F0?ooo`800000P`3oool002P0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0
oooo0P00001F0?ooo`800000A03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0800
oooo000X0?ooo`<00000603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0F03oool2000004<0oooo0P00000H0?ooo`030000003oool0oooo07l0oooo
000X0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo05/0oooo0P0000130?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0OP3oool002P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0GP3oool200000480oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1m0?ooo`002`3oool01@3o_g@00000000000000000
M;oo00D0oooo00<0_g@000000000M;l00`3oool00`3ookl0M000000000040000000307Boo`3oool0
oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0H@3oool200000440oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1l0?ooo`002`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0
_g@000000000M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0I03oool200000400oooo0P00000G0?ooo`030000003oool0oooo07/0oooo000:
0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0001809cOo`08
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo06L0oooo0P0000100?ooo`030000003oool0oooo01D0oooo0P00001k
0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P0
0018W=l01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`800000?`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo07P0oooo00000`3oool0W4P000000004000000050018W03oool0oooo0=nL
B018W=l00`3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00D0oooo1000000E0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1g0?oo
o`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`1_0?ooo`800000?P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo07H0oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0
2P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
LP3oool2000003d0oooo0P00000G0?ooo`030000003oool0oooo07D0oooo000;0?ooo`0609a8001d
_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol01@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1e0?ooo`800000?@3oool00`000000oooo0?ooo`0E0?ooo`800000M@3oool0
00/0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol01P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1h0?ooo`800000?03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0780oooo000X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0740oooo000X0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
07d0oooo0P00000k0?ooo`8000005`3oool00`000000oooo0?ooo`1`0?ooo`00:03oool3000001<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0800
oooo0P00000k0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0K`3oool002P0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0P`3oool2000003X0oooo00<000000?ooo`3oool05@3oool2000006l0oooo
000X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo08H0oooo0P00000i0?ooo`8000005`3oool00`000000oooo0?oo
o`1/0?ooo`00:03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`290?ooo`800000>@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo06/0oooo000X0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo08`0oooo0P00000h0?oo
o`8000005P3oool00`000000oooo0?ooo`1Z0?ooo`00:03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2?0?ooo`80
0000>03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06T0oooo000X0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0940oooo0P00000g0?ooo`8000005@3oool2000006T0oooo000X0?ooo`<000004@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0U03o
ool2000003L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1V0?ooo`00:03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`2G0?ooo`800000=P3oool2000001D0oooo00<000000?ooo`3oool0I@3oool0
02P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0VP3oool2000003H0oooo00<000000?ooo`3oool04`3oool20000
06D0oooo000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo09d0oooo0P00000e0?ooo`8000005@3oool00`000000
oooo0?ooo`1R0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2P0?ooo`800000=@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0640oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0:<0oooo0P00
000d0?ooo`800000503oool200000640oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0:H0oooo0P00000d
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0GP3oool002P0oooo0`00000?0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2Y0?oo
o`800000<`3oool2000001@0oooo00<000000?ooo`3oool0G@3oool002P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0[03oool2000003<0oooo00<000000?ooo`3oool04P3oool2000005d0oooo000X0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0:l0oooo0P00000b0?ooo`800000503oool00`000000oooo0?ooo`1J0?ooo`00:03o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`2b0?ooo`800000<P3oool2000001<0oooo00<000000?ooo`3oool0F@3o
ool002P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0]03oool200000380oooo00<000000?ooo`3oool04@3oool2
000005T0oooo000X0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0;L0oooo0P00000a0?ooo`8000004`3oool00`00
0000oooo0?ooo`1F0?ooo`00:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2j0?ooo`800000<@3oool00`000000
oooo0?ooo`0A0?ooo`800000EP3oool002P0oooo0`00000<0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2m0?ooo`800000<03oool2000001<0oooo
00<000000?ooo`3oool0D`3oool002P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0`03oool200000300oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1B0?ooo`00:03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`33
0?ooo`800000;`3oool200000180oooo0P00001B0?ooo`002`3oool01@3o_g@00000000000000000
M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000003001d_`3oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0aP3oool3000002h0oooo0P00000B0?ooo`030000003oool0
oooo04l0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d
_`070?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0bP3oool2000002h0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1>0?ooo`002P3oool00`3o_g@007Bo0?ooo`02
0?ooo`030=nLB018W=l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3<
0?ooo`800000;@3oool200000140oooo0P00001>0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3?0?oo
o`<00000;03oool200000140oooo00<000000?ooo`3oool0B`3oool000030?ooo`2LB000000000@0
000000D004RL0?ooo`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cO
o`3oool01P3oool4000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0=<0oooo0P00000/0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0BP3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`03
09a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0eP3oool3000002X0oooo0P00000@0?ooo`80
0000BP3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0fP3oool2000002X0oooo0P00000@0?ooo`030000
003oool0oooo04L0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01@3OW4P0
00000018W02LB4P0W=oo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0g@3oool3000002T0oooo00<000000?oo
o`3oool03P3oool2000004L0oooo000;0?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3O
W4P0001809cOo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0>40oooo0P00000X0?ooo`800000403oool00`00
0000oooo0?ooo`140?ooo`00:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3T0?ooo`<000009`3oool2000000l0
oooo0P0000140?ooo`00:03oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`3X0?ooo`8000009`3oool2000000l0oooo0P0000120?ooo`00
:03oool3000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0>/0oooo0`00000V0?ooo`8000003`3oool00`000000oooo0?ooo`0o0?ooo`00:03o
ool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo
0?ooo`3_0?ooo`8000009P3oool2000000h0oooo0P00000o0?ooo`00:03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3b0?ooo`<000009@3oool2000000h0oooo00<000000?ooo`3oool0?03oool002P0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000`0oooo0P00003h0?ooo`8000009@3o
ool2000000d0oooo0P00000l0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000002`3oool00`000000oooo0?ooo`3j0?ooo`<00000903oool00`000000oooo0?oo
o`0<0?ooo`800000>P3oool002P0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool0oP3oool2000002<0oooo0P00000>0?ooo`030000003o
ool0oooo03L0oooo000X0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo0?l0oooo0P3oool300000280oooo0P00000=0?ooo`800000=`3o
ool002P0oooo0`0000050?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3o
ool60?ooo`<000008@3oool2000000d0oooo0P00000e0?ooo`00:03oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`00
000P0?ooo`8000003@3oool2000003<0oooo000X0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo1000000N0?ooo`8000003@3o
ool00`000000oooo0?ooo`0`0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`<000007@3oool2000000`0oooo0P00000`
0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool0?`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3o
ool01@2oM0000000000000000000M;oo0500oooo00<0okmd0000000000000`0000000`00M;l0oooo
0?ooo`1=0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000
001d_`050?ooo`050;md0000000000000000001d_ol00P3oool3000001`0oooo0P00000<0?ooo`80
00007P3oool00`3ookl0M000000000040000000307Boo`3oool0oooo00H0oooo000X0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`100?ooo`0609a8
M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo
0?ooo`3ogi`0B00007Boo`1B0?ooo`0309a8B02Lgol0oooo05<0oooo00<0W4Q809cOo`3oool01@3o
ool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`040?ooo`<0
00006`3oool3000000/0oooo0P00000M0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3o
ool01`3oool002P0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?ooo`030000
003oool0oooo0400oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?no
M000M;l0oooo0540oooo00<0W4Q809cOo`3oool0D`3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?no
M000M;l0oooo00H0oooo0`00000K0?ooo`8000002`3oool2000001`0oooo00<0okmd0000B02Lgol0
2`3oool002P0oooo0`0000020?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0@@3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0okmd001d_`3oool0D@3o
ool00`2LB4P0W=oo0?ooo`1C0?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool02@3o
ool4000001T0oooo0`00000:0?ooo`030000003oool0oooo01X0oooo00<0omnL04P00018W=l02P3o
ool002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003oool0
oooo0480oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8001d_ol0
oooo0540oooo00<0W4Q809cOo`3oool0D`3oool00`2LB4P0W=oo0?ooo`0A0?ooo`0309a8001d_ol0
oooo00d0oooo0`00000I0?ooo`<00000203oool2000001`0oooo00<0W4P004RLg`3oool0203oool0
02P0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3oool0@`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P00
00000`18W=l0oooo0?ooo`1A0?ooo`0309a8B02Lgol0oooo05<0oooo00<0W4Q809cOo`3oool0303o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo0100oooo0`00000I0?ooo`800000203o
ool2000001/0oooo00<0W4Qd0;ooo`3oool01`3oool002P0oooo00L000000?ooo`3oool0oooo0000
003oool0000000D0oooo00<000000?ooo`3oool0A03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nL
B018W=l0oooo00X0oooo00<0oono07@0M02oool0EP3oool00`2LB4P0W=oo0?ooo`1C0?ooo`0309a8
B02Lgol0oooo00`0oooo00<0oono07@0M02oool0603oool4000001L0oooo0`0000070?ooo`800000
503oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo00L0oooo000X0?ooo`040000003o
ool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`0609a8001d_ol0oooo0?oOW018
07@0_ooo2`3oool00`3ookl0M01d0;ooo`1C0?ooo`050=nLB000000004RL09a8B02Lgol0D@3oool0
1@3OW4P000000018W02LB4P0W=oo00d0oooo00<0oono07@0M02oool0703oool4000001H0oooo0`00
00060?ooo`8000004P3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0203oool002P0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`800000B@3oool01@3ookl0M0000000000004P0
W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`1@0?ooo`030=nLB00004P0
W=oo05<0oooo00<0gia80000B02Lgol03@3oool00`3ookl0M00000000002000000030000M02oool0
oooo01/0oooo1000000E0?ooo`8000001P3oool200000140oooo00D0okmd000000000000001809cO
o`090?ooo`00:03oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0o`3ooom0
0?ooo`D000004P3oool3000000D0oooo0P00000M0?ooo`00:03oool500000080oooo00<000000?oo
o`3oool0o`3ooom60?ooo`D00000403oool3000000@0oooo0P00000K0?ooo`00:03oool010000000
oooo0000000000020?ooo`030000003oool0oooo0?l0ooooC03oool6000000d0oooo0P0000040?oo
o`<00000603oool002P0oooo00H000000?ooo`00000000000?ooo`00003o0?oooeD0oooo1@00000:
0?ooo`<00000103oool2000001H0oooo000X0?ooo`050000003oool000000?ooo`000000o`3ooomK
0?ooo`D00000203oool3000000<0oooo0`00000C0?ooo`00:03oool010000000oooo0?ooo`00003o
0?ooof40oooo1@0000060?ooo`@000000P3oool200000140oooo000X0?ooo`030000003oool00000
0?l0ooooI`3oool6000000@0oooo1`00000>0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooofd0
oooo3@00000<0?ooo`007`3ooooo0000094000000@3oool002P0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000X0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`00:03oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo00P0oooo000X0?ooo`030000003oool0oooo0?l0
ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooohH0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.215489, -0.712729, \
0.00788458, 0.00426756}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?D1SPDF\)\)], "Input"],

Cell[BoxData[
    \("D1SPDF[x, {\[Alpha], \[Beta], \[Gamma], \[Delta]}, param] calculates \
the first derivative of the density of a stable S(\[Alpha], \[Beta], \
\[Gamma], \[Delta]; param) distribution at the value in x.  \[Beta], \[Gamma] \
and \[Delta] may be omitted with default values of {0, 1, 0}.  param may be \
omitted with a default value of 1."\)], "Print",
  CellTags->"Info3310572828-5809677"]
}, Open  ]],

Cell["\<\
This function is used for the SMode calculation above.  A first derivative \
formula is numerically integrated.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{D1SPDF[x, {1.3, \(-1\)}], SPDF[x, {1.3, \(-1\)}]}, {x, \(-5\), 
          5}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.257597 1.24306 [
[.11905 .2451 -6 -9 ]
[.11905 .2451 6 0 ]
[.30952 .2451 -6 -9 ]
[.30952 .2451 6 0 ]
[.69048 .2451 -3 -9 ]
[.69048 .2451 3 0 ]
[.88095 .2451 -3 -9 ]
[.88095 .2451 3 0 ]
[.4875 .00899 -24 -4.5 ]
[.4875 .00899 0 4.5 ]
[.4875 .13329 -24 -4.5 ]
[.4875 .13329 0 4.5 ]
[.4875 .3819 -18 -4.5 ]
[.4875 .3819 0 4.5 ]
[.4875 .50621 -18 -4.5 ]
[.4875 .50621 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .2576 m
.11905 .26385 L
s
[(-4)] .11905 .2451 0 1 Mshowa
.30952 .2576 m
.30952 .26385 L
s
[(-2)] .30952 .2451 0 1 Mshowa
.69048 .2576 m
.69048 .26385 L
s
[(2)] .69048 .2451 0 1 Mshowa
.88095 .2576 m
.88095 .26385 L
s
[(4)] .88095 .2451 0 1 Mshowa
.125 Mabswid
.16667 .2576 m
.16667 .26135 L
s
.21429 .2576 m
.21429 .26135 L
s
.2619 .2576 m
.2619 .26135 L
s
.35714 .2576 m
.35714 .26135 L
s
.40476 .2576 m
.40476 .26135 L
s
.45238 .2576 m
.45238 .26135 L
s
.54762 .2576 m
.54762 .26135 L
s
.59524 .2576 m
.59524 .26135 L
s
.64286 .2576 m
.64286 .26135 L
s
.7381 .2576 m
.7381 .26135 L
s
.78571 .2576 m
.78571 .26135 L
s
.83333 .2576 m
.83333 .26135 L
s
.07143 .2576 m
.07143 .26135 L
s
.02381 .2576 m
.02381 .26135 L
s
.92857 .2576 m
.92857 .26135 L
s
.97619 .2576 m
.97619 .26135 L
s
.25 Mabswid
0 .2576 m
1 .2576 L
s
.5 .00899 m
.50625 .00899 L
s
[(-0.2)] .4875 .00899 1 0 Mshowa
.5 .13329 m
.50625 .13329 L
s
[(-0.1)] .4875 .13329 1 0 Mshowa
.5 .3819 m
.50625 .3819 L
s
[(0.1)] .4875 .3819 1 0 Mshowa
.5 .50621 m
.50625 .50621 L
s
[(0.2)] .4875 .50621 1 0 Mshowa
.125 Mabswid
.5 .03385 m
.50375 .03385 L
s
.5 .05871 m
.50375 .05871 L
s
.5 .08357 m
.50375 .08357 L
s
.5 .10843 m
.50375 .10843 L
s
.5 .15815 m
.50375 .15815 L
s
.5 .18301 m
.50375 .18301 L
s
.5 .20787 m
.50375 .20787 L
s
.5 .23274 m
.50375 .23274 L
s
.5 .28246 m
.50375 .28246 L
s
.5 .30732 m
.50375 .30732 L
s
.5 .33218 m
.50375 .33218 L
s
.5 .35704 m
.50375 .35704 L
s
.5 .40676 m
.50375 .40676 L
s
.5 .43163 m
.50375 .43163 L
s
.5 .45649 m
.50375 .45649 L
s
.5 .48135 m
.50375 .48135 L
s
.5 .53107 m
.50375 .53107 L
s
.5 .55593 m
.50375 .55593 L
s
.5 .58079 m
.50375 .58079 L
s
.5 .60565 m
.50375 .60565 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26175 m
.06244 .26262 L
.10458 .26386 L
.14415 .26537 L
.18221 .26726 L
.22272 .26993 L
.26171 .27334 L
.30316 .27825 L
.34309 .28467 L
.3815 .29297 L
.42237 .30474 L
.46172 .31953 L
.49955 .337 L
.53984 .35772 L
.55838 .36688 L
.57861 .37535 L
.58392 .37714 L
.58957 .37878 L
.59446 .37995 L
.59975 .38091 L
.60257 .38129 L
.60381 .38142 L
.60517 .38154 L
.60646 .38163 L
.60766 .38169 L
.60892 .38173 L
.60963 .38175 L
.61028 .38175 L
.6115 .38174 L
.61263 .38172 L
.61387 .38166 L
.61519 .38158 L
.61633 .38148 L
.6174 .38137 L
.61984 .38104 L
.62227 .3806 L
.62453 .38009 L
.62967 .37856 L
.63467 .37652 L
.64002 .37371 L
.64971 .3668 L
.65852 .35831 L
.6685 .34593 L
.67771 .33177 L
.6985 .28979 L
.73791 .17877 L
.75771 .11755 L
.7758 .06791 L
.7851 .04724 L
.79524 .02989 L
Mistroke
.8008 .02301 L
.80351 .02039 L
.80596 .01843 L
.8085 .01684 L
.81089 .01574 L
.8122 .0153 L
.81341 .01501 L
.81404 .0149 L
.81474 .0148 L
.81546 .01474 L
.81613 .01472 L
.8174 .01475 L
.81804 .01481 L
.81875 .01491 L
.81999 .01517 L
.82116 .01552 L
.82253 .01603 L
.82378 .01662 L
.82661 .01833 L
.83145 .02245 L
.83653 .02836 L
.8454 .04218 L
.8551 .06152 L
.89571 .16114 L
.91448 .2 L
.92506 .21694 L
.93481 .22922 L
.94516 .23904 L
.95038 .24288 L
.95611 .24634 L
.96112 .2488 L
.96649 .25093 L
.97619 .25369 L
Mfstroke
.02381 .26987 m
.06244 .27173 L
.10458 .27421 L
.14415 .27711 L
.18221 .28058 L
.22272 .28523 L
.26171 .29095 L
.30316 .29881 L
.34309 .30875 L
.3815 .32126 L
.42237 .33884 L
.46172 .36125 L
.49955 .38923 L
.53984 .42718 L
.57861 .47173 L
.61984 .52469 L
.64043 .55073 L
.65954 .57252 L
.67803 .5895 L
.68335 .59335 L
.68837 .59648 L
.69321 .59899 L
.69774 .60085 L
.70017 .60164 L
.70239 .60224 L
.70486 .60275 L
.70621 .60297 L
.7075 .60312 L
.70874 .60323 L
.71007 .6033 L
.7112 .60332 L
.71244 .6033 L
.71314 .60327 L
.71377 .60323 L
.71448 .60317 L
.71521 .60309 L
.71646 .60293 L
.71782 .6027 L
.72024 .60214 L
.72244 .60149 L
.72738 .59946 L
.73196 .5969 L
.73629 .59385 L
.74601 .58477 L
.7563 .57179 L
.77475 .54034 L
.81264 .45208 L
.83372 .39895 L
.85298 .35483 L
.87313 .3173 L
Mistroke
.89181 .29201 L
.90102 .28282 L
.91083 .27519 L
.92171 .26895 L
.93157 .26495 L
.93646 .26345 L
.94162 .26215 L
.95085 .26042 L
.95599 .25973 L
.96079 .25922 L
.96605 .25879 L
.97168 .25844 L
.97619 .25823 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00^@3oool01@3o_g@00000000000000000M;oo00D0
oooo00<0_g@000000000M;l00`3oool00`3ookl0M000000000040000000307Boo`3oool0oooo00@0
oooo00<000000?ooo`3oool0eP3oool00;T0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?oo
o`030;md0000000007Bo00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`050?oo
o`030000003oool0oooo0=H0oooo002h0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3o
ool02`3oool00`3o_g@0001809cOo`090?ooo`030000003oool0oooo0=H0oooo002h0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool0303oool00`3ogi`0B00004RLg`080?ooo`@00000
e@3oool00:l0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo
00<0okmd001d_`3oool03P3oool00`2LB000B9cO0?ooo`060?ooo`030000003oool0oooo0=H0oooo
002h0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`2LB7@0_ooo0?oo
o`050?ooo`030000003oool0oooo0=H0oooo002h0?ooo`030?noM018W=l0oooo0080oooo00<0gia8
04RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo00D0oooo00<00000
0?ooo`3oool0P@3oool6000004l0oooo002i0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3o
ool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol01P3oool00`000000oooo0?ooo`1o0?ooo`80
00001P3oool2000004d0oooo002i0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@0
00000000000004P0W=oo00L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo04X0oooo003G0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`190?ooo`00e`3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool00=L0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04P0oooo003G0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`170?ooo`00e`3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0AP3oool00=L0
oooo0`00001j0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A@3oool00=L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04D0oooo
003G0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`140?ooo`00e`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0@`3oool00=L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04<0oooo003G0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`120?ooo`00e`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00=L0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0440oooo003G0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`110?ooo`00e`3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0@03oool00=L0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0400
oooo003G0?ooo`<00000L`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03l0oooo
003G0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0o0?ooo`00e`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0?`3oool00=L0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo03h0oooo003G0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0n0?ooo`00e`3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0?@3oool00=L0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03d0oooo003G0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0m0?ooo`00e`3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?03oool00=L0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03`0
oooo003G0?ooo`<00000L03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03/0oooo
003G0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0k0?ooo`00e`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0>`3oool00=L0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo03X0oooo003G0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0j0?ooo`00e`3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0>@3oool00=L0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03T0oooo003G0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0i0?ooo`00e`3oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0>03oool00=L0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03P0
oooo003G0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0g0?ooo`00e`3oool3000006`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0g0?ooo`00e`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0=`3oool00=L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo03H0oooo003G0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0f0?ooo`00e`3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0=@3oool00=L0oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03D0oooo003G0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0d0?ooo`00^@3oool01@3o
_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@0000000000003
00000003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo03@0oooo002i0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103o
ool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03@0oooo002h0?ooo`030?noM000M;l0
oooo0080oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`00^03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool40000
06P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`00[`3oool00`2LB000
000000000003000000050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?oo
o`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0380oooo002h0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool03@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0b0?ooo`00^03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nL
B018W=l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0<P3oool00;T0oooo00H0W4P007Boo`3oool0omnL
04P0M02oool;0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<@3oool00;T0oooo00D0oono07@00000
0000001809cOo`0>0?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0340oooo003G0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0`0?ooo`00e`3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0<03oool00=L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0300oooo003G
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0_
0?ooo`00e`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0;`3oool00=L0oooo0`00001U0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0;P3oool00=L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo02h0oooo003G0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0^0?ooo`00e`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0;@3oool00=L0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo02d0oooo003G0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0/0?ooo`00e`3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0;03oool00=L0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02/0oooo003G
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0[
0?ooo`00e`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0:P3oool00=L0oooo0`00001R0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0:P3oool00=L0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo02T0oooo003G0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0Y0?ooo`00e`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0:03oool00=L0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo003G0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0W0?ooo`00e`3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool09`3oool00=L0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02H0oooo003G
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0V
0?ooo`00e`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool09@3oool00=L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo02D0oooo003G0?ooo`<00000GP3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo02@0oooo003G0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0S0?ooo`00e`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool08P3oool00=L0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0280oooo000h0?ooo`050?oOW018000000000000
001d_ol0B@3oool00`3ookl0M000000000040000000307Boo`3oool0oooo04L0oooo00<000000?oo
o`3oool0BP3oool00`3ookl0M000000000040000000307Boo`3oool0oooo00P0oooo00<000000?oo
o`3oool0?`3oool01@3ogi`0B000000000000000M;oo00l0oooo00<000000?ooo`3oool08@3oool0
03X0oooo00<0_g@007Boo`3oool0BP3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo
04P0oooo00<000000?ooo`3oool0B`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo
00T0oooo00<000000?ooo`3oool0@@3oool00`2oM000M;oo0?ooo`0@0?ooo`030000003oool0oooo
0200oooo000j0?ooo`030;md001d_ol0oooo04/0oooo00<0okmd0000B02Lgol0C03oool00`000000
oooo0?ooo`1<0?ooo`030?noM00004P0W=oo00`0oooo00<000000?ooo`3oool0@P3oool00`2oM000
M;oo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo000f0?ooo`030=nLB0000000000000<00000
00<0M;oo0?ooo`3oool0BP3oool00`3ogi`0B00004RLg`1;0?ooo`030000003oool0oooo04d0oooo
00<0omnL04P00018W=l02`3oool00`000000oooo0?ooo`0n0?ooo`030=nLB0000000000000<00000
00<0M;oo0?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`00;@3oool00`2LB00000000000
0003000000090018W03oool0oooo0?noM00007@0_ooo0?ooo`2oM000M;oo0480oooo00<0W4P00000
000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0oooo04T0oooo00<000000?oo
o`3oool0C`3oool00`2LB000B9cO0?ooo`090?ooo`030000003oool0oooo03h0oooo00H0okmd0000
M02oool0oooo0;md001d_olC0?ooo`030000003oool0oooo01h0oooo000g0?ooo`050=nLB000M;l0
oooo0;md001d_ol0D03oool00`2LB7@0_ooo0?ooo`180?ooo`030000003oool0oooo0500oooo00<0
W4Qd0;ooo`3oool01`3oool00`000000oooo0?ooo`100?ooo`050=nLB000M;l0oooo0;md001d_ol0
503oool00`000000oooo0?ooo`0M0?ooo`00>03oool0102LB000B9cO0;md001d_om;0?ooo`030=nL
B01d_ol0oooo0080oooo00<0_g@007Boo`3oool0B03oool00`000000oooo0?ooo`1;0?ooo`030=nL
B01d_ol0oooo0080oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`110?ooo`0409a8
0018W=l0_g@007BooaD0oooo00<000000?ooo`3oool0703oool003P0oooo00@0omnL04P0B018B000
M;ooB`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0B@3oool3000004/0oooo00L0okmd
0000M02oool0oooo0?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0@@3oool0103ogi`0B018
04Q8001d_olF0?ooo`030000003oool0oooo01/0oooo000i0?ooo`030?noM0000000M;oo04`0oooo
00D0okmd000000000000001809cOo`1:0?ooo`030000003oool0oooo04`0oooo00D0okmd00000000
0000001809cOo`080?ooo`030000003oool0oooo04<0oooo00<0okmd0000001d_ol05`3oool00`00
0000oooo0?ooo`0J0?ooo`00e`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool06@3oool00=L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`1O0?ooo`8000006@3oool00=L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo01H0oooo003G0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0H`3oool2000001H0oooo003G0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0I@3oool2000001@0oooo003G0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0J03oool400000100oooo003G0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
K03oool3000000d0oooo003G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0O@3o
ool00080ooooo`00002/000000<0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`060?ooo`d000003@3oool000`0oooo6P00000?0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00<0oooo0`00000<0?ooo`030000003oool0oooo00/0oooo000V0?ooob800000
?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0180oooo1@00000M0?ooo`00B03o
oolA000007h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1J0?ooo`8000008P3o
ool000`0oooo2@0000140?ooo`d00000L@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05T0oooo0P00000T0?ooo`005@3ooolA00000400oooo2000001Y0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0T0?ooo`009P3ooolB000003H0
oooo2@00001P0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0EP3oool2000002L0
oooo000h0?ooo``00000<`3oool8000005P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo02L0oooo00140?ooo`P00000<`3oool700000540oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02P0oooo001<
0?ooo`T00000<@3oool6000004/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1D
0?ooo`800000:`3oool005D0oooo2000000_0?ooo`H00000A@3oool300000580oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0[0?ooo`00G@3oool9000002`0oooo1@0000100?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0/0?ooo`00
IP3oool8000002T0oooo1P00000j0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0]0?ooo`00KP3oool7000002P0oooo1P00000d0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0^0?ooo`00M@3oool4
000002X0oooo1000000`0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0_0?ooo`00N@3oool4000002X0oooo1000000/0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0`0?ooo`00O@3oool4000002X0
oooo0`00000Y0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0`0?ooo`00P@3oool5000002P0oooo0`00000V0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0a0?ooo`00QP3oool4000002L0oooo1000
000R0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0b0?ooo`00RP3oool4000002L0oooo0`00000O0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0c0?ooo`00SP3oool4000002H0oooo0`00000L0?oo
o`<00000CP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03<0oooo002B0?ooo`@0
00009@3oool3000001T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo03@0oooo002F0?ooo`@00000903oool2000001L0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03D0oooo002J0?ooo`<000008`3o
ool3000001@0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo03H0oooo002M0?ooo`<000008`3oool300000140oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03H0oooo002P0?ooo`@000008P3oool20000
00l0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
03L0oooo002T0?ooo`<000008@3oool2000000d0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo03P0oooo002W0?ooo`8000008@3oool2000000/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03P0oooo
002Y0?ooo`8000008@3oool2000000T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo03T0oooo002[0?ooo`8000008@3oool2000000L0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo002]0?oo
o`8000008@3oool2000000D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo03X0oooo002_0?ooo`8000008@3oool2000000<0oooo0`0000190?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0>P3oool00;40oooo0P00000Q0?ooo`800000
00<0oooo0000003oool0B@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03/0oooo
002c0?ooo`8000008@3oool2000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0l0?ooo`00]@3oool200000200oooo0`0000170?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0?03oool00;L0oooo0P00000N0?ooo`030000003oool0oooo00800000A03oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo03d0oooo002i0?ooo`800000703oool00`000000
oooo0?ooo`020?ooo`800000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03d0
oooo002k0?ooo`8000006P3oool00`000000oooo0?ooo`040?ooo`800000?`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo03h0oooo002m0?ooo`800000603oool00`000000oooo0?oo
o`060?ooo`800000?03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03h0oooo002o
0?ooo`8000005P3oool00`000000oooo0?ooo`080?ooo`800000>@3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo03l0oooo00310?ooo`800000503oool00`000000oooo0?ooo`0:0?oo
o`800000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03l0oooo00330?ooo`80
00004P3oool3000000`0oooo0P00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0@03oool00<D0oooo0P00000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0400oooo00370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03`3oool2000002h0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`110?ooo`00b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0140oooo0P00000[0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0@@3oool0
0<T0oooo0P00000<0?ooo`030000003oool0oooo01<0oooo0P00000Y0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0@P3oool00</0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0E0?ooo`<000009@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0480
oooo003<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool200000280oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`130?ooo`00c@3oool2000000P0oooo00<0
00000?ooo`3oool06P3oool3000001d0oooo0P00001D0?ooo`030000003oool0oooo04<0oooo002i
0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM000
0000000000<0000000<007Bo0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`<00000603o
ool2000005D0oooo00<000000?ooo`3oool0A03oool00;T0oooo00H0W4Qd0;ooo`3oool0oono07@0
M02oool40?ooo`030;md0000000007Bo00L0oooo00@0W4Q809cOo`3oool000001P3oool00`000000
oooo0?ooo`0P0?ooo`800000503oool2000005L0oooo00<000000?ooo`3oool0A03oool00;P0oooo
00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0409a8B02Lgol0oooo0?ooo`80
0000103oool00`000000oooo0?ooo`0R0?ooo`@000002`3oool5000005T0oooo00<000000?ooo`3o
ool0A03oool00;P0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00<0oooo00@000000?ooo`3oool0oooo1000000U0?ooo`/00000G@3oool00`000000
oooo0?ooo`150?ooo`00^03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool0103oool010000000oooo0?ooo`00002@0?ooo`030000003oool0oooo04D0
oooo002h0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo
0?ooo`050?ooo`<00000S`3oool00`000000oooo0?ooo`160?ooo`00^03oool00`3o_g@0B9cO0?oo
o`020?ooo`030=nLB018W=l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo04H0oooo002i0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
2`3oool01@3OW4P000000018W02LB4P0W=oo00P0oooo0P00002=0?ooo`030000003oool0oooo04L0
oooo002i0?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cOo`080?ooo`03
0000003oool0000008`0oooo00<000000?ooo`3oool0A`3oool00=L0oooo00@000000?ooo`3oool0
0000RP3oool00`000000oooo0?ooo`180?ooo`00e`3oool01@000000oooo0?ooo`3oool0000008T0
oooo00<000000?ooo`3oool0B03oool00=L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo04P0oooo003G0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`190?ooo`00e`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0B@3oool00=L0oooo0`0000050?oo
o`800000PP3oool00`000000oooo0?ooo`1:0?ooo`00e`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0BP3oool00=L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo04X0oooo003G0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`1;0?ooo`00e`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0B`3oool0
0=L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
04`0oooo003G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`1<0?ooo`00e`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0C03oool00=L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo04d0oooo003G0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`1=0?ooo`00e`3oool300000100oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`1=0?ooo`00e`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0CP3oool00=L0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo04h0oooo003G0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1?0?ooo`00e`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0C`3oool0
0=L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
04l0oooo003G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`1@0?ooo`00e`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool0D03oool00=L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo0540oooo003G0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`1A0?ooo`00e`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool0D@3oool00=L0oooo0`00000I0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0DP3oool00=L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0580oooo003G0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1C0?ooo`00e`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0D`3oool0
0=L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
05@0oooo003G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`1D0?ooo`00e`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0E03oool00=L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo05D0oooo003G0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`1E0?ooo`00e`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool0EP3oool00=L0oooo0`00000Q0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0EP3oool00=L0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo05L0oooo003G0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1G0?ooo`00e`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0E`3oool0
0=L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
05P0oooo003G0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`1H0?ooo`00e`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0F@3oool00;T0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`040?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1I0?ooo`00^@3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool00`2oM000
001d0;ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo05X0oooo002h0?ooo`030?noM000M;l0oooo0080oooo
00<0gia804RLg`3oool02`3oool00`3o_g@0001809cOo`090?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1J0?ooo`00^03oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P00018W=l0203oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0F`3oool00;P0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00H0oooo1000000Y
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0F`3oool00;P0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8M02oool0oooo00D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo05/0oooo002h0?ooo`03
0?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`03
0;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo05`0oooo002i0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o
_g@0001d0;ooo`3oool0okmd0000B02Lgol01P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0G03oool00;T0oooo00D0oono07@000000000001809cO
o`0=0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0G@3oool00=L0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo05d0oooo003G0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1N0?ooo`00e`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0GP3oool00=L0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo05h0
oooo003G0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`1O0?ooo`00e`3oool300000380oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1O0?ooo`00e`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0H03oool00=L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0600oooo003G0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`1Q0?ooo`00e`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0H@3oool00=L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0680oooo003G0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1R0?ooo`00e`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0H`3oool00=L0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo06<0
oooo003G0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`1T0?ooo`00e`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0I03oool00=L0oooo0`00000k0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0I@3oool00=L0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo06H0oooo003G0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`1V0?ooo`00e`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0I`3oool00=L0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06L0oooo003G0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1X0?ooo`00e`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0J03oool00=L0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06T0
oooo003G0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`1Z0?ooo`00e`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0J`3oool00=L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo06/0oooo003G0?ooo`<00000A@3oool200000200oooo00<000000?oo
o`3oool0K03oool00=L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo06d0oooo003G0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1^0?ooo`00e`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0K`3oool00=L0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0700oooo003G0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1a0?ooo`00e`3oool00`000000
oooo0?ooo`1<0?ooo`8000004`3oool00`000000oooo0?ooo`1b0?ooo`00e`3oool00`000000oooo
0?ooo`1>0?ooo`800000403oool00`000000oooo0?ooo`1c0?ooo`00e`3oool00`000000oooo0?oo
o`1@0?ooo`8000002P3oool4000007H0oooo003G0?ooo`030000003oool0oooo0580oooo2P00001j
0?ooo`00e`3oool300000=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000
003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0
oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.31836, -0.212761, \
0.0370187, 0.00283622}}]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
WindowSize->{1135, 611},
WindowMargins->{{111, Automatic}, {Automatic, 79}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3310572771-1617216"->{
    Cell[1922, 60, 481, 7, 110, "Print",
      CellTags->"Info3310572771-1617216"]},
  "Info3310572774-9592314"->{
    Cell[3061, 94, 450, 7, 110, "Print",
      CellTags->"Info3310572774-9592314"]},
  "Info3310572775-6040401"->{
    Cell[4039, 125, 195, 3, 60, "Print",
      CellTags->"Info3310572775-6040401"]},
  "Info3310572775-9610662"->{
    Cell[4237, 130, 195, 3, 60, "Print",
      CellTags->"Info3310572775-9610662"]},
  "Info3310572801-1744629"->{
    Cell[51705, 1185, 371, 6, 85, "Print",
      CellTags->"Info3310572801-1744629"]},
  "Info3310572828-5809677"->{
    Cell[99748, 2144, 407, 6, 85, "Print",
      CellTags->"Info3310572828-5809677"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3310572771-1617216", 135760, 2909},
  {"Info3310572774-9592314", 135875, 2912},
  {"Info3310572775-6040401", 135990, 2915},
  {"Info3310572775-9610662", 136105, 2918},
  {"Info3310572801-1744629", 136220, 2921},
  {"Info3310572828-5809677", 136337, 2924}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 88, 2, 53, "Text"],

Cell[CellGroupData[{
Cell[1867, 57, 52, 1, 42, "Input"],
Cell[1922, 60, 481, 7, 110, "Print",
  CellTags->"Info3310572771-1617216"]
}, Open  ]],
Cell[2418, 70, 173, 3, 73, "Text"],

Cell[CellGroupData[{
Cell[2616, 77, 158, 2, 68, "Input"],
Cell[2777, 81, 91, 1, 41, "Output"],
Cell[2871, 84, 98, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3006, 91, 52, 1, 42, "Input"],
Cell[3061, 94, 450, 7, 110, "Print",
  CellTags->"Info3310572774-9592314"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3548, 106, 158, 2, 68, "Input"],
Cell[3709, 110, 98, 2, 41, "Output"],
Cell[3810, 114, 98, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3945, 121, 91, 2, 68, "Input"],
Cell[4039, 125, 195, 3, 60, "Print",
  CellTags->"Info3310572775-6040401"],
Cell[4237, 130, 195, 3, 60, "Print",
  CellTags->"Info3310572775-9610662"]
}, Open  ]],
Cell[4447, 136, 185, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[4657, 144, 99, 2, 68, "Input"],
Cell[4759, 148, 74, 1, 41, "Output"],
Cell[4836, 151, 74, 1, 41, "Output"]
}, Open  ]],
Cell[4925, 155, 84, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[5034, 161, 286, 5, 94, "Input"],
Cell[5323, 168, 40794, 862, 279, 6283, 431, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[46132, 1033, 458, 7, 125, "Text"],
Cell[46593, 1042, 42, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[46660, 1047, 173, 3, 68, "Input"],
Cell[46836, 1052, 440, 6, 53, "Message"],
Cell[47279, 1060, 439, 6, 53, "Message"],
Cell[47721, 1068, 439, 6, 53, "Message"],
Cell[48163, 1076, 334, 5, 32, "Message"],
Cell[48500, 1083, 879, 26, 185, "Output"]
}, Open  ]],
Cell[49394, 1112, 116, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[49535, 1119, 205, 4, 68, "Input"],
Cell[49743, 1125, 1026, 26, 185, "Output"]
}, Open  ]],
Cell[50784, 1154, 34, 0, 47, "Text"],
Cell[50821, 1156, 43, 1, 42, "Input"],
Cell[50867, 1159, 289, 5, 73, "Text"],

Cell[CellGroupData[{
Cell[51181, 1168, 42, 1, 42, "Input"],
Cell[51226, 1171, 396, 6, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51659, 1182, 43, 1, 42, "Input"],
Cell[51705, 1185, 371, 6, 85, "Print",
  CellTags->"Info3310572801-1744629"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52113, 1196, 146, 2, 42, "Input"],
Cell[52262, 1200, 56, 1, 41, "Output"]
}, Open  ]],
Cell[52333, 1204, 357, 6, 99, "Text"],

Cell[CellGroupData[{
Cell[52715, 1214, 583, 11, 198, "Input"],
Cell[53301, 1227, 46363, 909, 279, 5856, 404, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99701, 2141, 44, 1, 42, "Input"],
Cell[99748, 2144, 407, 6, 85, "Print",
  CellTags->"Info3310572828-5809677"]
}, Open  ]],
Cell[100170, 2153, 135, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[100330, 2160, 121, 2, 42, "Input"],
Cell[100454, 2164, 34659, 726, 279, 5041, 356, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

